// AlgebraicChemical.cpp: implementation of the CAlgebraicChemical class.
//
//////////////////////////////////////////////////////////////////////

#include "AlgebraicChemical.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

CAlgebraicChemical::CAlgebraicChemical(int chemicalNumber, std::string name, std::vector<Chemical *> chemRefVector)
{
	this->chemicalNumber = chemicalNumber;
	this->name = name;
	// load up reference vector
	for(int i = 0; i < chemRefVector.size(); i++)
	{
		m_vpChemRefVector.push_back(chemRefVector[i]);
	}
	this->SetTeXName();
}

CAlgebraicChemical::CAlgebraicChemical(int chemicalNumber, std::string name, std::vector<Chemical *> chemRefVector, std::vector<RateConstant *> rateRefVector)
{
	this->chemicalNumber = chemicalNumber;
	this->name = name;
	// load up reference vectors
	for(int i = 0; i < chemRefVector.size(); i++)
	{
		m_vpChemRefVector.push_back(chemRefVector[i]);
	}
	for(i = 0; i < rateRefVector.size(); i++)
	{
		m_vpRateRefVector.push_back(rateRefVector[i]);
	}
	this->SetTeXName();
}


CAlgebraicChemical::~CAlgebraicChemical()
{
	// don't delete the ref vectors here - pointers to chemicals 
	// get deleted elsewhere
}

void CAlgebraicChemical::SetAll()
{
	this->SetAmount(0);
	this->SetInitialAmount(0);
	this->SetErrorInInitialAmount(0);
}

void CAlgebraicChemical::SetAmount(double amount)
{
	this->ComputeAmount();
}

void CAlgebraicChemical::SetInitialAmount(double initialAmount)
{
	this->ComputeInitialAmount();
}

void CAlgebraicChemical::SetErrorInInitialAmount(double errorInInitialAmount)
{
	this->ComputeErrorInInitialAmount();
}

void CAlgebraicChemical::IncrementAmount(double change)
{
	// do nothing 
}

void CAlgebraicChemical::Reset()
{
	// should be relatively safe - if a global ChemicalReset() is 
	// called, the reference chemicals will have been updated first
	// since they must be created first and will thus occupy a lower
	// position in the list
	this->ComputeInitialAmount();
	amount = initialAmount;
}
