// AlgebraicChemical.h: interface for the CAlgebraicChemical class.
//		These chemicals are not dynamical variables, they are
//    bookkeeping chemicals (algebraic functions of other chemicals
//    in the network).  Hence the Set functions for amount and
//    such are basically just dummies; they call the ComputeAmount()
//    function which is overloaded in derived classes with the correct
//    algebraic expression.  Set has the same format so that
//    compatibility is maintained with the base class.  This class
//	  can also accommodate "chemicals" which are a function of rate
//	  constants and other chemicals.
//////////////////////////////////////////////////////////////////////

#if !defined(AFX_ALGEBRAICCHEMICAL_H__1E46E4E9_5F3B_4123_8B9C_131B88820DE3__INCLUDED_)
#define AFX_ALGEBRAICCHEMICAL_H__1E46E4E9_5F3B_4123_8B9C_131B88820DE3__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#include "..\SRC\Chemical.h"


class CAlgebraicChemical : public Chemical  
{
public:
	CAlgebraicChemical(int chemicalNumber, std::string name, std::vector<Chemical *> chemRefVector);
	CAlgebraicChemical(int chemicalNumber, std::string name, std::vector<Chemical *> chemRefVector, std::vector<RateConstant *> rateRefVector);
	virtual ~CAlgebraicChemical();
	virtual void SetAmount(double amount);
	virtual void SetInitialAmount(double initialAmount);
	virtual void SetErrorInInitialAmount(double errorInInitialAmount);
	virtual void IncrementAmount(double change);
	virtual void Reset();
	void SetAll();
protected:
	// must be overloaded in derived classes - depend on the arithmetic expression	
	virtual void ComputeAmount() = 0;
	virtual void ComputeInitialAmount() = 0;
	virtual void ComputeErrorInInitialAmount() = 0;
	// chemicals which the AlgebraicChemical uses to compute its own
	// amount
	std::vector<Chemical *> m_vpChemRefVector;
	// ditto for rates
	std::vector<RateConstant *> m_vpRateRefVector;
};

#endif // !defined(AFX_ALGEBRAICCHEMICAL_H__1E46E4E9_5F3B_4123_8B9C_131B88820DE3__INCLUDED_)
