// CellAverageObserver.cpp: implementation of the CellAverageObserver class.
//
//////////////////////////////////////////////////////////////////////

#include "CellAverageObserver.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

CellAverageObserver::CellAverageObserver(int numberOfChemicals, int numberOfTimeSteps, int numberOfCells)
{
	this->numberOfChemicals = numberOfChemicals;
	this->numberOfTimeSteps = numberOfTimeSteps;
	this->numberOfCells = numberOfCells;

	averageConcentration = new double *[numberOfChemicals];
	averageConcentration[0] = new double[numberOfChemicals*numberOfTimeSteps];

	for (int chem = 1; chem < numberOfChemicals; chem++)
	{
		averageConcentration[chem] = &(averageConcentration[0][chem*numberOfTimeSteps]);
	}

	ZeroConcentrations();
}

CellAverageObserver::~CellAverageObserver()
{
	delete [] averageConcentration[0];
	delete [] averageConcentration;
}

void CellAverageObserver::Update(Subject *theChangedSubject)
{
	// cast dynamically for safety
	// CReactionMover *reactionMover = dynamic_cast<CReactionMover *>(theChangedSubject);

	// static cast may be dangerous
	CReactionMover *reactionMover = (CReactionMover *)theChangedSubject;
	ReactionNetwork *reactionNetwork = reactionMover->GetReactionNetwork();

	int count = reactionMover->GetTimeCount();
	//cout << "count = " << count << endl;
	assert(count <= numberOfTimeSteps);
 
	for (int chem = 0; chem < reactionNetwork->GetNumberOfChemicals(); chem++)
	{	
		averageConcentration[chem][count-1] += (reactionNetwork->GetChemical(chem)->GetAmount())/numberOfCells;			
	}
				
}


void CellAverageObserver::ZeroConcentrations()
{
	for (int chem = 0; chem < numberOfChemicals; chem++)
	{
		for (int count = 0; count < numberOfTimeSteps; count++)
		{
			averageConcentration[chem][count] = 0;
		}
	}
}
