// ChemicalTimeSeriesData.h: interface for the ChemicalTimeSeriesData class.
//
//////////////////////////////////////////////////////////////////////

#if !defined(AFX_CHEMICALTIMESERIESDATA_H__DF38E9BB_9342_4B5F_8516_BBAECCE50783__INCLUDED_)
#define AFX_CHEMICALTIMESERIESDATA_H__DF38E9BB_9342_4B5F_8516_BBAECCE50783__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#include "DataPoint.h"
#include "TimeVectorPoint.h"
#include "ReactionNetwork.h"
#include "typedefs.h"
#include <string>
#include <algorithm>
#include <fstream.h>
#include <sstream>
#include <strstrea.h>
#include <assert.h>
#include <stdexcept>


class ChemicalTimeSeriesData : public DataPoint  
{
public:
	ChemicalTimeSeriesData(ReactionNetwork *reactionNetwork, std::string fileName);
	ChemicalTimeSeriesData(ReactionNetwork *reactionNetwork);
	virtual ~ChemicalTimeSeriesData();
	std::vector<DataPoint *> GetTimeSeries(int chemIndex);
	std::vector<TimeVectorPoint *> GetTimeVector() {return timeVector;}
	void AttachNewTimeSeries(ReactionNetwork *reactionNetwork, std::string fileName);
	void SortChemTimeSeriesData();
	void SortTimeVector();
	void TimeVectorSynchronize();
	// searches the time vector and returns the next time stored in 
	// the time vector (indicating there is data at that time) >= the
	// time given to the function
	double GetNextDataTime(double time);
	double GetLatestDataTime();
	int GetNDataPoints();
	int GetNTimeSeries();
	int GetNChemicals();
private:
	int nChem;
	int nTimeSeries;
	// Units will be used later for different experimental data formats 
	// (fold over basal, % total, etc.)
	std::string m_sUnits;
	std::vector<TimeVectorPoint *> timeVector;
	vvpDataPoint chemData;
};

#endif // !defined(AFX_CHEMICALTIMESERIESDATA_H__DF38E9BB_9342_4B5F_8516_BBAECCE50783__INCLUDED_)
