// ConcentrationObserver.cpp: implementation of the ConcentrationObserver class.
//
//////////////////////////////////////////////////////////////////////

#include "ConcentrationObserver.h"
#include "ReactionMover.h"
#include "ReactionNetwork.h"
#include <assert.h>

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////


ConcentrationObserver::ConcentrationObserver(int numberOfChemicals, int numberOfTimeSteps)
{
	this->numberOfChemicals = numberOfChemicals;
	this->numberOfTimeSteps = numberOfTimeSteps;

	summedConcentration = new double *[numberOfChemicals];
	summedConcentration[0] = new double[numberOfChemicals*numberOfTimeSteps];

	for (int chem = 1; chem < numberOfChemicals; chem++)
	{
		summedConcentration[chem] = &(summedConcentration[0][chem*numberOfTimeSteps]);
	}

	ZeroConcentrations();
}

ConcentrationObserver::~ConcentrationObserver()
{
	delete [] summedConcentration[0];
	delete [] summedConcentration;
}

void ConcentrationObserver::Update(Subject *theChangedSubject)
{
	// cast dynamically for safety
	// CReactionMover *reactionMover = dynamic_cast<CReactionMover *>(theChangedSubject);

	// static cast may be dangerous
	CReactionMover *reactionMover = (CReactionMover *)theChangedSubject;
	ReactionNetwork *reactionNetwork = reactionMover->GetReactionNetwork();

	int count = reactionMover->GetTimeCount();
	assert(count <= numberOfTimeSteps);
 
	for (int chem = 0; chem < reactionNetwork->GetNumberOfChemicals(); chem++)
	{	
		summedConcentration[chem][count-1] = summedConcentration[chem][count-1]  + reactionNetwork->GetChemical(chem)->GetAmount();			
	} 
			
}

void ConcentrationObserver::ZeroConcentrations()
{
	for (int chem = 0; chem< numberOfChemicals; chem++)
	{
		for (int count=0; count < numberOfTimeSteps; count++)
		{
			summedConcentration[chem][count] = 0;
		}
	}
}
