// Experiment.cpp: implementation of the Experiment class.
//
//////////////////////////////////////////////////////////////////////

#include "Experiment.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

Experiment::Experiment(ReactionNetwork *reactionNetwork, std::string experimentName)
{
	_reactionNetwork = reactionNetwork;
	_experimentName = experimentName;

	_data = new ChemicalTimeSeriesData(_reactionNetwork);
	_forcingData = new CForcingData();
}

Experiment::~Experiment()
{
	if(_data != 0) delete [] _data;
	if(_forcingData != 0) delete _forcingData;
}

void Experiment::AddDataFileToList(std::string fileName)
{
	_fileList.push_back(fileName);
	cout << "File '" << fileName.c_str() << "' added to experiment " << _experimentName.c_str() << endl;
}

void Experiment::AddForcingFileToList(std::string fileName)
{
	_forcingFileList.push_back(fileName);
	cout << "File '" << fileName.c_str() << "' added to forcing list of experiment " << _experimentName.c_str() << endl;
}

void Experiment::ReadData()
{
	// read in the experimental data
	// does not check for multiple reads, which should be done either
	// here or in the AttachNewTimeSeries() function - the only guard
	// against this now is popping the files off the list as they are 
	// read so they have to be explicitly re-added.  Something safer 
	// would be better.  (KSB, 10/12/00)
	for(int i = 0; i < _fileList.size(); i++)
	{
		_data->AttachNewTimeSeries(_reactionNetwork,_fileList[i]);
		cout << "Data read from file '" << _fileList[i].c_str() << "'" << endl;
	}
	_fileList.erase(_fileList.begin(),_fileList.end());
}

void Experiment::ReadForcingData()
{
	// read in the forcing data
	// comments are ditto as in ReadData();
	for(int i = 0; i < _forcingFileList.size(); i++)
	{
		_forcingData->AttachNewForcingData(_reactionNetwork,_forcingFileList[i]);
		cout << "Forcing data read from file '" << _forcingFileList[i].c_str() << "'" << endl;
	}
	_forcingFileList.erase(_forcingFileList.begin(),_forcingFileList.end());
}