// FirstOrderDestructionReaction.cpp: implementation of the CFirstOrderDestructionReaction class.
//
//////////////////////////////////////////////////////////////////////

#include "FirstOrderDestructionReaction.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

CFirstOrderDestructionReaction::CFirstOrderDestructionReaction(Chemical *DestroyingEnzyme, Chemical *Substrate, RateConstant *k_fod, std::string reactionName)
:Reaction(reactionName)
{
	// stoichiometry
	this->DestroyingEnzyme = chemicals.size();
	chemicals.push_back(DestroyingEnzyme);
	numberOfEachChemicalChangedByReaction.push_back(0);

	this->Substrate = chemicals.size();
	chemicals.push_back(Substrate);
	numberOfEachChemicalChangedByReaction.push_back(-1);

	// rates
	this->k_fod = rateConstants.size();
	rateConstants.push_back(k_fod);

	// put enough dummy chemicalJacobian elements on the vector 
	// - they are recomputed every time you ask for the chemicalJacobian
	chemicalJacobian.push_back(new JElement(-1,-1));
	chemicalJacobian.push_back(new JElement(-1,-1));

	this->SetTeXForm();

}

CFirstOrderDestructionReaction::~CFirstOrderDestructionReaction()
{

}

double CFirstOrderDestructionReaction::GetRate() const
{
	double kfod = rateConstants[k_fod]->GetValue();
	double de = chemicals[DestroyingEnzyme]->GetAmount();
	double su = chemicals[Substrate]->GetAmount();
	return kfod*de*su; 
}

void CFirstOrderDestructionReaction::SetTeXForm()
{
	strstream stream;
	// TeX form of the reaction
	stream << rateConstants[k_fod]->GetTeXName().c_str();
	stream << "\\left [" << chemicals[DestroyingEnzyme]->GetTeXName().c_str();
	stream << "\\right ]";
	stream << " \\left [" << chemicals[Substrate]->GetTeXName().c_str();
	stream << "\\right ]";
	stream << ends;
	// set the TeX string equal to what's in the stream
	m_sTeXForm = stream.str();
	// free up the string
	stream.rdbuf()->freeze(0);
}

std::vector<Reaction::JElement *> *CFirstOrderDestructionReaction::GetChemicalJacobian()
{
	chemicalJacobian[0]->SetWithRespectTo(chemicals[DestroyingEnzyme]->GetChemicalNumber());
	chemicalJacobian[0]->SetJValue(rateConstants[k_fod]->GetValue()*chemicals[Substrate]->GetAmount());

	chemicalJacobian[1]->SetWithRespectTo(chemicals[Substrate]->GetChemicalNumber());
	chemicalJacobian[1]->SetJValue(rateConstants[k_fod]->GetValue()*chemicals[DestroyingEnzyme]->GetAmount());
	
	return &chemicalJacobian;
}

