// GenerationReaction.cpp: implementation of the GenerationReaction class.
//
//////////////////////////////////////////////////////////////////////

#include "GenerationReaction.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

GenerationReaction::GenerationReaction(Chemical *Generator, Chemical *Product, RateConstant *k_g, std::string reactionName)
:Reaction(reactionName)
{
	// stoichiometry
	this->Generator = chemicals.size();
	chemicals.push_back(Generator);
	numberOfEachChemicalChangedByReaction.push_back(0);

	this->Product = chemicals.size();
	chemicals.push_back(Product);
	numberOfEachChemicalChangedByReaction.push_back(+1);

	// rates
	this->k_g = rateConstants.size();
	rateConstants.push_back(k_g);

	// put enough dummy chemicalJacobian elements on the vector 
	// - they are recomputed every time you ask for the chemicalJacobian
	chemicalJacobian.push_back(new JElement(-1,-1));

	this->SetTeXForm();
}

GenerationReaction::~GenerationReaction()
{

}

double GenerationReaction::GetRate() const
{
	return rateConstants[k_g]->GetValue() * chemicals[Generator]->GetAmount();
}

void GenerationReaction::SetTeXForm()
{
	strstream stream;
	// TeX form of the reaction
	stream << rateConstants[k_g]->GetTeXName().c_str();
	stream << "\\left [" << chemicals[Generator]->GetTeXName().c_str();
	stream << "\\right ]";
	// add a NULL
	//int namesize = (chemicals[Generator]->GetName()).length();
	//stream << (chemicals[Generator]->GetName())[namesize];
	stream << ends;
	// set the TeX string equal to what's in the stream
	m_sTeXForm = stream.str();
	// free up the string
	stream.rdbuf()->freeze(0);
}

std::vector<Reaction::JElement *> *GenerationReaction::GetChemicalJacobian()
{
	chemicalJacobian[0]->SetWithRespectTo(chemicals[Generator]->GetChemicalNumber());
	chemicalJacobian[0]->SetJValue(rateConstants[k_g]->GetValue());
	
	return &chemicalJacobian;
}
