// This plotting program courtesy of M. Rauscher, modifications by K. S. Brown
#include <typeinfo>
#include <math.h>
#include <assert.h>
#ifdef _WIN32
#include <windows.h>
#endif //_WIN32
#include "GnuPlotter.h"

GnuPlotter::GnuPlotter(void) : Observer(), buffername(NULL), gnuplot_pipe(NULL), buffer(NULL)
{
	strcpy(title, "");
#ifdef _WIN32
		// local
		gnuplot_pipe = _popen("C:\\gnuplot\\gp371w32\\pgnuplot.exe", "w");
		// ctc login
		//gnuplot_pipe = _popen("H:\\Users\\kevin\\gnuplot\\gp371w32\\pgnuplot.exe", "w");	
		//SendPlotCommand("set terminal windows \"Helvetica\" 18\n");
#else
	#ifdef _DEBUG
		char name[128];
		sprintf(name, "tee gnuplot.protocol%d |  gnuplot -geometry 480x360", (int)this);
		gnuplot_pipe = popen(name, "w");
	#else
		gnuplot_pipe = popen("gnuplot -geometry 480x360", "w");
	#endif // _DEBUG
#endif // _WIN32
	if (gnuplot_pipe==NULL) {
		cout << "GnuPlotter::GnuPlotter(): Gnuplot couldn't be opened!" << endl;
		exit(-1);
	}
	buffername=tempnam(NULL, "gnuplotter");
	if (buffername==NULL) {
		cout << "GnuPlotter::GnuPlotter(): Buffername couldn't be created!" << endl;
		exit(-1);
	}
	buffer=fopen(buffername, "w");
	if (buffer==NULL) {
		cout << "GnuPlotter::GnuPlotter(): Buffer couldn't be created!" << endl;
		exit(-1);
	}
}

GnuPlotter::GnuPlotter(FILE * gplotpipe) : Observer(), buffername(NULL), gnuplot_pipe(gplotpipe)
{
	#ifdef _DEBUG
		assert(gnuplot_pipe!=NULL);
	#endif //_DEBUG
	buffername=tempnam(NULL, "gnuplotter");
	if (buffername==NULL) {
		cout << "GnuPlotter::GnuPlotter(): Buffername couldn't be created!" << endl;
		exit(-1);
	}
	buffer=fopen(buffername, "w");
	if (buffer==NULL) {
		cout << "GnuPlotter::GnuPlotter(): Buffer couldn't be created!" << endl;
		exit(-1);
	}
}

GnuPlotter::~GnuPlotter(void) { 
	if (gnuplot_pipe!=NULL) {
		//cout << "GnuPlotter::~GnuPlotter()" << endl;
		#ifdef _WIN32
			_pclose(gnuplot_pipe);
		#else
			pclose(gnuplot_pipe); 
		#endif //_WIN32
	}
	if (buffer!=NULL) fclose(buffer);
	if (buffername!=NULL) {
		unlink(buffername);
		free(buffername);
	}
	// else nothing to close
}

bool GnuPlotter::SendPlotCommand(const char* commandstring)
{
	if (gnuplot_pipe!=NULL) {
		fprintf(gnuplot_pipe, "%s", commandstring);
		FlushGnuPlotter();
		return(true);
	}
	else return(false);
}




