// GnuPlotterSimulatedAnnealingObserver.cpp: implementation of the GnuPlotterSimulatedAnnealingObserver class.
//
//////////////////////////////////////////////////////////////////////

#include "GnuPlotterSimulatedAnnealingObserver.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

GnuPlotterSimulatedAnnealingObserver::GnuPlotterSimulatedAnnealingObserver()
{

}

GnuPlotterSimulatedAnnealingObserver::~GnuPlotterSimulatedAnnealingObserver()
{

}

void GnuPlotterSimulatedAnnealingObserver::Update(Subject *theChangedSubject)
{
	// static cast may be dangerous
	CSimulatedAnnealingStrategy *SA = (CSimulatedAnnealingStrategy *)theChangedSubject;

	// arrays to send to gnuplot
	char titlestring[100];
	char commandstring[1000];

	// write the appropriate quantities to the buffer
	double OneOverT = 1/(SA->GetTemperature());
	double Ratio = SA->GetAcceptanceRatio();
	double EBar = SA->GetEBar();
	double SpecHeat = (SA->GetE2Bar() - (EBar*EBar))*OneOverT*OneOverT;
	double EMin = SA->GetEMin();
	fprintf(buffer,"%e\t%e\t%e\t%e\t%e\n",OneOverT,EBar,Ratio,SpecHeat,EMin);
	
	// set up for multiplot
	SendPlotCommand("set multiplot\n");

	// FIRST PLOT
	SendPlotCommand("set origin 0.0,0.0\n");
	SendPlotCommand("set size 0.5,0.5\n");
	sprintf(titlestring,"set title \"Average Energy\"\n");
	SendPlotCommand(titlestring);
	SendPlotCommand("set grid\n");
	SendPlotCommand("set nokey\n");
	SendPlotCommand("set logscale x\n");
	SendPlotCommand("set xlabel \"1/T\"\n");
	SendPlotCommand("set ylabel \"<E>\"\n");

	sprintf(commandstring,"plot \"%s\" u 1:2 t \"<E>\" w linespoints\n",buffername);

	// change single backslashes to forward slashes to keep windows happy
#ifdef _WIN32
	int iterator = 0;
	while(commandstring[iterator] != '\0')
	{
		if(commandstring[iterator] == '\\') {commandstring[iterator] = '/';}
		iterator++;
	}
#endif

	fflush(buffer);
	SendPlotCommand(commandstring);

	// SECOND PLOT
	SendPlotCommand("set origin 0.5,0.0\n");
	SendPlotCommand("set size 0.5,0.5\n");
	sprintf(titlestring,"set title \"Acceptance Ratio\"\n");
	SendPlotCommand(titlestring);
	SendPlotCommand("set grid\n");
	SendPlotCommand("set nokey\n");
	SendPlotCommand("set logscale x\n");
	SendPlotCommand("set xlabel \"1/T\"\n");
	SendPlotCommand("set ylabel \"R\"\n");

	sprintf(commandstring,"plot \"%s\" u 1:3 t \"R\" w linespoints\n",buffername);

	// change single backslashes to forward slashes to keep windows happy
#ifdef _WIN32
	iterator = 0;
	while(commandstring[iterator] != '\0')
	{
		if(commandstring[iterator] == '\\') {commandstring[iterator] = '/';}
		iterator++;
	}
#endif

	fflush(buffer);
	SendPlotCommand(commandstring);
	
	// THIRD PLOT
	SendPlotCommand("set origin 0.0,0.5\n");
	SendPlotCommand("set size 0.5,0.5\n");
	sprintf(titlestring,"set title \"Specific Heat\"\n");
	SendPlotCommand(titlestring);
	SendPlotCommand("set grid\n");
	SendPlotCommand("set nokey\n");
	SendPlotCommand("set logscale x\n");
	SendPlotCommand("set xlabel \"1/T\"\n");
	SendPlotCommand("set ylabel \"C(T)\"\n");

	sprintf(commandstring,"plot \"%s\" u 1:4 t \"C(T)\" w linespoints\n",buffername);

	// change single backslashes to forward slashes to keep windows happy
#ifdef _WIN32
	iterator = 0;
	while(commandstring[iterator] != '\0')
	{
		if(commandstring[iterator] == '\\') {commandstring[iterator] = '/';}
		iterator++;
	}
#endif
	
	fflush(buffer);
	SendPlotCommand(commandstring);

	// FOURTH PLOT
	SendPlotCommand("set origin 0.5,0.5\n");
	SendPlotCommand("set size 0.5,0.5\n");
	sprintf(titlestring,"set title \"Minimum Energy\"\n");
	SendPlotCommand(titlestring);
	SendPlotCommand("set grid\n");
	SendPlotCommand("set nokey\n");
	SendPlotCommand("set logscale x\n");
	SendPlotCommand("set xlabel \"1/T\"\n");
	SendPlotCommand("set ylabel \"EMin\"\n");

	sprintf(commandstring,"plot \"%s\" u 1:5 t \"Emin\" w linespoints\n",buffername);

	// change single backslashes to forward slashes to keep windows happy
#ifdef _WIN32
	iterator = 0;
	while(commandstring[iterator] != '\0')
	{
		if(commandstring[iterator] == '\\') {commandstring[iterator] = '/';}
		iterator++;
	}
#endif
	
	fflush(buffer);
	SendPlotCommand(commandstring);
}
