// GnuPlotterTimeSeriesObserver.cpp: implementation of the GnuPlotterTimeSeriesObserver class.
//
//////////////////////////////////////////////////////////////////////

#include "GnuPlotterTimeSeriesObserver.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

GnuPlotterTimeSeriesObserver::GnuPlotterTimeSeriesObserver()
{

}

GnuPlotterTimeSeriesObserver::~GnuPlotterTimeSeriesObserver()
{

}

// default behavior is to plot things in terms of (arbitrary) experimental
// units

void GnuPlotterTimeSeriesObserver::Update(Subject *theChangedSubject)
{
	// static cast may be dangerous
	SingleNetworkMinimizable *nM = (SingleNetworkMinimizable *)theChangedSubject;

	// set the plot title
	char titlestring[100];
	char commandstring[1000];
	sprintf(titlestring,"set title \"%s\"\n",title);
	SendPlotCommand(titlestring);
	SendPlotCommand("set grid\n");
	SendPlotCommand("set xlabel \"time (min)\"\n");
	//SendPlotCommand("set ylabel \"[Chemical] (molecules)\"\n");
	SendPlotCommand("set ylabel \"Concentration/Activity (arb. units)\"\n");

	// write the experimental data to the temporary file
	freopen(buffername,"w",buffer);

	std::vector<int> whichSimToPrint;
	// dump blocks of data/simulation to files, separated by double newlines
	// EXPERIMENT
	int nChem = nM->GetExperiment()->GetChemicalTimeSeriesData()->GetNChemicals();
	int nTimeSeries = nM->GetExperiment()->GetChemicalTimeSeriesData()->GetNTimeSeries();

	std::vector<DataPoint *> nullVector;

	for(int i = 0; i < nChem; i++)
	{
		if( (nM->GetExperiment()->GetChemicalTimeSeriesData()->GetTimeSeries(i)) != nullVector )
		{
			whichSimToPrint.push_back(i);
			for(int j = 0; j < (nM->GetExperiment()->GetChemicalTimeSeriesData()->GetTimeSeries(i)).size(); j++)
			{
				double time = nM->GetExperiment()->GetChemicalTimeSeriesData()->GetTimeSeries(i)[j]->GetTime();
				double data = nM->GetExperiment()->GetChemicalTimeSeriesData()->GetTimeSeries(i)[j]->GetDatum();
				double error = nM->GetExperiment()->GetChemicalTimeSeriesData()->GetTimeSeries(i)[j]->GetError();
				fprintf(buffer,"%e\t%e\t%e\n",time,data,error);
			}
			fprintf(buffer,"\n\n");

		}
	}

	// SIMULATION
	int maxTime = nM->GetCellObserver()->GetNumberOfTimeSteps();
	for(i = 0; i < whichSimToPrint.size(); i++)
	{
		for(int j = 0; j < (maxTime-1); j++)
		{
			int target = whichSimToPrint[i];
			double time = double (j);
			double sim = nM->GetCellObserver()->GetAverageConcentration()[target][j];
			if(nM->GetConversionFactor(target)->IsFactorNeeded())
			{
				double scale = nM->GetConversionFactor(target)->GetFactorValue();
				sim = sim*scale;
			}
			fprintf(buffer,"%e\t%e\n",time,sim);
		}
		fprintf(buffer,"\n\n");
	}
	
	// now plot everything
	// first block (done this way to keep the commas straight)
	char namestring[100];
	sprintf(namestring,nM->GetExperiment()->GetReactionNetwork()->GetChemical(whichSimToPrint[0])->GetName().c_str());
	sprintf(commandstring,"plot \"%s\" index 0 t \"%s\" w errorbars lw 2 ps 2",buffername,namestring);
	// the rest - experiment first
	for(i = 1; i < nTimeSeries; i++)
	{
		char tempbuffer[200];
		sprintf(namestring,nM->GetExperiment()->GetReactionNetwork()->GetChemical(whichSimToPrint[i])->GetName().c_str());
		sprintf(tempbuffer,",\"%s\" index %i t \"%s\" w errorbars lw 2 ps 2",buffername,i,namestring);
		strcat(commandstring,tempbuffer);
	}
	for(i = nTimeSeries; i < 2*nTimeSeries; i++)
	{
		char tempbuffer[200];
		sprintf(tempbuffer,",\"%s\" index %i notitle w lines lt %i lw 4",buffername,i,i-nTimeSeries+1);
		strcat(commandstring,tempbuffer);
	}
	strcat(commandstring,"\n");
	
	// change single backslashes to forward slashes to keep windows happy
#ifdef _WIN32
	int iterator = 0;
	while(commandstring[iterator] != '\0')
	{
		if(commandstring[iterator] == '\\') {commandstring[iterator] = '/';}
		iterator++;
	}
#endif

	fflush(buffer);
	SendPlotCommand(commandstring);

	return;
}