// HeterodimerDissociationReaction.cpp: implementation of the HeterodimerDissociationReaction class.
//
//////////////////////////////////////////////////////////////////////

#include "HeterodimerDissociationReaction.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

HeterodimerDissociationReaction::HeterodimerDissociationReaction(Chemical *Heterodimer, Chemical *ReactantA, Chemical *ReactantB, RateConstant *k_udim, std::string reactionName)
:Reaction(reactionName)
{
	// stoichiometry
	this->Heterodimer = chemicals.size();
	chemicals.push_back(Heterodimer);
	numberOfEachChemicalChangedByReaction.push_back(-1);

	this->ReactantA = chemicals.size();
	chemicals.push_back(ReactantA);
	numberOfEachChemicalChangedByReaction.push_back(+1);

	this->ReactantB = chemicals.size();
	chemicals.push_back(ReactantB);
	numberOfEachChemicalChangedByReaction.push_back(+1);

	// rates
	this->k_udim = rateConstants.size();
	rateConstants.push_back(k_udim);

	// put enough dummy chemicalJacobian elements on the vector 
	// - they are recomputed every time you ask for the chemicalJacobian
	chemicalJacobian.push_back(new JElement(-1,-1));

	this->SetTeXForm();
}

HeterodimerDissociationReaction::~HeterodimerDissociationReaction()
{

}

double HeterodimerDissociationReaction::GetRate() const
{
	return rateConstants[k_udim]->GetValue() * chemicals[Heterodimer]->GetAmount();
}

void HeterodimerDissociationReaction::SetTeXForm()
{
	strstream stream;
	// TeX form of the reaction
	stream << rateConstants[k_udim]->GetTeXName().c_str();
	stream << "\\left [" << chemicals[Heterodimer]->GetTeXName().c_str();
	stream << "\\right ]";
	stream << ends;
	// set the TeX string equal to what's in the stream
	m_sTeXForm = stream.str();
	// allow memory to be freed
	stream.rdbuf()->freeze(0);
}

std::vector<Reaction::JElement *> *HeterodimerDissociationReaction::GetChemicalJacobian()
{
	chemicalJacobian[0]->SetWithRespectTo(chemicals[Heterodimer]->GetChemicalNumber());
	chemicalJacobian[0]->SetJValue(rateConstants[k_udim]->GetValue());
	
	return &chemicalJacobian;
}
