// HeterodimerizationReaction.cpp: implementation of the HeterodimerizationReaction class.
//
//////////////////////////////////////////////////////////////////////

#include "HeterodimerizationReaction.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

HeterodimerizationReaction::HeterodimerizationReaction(Chemical *ReactantA, Chemical *ReactantB, Chemical *Heterodimer, RateConstant *k_dim, std::string reactionName)
:Reaction(reactionName)
{
	// stoichiometry
	this->ReactantA = chemicals.size();
	chemicals.push_back(ReactantA);
	numberOfEachChemicalChangedByReaction.push_back(-1);

	this->ReactantB = chemicals.size();
	chemicals.push_back(ReactantB);
	numberOfEachChemicalChangedByReaction.push_back(-1);

	this->Heterodimer = chemicals.size();
	chemicals.push_back(Heterodimer);
	numberOfEachChemicalChangedByReaction.push_back(+1);

	// rates
	this->k_dim = rateConstants.size();
	rateConstants.push_back(k_dim);

	// put enough dummy chemicalJacobian elements on the vector 
	// - they are recomputed every time you ask for the chemicalJacobian
	chemicalJacobian.push_back(new JElement(-1,-1));
	chemicalJacobian.push_back(new JElement(-1,-1));

	this->SetTeXForm();
}

HeterodimerizationReaction::~HeterodimerizationReaction()
{

}

double HeterodimerizationReaction::GetRate() const
{
	return ((rateConstants[k_dim]->GetValue())*(chemicals[ReactantA]->GetAmount())*(chemicals[ReactantB]->GetAmount()));
}

void HeterodimerizationReaction::SetTeXForm()
{
	strstream stream;
	// TeX form of the reaction
	stream << rateConstants[k_dim]->GetTeXName().c_str();
	stream << "\\left [" << chemicals[ReactantA]->GetTeXName().c_str();
	stream << "\\right ]";
	stream << "\\left [" << chemicals[ReactantB]->GetTeXName().c_str();
	stream << "\\right ]";
	// add a NULL
	stream << ends;
	// set the TeX string equal to what's in the stream
	m_sTeXForm = stream.str();
	// allow memory to be freed
	stream.rdbuf()->freeze(0);
}

std::vector<Reaction::JElement *> *HeterodimerizationReaction::GetChemicalJacobian()
{
	chemicalJacobian[0]->SetWithRespectTo(chemicals[ReactantA]->GetChemicalNumber());
	chemicalJacobian[0]->SetJValue((rateConstants[k_dim]->GetValue())*(chemicals[ReactantB]->GetAmount()));
	
	chemicalJacobian[1]->SetWithRespectTo(chemicals[ReactantB]->GetChemicalNumber());
	chemicalJacobian[1]->SetJValue((rateConstants[k_dim]->GetValue())*(chemicals[ReactantA]->GetAmount()));

	return &chemicalJacobian;
}
