// HomodimerDissociationReaction.cpp: implementation of the HomodimerDissociationReaction class.
//
//////////////////////////////////////////////////////////////////////

#include "HomodimerDissociationReaction.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

HomodimerDissociationReaction::HomodimerDissociationReaction(Chemical *Homodimer, Chemical *Monomer, RateConstant *k_udim, std::string reactionName)
:Reaction(reactionName)
{
	// stoichiometry
	this->Homodimer = chemicals.size();
	chemicals.push_back(Homodimer);
	numberOfEachChemicalChangedByReaction.push_back(-1);

	this->Monomer = chemicals.size();
	chemicals.push_back(Monomer);
	numberOfEachChemicalChangedByReaction.push_back(+2);

	// rates
	this->k_udim = rateConstants.size();
	rateConstants.push_back(k_udim);

	// put enough dummy chemicalJacobian elements on the vector 
	// - they are recomputed every time you ask for the chemicalJacobian
	chemicalJacobian.push_back(new JElement(-1,-1));

	this->SetTeXForm();
}

HomodimerDissociationReaction::~HomodimerDissociationReaction()
{

}

double HomodimerDissociationReaction::GetRate() const
{
	return rateConstants[k_udim]->GetValue() * chemicals[Homodimer]->GetAmount();
}

void HomodimerDissociationReaction::SetTeXForm()
{
	strstream stream;
	// TeX form of the reaction
	stream << rateConstants[k_udim]->GetTeXName().c_str();
	stream << "\\left [" << chemicals[Homodimer]->GetTeXName().c_str();
	stream << "\\right ]";
	// add a NULL
	stream << ends;
	// set the TeX string equal to what's in the stream
	m_sTeXForm = stream.str();
	// allow memory to be freed
	stream.rdbuf()->freeze(0);
}

std::vector<Reaction::JElement *> *HomodimerDissociationReaction::GetChemicalJacobian()
{
	chemicalJacobian[0]->SetWithRespectTo(chemicals[Homodimer]->GetChemicalNumber());
	chemicalJacobian[0]->SetJValue(rateConstants[k_udim]->GetValue());
	
	return &chemicalJacobian;
}
