// HomodimerizationReaction.cpp: implementation of the HomodimerizationReaction class.
//
//////////////////////////////////////////////////////////////////////

#include "HomodimerizationReaction.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

HomodimerizationReaction::HomodimerizationReaction(Chemical *Monomer, Chemical *Homodimer, RateConstant *k_dim, std::string reactionName)
:Reaction(reactionName)
{
	// stoichiometry
	this->Monomer = chemicals.size();
	chemicals.push_back(Monomer);
	numberOfEachChemicalChangedByReaction.push_back(-2);

	this->Homodimer = chemicals.size();
	chemicals.push_back(Homodimer);
	numberOfEachChemicalChangedByReaction.push_back(+1);
	
	// rates
	this->k_dim = rateConstants.size();
	rateConstants.push_back(k_dim);

	// dummy jacobian
	chemicalJacobian.push_back(new JElement(-1,-1));

	this->SetTeXForm();
}

HomodimerizationReaction::~HomodimerizationReaction()
{

}

double HomodimerizationReaction::GetRate() const
{
	return (rateConstants[k_dim]->GetValue() * chemicals[Monomer]->GetAmount() * (chemicals[Monomer]->GetAmount() - 1.0));
}

void HomodimerizationReaction::SetTeXForm()
{
	strstream stream;
	// TeX form of the reaction
	stream << rateConstants[k_dim]->GetTeXName().c_str();
	stream << "\\left [" << chemicals[Monomer]->GetTeXName().c_str();
	stream << "\\right ]" << "\\left(";
	stream << "\\left [" << chemicals[Monomer]->GetTeXName().c_str() << " - 1 ";
	stream << "\\right)";
	stream << "\\right ]";
	// add a NULL
	stream << ends;
	// set the TeX string equal to what's in the stream
	m_sTeXForm = stream.str();
	// allow memory to be freed
	stream.rdbuf()->freeze(0);
}

std::vector<Reaction::JElement *> *HomodimerizationReaction::GetChemicalJacobian()
{
	chemicalJacobian[0]->SetWithRespectTo(chemicals[Monomer]->GetChemicalNumber());
	chemicalJacobian[0]->SetJValue((rateConstants[k_dim]->GetValue())*(2*(chemicals[Monomer]->GetAmount()) - 1));
	
	return &chemicalJacobian;
}
