// LeastSquaresMinimizer.h: interface for the LeastSquaresMinimizer class.
//
//////////////////////////////////////////////////////////////////////

#if !defined(AFX_LEASTSQUARESMINIMIZER_H__B872BB8D_BEEB_412D_BDC2_43D6F067FD89__INCLUDED_)
#define AFX_LEASTSQUARESMINIMIZER_H__B872BB8D_BEEB_412D_BDC2_43D6F067FD89__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#ifdef _WIN32
#include <mkl.h>
#else
#include "lapack.h"
#endif

#include <iostream>
#include <fstream.h>
#include <cmath>
#include <cfloat>
#include <assert.h>
#include "Minimizer.h"
#include "NLLSMinimizable.h"
#include "../src/ParameterFilter.h"

class CLeastSquaresMinimizer : public Minimizer  
{
public:
	CLeastSquaresMinimizer();
	virtual ~CLeastSquaresMinimizer();
	// Compute the Hessian and the Gradient via numerical differentiation
	void ComputeDerivativeInformation(double *parameters, NLLSMinimizable *nlls);
	// Store the diagonal elements of the Hessian
	void SaveDiagonal();
	// returns the force matrix
	const double **GetForceMatrix() const {return (const double **)m_pdForceMatrix;}
    int GetNParameters() {return nParameters;}
	int GetNResiduals() {return m_iNResiduals;}
//private:
	double m_dFuncAccuracy;			// Accuracy of objective function evaluations
	double** m_pdAlpha;				// Approximate Hessian matrix
	double* m_pdGrad;				// Gradient (-JT.f)
	double* m_pdDiagonal;			// Used to preserve diagonal H elements before scaling
	CParameterFilter *m_pFilter;	// Filter for parameter rescaling
	double** m_pdForceMatrix;		// Components of gradient (-JT.f)
	int m_iNResiduals;				// number of residuals in NLLSMinimizable
};

#endif // !defined(AFX_LEASTSQUARESMINIMIZER_H__B872BB8D_BEEB_412D_BDC2_43D6F067FD89__INCLUDED_)
