// LevenbergMarquardtMinimizer.h: interface for the CLevenbergMarquardtMinimizer class.
//
//////////////////////////////////////////////////////////////////////

#if !defined(AFX_LEVENBERGMARQUARDTMINIMIZER_H__B872BB8D_BEEB_412D_BDC2_43D6F067FD89__INCLUDED_)
#define AFX_LEVENBERGMARQUARDTMINIMIZER_H__B872BB8D_BEEB_412D_BDC2_43D6F067FD89__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#ifdef _WIN32
#include <mkl.h>
#else
#include "lapack.h"
#endif

#include <iostream>
#include <fstream.h>
#include <cmath>
#include <cfloat>
#include <assert.h>
#include "LeastSquaresMinimizer.h"
#include "NLLSMinimizable.h"
#include "../src/ParameterFilter.h"

class CLevenbergMarquardtMinimizer : public CLeastSquaresMinimizer  
{
public:
	CLevenbergMarquardtMinimizer();
	virtual ~CLevenbergMarquardtMinimizer();
	// Adds the marquardt parameter to the diagonal
	void RescaleDiagonal(double scaleParameter);
	// Restores the diagonal elements of the Hessian to their saved values
	void RestoreDiagonal();
	// Enforce positive semi-definiteness on the parameters
	void CheckBounds(double *parameters);
	// Obtain the trial parameters from the current parameters and the change
	void ObtainTrialParameters(double *currentP, double *deltaP, double *trialP);
	// Accepts trial parameters as the new parameters
	void AcceptParameters(double *parameters, double *trialP, double newCost);
	// The next three functions return true if the values are below their respective
	// tolerances
	// Computes the fractional cost tolerance
	bool ComputeChiSqTol(double oldCost, double newCost);
	// Computes the gradient tolerance
	bool ComputeGradTol();
	// Computes the parameter tolerance
	bool ComputeParTol(double *oldP, double *deltaP);
//private:
	bool m_bCheckChi;				// Set to true if you want to use fractional
									//    change in chi^2 as a convergence crit.
	bool m_bCheckGrad;				// Set to true if you want to use the 2-norm
									//    of the gradient as a convergence crit.
	bool m_bCheckPar;				// Set to true if you want to use parameter 
									//    norms as a convergence crit.
	bool m_bPositiveSemiDef;		// Set to true if all parameters >= 0.  If you
									//    do so, you must use the identity filter
	double m_dLambda;				// Marquardt parameter
	double m_dNu;					// Divisor of MarquardtParameter
	int m_iNIterations;				// Maximum number of LM iterations
	double m_dChiSqTol;				// Fractional stopping criterion for Chi squared
	double m_dGradTol;				// Stopping criterion for the norm of the gradient
	double m_dParTol;				// Stopping criterion based on deltaP
	double m_dTau;					// Small number
};

#endif // !defined(AFX_LEVENBERGMARQUARDTMINIMIZER_H__B872BB8D_BEEB_412D_BDC2_43D6F067FD89__INCLUDED_)
