// Minimizable.h: interface for the Minimizable class.
//
//////////////////////////////////////////////////////////////////////

#ifndef MINIMIZABLE_H
#define MINIMIZABLE_H

#ifndef SWIG
#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000
#endif // SWIG

#include <stdexcept>

class Minimizable
{
public:
	virtual double ObjectiveFunction(double *parameters)=0;
	virtual double *Gradient(double *parameters) {throw std::runtime_error("Gradient is not defined for this Minimizable");}
	virtual double **Hessian(double *parameters) {throw std::runtime_error("Hessian is not defined for this Minimizable");}
	virtual int GetNParameters()=0;
	// computes energy and entropy at temp T for a single set of parameters
	virtual double ComputeES(double *parameters, double T) = 0;
	// computes entropy shift (largely irrelevant constant) at temperature T
	virtual double EntropyShift(double T) = 0;
	// gives the free energy less the entropy shift
	virtual double F(double *parameters, double T) = 0;
	// gives the total free energy
	virtual double F0(double *parameters, double T) = 0;
	// returns last computed energy
	virtual double GetEnergyLastComputed() {return m_dEnergyLastComputed;}
	// returns last computed entropy
	virtual double GetEntropyLastComputed() {return m_dEntropyLastComputed;}
protected:
	double m_dEnergyLastComputed;
	double m_dEntropyLastComputed;
};



#endif // MINIMIZABLE_H
