#pragma once
#include <vector>
#include <iostream>
#include <float.h>
#include <fstream.h>
#include <iomanip.h>
#include "../src/Minimizer.h"
#include "../src/Minimizable.h"
#include "../src/MatrixOperations.h"
#include "../src/ParameterFilter.h"

class CNelderMeadSimplexMinimizer : public Minimizer
{
public:
	CNelderMeadSimplexMinimizer();
	CNelderMeadSimplexMinimizer(CParameterFilter *pFilter, int nIterations=500, double lambda=1.0, double tol=1.0e-06);
	virtual ~CNelderMeadSimplexMinimizer(void);
	double Minimize(double *parameters, Minimizable *minimizable);
	void InitializeSimplex(double *parameters);
	void EvaluateSimplex();
	void ComputePointSum();
	int GetNParameters() {return nParameters;}
	bool CheckFuncTol();
	double TryPoint(double exfac);
private:
	CMatrixOperations *m_pMO;
	Minimizable *m_pMinimizable;
	std::vector<double *> m_vpdSimplex;
	CParameterFilter *m_pFilter;
	double *m_pdSimplexCosts;
	double *m_pdPointSum;
	double m_dLambda;
	double m_dTol;
	int m_iHi, m_iLo, m_iNextHi;
	int m_iNIterations;
};
