// NetworkMinimizableDirector.h: interface for the NetworkMinimizableDirector class.
//
//////////////////////////////////////////////////////////////////////

#if !defined(AFX_NETWORKMINIMIZABLEDIRECTOR_H__C03A8E92_E561_4180_B799_A6972926C1B7__INCLUDED_)
#define AFX_NETWORKMINIMIZABLEDIRECTOR_H__C03A8E92_E561_4180_B799_A6972926C1B7__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#include "SingleNetworkMinimizable.h"

class NetworkMinimizableDirector : public NLLSMinimizable
{
public:
	NetworkMinimizableDirector();
	virtual ~NetworkMinimizableDirector();
	// Inherited from Minimizable - should return the size of Union_i(p_i) over 
	// _minimizableList (pure virtual)
	virtual int GetNParameters() = 0;
	// Inherited from Minimizable - returns the summed objective function for all 
	// minimizables in _minimizableList
	virtual double ObjectiveFunction(double *parameters);
	// Inherited from NLLSMinimizable - computes residuals for all the individual 
	// minimizables in _minimizableList and stores them appropriately
	virtual double ComputeResiduals(double *parameters);
	virtual double ComputeES(double *parameters, double T);
	virtual double EntropyShift(double T);
	virtual double F(double *parameters, double T);
	virtual double F0(double *parameters, double T);
	// Inherited from Minimizable - should return the appropriate parameter
	// (pure virtual)
	virtual double GetParameter(int parIndex) = 0;
	// Returns a single mover
	virtual CReactionMover *GetMover(int moverIndex) {return _moverList[moverIndex];}
	// Returns the number of experiments
	virtual int GetNExperiments() const {return _experimentList.size();}
	// Returns a single reaction network
	virtual ReactionNetwork *GetReactionNetwork(int networkIndex) {return _networkList[networkIndex];}
	// Dumps information about residuals order to a file
	virtual void DumpResidualInfo();
private:
	// Initialization of conditions for each minimizable
	virtual void DefineExperiments() = 0;
protected:
	std::vector<SingleNetworkMinimizable *> _minimizableList;
	std::vector<Experiment *> _experimentList;
	std::vector<ReactionNetwork *> _networkList;
	std::vector<CReactionMover *> _moverList;
	// indices of parameters (if any) that have a cost for deviation from guessed values
	std::vector<int> m_iPriorList;
	// penalty for difficult integrations; always make it the last residual in
	// the list
	double m_dGammaSquared;
};

#endif // !defined(AFX_NETWORKMINIMIZABLEDIRECTOR_H__C03A8E92_E561_4180_B799_A6972926C1B7__INCLUDED_)
