// OneGeneInhibitoryNetwork.cpp: implementation of the OneGeneInhibitoryNetwork class.
//
//////////////////////////////////////////////////////////////////////

#ifdef _WINDOWS
#include "stdafx.h"
#endif

#include "OneGeneInhibitoryNetwork.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

OneGeneInhibitoryNetwork::OneGeneInhibitoryNetwork()
{
	Chemical *freePromoter = new Chemical(chemicals.size(), 1.0, "P");
	chemicals.push_back(freePromoter);

	Chemical *boundPromoter = new Chemical(chemicals.size(), 0.0, "P:A");
	chemicals.push_back(boundPromoter);

	Chemical *mRNA = new Chemical(chemicals.size(), 0.0, "mRNA");
	chemicals.push_back(mRNA);

	Chemical *protein = new Chemical(chemicals.size(), 0.0, "A");
	chemicals.push_back(protein);

	RateConstant *kb = new RateConstant(0.6,0.2*0.6, "kb");
	rateConstants.push_back(kb);
	RateConstant *ku = new RateConstant(0.15,0.2*0.15, "ku");
	rateConstants.push_back(ku);
	RateConstant *ktm = new RateConstant(10.0,0.2*10.0, "ktm");
	rateConstants.push_back(ktm);
	RateConstant *kdm = new RateConstant(0.05,0.2*0.05, "kdm");
	rateConstants.push_back(kdm);
	RateConstant *kt = new RateConstant(1.2,0.2*1.2, "kt");
	rateConstants.push_back(kt);
	RateConstant *kd = new RateConstant(0.1,0.2*0.1, "kd");
	rateConstants.push_back(kd);

	PromoterBindingReaction *bindingReaction = new PromoterBindingReaction(freePromoter, protein, boundPromoter, kb, "tb");
	reactions.push_back(bindingReaction);
	PromoterUnbindingReaction *unbindingReaction = new PromoterUnbindingReaction(boundPromoter, freePromoter, protein, ku, "tu");
	reactions.push_back(unbindingReaction);
	TranscriptionReaction *transcriptionReaction = new TranscriptionReaction(freePromoter, mRNA, ktm, "tr");
	reactions.push_back(transcriptionReaction);
	RNADegradationReaction *mRNADegradationReaction = new RNADegradationReaction(mRNA, kdm, "tdm");
	reactions.push_back(mRNADegradationReaction);
	ProteinTranslationReaction *translationReaction = new ProteinTranslationReaction(mRNA, protein, kt, "tl");
	reactions.push_back(translationReaction);
	UnstableProteinDegradationReaction *proteinDegradationReaction = new UnstableProteinDegradationReaction(protein, kd, "tdA");
	reactions.push_back(proteinDegradationReaction);

}

OneGeneInhibitoryNetwork::~OneGeneInhibitoryNetwork()
{

}