// OneGeneInhibitoryNetworkMinimizableDirector.cpp: implementation of the OneGeneInhibitoryNetworkMinimizableDirector class.
//
//////////////////////////////////////////////////////////////////////

#include "OneGeneInhibitoryNetworkMinimizableDirector.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

COneGeneInhibitoryNetworkMinimizableDirector::COneGeneInhibitoryNetworkMinimizableDirector()
{
	double maxSimTime = 91.0;
	double stepSize = 0.0001;
	double frequency = 1.0;
	int nCells = 1;
	double moveTol = 1.0e-06;

	bool rateFlag = true;
	bool chemFlag = false;
	bool logsFlag = false;
	double timeWeight = 1.0;
	double rateWeight = 0.0;
	double chemWeight = 0.0;

	m_dGammaSquared = 1.0e-07;

	// fake experiment 1 - 1 free promoter, no mRNA or protein
	_networkList.push_back(new OneGeneInhibitoryNetwork());
	_experimentList.push_back(new Experiment(_networkList[0],"SmallNetwork"));
	// data files
	_experimentList[0]->AddDataFileToList("smallOneGeneDS.dat");
	// mover and plotter
	_moverList.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	// minimizable
	_minimizableList.push_back(new SingleNetworkMinimizable());
	// parameters
	_minimizableList[0]->Initialize(_experimentList[0],_moverList[0],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	_minimizableList[0]->SetRateConstantsWeight(0.0);
	// attach observer
	m_vpPlotterList.push_back(new GnuPlotterTimeSeriesObserver());
	// title
	m_vpPlotterList[0]->SetTitle("Small OGN:1 Free Promoter:ODE");
	_minimizableList[0]->Attach(m_vpPlotterList[0]);

	// parameters which need a prior
	m_iPriorList.push_back(0);
	m_iPriorList.push_back(1);
	m_iPriorList.push_back(2);
	m_iPriorList.push_back(3);
	m_iPriorList.push_back(4);
	m_iPriorList.push_back(5);

	// allocate the master residuals list
	int masterResidualsSize = 0;
	for(int i = 0; i < _minimizableList.size(); i++)
	{
		int subRes = _minimizableList[i]->GetNResiduals();
		masterResidualsSize += subRes;
		cout << subRes << " residuals in minimizable " << i << endl;
	}
	// add residuals for prior parameter costs, if applicable
	masterResidualsSize += m_iPriorList.size();
	cout << m_iPriorList.size() << " parameters are constrained by a prior " << endl;
	if(m_dGammaSquared > 0.0)
	{
		masterResidualsSize += 1;
	}
	Allocate(masterResidualsSize);

	cout << "Master Residuals size : " << masterResidualsSize << endl;

	// define the experiments
	DefineExperiments();

	// dump info about residuals
	//DumpResidualInfo();
}

COneGeneInhibitoryNetworkMinimizableDirector::~COneGeneInhibitoryNetworkMinimizableDirector()
{
	for(int i = 0; i < m_vpPlotterList.size(); i++)
	{
		_minimizableList[i]->Detach(m_vpPlotterList[i]);
		delete m_vpPlotterList[i];
	}
}

void COneGeneInhibitoryNetworkMinimizableDirector::DefineExperiments()
{
	// 1 free promoter region, no bound, no mRNA, no protein
	_minimizableList[0]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(1.0);
	_minimizableList[0]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->Reset();
	_minimizableList[0]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->SetInitialAmount(0.0);
	_minimizableList[0]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->Reset();
}

double COneGeneInhibitoryNetworkMinimizableDirector::GetParameter(int parIndex)
{
	// Just return the first set (they are all the same)
	return _minimizableList[0]->GetParameter(parIndex);
}

int COneGeneInhibitoryNetworkMinimizableDirector::GetNParameters()
{
	// Return the size of the first set (all have the same size)
	return _minimizableList[0]->GetNParameters();
}

