// LevenbergMarquardtMinimizer.h: interface for the LevenbergMarquardtMinimizer class.
//
//////////////////////////////////////////////////////////////////////

#if !defined(AFX_POSITIVEDEFINITELEVENBERGMARQUARDTMINIMIZER_H__B872BB8D_BEEB_412D_BDC2_43D6F067FD89__INCLUDED_)
#define AFX_POSITIVEDEFINITELEVENBERGMARQUARDTMINIMIZER_H__B872BB8D_BEEB_412D_BDC2_43D6F067FD89__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

// XXX debug 
#include <iostream>

#include <fstream.h>
#include <cmath>
#include <cfloat>
#include <mkl.h>
#include <assert.h>
#include "Minimizer.h"
#include "NLLSMinimizable.h"
#include "../src/ParameterFilter.h"

class CPositiveDefiniteLevenbergMarquardtMinimizer : public Minimizer  
{
public:
	CPositiveDefiniteLevenbergMarquardtMinimizer();
	CPositiveDefiniteLevenbergMarquardtMinimizer(CParameterFilter *pFilter, double marquardt, double chiTol, double gradTol, int nIterations);
	virtual ~CPositiveDefiniteLevenbergMarquardtMinimizer();
	double Minimize(double *parameters, Minimizable *minimizable);
	void ComputeDerivativeInformation(double *parameters, NLLSMinimizable *nlls);
	// Solve LM system using Singular Value Decomp.
	void SVDSolveMarquardtSystem(double *deltaP);
	// Solve LM system using LU factorization
	void LUSolveMarquardtSystem(double *deltaP);
	void SetBounds(double *parameters);
	void CheckBounds(double *parameters);
private:
	bool m_bBreakFlag;				// Set to true to break out of the routine
	bool m_bReconditionFlag;		// Set to true to recondition the LM Hessian
	double m_dMarquardt;			// Marquardt parameter
	int m_iNIterations;				// Maximum number of LM iterations
	double m_dChiSqTol;				// Fractional stopping criterion for Chi squared
	double m_dGradTol;				// Stopping criterion for the norm of the gradient
	double** m_pdAlpha;				// (1/2)*approximate Hessian matrix
	double* m_pdBeta;				// (-1/2)*gradient
	double* m_pdUpperBounds;		// Keeps parameters from getting too big
	double* m_pdLowerBounds;		// Keeps parameters from getting too small
	int m_iNResiduals;				// number of residuals in NLLSMinimizable
	CParameterFilter *m_pFilter;	// Filter if parameters need to be kept positive
};

#endif // !defined(AFX_POSITIVEDEFINITELEVENBERGMARQUARDTMINIMIZER_H__B872BB8D_BEEB_412D_BDC2_43D6F067FD89__INCLUDED_)
