// RK2TMover.cpp: implementation of the CRK2TMover class.
//
//////////////////////////////////////////////////////////////////////

#include "RK2TMover.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

CRK2TMover::CRK2TMover()
{

}

CRK2TMover::CRK2TMover(double frequency, double stepSize)
:CRungeKuttaMover(frequency,stepSize)
{

}

CRK2TMover::~CRK2TMover()
{

}

//////////////////////////////////////////////////////////////////////
// This function takes a second-order trapezoidal RK step.
//////////////////////////////////////////////////////////////////////

void CRK2TMover::RungeKuttaStep(int nRHS, double *y, double *dydt)
{
	double *yTemp = new double[nRHS];
	double *dydtTemp = new double[nRHS];
	double halfStep = 0.5*m_dStepSize;
	
	// beginning of interval
	ComputeDerivatives(y,dydt);
	for(int i = 0; i < nRHS; i++)
	{
		yTemp[i] = y[i] + halfStep*dydt[i];
	}
	
	// step forward
	ComputeDerivatives(yTemp,dydtTemp);

	// update y(t) to y(t+h)
	for(i = 0; i < nRHS; i++)
	{
		y[i] = y[i] + halfStep*(dydt[i] + dydtTemp[i]);
	}
	
	// free memory
	delete [] yTemp;
	delete [] dydtTemp;
}