// Reaction.h: interface for the Reaction class.
//
//////////////////////////////////////////////////////////////////////

#if !defined(AFX_REACTION_H__17E9EE60_DB43_11D3_8099_00A0C9B3BB18__INCLUDED_)
#define AFX_REACTION_H__17E9EE60_DB43_11D3_8099_00A0C9B3BB18__INCLUDED_

#ifndef SWIG
#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000
#endif

#include <vector>
#include <string>
#include <strstrea.h>
#include <sstream>
#include <iostream>
#include "Chemical.h"
#include "RateConstant.h"

class Chemical;	// Both files refer to one another


class Reaction  
{
public:
	class JElement
	{
	public:
		JElement() {return;}
		JElement(int withRespectTo, double jValue)
		{
			_withRespectTo = withRespectTo;
			_jValue = jValue;
		}
		virtual ~JElement() {return;}
		int GetWithRespectTo() const {return _withRespectTo;}
		double GetJValue() const {return _jValue;}
		void SetWithRespectTo(int withRespectTo) {_withRespectTo = withRespectTo;}
		void SetJValue(double jValue) {_jValue = jValue;}
	private:
		int _withRespectTo;
		double _jValue;
	};
	int GetNumberChangedByReaction(int chemicalNumber);
	void DoReactionOnce();
	Reaction();
	Reaction(std::string reactionName);
	virtual ~Reaction();	
	std::vector<Chemical *> *GetChemicals();
	virtual double GetRate() const = 0;	
	virtual std::vector<JElement *> *GetChemicalJacobian() = 0;
	virtual std::string GetTeXForm() const {return m_sTeXForm;}
	virtual void SetTeXForm() = 0;
	std::string GetName() const {return reactionName;}
protected:
	// For stochastic simulations, should probably store the rate last
	// calculated, and store a bool that tells whether any neighboring 
	// chemical has changed concentration. Would need a member function
	// for alerting the reaction, called in SetAmount for the chemical.

	// Reactions that depend or affect the chemical
	std::vector<Chemical *> chemicals;	
	// Name explains it all
	std::vector<int> numberOfEachChemicalChangedByReaction;	
	// Rate constants for this reaction
	std::vector<RateConstant *> rateConstants;
	// Jacobian w.r.t. variables (chemicals)
	std::vector<JElement *> chemicalJacobian;
	// string for name of reaction
	std::string reactionName;
	// string giving TeX formatted reaction term
	std::string m_sTeXForm;
};

#endif // !defined(AFX_REACTION_H__17E9EE60_DB43_11D3_8099_00A0C9B3BB18__INCLUDED_)
