// ReactionMover.h: interface for the CReactionMover class.
//
//////////////////////////////////////////////////////////////////////

#include "ReactionNetwork.h"
#include <fstream.h>

#if !defined(AFX_REACTIONMOVER_H__9391CECD_F146_11D3_8680_00A0C9B3BAB6__INCLUDED_)
#define AFX_REACTIONMOVER_H__9391CECD_F146_11D3_8680_00A0C9B3BAB6__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

class CReactionMover : public Subject
{
public:
	CReactionMover();
	CReactionMover(int seed, double frequency);
	virtual ~CReactionMover();
	virtual void Move(double xInitial, double xFinal, ReactionNetwork *pReactionNetwork) = 0;
	int GetTimeCount() const {return m_iCount;}
	int GetSeed() const {return m_iSeed;}
	ReactionNetwork *GetReactionNetwork() {return m_pReactionNetwork;}
	bool MoveTimeIsZero(double deltaTime);
	virtual void SetMinStepSize(double size) {m_dMinStepSize = size;}
	virtual double GetMinStepSize() const {return m_dMinStepSize;}
	virtual void SetMaxStepSize(double size) {m_dMaxStepSize = size;}
	virtual double GetMaxStepSize() const {return m_dMaxStepSize;}
	virtual void IncrementTotalSteps() {m_iTotalStepsTaken++;}
	virtual int GetTotalStepsTaken() const {return m_iTotalStepsTaken;}
	virtual void ResetStepStatistics(double interval);
protected:
	double m_dTime;
	int m_iCount;
	int m_iSeed;
	double m_dFrequency;
	ReactionNetwork *m_pReactionNetwork;
	// smallest stepsize used; may only be useful for var. step diff. eq. movers
	double m_dMinStepSize;
	// largest stepsize used; may only be useful for var. step diff. eq. movers
	double m_dMaxStepSize;
	// total number of steps taken; may only be useful for var. step diff. eq. movers
	int m_iTotalStepsTaken;

};

#endif // !defined(AFX_REACTIONMOVER_H__9391CECD_F146_11D3_8680_00A0C9B3BAB6__INCLUDED_)
