// ReactionNetwork.h: interface for the ReactionNetwork class.
//
//////////////////////////////////////////////////////////////////////

#if !defined(AFX_REACTIONNETWORK_H__17E9EE61_DB43_11D3_8099_00A0C9B3BB18__INCLUDED_)
#define AFX_REACTIONNETWORK_H__17E9EE61_DB43_11D3_8099_00A0C9B3BB18__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#include <vector>
#include <iostream>
#include <fstream.h>
#include <strstrea.h>
#include <algorithm>
#include "Reaction.h"
#include "Chemical.h"
#include "RateConstant.h"
#include "SubjectObserver.h"

class Reaction;		// Avoid recursion
class Chemical;
class RateConstant;

class ReactionNetwork
{
public:
	ReactionNetwork();
	virtual ~ReactionNetwork();
	virtual Chemical *GetChemical(int chemicalNumber);
	virtual RateConstant *GetRateConstant(int rateConstantNumber);
	virtual Reaction *GetReaction(int reactionNumber);
	virtual int GetNumberOfRateConstants() const;
	virtual int GetNumberOfReactions() const;
	virtual int GetNumberOfChemicals() const;
	virtual int GetNumberOfAlgebraicChemicals() const;
	virtual void SetAmount(int chemicalNumber, double amount);
	virtual void AddAlgebraicIndex(Chemical *chemical);
	virtual void ChemicalReset();
	virtual void RateConstantReset();
	virtual std::vector<int> *GetAlgebraicIndices();
	virtual std::vector<Reaction*> *GetReactions();
	virtual std::vector<Chemical*> *GetChemicals();
	virtual std::vector<RateConstant*> *GetRateConstants();
	virtual std::vector<double> *GetReactionRates();
	// this could be a dangerous function, but used properly it allows one to 
	// model simple Loss-of-Function mutations without changing the number of
	// parameters (very useful for ensembles where a couple of the networks 
	// are only different in a subtle way)
	virtual void RemoveReaction(int rxnNumber);
	virtual void DumpTeXForm(std::string fileName);
	virtual void DumpPetriNetDotFile(std::string fileName);
	virtual int GetNTermsPerLine() {return 1;}
	virtual bool GetLRGraph() {return false;}
protected:	// Probably should be private!  protected should be fine.
	std::vector<Chemical*> chemicals;
	std::vector<Reaction*> reactions;
	std::vector<RateConstant*> rateConstants;	
	std::vector<double> reactionRates;
	std::vector<int> algebraicIndices;
};

#endif // !defined(AFX_REACTIONNETWORK_H__17E9EE61_DB43_11D3_8099_00A0C9B3BB18__INCLUDED_)
