// RungeKuttaMover.cpp: implementation of the CRungeKuttaMover class.
//
//////////////////////////////////////////////////////////////////////

#include "RungeKuttaMover.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

CRungeKuttaMover::CRungeKuttaMover()
{

}

CRungeKuttaMover::CRungeKuttaMover(double frequency,double stepSize)
:CDifferentialEquationMover(frequency,stepSize)
{

}

CRungeKuttaMover::~CRungeKuttaMover()
{

}

void CRungeKuttaMover::Move(double xInitial, double xFinal, ReactionNetwork *pReactionNetwork)
{
	double xInterval = xFinal-xInitial;
	if(this->MoveTimeIsZero(xInterval)) {return;}
	if(m_dStepSize > xInterval) {m_dStepSize = xInterval;}

	// set the member pointer to the network pointer passed in
	this->m_pReactionNetwork = pReactionNetwork;

	int dataCnt=0;
	int nChem = m_pReactionNetwork->GetNumberOfChemicals();
	double *chem = new double[nChem];
	double *dChemdt = new double[nChem];
	int freq = 1/m_dStepSize;
	
	double nextTime = xInitial;

	m_dTime = xInitial;
	// may be unsafe if xInitial has a fractional part! Most likely the storage of time 
	// series data will be altered before this is a problem.
	m_iCount = (int) xInitial;

	for (int cNum = 0; cNum < nChem; cNum++)
	{
		chem[cNum] = m_pReactionNetwork->GetChemical(cNum)->GetAmount();
	}	

	while(m_dTime < xFinal)
	{
		while(m_dTime < nextTime)
		{
			RungeKuttaStep(nChem,chem,dChemdt);
			m_dTime += m_dStepSize;
		}
		
		//dataCnt++;

		//if ( ((dataCnt-1) % freq) == 0 )
		//if(m_dTime == nextTime)
		//{
			m_iCount++;
			// before notification, make sure chemical conc. are current
			for(int i = 0; i < nChem; i++)
			{
				m_pReactionNetwork->GetChemical(i)->SetAmount(chem[i]);
			}
			Notify();	// Notify observers of end of time step
			nextTime += 1.0;
		//}

		//RungeKuttaStep(nChem,chem,dChemdt);
		//m_dTime += m_dStepSize;
	}

	// free memory

	delete [] chem;
	delete [] dChemdt;
}