// SingleNetworkMinimizable.h: interface for the SingleNetworkMinimizable class.
//
//////////////////////////////////////////////////////////////////////

#if !defined(AFX_SINGLENETWORKMINIMIZABLE_H__8F38BFB2_7B39_41DB_A979_3A20AD69180D__INCLUDED_)
#define AFX_SINGLENETWORKMINIMIZABLE_H__8F38BFB2_7B39_41DB_A979_3A20AD69180D__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#include <iomanip.h>
#include <cmath>
#include <assert.h>
#include "SubjectObserver.h"
#include "NLLSMinimizable.h"
#include "Experiment.h"
#include "ReactionMover.h"
#include "CellAverageObserver.h"
#include "ConversionFactor.h"

class SingleNetworkMinimizable : public NLLSMinimizable, public Subject  
{
public:
	// default construction gives no free parameters (nothing to optimize)
	SingleNetworkMinimizable();
	SingleNetworkMinimizable(Experiment *experiment,CReactionMover *reactionMover,bool rateConstantsOptimizable,bool initialChemConcOptimizable,bool logsInObjectiveFunction,double timeSeriesWeight,double rateConstantsWeight,double initialChemConcWeight,int nCells=1);
	// probably only necessary temporarily
	void Initialize(Experiment *experiment, CReactionMover *reactionMover, int nCells, bool rateConstantsOptimizable, bool initialChemConcOptimizable, bool logsInObjectiveFunction, double timeSeriesWeight, double rateConstantsWeight, double initialChemConcWeight);
	virtual ~SingleNetworkMinimizable();
	// Get() functions
	Experiment *GetExperiment() {return experiment;}
	CellAverageObserver *GetCellObserver() {return cellObserver;}
	int GetNCells() {return nCells;} 
	bool GetRateConstantsOptimizable() const {return rateConstantsOptimizable;}
	bool GetInitialChemConcOptimizable() const {return initialChemConcOptimizable;}
	bool GetLogsInObjectiveFunction() const {return logsInObjectiveFunction;}
	double GetTimeSeriesWeight() const {return timeSeriesWeight;}
	double GetRateConstantsWeight() const {return rateConstantsWeight;}
	double GetInitialChemConcWeight() const {return initialChemConcWeight;}
	void SetTimeSeriesWeight(double timeSeriesWeight) {this->timeSeriesWeight = timeSeriesWeight;}
	void SetRateConstantsWeight(double rateConstantsWeight) {this->rateConstantsWeight = rateConstantsWeight;}
	void SetInitialChemConcWeight(double initialChemConcWeight) {this->initialChemConcWeight = initialChemConcWeight;}
	//double *GetParameters();
	double GetParameter(int parIndex);
	// overloaded from base classes
	int GetNParameters();
	double ComputeResiduals(double *parameters);
	CConversionFactor *GetConversionFactor(int factorIndex) {return m_pConversionFactors[factorIndex];} 
	virtual double ComputeES(double *parameters, double T);
	virtual double EntropyShift(double T);
	virtual double F(double *parameters, double T);
	virtual double F0(double *parameters, double T);
	int GetNBFactors() {return m_iNBFactors;}
private:
	bool rateConstantsOptimizable;
	bool initialChemConcOptimizable;
	bool logsInObjectiveFunction;
	Experiment *experiment;
	CReactionMover *reactionMover;
	CellAverageObserver *cellObserver;
	int nCells;
	double timeSeriesWeight;
	double rateConstantsWeight;
	double initialChemConcWeight;
	double *initialNetworkData;
	double *currentNetworkData;
	std::vector<CConversionFactor *> m_pConversionFactors;
	// maybe don't need
	int m_iNBFactors;
};

#endif // !defined(AFX_SINGLENETWORKMINIMIZABLE_H__8F38BFB2_7B39_41DB_A979_3A20AD69180D__INCLUDED_)
