// SubjectObserver.h: interface for the Subject and Observer classes
//
//////////////////////////////////////////////////////////////////////

// Adapted from the Subject-Observer section of 
// "Design Patterns, Elements of Reusable Object-Oriented Software"
// by E. Gamma, R. Helm, R. Johnson, and J. Vlissides, 
// Addison Wesley, Massachusetts, 1995
// ISBN 0-201-63361-2


#ifndef OBSERVER_H
#define OBSERVER_H

#ifndef SWIG
#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000
#endif

#include <list>
// #include "Introspective.h"

class Subject;

// class Observer : public Introspective
class Observer
{
public:
	virtual ~Observer() {};
	virtual void Update(Subject *theChangedSubject) = 0;

protected:
	Observer()
	{
/*		// Drew's registration with MOP: allows Get and Set functions to be called
		// from dialog boxes, in serialization, and for copying
		if (NotYetRegistered("Observer",typeid(*this))) 
		{
			AddType("Observer",typeid(*this));
		} */
	} 
};

class Subject  
{
public:
	virtual ~Subject() 
	{
		delete _observers;
	}
	virtual void  Attach(Observer* o) 
	{
		_observers->push_back(o);
	}
	virtual void Detach(Observer* o) 
	{
		_observers->remove(o);
	}
	virtual void Notify() 
	{
		std::list<Observer*>::iterator i = _observers->begin();
		while (i != _observers->end()) 
		{
			(*i)->Update(this);
			i++;
		}
	}

protected:
#ifndef SWIG // XXX SWIG doesn't support standard template libraries
	Subject() 
	{
		_observers = new std::list<Observer*>;
	}
#endif // SWIG
private:
#ifndef SWIG // XXX SWIG doesn't support standard template libraries
	std::list<Observer*> *_observers;
#endif // SWIG
};

#endif // !defined(OBSERVER_H)
