// TimeVectorPoint.h: interface for the TimeVectorPoint class.
//		TimeVectorPoint is the base for the TimeVectorClass, which
// stores times, chemical names, and chemical numbers to be used in 
// ReactionMovers and NetworkMinimizables.  TimeVectorPointComparator
// allows us to compare pointers to TimeVectorPoints based on their
// time of occurence - used for STL algorithms that need a predicate.
//////////////////////////////////////////////////////////////////////

#if !defined(AFX_TIMEVECTORPOINT_H__D18AB655_3F6E_47E9_B3B2_3A086CA5736D__INCLUDED_)
#define AFX_TIMEVECTORPOINT_H__D18AB655_3F6E_47E9_B3B2_3A086CA5736D__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#include <string>

class TimeVectorPoint  
{
public:
	TimeVectorPoint(double time=0.0,int vectorIndex=0,int chemNumber=0);
	virtual ~TimeVectorPoint();
	int GetChemNumber() {return chemNumber;}
	double GetTime() {return time;}
	int GetVectorIndex() {return vectorIndex;}
	void SetChemNumber(int chemNumber) {this->chemNumber = chemNumber;}
	void SetTime(double time) {this->time = time;}
	void SetVectorIndex(int vectorIndex) {this->vectorIndex = vectorIndex;}
	class TimeVectorPointComparator
	{
	public:
		TimeVectorPointComparator() {return;}
		virtual ~TimeVectorPointComparator() {return;}
		bool operator()(TimeVectorPoint *t1, TimeVectorPoint *t2)
		{
			return t1->GetTime() < t2->GetTime();
		}
	};
private:
	int chemNumber;
	int vectorIndex;
	double time;
};

#endif // !defined(AFX_TIMEVECTORPOINT_H__D18AB655_3F6E_47E9_B3B2_3A086CA5736D__INCLUDED_)
