// TranscriptionReaction.cpp: implementation of the TranscriptionReaction class.
//
//////////////////////////////////////////////////////////////////////

#ifdef _WINDOWS
#include "stdafx.h"
#endif

#include "TranscriptionReaction.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

TranscriptionReaction::TranscriptionReaction(Chemical *freePromoter, Chemical *mRNA, RateConstant *ktm,std::string reactionName)
:Reaction(reactionName)
{

	int numChemicals = 0;


	chemicals.push_back(freePromoter);
	this->freePromoter = numChemicals;	// Number in private array
	numChemicals++;
	numberOfEachChemicalChangedByReaction.push_back(0);

	chemicals.push_back(mRNA);
	this->mRNA = numChemicals;	// Number in private array
	numChemicals ++;
	numberOfEachChemicalChangedByReaction.push_back(+1);

	
	int numRateConstants = 0;

	rateConstants.push_back(ktm);
	this->ktm = numRateConstants;
	numRateConstants++;

	// put enough dummy chemicalJacobian elements on the vector 
	// - they are recomputed every time you ask for the chemicalJacobian
	chemicalJacobian.push_back(new JElement(-1,-1));

	this->SetTeXForm();
}

TranscriptionReaction::~TranscriptionReaction()
{

}

double TranscriptionReaction::GetRate() const
{
	return rateConstants[ktm]->GetValue() * chemicals[freePromoter]->GetAmount();
}

void TranscriptionReaction::SetTeXForm()
{
	strstream stream;
	// TeX form of the reaction
	stream << rateConstants[ktm]->GetTeXName().c_str();
	stream << "\\left [" << chemicals[freePromoter]->GetTeXName().c_str();
	stream << "\\right ]";
	// add a NULL
	stream << ends;
	// set the TeX string equal to what's in the stream
	m_sTeXForm = stream.str();
	// allow memory to be freed
	stream.rdbuf()->freeze(0);
}

std::vector<Reaction::JElement *> *TranscriptionReaction::GetChemicalJacobian()
{	
	return &chemicalJacobian;
}