// TransformationReaction.cpp: implementation of the TransformationReaction class.
//
//////////////////////////////////////////////////////////////////////

#include "TransformationReaction.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

TransformationReaction::TransformationReaction(Chemical *OldForm, Chemical *NewForm, RateConstant *k_trans, std::string reactionName)
:Reaction(reactionName)
{
	// stoichiometry
	this->OldForm = chemicals.size();
	chemicals.push_back(OldForm);
	numberOfEachChemicalChangedByReaction.push_back(-1);

	this->NewForm = chemicals.size();
	chemicals.push_back(NewForm);
	numberOfEachChemicalChangedByReaction.push_back(+1);

	// rates
	this->k_trans = rateConstants.size();
	rateConstants.push_back(k_trans);

	// put enough dummy chemicalJacobian elements on the vector 
	// - they are recomputed every time you ask for the chemicalJacobian
	chemicalJacobian.push_back(new JElement(-1,-1));

	this->SetTeXForm();
}

TransformationReaction::~TransformationReaction()
{

}

double TransformationReaction::GetRate() const
{
	return rateConstants[k_trans]->GetValue() * chemicals[OldForm]->GetAmount();
}

void TransformationReaction::SetTeXForm()
{
	strstream stream;
	// TeX form of the reaction
	stream << rateConstants[k_trans]->GetTeXName().c_str();
	stream << "\\left [" << chemicals[OldForm]->GetTeXName().c_str();
	stream << "\\right ]";
	// add a NULL
	stream << ends;
	// set the TeX string equal to what's in the stream
	m_sTeXForm = stream.str();
	// allow memory to be freed
	stream.rdbuf()->freeze(0);
}

std::vector<Reaction::JElement *> *TransformationReaction::GetChemicalJacobian()
{
	chemicalJacobian[0]->SetWithRespectTo(chemicals[OldForm]->GetChemicalNumber());
	chemicalJacobian[0]->SetJValue(rateConstants[k_trans]->GetValue());
	
	return &chemicalJacobian;
}
