// UnaryDegradationReaction.cpp: implementation of the UnaryDegradationReaction class.
//
//////////////////////////////////////////////////////////////////////

#include "UnaryDegradationReaction.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

UnaryDegradationReaction::UnaryDegradationReaction(Chemical *UnstableChemical, RateConstant *k_deg, std::string reactionName)
:Reaction(reactionName)
{
	// stoichiometry
	this->UnstableChemical = chemicals.size();
	chemicals.push_back(UnstableChemical);
	numberOfEachChemicalChangedByReaction.push_back(-1);
	
	// rates
	this->k_deg = rateConstants.size();
	rateConstants.push_back(k_deg);

	// put enough dummy chemicalJacobian elements on the vector 
	// - they are recomputed every time you ask for the chemicalJacobian
	chemicalJacobian.push_back(new JElement(-1,-1));

	this->SetTeXForm();
}

UnaryDegradationReaction::~UnaryDegradationReaction()
{

}

double UnaryDegradationReaction::GetRate() const
{
	return rateConstants[k_deg]->GetValue() * chemicals[UnstableChemical]->GetAmount();
}

void UnaryDegradationReaction::SetTeXForm()
{
	strstream stream;
	// TeX form of the reaction
	stream << rateConstants[k_deg]->GetTeXName().c_str();
	stream << "\\left [" << chemicals[UnstableChemical]->GetTeXName().c_str();
	stream << "\\right ]";
	// add a NULL
	stream << ends;
	// set the TeX string equal to what's in the stream
	m_sTeXForm = stream.str();
	// allow memory to be freed
	stream.rdbuf()->freeze(0);
}

std::vector<Reaction::JElement *> *UnaryDegradationReaction::GetChemicalJacobian()
{
	chemicalJacobian[0]->SetWithRespectTo(chemicals[UnstableChemical]->GetChemicalNumber());
	chemicalJacobian[0]->SetJValue(rateConstants[k_deg]->GetValue());
	
	return &chemicalJacobian;
}
