// ZeroTAnnealMinimizer.cpp: implementation of the ZeroTAnnealMinimizer class.
//
//////////////////////////////////////////////////////////////////////

#include "ZeroTAnnealMinimizer.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

ZeroTAnnealMinimizer::ZeroTAnnealMinimizer()
{

}

ZeroTAnnealMinimizer::ZeroTAnnealMinimizer(int seed, int nSteps)
{
	this->seed = seed;
	this->nSteps = nSteps;
}

ZeroTAnnealMinimizer::~ZeroTAnnealMinimizer()
{

}

double ZeroTAnnealMinimizer::Minimize(double *parameters, Minimizable *minimizable)
{
	Rand *RNG = new Rand(seed);
	double currentCost;
	double bestCost;
	nParameters = minimizable->GetNParameters();
	double *trial = new double[nParameters];

	// compute the cost for the initial parameter values
	bestCost = minimizable->ObjectiveFunction(parameters);

	cout << "Starting cost of " << bestCost << endl;

	for(int iterationStep = 1; iterationStep <= nSteps; iterationStep++)
	{
		// now construct a set of trial values
		// this method adds between -(1/2)value and (1/2)value to each parameter
		// to form the trial set of parameters
		for(int i = 0; i < nParameters; i++)
		{
			double temp = parameters[i];
			temp = temp + (-0.5 + 1*(RNG->uniform()))*temp;
			trial[i] = temp;
		} 
		currentCost = minimizable->ObjectiveFunction(trial);

		if(currentCost < bestCost)
		{	
			bestCost = currentCost;
			*parameters = *trial;
		}

		cout << "Current best cost is " << bestCost << " at iteration number " << iterationStep << endl;
	}

	// cleanup
	delete [] trial;
	delete RNG;

	// return the best cost
	return bestCost;
}

