// AlternateOneGeneInhibitoryNetworkMinimizableDirector.cpp: implementation of the CAlternateOneGeneInhibitoryNetworkMinimizableDirector class.
//
//////////////////////////////////////////////////////////////////////

#include "AlternateOneGeneInhibitoryNetworkMinimizableDirector.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

CAlternateOneGeneInhibitoryNetworkMinimizableDirector::CAlternateOneGeneInhibitoryNetworkMinimizableDirector()
{
	double maxSimTime = 91.0;
	double stepSize = 0.0001;
	double frequency = 1.0;
	int nCells = 1;
	double moveTol = 1.0e-06;

	bool rateFlag = true;
	bool chemFlag = false;
	bool logsFlag = false;
	double timeWeight = 1.0;
	double rateWeight = 0.0;
	double chemWeight = 0.0;

	m_dGammaSquared = 1.0e-08;

	// fake experiment 1 - 1 free promoter, no mRNA or protein
	_networkList.push_back(new CAlternateOneGeneInhibitoryNetwork());
	_experimentList.push_back(new Experiment(_networkList[0],"BigNetwork"));
	_experimentList[0]->AddDataFileToList("bigOneGeneDS.dat");
	// mover and plotter
	_moverList.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	m_vpPlotterList.push_back(new GnuPlotterTimeSeriesObserver());
	// title
	m_vpPlotterList[0]->SetTitle("Big OGN:1 Free Promoter:ODE");
	// minimizable
	_minimizableList.push_back(new SingleNetworkMinimizable());
	// parameters
	_minimizableList[0]->Initialize(_experimentList[0],_moverList[0],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	_minimizableList[0]->SetRateConstantsWeight(0.0);
	// attach observer
	_minimizableList[0]->Attach(m_vpPlotterList[0]);

	// allocate the master residuals list
	int masterResidualsSize = 0;
	for(int i = 0; i < _minimizableList.size(); i++)
	{
		masterResidualsSize += _minimizableList[i]->GetNResiduals();
	}
	if(m_dGammaSquared > 0.0)
	{
		masterResidualsSize += 1;
	}
	Allocate(masterResidualsSize);

	cout << "Master Residuals size : " << masterResidualsSize << endl;
 
	// define the experiments
	DefineExperiments();
}

CAlternateOneGeneInhibitoryNetworkMinimizableDirector::~CAlternateOneGeneInhibitoryNetworkMinimizableDirector()
{
	for(int i = 0; i < _minimizableList.size(); i++)
	{
		_minimizableList[i]->Detach(m_vpPlotterList[i]);
	}
	for(i = 0; i < m_vpPlotterList.size(); i++)
	{
		delete m_vpPlotterList[i];
	}
}

void CAlternateOneGeneInhibitoryNetworkMinimizableDirector::DefineExperiments()
{
	// 1 free promoter, no bound, no mRNA, no protein
	_minimizableList[0]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(1.0);
	_minimizableList[0]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->Reset();
	_minimizableList[0]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->SetInitialAmount(0.0);
	_minimizableList[0]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->Reset();
}

double CAlternateOneGeneInhibitoryNetworkMinimizableDirector::GetParameter(int parIndex)
{
	// Just return the first set (they are all the same)
	return _minimizableList[0]->GetParameter(parIndex);
}

int CAlternateOneGeneInhibitoryNetworkMinimizableDirector::GetNParameters()
{
	// Return the size of the first set (all have the same size)
	return _minimizableList[0]->GetNParameters();

}
