// ChemicalSink.cpp: implementation of the CChemicalSink class.
//
//////////////////////////////////////////////////////////////////////

#include "ChemicalSink.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

CChemicalSink::CChemicalSink(Chemical *ChangedChemical, Chemical *SinkChemical, std::string reactionName)
:Reaction(reactionName)
{
	// stoichiometry
	this->ChangedChemical = chemicals.size();
	chemicals.push_back(ChangedChemical);
	numberOfEachChemicalChangedByReaction.push_back(-1);

	this->SinkChemical = chemicals.size();
	chemicals.push_back(SinkChemical);
	numberOfEachChemicalChangedByReaction.push_back(0);

	// put enough dummy chemicalJacobian elements on the vector 
	// - they are recomputed every time you ask for the chemicalJacobian
	chemicalJacobian.push_back(new JElement(-1,-1));

	this->SetTeXForm();


}

CChemicalSink::~CChemicalSink()
{

}

double CChemicalSink::GetRate() const
{
	return chemicals[SinkChemical]->GetAmount();
}

void CChemicalSink::SetTeXForm()
{
	strstream stream;
	// TeX form of the reaction
	stream << chemicals[SinkChemical]->GetTeXName().c_str();
	stream << ends;
	// set the TeX string equal to what's in the stream
	m_sTeXForm = stream.str();
	// allow memory to be freed
	stream.rdbuf()->freeze(0);
}

std::vector<Reaction::JElement *> *CChemicalSink::GetChemicalJacobian()
{
	chemicalJacobian[0]->SetWithRespectTo(chemicals[SinkChemical]->GetChemicalNumber());
	chemicalJacobian[0]->SetJValue(1.0);
	
	return &chemicalJacobian;
}

