// ChemicalSource.cpp: implementation of the CChemicalSource class.
//
//////////////////////////////////////////////////////////////////////

#include "ChemicalSource.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

CChemicalSource::CChemicalSource(Chemical *ChangedChemical, Chemical *SourceChemical, std::string reactionName)
:Reaction(reactionName)
{
	// stoichiometry
	this->ChangedChemical = chemicals.size();
	chemicals.push_back(ChangedChemical);
	numberOfEachChemicalChangedByReaction.push_back(+1);

	this->SourceChemical = chemicals.size();
	chemicals.push_back(SourceChemical);
	numberOfEachChemicalChangedByReaction.push_back(0);

	// put enough dummy chemicalJacobian elements on the vector 
	// - they are recomputed every time you ask for the chemicalJacobian
	chemicalJacobian.push_back(new JElement(-1,-1));

	this->SetTeXForm();


}

CChemicalSource::~CChemicalSource()
{

}

double CChemicalSource::GetRate() const
{
	return chemicals[SourceChemical]->GetAmount();
}

void CChemicalSource::SetTeXForm()
{
	strstream stream;
	// TeX form of the reaction
	stream << chemicals[SourceChemical]->GetTeXName().c_str();
	stream << ends;
	// set the TeX string equal to what's in the stream
	m_sTeXForm = stream.str();
	// allow memory to be freed
	stream.rdbuf()->freeze(0);
}

std::vector<Reaction::JElement *> *CChemicalSource::GetChemicalJacobian()
{
	chemicalJacobian[0]->SetWithRespectTo(chemicals[SourceChemical]->GetChemicalNumber());
	chemicalJacobian[0]->SetJValue(1.0);
	
	return &chemicalJacobian;
}