// CombinatorialNetwork.cpp: implementation of the CCombinatorialNetwork class.
//
//////////////////////////////////////////////////////////////////////

#include "CombinatorialNetwork.h"
#include <iostream>

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

CCombinatorialNetwork::CCombinatorialNetwork()
{
	// chemicals
	// small molecules
	Chemical *IPTG = new Chemical(chemicals.size(), 0.0, "IPTG");
	chemicals.push_back(IPTG);

	Chemical *aTc = new Chemical(chemicals.size(), 0.0, "aTc");
	chemicals.push_back(aTc);

	// proteins
	Chemical *GFP = new Chemical(chemicals.size(),0.0,"GFP");
	chemicals.push_back(GFP);
	
	Chemical *cI = new Chemical(chemicals.size(),0.0,"cI");
	chemicals.push_back(cI);

   	Chemical *FreeTetR = new Chemical(chemicals.size(),0.0,"FreeTetR");
	chemicals.push_back(FreeTetR);
	
	Chemical *BoundTetR = new Chemical(chemicals.size(),0.0,"BoundTetR");
	chemicals.push_back(BoundTetR);
	
	Chemical *FreeLacI = new Chemical(chemicals.size(),0.0,"FreeLacI");
	chemicals.push_back(FreeLacI);
	
	Chemical *BoundLacI = new Chemical(chemicals.size(),0.0,"BoundLacI");
	chemicals.push_back(BoundLacI);

	// promoters
	//Pi - promoter for lacI gene
	Chemical *lacIBoundPromoter = new Chemical(chemicals.size(),0.0,"lacIBoundPromoter");
	chemicals.push_back(lacIBoundPromoter);

	Chemical *lacIFreePromoter = new Chemical(chemicals.size(),4.0,"lacIFreePromoter");
	chemicals.push_back(lacIFreePromoter);

	//Pj - promoter for cI gene
	Chemical *cIBoundPromoter = new Chemical(chemicals.size(),0.0,"cIBoundPromoter");
	chemicals.push_back(cIBoundPromoter);

	Chemical *cIFreePromoter = new Chemical(chemicals.size(),4.0,"cIFreePromoter");
	chemicals.push_back(cIFreePromoter);

	//Pk - promoter for tetR gene
	Chemical *tetRBoundPromoter = new Chemical(chemicals.size(),0.0,"tetRBoundPromoter");
	chemicals.push_back(tetRBoundPromoter);

	Chemical *tetRFreePromoter = new Chemical(chemicals.size(),4.0,"tetRFreePromoter");
	chemicals.push_back(tetRFreePromoter);

	//cI repressible promoter for GFP
	Chemical *GFPBoundPromoter = new Chemical(chemicals.size(),0.0,"GFPBoundPromoter");
	chemicals.push_back(GFPBoundPromoter);

	Chemical *GFPFreePromoter = new Chemical(chemicals.size(),4.0,"GFPFreePromoter");
	chemicals.push_back(GFPFreePromoter);


	// rate constants

	//bind cI to cI repressible promoter
	RateConstant *kbPcIr = new RateConstant(0.005,"kbPcIr");
	rateConstants.push_back(kbPcIr);

	//unbind cI from cI repressible promoter
	RateConstant *kuPcIr = new RateConstant(0.5,"kuPcIr");
	rateConstants.push_back(kuPcIr);

	//bind cI to cI inducible promoter
	RateConstant *kbPcIi = new RateConstant(0.005,"kbPcIi");
	rateConstants.push_back(kbPcIi);

	//unbind cI from cI inducible promoter
	RateConstant *kuPcIi = new RateConstant(0.5,"kuPcIi");
	rateConstants.push_back(kuPcIi);

	//bind free TetR to TetR repressible promoter
	RateConstant *kbPtetRr = new RateConstant(0.005,"kbPtetRr");
	rateConstants.push_back(kbPtetRr);

	//unbind TetR from TetR repressible promoter
	RateConstant *kuPtetRr = new RateConstant(0.5,"kuPtetRr");
	rateConstants.push_back(kuPtetRr);

	//bind free LacI to LacI repressible promoter1
	RateConstant *kbPlacIr1 = new RateConstant(0.005,"kbPlacIr1");
	rateConstants.push_back(kbPlacIr1);

	//unbind LacI  from LacI repressible promoter1
	RateConstant *kuPlacIr1 = new RateConstant(0.5,"kuPlacIr1");
	rateConstants.push_back(kuPlacIr1);

	//bind free LacI to LacI repressible promoter2
	RateConstant *kbPlacIr2 = new RateConstant(0.005,"kbPlacIr2");
	rateConstants.push_back(kbPlacIr2);

	//unbind LacI  from LacI repressible promoter2
	RateConstant *kuPlacIr2 = new RateConstant(0.5,"kuPlacIr2");
	rateConstants.push_back(kuPlacIr2);

	//bind free TetR to aTc
	RateConstant *kbaTcTetR = new RateConstant(0.005, "kbaTcTetR");
	rateConstants.push_back(kbaTcTetR);

	//unbind free TetR from aTc
	RateConstant *kuaTcTetR = new RateConstant(0.5, "kuaTcTetR");
	rateConstants.push_back(kuaTcTetR);

	//bind free LacI to IPTG
	RateConstant *kbIPTGLacI = new RateConstant(0.005,"kbIPTGLacI");
	rateConstants.push_back(kbIPTGLacI);

	//unbind LacI from IPTG
	RateConstant *kuIPTGLacI = new RateConstant(0.5,"kuIPTGLacI");
	rateConstants.push_back(kuIPTGLacI);

	//degrade free cI
	RateConstant *kdcI = new RateConstant(0.5, "kdcI");
	rateConstants.push_back(kdcI);

	//degrade free TetR
	RateConstant *kdTetR = new RateConstant(0.5, "kdTetR");
	rateConstants.push_back(kdTetR);

	//degrade free LacI
	RateConstant *kdLacI = new RateConstant(0.5, "kdLacI");
	rateConstants.push_back(kdLacI);

	//degrade GFP
	RateConstant *kdGFP = new RateConstant(0.1,"kdGFP");
	rateConstants.push_back(kdGFP);

	//these reactions encapsulate both transcription and translation (protein made
	// directly); simple reactions likely not appropriate
	//transcribe cI
	RateConstant *ktcI = new RateConstant(0.5, "ktcI");
	rateConstants.push_back(ktcI);

	//transcribe TetR
	RateConstant *ktTetR = new RateConstant(0.5, "ktTetR");
	rateConstants.push_back(ktTetR);

	//transcribe LacI
	RateConstant *ktLacI = new RateConstant(0.5, "ktLacI");
	rateConstants.push_back(ktLacI);

	//transcribe GFP
	RateConstant *ktGFP = new RateConstant(0.5,"ktGFP");
	rateConstants.push_back(ktGFP);

	// reactions
	// the first 11 reactions should be true for all the networks
	TranscriptionReaction *GFPTranscription = new TranscriptionReaction(GFPFreePromoter, GFP, ktGFP, "GFPTranscription");
	reactions.push_back(GFPTranscription);

	UnstableProteinDegradationReaction *GFPDegradation = new UnstableProteinDegradationReaction(GFP,kdGFP,"GFPDegradation");
	reactions.push_back(GFPDegradation);

	HeterodimerizationReaction *GFPPromoterBinding = new HeterodimerizationReaction(GFPFreePromoter,cI,GFPBoundPromoter,kbPcIr,"GFPPromoterBinding");
	reactions.push_back(GFPPromoterBinding);

	HeterodimerDissociationReaction *GFPPromoterUnbinding = new HeterodimerDissociationReaction(GFPBoundPromoter,GFPFreePromoter,cI,kuPcIr,"GFPPromoterUnbinding");
	reactions.push_back(GFPPromoterUnbinding);

	UnstableProteinDegradationReaction *cIDegradation = new UnstableProteinDegradationReaction(cI,kdcI,"cIDegradation");
	reactions.push_back(cIDegradation);

	UnstableProteinDegradationReaction *FreeLacIDegradation = new UnstableProteinDegradationReaction(FreeLacI,kdLacI,"FreeLacIDegradation");
	reactions.push_back(FreeLacIDegradation);

	UnstableProteinDegradationReaction *FreeTetRDegradation = new UnstableProteinDegradationReaction(FreeTetR,kdTetR,"FreeTetRDegradation");
	reactions.push_back(FreeTetRDegradation);

	HeterodimerizationReaction *IPTGLacIBinding = new HeterodimerizationReaction(IPTG,FreeLacI,BoundLacI,kbIPTGLacI,"IPTGLacIBinding");
	reactions.push_back(IPTGLacIBinding);

	HeterodimerDissociationReaction *IPTGLacIUnbinding = new HeterodimerDissociationReaction(BoundLacI,FreeLacI,IPTG,kuIPTGLacI,"IPTGLacIUnbinding");
	reactions.push_back(IPTGLacIUnbinding);

	HeterodimerizationReaction *aTcTetRBinding = new HeterodimerizationReaction(aTc,FreeTetR,BoundTetR,kbaTcTetR,"aTcTetRBinding");
	reactions.push_back(aTcTetRBinding);

	HeterodimerDissociationReaction *aTcTetRUnbinding = new HeterodimerDissociationReaction(BoundTetR,FreeTetR,aTc,kuaTcTetR,"aTcTetRUnbinding");
	reactions.push_back(aTcTetRUnbinding);

	// the following reactions are not true for all the networks
	//for cI governed by any repressible promoter (rxn 11)
	TranscriptionReaction *cITranscriptionFromFreePromoter = new TranscriptionReaction(cIFreePromoter, cI, ktcI, "cITranscriptionFromFreePromoter");
	reactions.push_back(cITranscriptionFromFreePromoter);

	//for cI governed by any inducible promoter (rxn 12)
	TranscriptionReaction *cITranscriptionFromBoundPromoter = new TranscriptionReaction(cIBoundPromoter, cI, ktcI, "cITranscriptionFromBoundPromoter");
	reactions.push_back(cITranscriptionFromBoundPromoter);

	//for tetR governed by any repressible promoter (rxn 13)
	TranscriptionReaction *TetRTranscriptionFromFreePromoter = new TranscriptionReaction(tetRFreePromoter, FreeTetR, ktTetR, "TetRTranscriptionFromFreePromoter");
	reactions.push_back(TetRTranscriptionFromFreePromoter);

	//for tetR governed by any inducible promoter (rxn 14)
	TranscriptionReaction *TetRTranscriptionFromBoundPromoter = new TranscriptionReaction(tetRBoundPromoter, FreeTetR, ktTetR, "TetRTranscriptionFromBoundPromoter");
	reactions.push_back(TetRTranscriptionFromBoundPromoter);

	//for lacI governed by any repressible promoter (rxn 15)
	TranscriptionReaction *LacITranscriptionFromFreePromoter = new TranscriptionReaction(lacIFreePromoter, FreeLacI, ktLacI, "LacITranscriptionFromFreePromoter");
	reactions.push_back(LacITranscriptionFromFreePromoter);

	//for lacI governed by any inducible promoter (rxn 16)
	TranscriptionReaction *LacITranscriptionFromBoundPromoter = new TranscriptionReaction(lacIBoundPromoter, FreeLacI, ktLacI, "LacITranscriptionFromBoundPromoter");
	reactions.push_back(LacITranscriptionFromBoundPromoter);

	//lacI promoter varieties:
	//use next two if lacI governed by cI repressible promoter (rxns 17,18)
	HeterodimerizationReaction *BindingcIRepressibleLacIPromoter = new HeterodimerizationReaction(cI, lacIFreePromoter, lacIBoundPromoter, kbPcIr, "BindingcIRepressibleLacIPromoter");
	reactions.push_back(BindingcIRepressibleLacIPromoter);

	HeterodimerDissociationReaction *UnbindingcIRepressibleLacIPromoter = new HeterodimerDissociationReaction(lacIBoundPromoter, lacIFreePromoter, cI, kuPcIr, "UnbindingcIRepressibleLacIPromoter");
	reactions.push_back(UnbindingcIRepressibleLacIPromoter);

	//use next two if lacI governed by cI inducible promoter (rxns 19,20)
	HeterodimerizationReaction *BindingcIInducibleLacIPromoter = new HeterodimerizationReaction(cI, lacIFreePromoter, lacIBoundPromoter, kbPcIi, "BindingcIInducibleLacIPromoter");
	reactions.push_back(BindingcIInducibleLacIPromoter);

	HeterodimerDissociationReaction *UnbindingcIInducibleLacIPromoter = new HeterodimerDissociationReaction(lacIBoundPromoter, lacIFreePromoter, cI, kuPcIi, "UnbindingcIInducibleLacIPromoter");
	reactions.push_back(UnbindingcIInducibleLacIPromoter);

	//use next two if lacI governed by tetR repressible promoter (rxns 21,22)
	HeterodimerizationReaction *BindingTetRRepressibleLacIPromoter = new HeterodimerizationReaction(FreeTetR, lacIFreePromoter, lacIBoundPromoter, kbPtetRr, "BindingTetRRepressibleLacIPromoter");
	reactions.push_back(BindingTetRRepressibleLacIPromoter);

	HeterodimerDissociationReaction *UnbindingTetRRepressibleLacIPromoter = new HeterodimerDissociationReaction(lacIBoundPromoter, lacIFreePromoter, FreeTetR, kuPcIi, "UnbindingTetRRepressibleLacIPromoter");
	reactions.push_back(UnbindingTetRRepressibleLacIPromoter);

	//use next two if lacI governed by lacI repressible promoter 1 (rxns 23,24)
	HeterodimerizationReaction *BindingLacIRepressible1LacIPromoter = new HeterodimerizationReaction(FreeLacI, lacIFreePromoter, lacIBoundPromoter, kbPlacIr1, "BindingLacIRepressible1LacIPromoter");
	reactions.push_back(BindingLacIRepressible1LacIPromoter);

	HeterodimerDissociationReaction *UnbindingLacIRepressible1LacIPromoter = new HeterodimerDissociationReaction(lacIBoundPromoter, lacIFreePromoter, FreeLacI, kuPlacIr1, "UnbindingLacIRepressible1LacIPromoter");
	reactions.push_back(UnbindingLacIRepressible1LacIPromoter);

	//use next two if lacI governed by lacI repressible promoter 2 (rxns 25,26)
	HeterodimerizationReaction *BindingLacIRepressible2LacIPromoter = new HeterodimerizationReaction(FreeLacI, lacIFreePromoter, lacIBoundPromoter, kbPlacIr2, "BindingLacIRepressible2LacIPromoter");
	reactions.push_back(BindingLacIRepressible2LacIPromoter);

	HeterodimerDissociationReaction *UnbindingLacIRepressible2LacIPromoter = new HeterodimerDissociationReaction(lacIBoundPromoter, lacIFreePromoter, FreeLacI, kuPlacIr2, "UnbindingLacIRepressible2LacIPromoter");
	reactions.push_back(UnbindingLacIRepressible2LacIPromoter);

	//tetR promoter varieties:
	//use next two if tetR governed by cI repressible promoter (rxns 27,28)
	HeterodimerizationReaction *BindingcIRepressibleTetRPromoter = new HeterodimerizationReaction(cI, tetRFreePromoter, tetRBoundPromoter, kbPcIr, "BindingcIRepressibleTetRPromoter");
	reactions.push_back(BindingcIRepressibleTetRPromoter);

	HeterodimerDissociationReaction *UnbindingcIRepressibleTetRPromoter = new HeterodimerDissociationReaction(tetRBoundPromoter, tetRFreePromoter, cI, kuPcIr, "UnbindingcIRepressibleTetRPromoter");
	reactions.push_back(UnbindingcIRepressibleTetRPromoter);

	//use next two if tetR governed by cI inducible promoter (rxns 29,30)
	HeterodimerizationReaction *BindingcIInducibleTetRPromoter = new HeterodimerizationReaction(cI, tetRFreePromoter, tetRBoundPromoter, kbPcIi, "BindingcIInducibleTetRPromoter");
	reactions.push_back(BindingcIInducibleTetRPromoter);

	HeterodimerDissociationReaction *UnbindingcIInducibleTetRPromoter = new HeterodimerDissociationReaction(tetRBoundPromoter, tetRFreePromoter, cI, kuPcIi, "UnbindingcIInducibleTetRPromoter");
	reactions.push_back(UnbindingcIInducibleTetRPromoter);

	//use next two if tetR governed by tetR repressible promoter (rxns 31,32)
	HeterodimerizationReaction *BindingTetRRepressibleTetRPromoter = new HeterodimerizationReaction(FreeTetR, tetRFreePromoter, tetRBoundPromoter, kbPtetRr, "BindingTetRRepressibleTetRPromoter");
	reactions.push_back(BindingTetRRepressibleTetRPromoter);

	HeterodimerDissociationReaction *UnbindingTetRRepressibleTetRPromoter = new HeterodimerDissociationReaction(tetRBoundPromoter, tetRFreePromoter, FreeTetR, kuPcIi, "UnbindingTetRRepressibleTetRPromoter");
	reactions.push_back(UnbindingTetRRepressibleTetRPromoter);

	//use next two if tetR governed by lacI repressible promoter 1 (rxns 33,34)
	HeterodimerizationReaction *BindingLacIRepressible1TetRPromoter = new HeterodimerizationReaction(FreeLacI, tetRFreePromoter, tetRBoundPromoter, kbPlacIr1, "BindingLacIRepressible1TetRPromoter");
	reactions.push_back(BindingLacIRepressible1TetRPromoter);

	HeterodimerDissociationReaction *UnbindingLacIRepressible1TetRPromoter = new HeterodimerDissociationReaction(tetRBoundPromoter, tetRFreePromoter, FreeLacI, kuPlacIr1, "UnbindingLacIRepressible1TetRPromoter");
	reactions.push_back(UnbindingLacIRepressible1TetRPromoter);

	//use next two if tetR governed by lacI repressible promoter 2 (rxns 35,36)
	HeterodimerizationReaction *BindingLacIRepressible2TetRPromoter = new HeterodimerizationReaction(FreeLacI, tetRFreePromoter, tetRBoundPromoter, kbPlacIr2, "BindingLacIRepressible2TetRPromoter");
	reactions.push_back(BindingLacIRepressible2TetRPromoter);

	HeterodimerDissociationReaction *UnbindingLacIRepressible2TetRPromoter = new HeterodimerDissociationReaction(tetRBoundPromoter, tetRFreePromoter, FreeLacI, kuPlacIr2, "UnbindingLacIRepressible2TetRPromoter");
	reactions.push_back(UnbindingLacIRepressible2TetRPromoter);

	//cI promoter varieties:
	//use next two if cI governed by cI repressible promoter (rxns 37,38)
	HeterodimerizationReaction *BindingcIRepressiblecIPromoter = new HeterodimerizationReaction(cI, cIFreePromoter, cIBoundPromoter, kbPcIr, "BindingcIRepressiblecIPromoter");
	reactions.push_back(BindingcIRepressiblecIPromoter);

	HeterodimerDissociationReaction *UnbindingcIRepressiblecIPromoter = new HeterodimerDissociationReaction(cIBoundPromoter, cIFreePromoter, cI, kuPcIr, "UnbindingcIRepressiblecIPromoter");
	reactions.push_back(UnbindingcIRepressiblecIPromoter);

	//use next two if cI governed by cI inducible promoter (rxns 39,40)
	HeterodimerizationReaction *BindingcIInduciblecIPromoter = new HeterodimerizationReaction(cI, cIFreePromoter, cIBoundPromoter, kbPcIi, "BindingcIInduciblecIPromoter");
	reactions.push_back(BindingcIInduciblecIPromoter);

	HeterodimerDissociationReaction *UnbindingcIInduciblecIPromoter = new HeterodimerDissociationReaction(cIBoundPromoter, cIFreePromoter, cI, kuPcIi, "UnbindingcIInduciblecIPromoter");
	reactions.push_back(UnbindingcIInduciblecIPromoter);

	//use next two if cI governed by tetR repressible promoter (rxns 41,42)
	HeterodimerizationReaction *BindingTetRRepressiblecIPromoter = new HeterodimerizationReaction(FreeTetR, cIFreePromoter, cIBoundPromoter, kbPtetRr, "BindingTetRRepressiblecIPromoter");
	reactions.push_back(BindingTetRRepressiblecIPromoter);

	HeterodimerDissociationReaction *UnbindingTetRRepressiblecIPromoter = new HeterodimerDissociationReaction(cIBoundPromoter, cIFreePromoter, FreeTetR, kuPcIi, "UnbindingTetRRepressiblecIPromoter");
	reactions.push_back(UnbindingTetRRepressiblecIPromoter);

	//use next two if cI governed by lacI repressible promoter 1 (rxns 43,44)
	HeterodimerizationReaction *BindingLacIRepressible1cIPromoter = new HeterodimerizationReaction(FreeLacI, cIFreePromoter, cIBoundPromoter, kbPlacIr1, "BindingLacIRepressible1cIPromoter");
	reactions.push_back(BindingLacIRepressible1cIPromoter);

	HeterodimerDissociationReaction *UnbindingLacIRepressible1cIPromoter = new HeterodimerDissociationReaction(cIBoundPromoter, cIFreePromoter, FreeLacI, kuPlacIr1, "UnbindingLacIRepressible1cIPromoter");
	reactions.push_back(UnbindingLacIRepressible1cIPromoter);

	//use next two if cI governed by lacI repressible promoter 2 (rxns 45,46)
	HeterodimerizationReaction *BindingLacIRepressible2cIPromoter = new HeterodimerizationReaction(FreeLacI, cIFreePromoter, cIBoundPromoter, kbPlacIr2, "BindingLacIRepressible2cIPromoter");
	reactions.push_back(BindingLacIRepressible2cIPromoter);

	HeterodimerDissociationReaction *UnbindingLacIRepressible2cIPromoter = new HeterodimerDissociationReaction(cIBoundPromoter, cIFreePromoter, FreeLacI, kuPlacIr2, "UnbindingLacIRepressible2cIPromoter");
	reactions.push_back(UnbindingLacIRepressible2cIPromoter);

}

CCombinatorialNetwork::~CCombinatorialNetwork()
{

}
