// CombinatorialNetworkMinimizableDirector.cpp: implementation of the CCombinatorialNetworkMinimizableDirector class.
//
//////////////////////////////////////////////////////////////////////

#include "CombinatorialNetworkMinimizableDirector.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

CCombinatorialNetworkMinimizableDirector::CCombinatorialNetworkMinimizableDirector()
{
	// counter for experimet number
	int expt = -1;
	// create networks,experiments,observers,movers,minimizables
	double maxSimTime = 720.0;
	double stepSize = 0.001;
	double frequency = 0.1;
	int nCells = 1;
	double moveTol = 1.0e-06;

	//computer time cost
	m_dGammaSquared = 0.0;
	
	// flags for all minimizables
	bool rateFlag = true;
	bool chemFlag = false;
	bool logsFlag = false;
	double timeWeight = 1.0;
	double rateWeight = 0.0;
	double chemWeight = 0.0;

	// expt. 1 - D016 no aTc, no IPTG
	expt++;
	_networkList.push_back(new CCombinatorialNetwork());
	_experimentList.push_back(new Experiment(_networkList[expt],"D016 no aTc, no IPTG"));
	// put data files here
	_experimentList[expt]->AddDataFileToList("../DataFiles/Combinatorial/D016_1.dat");
	// mover
	_moverList.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	// minimizable
	_minimizableList.push_back(new SingleNetworkMinimizable());
	// parameters
	_minimizableList[expt]->Initialize(_experimentList[expt],_moverList[expt],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	//_minimizableList[0]->GetConversionFactor(7)->SetFactorFixed(true);
	//_minimizableList[0]->GetConversionFactor(7)->SetFactorValue(100.0/100000.0);
	_minimizableList[expt]->SetRateConstantsWeight(0.0);

	// expt. 2 - D016  aTc, no IPTG
	expt++;
	_networkList.push_back(new CCombinatorialNetwork());
	_experimentList.push_back(new Experiment(_networkList[expt],"D016 with aTc, no IPTG"));
	// put data files here
	_experimentList[expt]->AddDataFileToList("../DataFiles/Combinatorial/D016_2.dat");
	// mover
	_moverList.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	// minimizable
	_minimizableList.push_back(new SingleNetworkMinimizable());
	// parameters
	_minimizableList[expt]->Initialize(_experimentList[expt],_moverList[expt],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	//_minimizableList[0]->GetConversionFactor(7)->SetFactorFixed(true);
	//_minimizableList[0]->GetConversionFactor(7)->SetFactorValue(100.0/100000.0);
	_minimizableList[expt]->SetRateConstantsWeight(0.0);

	// expt. 3 - D016 no aTc, with IPTG
	expt++;
	_networkList.push_back(new CCombinatorialNetwork());
	_experimentList.push_back(new Experiment(_networkList[expt],"D016 no aTc, with IPTG"));
	// put data files here
	_experimentList[expt]->AddDataFileToList("../DataFiles/Combinatorial/D016_3.dat");
	// mover
	_moverList.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	// minimizable
	_minimizableList.push_back(new SingleNetworkMinimizable());
	// parameters
	_minimizableList[expt]->Initialize(_experimentList[expt],_moverList[expt],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	//_minimizableList[0]->GetConversionFactor(7)->SetFactorFixed(true);
	//_minimizableList[0]->GetConversionFactor(7)->SetFactorValue(100.0/100000.0);
	_minimizableList[expt]->SetRateConstantsWeight(0.0);

	// expt. 4 - D016 with aTc and IPTG
	expt++;
	_networkList.push_back(new CCombinatorialNetwork());
	_experimentList.push_back(new Experiment(_networkList[expt],"D016 with aTc and IPTG"));
	// put data files here
	_experimentList[expt]->AddDataFileToList("../DataFiles/Combinatorial/D016_4.dat");
	// mover
	_moverList.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	// minimizable
	_minimizableList.push_back(new SingleNetworkMinimizable());
	// parameters
	_minimizableList[expt]->Initialize(_experimentList[expt],_moverList[expt],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	//_minimizableList[0]->GetConversionFactor(7)->SetFactorFixed(true);
	//_minimizableList[0]->GetConversionFactor(7)->SetFactorValue(100.0/100000.0);
	_minimizableList[expt]->SetRateConstantsWeight(0.0);

//Plot Commands
	expt = -1;

	//expt D016 no aTc, no IPTG
	expt++;
	_plotterList.push_back(new GnuPlotterTimeSeriesObserver());
	_plotterList[expt]->SetTitle("D016: No aTc, No IPTG");
	_minimizableList[expt]->Attach(_plotterList[expt]);

	//expt D016 with aTc, no IPTG
	expt++;
	_plotterList.push_back(new GnuPlotterTimeSeriesObserver());
	_plotterList[expt]->SetTitle("D016: With aTc, No IPTG");
	_minimizableList[expt]->Attach(_plotterList[expt]);

	//expt D016 no aTc, with IPTG
	expt++;
	_plotterList.push_back(new GnuPlotterTimeSeriesObserver());
	_plotterList[expt]->SetTitle("D016: No aTc, with IPTG");
	_minimizableList[expt]->Attach(_plotterList[expt]);

	//expt D016 with aTc and IPTG
	expt++;
	_plotterList.push_back(new GnuPlotterTimeSeriesObserver());
	_plotterList[expt]->SetTitle("D016: with aTc and IPTG");
	_minimizableList[expt]->Attach(_plotterList[expt]);

	// allocate the master residuals list
	int masterResidualsSize = 0;
	for(int i = 0; i < _minimizableList.size(); i++)
	{
		int subRes = _minimizableList[i]->GetNResiduals();
		masterResidualsSize += subRes;
		cout << subRes << " residuals in minimizable " << i << endl;
	}
	if(m_dGammaSquared > 0.0)
	{
		masterResidualsSize += 1;
	}
	Allocate(masterResidualsSize);

	cout << "Master Residuals size : " << masterResidualsSize << endl;

	// define the experiments
	DefineExperiments();

}

CCombinatorialNetworkMinimizableDirector::~CCombinatorialNetworkMinimizableDirector()
{
	for(int i = 0; i < _plotterList.size(); i++)
	{
		_minimizableList[i]->Detach(_plotterList[i]);
		delete _plotterList[i];
	}
}

void CCombinatorialNetworkMinimizableDirector::DefineExperiments()
{	
	int expt = -1;

	// strain D016 general settings
	for (expt = 0; expt < 4; expt++) {
		_minimizableList[expt]->GetExperiment()->GetReactionNetwork()->RemoveReaction(44);
		_minimizableList[expt]->GetExperiment()->GetReactionNetwork()->RemoveReaction(43);
		_minimizableList[expt]->GetExperiment()->GetReactionNetwork()->RemoveReaction(42);
		_minimizableList[expt]->GetExperiment()->GetReactionNetwork()->RemoveReaction(41);
		_minimizableList[expt]->GetExperiment()->GetReactionNetwork()->RemoveReaction(40);
		_minimizableList[expt]->GetExperiment()->GetReactionNetwork()->RemoveReaction(39);
		_minimizableList[expt]->GetExperiment()->GetReactionNetwork()->RemoveReaction(38);
		_minimizableList[expt]->GetExperiment()->GetReactionNetwork()->RemoveReaction(37);
		_minimizableList[expt]->GetExperiment()->GetReactionNetwork()->RemoveReaction(36);
		_minimizableList[expt]->GetExperiment()->GetReactionNetwork()->RemoveReaction(35);
		_minimizableList[expt]->GetExperiment()->GetReactionNetwork()->RemoveReaction(34);
		_minimizableList[expt]->GetExperiment()->GetReactionNetwork()->RemoveReaction(33);
		_minimizableList[expt]->GetExperiment()->GetReactionNetwork()->RemoveReaction(30);
		_minimizableList[expt]->GetExperiment()->GetReactionNetwork()->RemoveReaction(29);
		_minimizableList[expt]->GetExperiment()->GetReactionNetwork()->RemoveReaction(28);
		_minimizableList[expt]->GetExperiment()->GetReactionNetwork()->RemoveReaction(27);
		_minimizableList[expt]->GetExperiment()->GetReactionNetwork()->RemoveReaction(26);
		_minimizableList[expt]->GetExperiment()->GetReactionNetwork()->RemoveReaction(25);
		_minimizableList[expt]->GetExperiment()->GetReactionNetwork()->RemoveReaction(22);
		_minimizableList[expt]->GetExperiment()->GetReactionNetwork()->RemoveReaction(21);
		_minimizableList[expt]->GetExperiment()->GetReactionNetwork()->RemoveReaction(20);
		_minimizableList[expt]->GetExperiment()->GetReactionNetwork()->RemoveReaction(19);
		_minimizableList[expt]->GetExperiment()->GetReactionNetwork()->RemoveReaction(18);
		_minimizableList[expt]->GetExperiment()->GetReactionNetwork()->RemoveReaction(17);
		_minimizableList[expt]->GetExperiment()->GetReactionNetwork()->RemoveReaction(16);
		_minimizableList[expt]->GetExperiment()->GetReactionNetwork()->RemoveReaction(14);
		_minimizableList[expt]->GetExperiment()->GetReactionNetwork()->RemoveReaction(12);
	}

	expt = -1;
	//no aTc, no IPTG
	expt++;
	_minimizableList[expt]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(0.0);
	_minimizableList[expt]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->SetInitialAmount(0.0);
	_minimizableList[expt]->GetExperiment()->GetReactionNetwork()->ChemicalReset();

	//with aTc, no IPTG
	expt++;
	_minimizableList[expt]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(500.0);
	_minimizableList[expt]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->SetInitialAmount(0.0);
	_minimizableList[expt]->GetExperiment()->GetReactionNetwork()->ChemicalReset();

	//no aTc, with IPTG
	expt++;
	_minimizableList[expt]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(0.0);
	_minimizableList[expt]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->SetInitialAmount(500.0);
	_minimizableList[expt]->GetExperiment()->GetReactionNetwork()->ChemicalReset();

	//with aTc and IPTG
	expt++;
	_minimizableList[expt]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(500.0);
	_minimizableList[expt]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->SetInitialAmount(500.0);
	_minimizableList[expt]->GetExperiment()->GetReactionNetwork()->ChemicalReset();

}

double CCombinatorialNetworkMinimizableDirector::GetParameter(int parIndex)
{
	// for this director, everyone has the same parameters so any set 
	// can be returned
	return _minimizableList[0]->GetParameter(parIndex);
}

int CCombinatorialNetworkMinimizableDirector::GetNParameters()
{
	// ditto as for GetParameters()
	return _minimizableList[0]->GetNParameters();
}
