#include "CombinatorialNetworksSloppyMinimizableDirector.h"

CCombinatorialNetworksSloppyMinimizableDirector::CCombinatorialNetworksSloppyMinimizableDirector(void)
{
	double maxSimTime = 720.0;
	int intTime = (int) maxSimTime + 2;
	double stepSize = 0.001;
	double frequency = 0.1;
	double moveTol = 1.0e-06;
	int cnt = 0;
	int nChemicals;

	m_dGammaSquared = 1.0e-07;

	// D016, IPTG-, aTc-
	m_vpRxnNetworks.push_back(new CCombinatorialNetwork());
	m_vpRxnMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	nChemicals = m_vpRxnNetworks[cnt]->GetNumberOfChemicals();
	m_vpCellObservers.push_back(new CellAverageObserver(nChemicals,intTime,1));
	m_vpRunnables.push_back(new CRunnable());
	m_vpRunnables[cnt]->SetComponents(m_vpRxnNetworks[cnt],m_vpRxnMovers[cnt],m_vpCellObservers[cnt]);
	m_vpRunnables[cnt]->SetRunnableName("D016_IPTGm_aTcm");
	// create an observer for the runnable
	m_vpGnuPlotters.push_back(new GnuPlotterRunnableObserver());
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(0);
	m_vpGnuPlotters[cnt]->SetTitle("D016 IPTG -, aTc -");
	m_vpRunnables[cnt]->Attach(m_vpGnuPlotters[cnt]);
	cnt++;

	// D016, IPTG+, aTc-
	m_vpRxnNetworks.push_back(new CCombinatorialNetwork());
	m_vpRxnMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	nChemicals = m_vpRxnNetworks[cnt]->GetNumberOfChemicals();
	m_vpCellObservers.push_back(new CellAverageObserver(nChemicals,intTime,1));
	m_vpRunnables.push_back(new CRunnable());
	m_vpRunnables[cnt]->SetComponents(m_vpRxnNetworks[cnt],m_vpRxnMovers[cnt],m_vpCellObservers[cnt]);
	m_vpRunnables[cnt]->SetRunnableName("D016_IPTGp_aTcm");
	// create an observer for the runnable
	m_vpGnuPlotters.push_back(new GnuPlotterRunnableObserver());
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(0);
	m_vpGnuPlotters[cnt]->SetTitle("D016 IPTG +, aTc -");
	m_vpRunnables[cnt]->Attach(m_vpGnuPlotters[cnt]);
	cnt++;

	// D016, IPTG-, aTc+
	m_vpRxnNetworks.push_back(new CCombinatorialNetwork());
	m_vpRxnMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	nChemicals = m_vpRxnNetworks[cnt]->GetNumberOfChemicals();
	m_vpCellObservers.push_back(new CellAverageObserver(nChemicals,intTime,1));
	m_vpRunnables.push_back(new CRunnable());
	m_vpRunnables[cnt]->SetComponents(m_vpRxnNetworks[cnt],m_vpRxnMovers[cnt],m_vpCellObservers[cnt]);
	m_vpRunnables[cnt]->SetRunnableName("D016_IPTGm_aTcp");
	// create an observer for the runnable
	m_vpGnuPlotters.push_back(new GnuPlotterRunnableObserver());
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(0);
	m_vpGnuPlotters[cnt]->SetTitle("D016 IPTG -, aTc +");
	m_vpRunnables[cnt]->Attach(m_vpGnuPlotters[cnt]);
	cnt++;

	// D016, IPTG+, aTc+
	m_vpRxnNetworks.push_back(new CCombinatorialNetwork());
	m_vpRxnMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	nChemicals = m_vpRxnNetworks[cnt]->GetNumberOfChemicals();
	m_vpCellObservers.push_back(new CellAverageObserver(nChemicals,intTime,1));
	m_vpRunnables.push_back(new CRunnable());
	m_vpRunnables[cnt]->SetComponents(m_vpRxnNetworks[cnt],m_vpRxnMovers[cnt],m_vpCellObservers[cnt]);
	m_vpRunnables[cnt]->SetRunnableName("D016_IPTGp_aTcp");
	// create an observer for the runnable
	m_vpGnuPlotters.push_back(new GnuPlotterRunnableObserver());
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(0);
	m_vpGnuPlotters[cnt]->SetTitle("D016 IPTG -, aTc +");
	m_vpRunnables[cnt]->Attach(m_vpGnuPlotters[cnt]);
	cnt++;

	// parse data files
	this->ParseDataFile("combinatorial.dat");

	// XXX debug
	/*
	for(int i = 0; i < m_vpRelationList.size(); i++)
	{
		cout << m_vpRelationList[i]->GetR1() << "\t" << m_vpRelationList[i]->GetQ1() << "\t" << m_vpRelationList[i]->Gett1() << "\t";
		cout << m_vpRelationList[i]->GetR2() << "\t" << m_vpRelationList[i]->GetQ2() << "\t" << m_vpRelationList[i]->Gett2() << "\t";
		cout << m_vpRelationList[i]->GetType() << endl;
	}
	*/
	// define runs
	DefineRuns();
}

CCombinatorialNetworksSloppyMinimizableDirector::~CCombinatorialNetworksSloppyMinimizableDirector(void)
{
}

int CCombinatorialNetworksSloppyMinimizableDirector::GetNParameters()
{
	// all the combinatorial networks share a master set of rate constants
	return m_vpRunnables[0]->GetReactionNetwork()->GetNumberOfRateConstants();
}

void CCombinatorialNetworksSloppyMinimizableDirector::DefineRuns()
{
	int i;
	// Strain D016
	for(i = 0; i < 4; i++)
	{
		m_vpRunnables[i]->GetReactionNetwork()->RemoveReaction(44);
		m_vpRunnables[i]->GetReactionNetwork()->RemoveReaction(43);
		m_vpRunnables[i]->GetReactionNetwork()->RemoveReaction(42);
		m_vpRunnables[i]->GetReactionNetwork()->RemoveReaction(41);
		m_vpRunnables[i]->GetReactionNetwork()->RemoveReaction(40);
		m_vpRunnables[i]->GetReactionNetwork()->RemoveReaction(39);
		m_vpRunnables[i]->GetReactionNetwork()->RemoveReaction(38);
		m_vpRunnables[i]->GetReactionNetwork()->RemoveReaction(37);
		m_vpRunnables[i]->GetReactionNetwork()->RemoveReaction(36);
		m_vpRunnables[i]->GetReactionNetwork()->RemoveReaction(35);
		m_vpRunnables[i]->GetReactionNetwork()->RemoveReaction(34);
		m_vpRunnables[i]->GetReactionNetwork()->RemoveReaction(33);
		m_vpRunnables[i]->GetReactionNetwork()->RemoveReaction(30);
		m_vpRunnables[i]->GetReactionNetwork()->RemoveReaction(29);
		m_vpRunnables[i]->GetReactionNetwork()->RemoveReaction(28);
		m_vpRunnables[i]->GetReactionNetwork()->RemoveReaction(27);
		m_vpRunnables[i]->GetReactionNetwork()->RemoveReaction(26);
		m_vpRunnables[i]->GetReactionNetwork()->RemoveReaction(25);
		m_vpRunnables[i]->GetReactionNetwork()->RemoveReaction(22);
		m_vpRunnables[i]->GetReactionNetwork()->RemoveReaction(21);
		m_vpRunnables[i]->GetReactionNetwork()->RemoveReaction(20);
		m_vpRunnables[i]->GetReactionNetwork()->RemoveReaction(19);
		m_vpRunnables[i]->GetReactionNetwork()->RemoveReaction(18);
		m_vpRunnables[i]->GetReactionNetwork()->RemoveReaction(17);
		m_vpRunnables[i]->GetReactionNetwork()->RemoveReaction(16);
		m_vpRunnables[i]->GetReactionNetwork()->RemoveReaction(14);
		m_vpRunnables[i]->GetReactionNetwork()->RemoveReaction(12);
	}

	m_vpRunnables[0]->GetReactionNetwork()->ChemicalReset();
	m_vpRunnables[1]->GetReactionNetwork()->ChemicalReset();
}
