// CombinatorialRunDirector.cpp: implementation of the CCombinatorialRunDirector class.
//
//////////////////////////////////////////////////////////////////////

#include "CombinatorialRunDirector.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

CCombinatorialRunDirector::CCombinatorialRunDirector()
{
	double maxSimTime = 720.0;
	int intTime = (int) maxSimTime + 2;
	double stepSize = 0.001;
	double frequency = 0.1;
	double moveTol = 1.0e-06;
	int seed = 298989;

	m_vpRxnNetworks.push_back(new CCombinatorialNetwork());
//	m_vpRxnNetworks[0]->DumpTeXForm("CombinatorialEquations.tex");
	m_vpRxnMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
//	m_vpRxnMovers.push_back(new CQualityControlRK2TMover(frequency,stepSize,moveTol));
//	m_vpRxnMovers.push_back(new CContinuousTimeMonteCarloMover(seed,frequency));
	int nChemicals = m_vpRxnNetworks[0]->GetNumberOfChemicals();
	m_vpCellObservers.push_back(new CellAverageObserver(nChemicals,intTime,1));
	m_vpRunnables.push_back(new CRunnable());
	m_vpRunnables[0]->SetComponents(m_vpRxnNetworks[0],m_vpRxnMovers[0],m_vpCellObservers[0]);

	// create an observer for the runnable
	m_vpGnuPlotters.push_back(new GnuPlotterRunnableObserver());
	m_vpGnuPlotters[0]->AddChemicalNumberToList(0);
	m_vpGnuPlotters[0]->AddChemicalNumberToList(1);
	m_vpGnuPlotters[0]->AddChemicalNumberToList(2);
	m_vpGnuPlotters[0]->AddChemicalNumberToList(3);
	m_vpGnuPlotters[0]->AddChemicalNumberToList(4);
	m_vpGnuPlotters[0]->AddChemicalNumberToList(5);

	m_vpGnuPlotters.push_back(new GnuPlotterRunnableObserver());
	m_vpGnuPlotters[1]->AddChemicalNumberToList(6);
	m_vpGnuPlotters[1]->AddChemicalNumberToList(7);
	m_vpGnuPlotters[1]->AddChemicalNumberToList(8);
	m_vpGnuPlotters[1]->AddChemicalNumberToList(9);
	m_vpGnuPlotters[1]->AddChemicalNumberToList(10);

	m_vpGnuPlotters.push_back(new GnuPlotterRunnableObserver());
	m_vpGnuPlotters[2]->AddChemicalNumberToList(11);
	m_vpGnuPlotters[2]->AddChemicalNumberToList(12);
	m_vpGnuPlotters[2]->AddChemicalNumberToList(13);
	m_vpGnuPlotters[2]->AddChemicalNumberToList(14);
	m_vpGnuPlotters[2]->AddChemicalNumberToList(15);

	// attach the observer
	m_vpRunnables[0]->Attach(m_vpGnuPlotters[0]);
	m_vpRunnables[0]->Attach(m_vpGnuPlotters[1]);
	m_vpRunnables[0]->Attach(m_vpGnuPlotters[2]);

	// define runs
	DefineRuns();

}

CCombinatorialRunDirector::~CCombinatorialRunDirector()
{

}

void CCombinatorialRunDirector::DefineRuns()
{
	// set parameters in the runnables to those read from a previous
	// optimization pass; assumes all runnables have same number of 
	// rate constants

	ParameterReader *pReader = new ParameterReader("CombinatorialInput.par");
	int nRC = m_vpRunnables[0]->GetReactionNetwork()->GetNumberOfRateConstants();
	for(int j = 0; j < nRC; j++)
	{
		double rate = pReader->ReadParameter();
		for(int i = 0; i < m_vpRunnables.size(); i++)
		{
			m_vpRunnables[i]->GetReactionNetwork()->GetRateConstant(j)->SetRateConstant(rate);
		}
	}
	delete pReader;


	// specific to this simulation
	// Strain D016
	m_vpRunnables[0]->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(1.0);
	m_vpRunnables[0]->GetReactionNetwork()->GetChemical(1)->SetInitialAmount(1.0);
	m_vpRunnables[0]->GetReactionNetwork()->RemoveReaction(44);
	m_vpRunnables[0]->GetReactionNetwork()->RemoveReaction(43);
	m_vpRunnables[0]->GetReactionNetwork()->RemoveReaction(42);
	m_vpRunnables[0]->GetReactionNetwork()->RemoveReaction(41);
	m_vpRunnables[0]->GetReactionNetwork()->RemoveReaction(40);
	m_vpRunnables[0]->GetReactionNetwork()->RemoveReaction(39);
	m_vpRunnables[0]->GetReactionNetwork()->RemoveReaction(38);
	m_vpRunnables[0]->GetReactionNetwork()->RemoveReaction(37);
	m_vpRunnables[0]->GetReactionNetwork()->RemoveReaction(36);
	m_vpRunnables[0]->GetReactionNetwork()->RemoveReaction(35);
	m_vpRunnables[0]->GetReactionNetwork()->RemoveReaction(34);
	m_vpRunnables[0]->GetReactionNetwork()->RemoveReaction(33);
	m_vpRunnables[0]->GetReactionNetwork()->RemoveReaction(30);
	m_vpRunnables[0]->GetReactionNetwork()->RemoveReaction(29);
	m_vpRunnables[0]->GetReactionNetwork()->RemoveReaction(28);
	m_vpRunnables[0]->GetReactionNetwork()->RemoveReaction(27);
	m_vpRunnables[0]->GetReactionNetwork()->RemoveReaction(26);
	m_vpRunnables[0]->GetReactionNetwork()->RemoveReaction(25);
	m_vpRunnables[0]->GetReactionNetwork()->RemoveReaction(22);
	m_vpRunnables[0]->GetReactionNetwork()->RemoveReaction(21);
	m_vpRunnables[0]->GetReactionNetwork()->RemoveReaction(20);
	m_vpRunnables[0]->GetReactionNetwork()->RemoveReaction(19);
	m_vpRunnables[0]->GetReactionNetwork()->RemoveReaction(18);
	m_vpRunnables[0]->GetReactionNetwork()->RemoveReaction(17);
	m_vpRunnables[0]->GetReactionNetwork()->RemoveReaction(16);
	m_vpRunnables[0]->GetReactionNetwork()->RemoveReaction(14);
	m_vpRunnables[0]->GetReactionNetwork()->RemoveReaction(12);

	m_vpRunnables[0]->GetReactionNetwork()->ChemicalReset();
	m_vpGnuPlotters[0]->SetTitle("CombinatorialNetwork");


}
