// ConjugateGradientMinimizer.h: interface for the CConjugateGradientMinimizer class.
// 
//////////////////////////////////////////////////////////////////////

// Made UNIX friendly 9/5/02

#if !defined(AFX_CONJUGATEGRADIENTMINIMIZER_H__2176D52C_749D_4C52_9C91_00755175F63B__INCLUDED_)
#define AFX_CONJUGATEGRADIENTMINIMIZER_H__2176D52C_749D_4C52_9C91_00755175F63B__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#include <iostream>
#include <fstream.h>
#include <iomanip.h>
#include <cmath>
#include <cfloat>
#include "../src/Minimizer.h"
#include "../src/Minimizable.h"
#include "../src/MatrixOperations.h"
#include "../src/ParameterFilter.h"
#include "../src/ParameterReader.h"

class CConjugateGradientMinimizer : public Minimizer  
{
public:
	CConjugateGradientMinimizer(bool searchFlag, CParameterFilter *pFilter, int nIterations, double funcAccuracy, int nRestarts=3, double gradTol=1.0e-06, double funcTol=1.0e-08);
	virtual ~CConjugateGradientMinimizer();
	double Minimize(double *parameters, Minimizable *minimizable);
	void ComputeGradient(double *parameters);
	void BracketMinimum(double *xA, double *fA, double *xB, double *fB, double *xC, double *fC);
	void BrentLine(double xA, double xB, double xC, double *xM, double *fM);
	bool CheckGradTol(double norm);
	bool CheckFuncTol(double diff);
	// evaluates currentP + alpha*searchDir, for scalar a. Neither the current parameters or
	// the searchDirection are changed by the call
	double LineEvaluate(double alpha);
	// returns sgn(b)*|a|
	double SgnProduct(double a, double b);
	// returns the force vector
	const double *GetForceVector() const {return (const double *)m_pdForceVector;}
    int GetNParameters() {return nParameters;}
private:
	bool m_bSearchFlag;
	static const double m_dGOLD;
	int m_iNIterations;
	int m_iNRestarts;
	// used for finite differencing
	double m_dFuncAccuracy;
	double m_dGradTol;
	double m_dFuncTol;
	double *m_pdCurrentParameters;
	double *m_pdSearchDirection;
	double *m_pdGradient;
	double *m_pdForceVector;
	// tolerance for line searches
	double m_dMinTol;
	CMatrixOperations *m_pMO;
	CParameterFilter *m_pFilter;
	Minimizable *m_pMinimizable;
};

#endif // !defined(AFX_CONJUGATEGRADIENTMINIMIZER_H__2176D52C_749D_4C52_9C91_00755175F63B__INCLUDED_)
