// ConstantSourceReaction.cpp: implementation of the CConstantSourceReaction class.
//
//////////////////////////////////////////////////////////////////////

#include "ConstantSourceReaction.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

CConstantSourceReaction::CConstantSourceReaction(Chemical *ChangedChemical, RateConstant *k_source, std::string reactionName)
:Reaction(reactionName)
{
	// stoichiometry
	this->ChangedChemical = chemicals.size();
	chemicals.push_back(ChangedChemical);
	numberOfEachChemicalChangedByReaction.push_back(+1);

	// rates
	this->k_source = rateConstants.size();
	rateConstants.push_back(k_source);

	// put enough dummy chemicalJacobian elements on the vector 
	// - they are recomputed every time you ask for the chemicalJacobian
	chemicalJacobian.push_back(new JElement(-1,-1));

	this->SetTeXForm();
}

CConstantSourceReaction::~CConstantSourceReaction()
{

}

double CConstantSourceReaction::GetRate() const
{
	return rateConstants[k_source]->GetValue();
}

void CConstantSourceReaction::SetTeXForm()
{
	strstream stream;
	// TeX form of the reaction
	stream << rateConstants[k_source]->GetTeXName().c_str();
	stream << ends;
	// set the TeX string equal to what's in the stream
	m_sTeXForm = stream.str();
	// allow memory to be freed
	stream.rdbuf()->freeze(0);
}

std::vector<Reaction::JElement *> *CConstantSourceReaction::GetChemicalJacobian()
{
	chemicalJacobian[0]->SetWithRespectTo(chemicals[ChangedChemical]->GetChemicalNumber());
	chemicalJacobian[0]->SetJValue(0.0);
	
	return &chemicalJacobian;
}