#include "EGFRTraffickingEnsembleDirector.h"

CEGFRTraffickingEnsembleDirector::CEGFRTraffickingEnsembleDirector(int ensembleSize)
:CEnsembleCombinationDirector(ensembleSize)
{
	double maxSimTime = 241.0;
	int intTime = (int) (maxSimTime + 2);
	double stepSize = 0.0001;
	double frequency = 1.0;
	double moveTol = 1.0e-6;
	bool rateFlag = true;
	bool chemFlag = false;
	bool logsFlag = false;
	double timeWeight = 1.0;
	double rateWeight = 0.0;
	double chemWeight = 0.0;
	int nCells = 1;

	int oldcnt = 0;
	int newcnt = 0;
	/*
	// NIH-3T3 cells
	// expt. 0 - NIH-3T3 cells transfected with 1.0(5) X 10^5 receptors, treated 
	//		with EGF at 100 nM concentration
	m_vpNetworks.push_back(new CEGFRTraffickingNetwork());
	m_vpExperiments.push_back(new Experiment(m_vpNetworks[oldcnt],"EGF at 100 nM, Helin 1991"));
	// put data files here
	m_vpExperiments[oldcnt]->AddDataFileToList("../DataFiles/TimeSeries/SurfaceEGFREGFHelin100nM.dat");
	// mover and plotter
	m_vpMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	// minimizable
	m_vpMinimizables.push_back(new SingleNetworkMinimizable());
	// parameters
	m_vpMinimizables[oldcnt]->Initialize(m_vpExperiments[oldcnt],m_vpMovers[oldcnt],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	m_vpMinimizables[oldcnt]->GetConversionFactor(47)->SetFactorFixed(true);
	m_vpMinimizables[oldcnt]->GetConversionFactor(47)->SetFactorValue(100.0/100000.0);
	m_vpMinimizables[oldcnt]->SetRateConstantsWeight(0.0);
	// attach observer
	m_vpEnsembleDataPlotters.push_back(new GnuPlotterEnsembleDataDirectorObserver());
	m_vpEnsembleDataPlotters[oldcnt]->SetTitle("EGF at 100 nM, Helin 1991 : ODE");
	m_vpEnsembleDataPlotters[oldcnt]->FixMinimizable(oldcnt);
	this->Attach(m_vpEnsembleDataPlotters[oldcnt]);
	oldcnt++;

	// expt. 1 - NIH-3T3's transfected w/ wild-type EGFR; measurements made
	//		with 10-30% of receptors initially occupied; cells express 
	//		1.0(5) X 10^5 receptors
	m_vpNetworks.push_back(new CEGFRTraffickingNetwork());
	m_vpExperiments.push_back(new Experiment(m_vpNetworks[oldcnt],"20 Percent Initial Occupancy, Helin 1991"));
	// put data files here
	m_vpExperiments[oldcnt]->AddDataFileToList("../DataFiles/TimeSeries/EGFHelinOccupied.dat");
	// mover and plotter
	m_vpMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	// minimizable
	m_vpMinimizables.push_back(new SingleNetworkMinimizable());
	// parameters
	m_vpMinimizables[oldcnt]->Initialize(m_vpExperiments[oldcnt],m_vpMovers[oldcnt],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	m_vpMinimizables[oldcnt]->GetConversionFactor(48)->SetFactorFixed(true);
	m_vpMinimizables[oldcnt]->GetConversionFactor(48)->SetFactorValue(100.0/20000.0);
	m_vpMinimizables[oldcnt]->SetRateConstantsWeight(0.0);
	// attach observer
	m_vpEnsembleDataPlotters.push_back(new GnuPlotterEnsembleDataDirectorObserver());
	m_vpEnsembleDataPlotters[oldcnt]->SetTitle("20 Percent Initial Occupancy, Helin 1991 : ODE");
	m_vpEnsembleDataPlotters[oldcnt]->FixMinimizable(oldcnt);
	this->Attach(m_vpEnsembleDataPlotters[oldcnt]);
	oldcnt++;

	// expt. 2 - NIH-3T3's transfected with wt EGFR; 1 X 10^5 receptors, EGF of
	//		100 ng/ml
	m_vpNetworks.push_back(new CEGFRTraffickingNetwork());
	m_vpExperiments.push_back(new Experiment(m_vpNetworks[oldcnt],"EGF at 100 ng/ml wt1, Carter 1998"));
	// put data files here
	m_vpExperiments[oldcnt]->AddDataFileToList("../DataFiles/TimeSeries/SurfaceEGFREGFwt1Carter.dat");
	// mover and plotter
	m_vpMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	// minimizable
	m_vpMinimizables.push_back(new SingleNetworkMinimizable());
	// parameters
	m_vpMinimizables[oldcnt]->Initialize(m_vpExperiments[oldcnt],m_vpMovers[oldcnt],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	m_vpMinimizables[oldcnt]->GetConversionFactor(47)->SetFactorFixed(true);
	m_vpMinimizables[oldcnt]->GetConversionFactor(47)->SetFactorValue(100.0/100000.0);
	m_vpMinimizables[oldcnt]->SetRateConstantsWeight(0.0);
	// attach observer
	m_vpEnsembleDataPlotters.push_back(new GnuPlotterEnsembleDataDirectorObserver());
	m_vpEnsembleDataPlotters[oldcnt]->SetTitle("EGF at 100 ng/ml wt1, Carter 1998 : ODE");
	m_vpEnsembleDataPlotters[oldcnt]->FixMinimizable(oldcnt);
	this->Attach(m_vpEnsembleDataPlotters[oldcnt]);
	oldcnt++;

	// expt. 3 - NIH-3T3's transfected with wt EGFR; 2.75 X 10^5 receptors, EGF of
	//		100 ng/ml
	m_vpNetworks.push_back(new CEGFRTraffickingNetwork());
	m_vpExperiments.push_back(new Experiment(m_vpNetworks[oldcnt],"EGF at 100 ng/ml wt2, Carter 1998"));
	// put data files here
	m_vpExperiments[oldcnt]->AddDataFileToList("../DataFiles/TimeSeries/SurfaceEGFREGFwt2Carter.dat");
	// mover and plotter
	m_vpMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	// minimizable
	m_vpMinimizables.push_back(new SingleNetworkMinimizable());
	// parameters
	m_vpMinimizables[oldcnt]->Initialize(m_vpExperiments[oldcnt],m_vpMovers[oldcnt],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	m_vpMinimizables[oldcnt]->GetConversionFactor(47)->SetFactorFixed(true);
	m_vpMinimizables[oldcnt]->GetConversionFactor(47)->SetFactorValue(100.0/275000.0);
	m_vpMinimizables[oldcnt]->SetRateConstantsWeight(0.0);
	// attach observer
	m_vpEnsembleDataPlotters.push_back(new GnuPlotterEnsembleDataDirectorObserver());
	m_vpEnsembleDataPlotters[oldcnt]->SetTitle("EGF at 100 ng/ml wt2, Carter 1998 : ODE");
	m_vpEnsembleDataPlotters[oldcnt]->FixMinimizable(oldcnt);
	this->Attach(m_vpEnsembleDataPlotters[oldcnt]);
	oldcnt++;
	*/
	
	// CHO cells
	// expt. 0 - CHO cells transfected with ? receptors, treated with EGF at 5 ng/ml
	//		concentration
	m_vpNetworks.push_back(new CEGFRTraffickingNetwork());
	m_vpExperiments.push_back(new Experiment(m_vpNetworks[oldcnt],"EGF at 5 ng/ml, Bao 2000"));
	// put data files here
	m_vpExperiments[oldcnt]->AddDataFileToList("../DataFiles/TimeSeries/InternalizedEGFREGFYarden.dat");
	// mover and plotter
	m_vpMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	// minimizable
	m_vpMinimizables.push_back(new SingleNetworkMinimizable());
	// parameters
	m_vpMinimizables[oldcnt]->Initialize(m_vpExperiments[oldcnt],m_vpMovers[oldcnt],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	m_vpMinimizables[oldcnt]->SetRateConstantsWeight(0.0);
	// attach observer
	m_vpEnsembleDataPlotters.push_back(new GnuPlotterEnsembleDataDirectorObserver());
	m_vpEnsembleDataPlotters[oldcnt]->SetTitle("EGF at 5 ng/ml, Bao 2000 : ODE");
	m_vpEnsembleDataPlotters[oldcnt]->FixMinimizable(oldcnt);
	this->Attach(m_vpEnsembleDataPlotters[oldcnt]);
	oldcnt++;

	// expt. 1 - CHO cells transfected with 8.2(7) X 10^4 receptors, treated 
	//		with EGF at 100 nM concentration
	m_vpNetworks.push_back(new CEGFRTraffickingNetwork());
	m_vpExperiments.push_back(new Experiment(m_vpNetworks[oldcnt],"EGF at 100 nM, Davis 1992"));
	// put data files here
	m_vpExperiments[oldcnt]->AddDataFileToList("../DataFiles/TimeSeries/SurfaceEGFREGFDavis100nM.dat");
	// mover and plotter
	m_vpMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	// minimizable
	m_vpMinimizables.push_back(new SingleNetworkMinimizable());
	// parameters
	m_vpMinimizables[oldcnt]->Initialize(m_vpExperiments[oldcnt],m_vpMovers[oldcnt],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	m_vpMinimizables[oldcnt]->GetConversionFactor(47)->SetFactorFixed(true);
	m_vpMinimizables[oldcnt]->GetConversionFactor(47)->SetFactorValue(100.0/82000.0);
	m_vpMinimizables[oldcnt]->SetRateConstantsWeight(0.0);
	// attach observer
	m_vpEnsembleDataPlotters.push_back(new GnuPlotterEnsembleDataDirectorObserver());
	m_vpEnsembleDataPlotters[oldcnt]->SetTitle("EGF at 100 nM, Davis 1992 : ODE");
	m_vpEnsembleDataPlotters[oldcnt]->FixMinimizable(oldcnt);
	this->Attach(m_vpEnsembleDataPlotters[oldcnt]);
	oldcnt++;

	// expt. 2 - CHO cells transfected with 8.2(7) X 10^4 receptors, treated 
	//		with EGF at 10 nM concentration
	m_vpNetworks.push_back(new CEGFRTraffickingNetwork());
	m_vpExperiments.push_back(new Experiment(m_vpNetworks[oldcnt],"EGF at 10 nM, Davis 1992"));
	// put data files here
	m_vpExperiments[oldcnt]->AddDataFileToList("../DataFiles/TimeSeries/SurfaceEGFREGFDavis10nM.dat");
	// mover and plotter
	m_vpMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	// minimizable
	m_vpMinimizables.push_back(new SingleNetworkMinimizable());
	// parameters
	m_vpMinimizables[oldcnt]->Initialize(m_vpExperiments[oldcnt],m_vpMovers[oldcnt],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	m_vpMinimizables[oldcnt]->GetConversionFactor(47)->SetFactorFixed(true);
	m_vpMinimizables[oldcnt]->GetConversionFactor(47)->SetFactorValue(100.0/82000.0);
	m_vpMinimizables[oldcnt]->SetRateConstantsWeight(0.0);
	// attach observer
	m_vpEnsembleDataPlotters.push_back(new GnuPlotterEnsembleDataDirectorObserver());
	m_vpEnsembleDataPlotters[oldcnt]->SetTitle("EGF at 10 nM, Davis 1992 : ODE");
	m_vpEnsembleDataPlotters[oldcnt]->FixMinimizable(oldcnt);
	this->Attach(m_vpEnsembleDataPlotters[oldcnt]);
	oldcnt++;

	// expt. 3 - CHO cells transfected with 8.2(7) X 10^4 receptors, treated 
	//		with EGF at 1 nM concentration
	m_vpNetworks.push_back(new CEGFRTraffickingNetwork());
	m_vpExperiments.push_back(new Experiment(m_vpNetworks[oldcnt],"EGF at 1 nM, Davis 1992"));
	// put data files here
	m_vpExperiments[oldcnt]->AddDataFileToList("../DataFiles/TimeSeries/SurfaceEGFREGFDavis1nM.dat");
	// mover and plotter
	m_vpMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	// minimizable
	m_vpMinimizables.push_back(new SingleNetworkMinimizable());
	// parameters
	m_vpMinimizables[oldcnt]->Initialize(m_vpExperiments[oldcnt],m_vpMovers[oldcnt],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	m_vpMinimizables[oldcnt]->GetConversionFactor(47)->SetFactorFixed(true);
	m_vpMinimizables[oldcnt]->GetConversionFactor(47)->SetFactorValue(100.0/82000.0);
	m_vpMinimizables[oldcnt]->SetRateConstantsWeight(0.0);
	// attach observer
	m_vpEnsembleDataPlotters.push_back(new GnuPlotterEnsembleDataDirectorObserver());
	m_vpEnsembleDataPlotters[oldcnt]->SetTitle("EGF at 1 nM, Davis 1992 : ODE");
	m_vpEnsembleDataPlotters[oldcnt]->FixMinimizable(oldcnt);
	this->Attach(m_vpEnsembleDataPlotters[oldcnt]);
	oldcnt++;
	
	// expt. 4 - CHO cells transfected with ? EGFR and treated with EGF at 
	//		100 ng/ml concentration
	m_vpNetworks.push_back(new CEGFRTraffickingNetwork());
	m_vpExperiments.push_back(new Experiment(m_vpNetworks[oldcnt],"EGF at 100 ng/ml, Levkowitz 1999"));
	// put data files here
	m_vpExperiments[oldcnt]->AddDataFileToList("../DataFiles/TimeSeries/SurfaceEGFREGFLevkowitz.dat");
	// mover and plotter
	m_vpMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	// minimizable
	m_vpMinimizables.push_back(new SingleNetworkMinimizable());
	// parameters
	m_vpMinimizables[oldcnt]->Initialize(m_vpExperiments[oldcnt],m_vpMovers[oldcnt],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	m_vpMinimizables[oldcnt]->GetConversionFactor(47)->SetFactorFixed(true);
	m_vpMinimizables[oldcnt]->GetConversionFactor(47)->SetFactorValue(100.0/80000.0);
	m_vpMinimizables[oldcnt]->SetRateConstantsWeight(0.0);
	// attach observer
	m_vpEnsembleDataPlotters.push_back(new GnuPlotterEnsembleDataDirectorObserver());
	m_vpEnsembleDataPlotters[oldcnt]->SetTitle("EGF at 100 ng/ml, Levkowitz 1999 : ODE");
	m_vpEnsembleDataPlotters[oldcnt]->FixMinimizable(oldcnt);
	this->Attach(m_vpEnsembleDataPlotters[oldcnt]);
	oldcnt++;
	
	// expt. 5 - CHO cells transfected with ? EGFR Y1045F and treated with EGF at
	//		100 ng/ml concentration
	m_vpNetworks.push_back(new CEGFRTraffickingNetwork());
	m_vpExperiments.push_back(new Experiment(m_vpNetworks[oldcnt],"EGF at 100 ng/ml, Y1045F EGFR, Levkowitz 1999"));
	// put data files here
	m_vpExperiments[oldcnt]->AddDataFileToList("../DataFiles/TimeSeries/SurfaceEGFREGFY1045FLevkowitz.dat");
	// mover and plotter
	m_vpMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	// minimizable
	m_vpMinimizables.push_back(new SingleNetworkMinimizable());
	// parameters
	m_vpMinimizables[oldcnt]->Initialize(m_vpExperiments[oldcnt],m_vpMovers[oldcnt],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	m_vpMinimizables[oldcnt]->GetConversionFactor(47)->SetFactorFixed(true);
	m_vpMinimizables[oldcnt]->GetConversionFactor(47)->SetFactorValue(100.0/80000.0);
	m_vpMinimizables[oldcnt]->SetRateConstantsWeight(0.0);
	// attach observer
	m_vpEnsembleDataPlotters.push_back(new GnuPlotterEnsembleDataDirectorObserver());
	m_vpEnsembleDataPlotters[oldcnt]->SetTitle("EGF at 100 ng/ml, Y1045 EGFR, Levkowitz 1999 : ODE");
	m_vpEnsembleDataPlotters[oldcnt]->FixMinimizable(oldcnt);
	this->Attach(m_vpEnsembleDataPlotters[oldcnt]);
	oldcnt++;

	// Runnables, common to CHO and 3T3
	// EGF at 100 ng/ml, EGFR overexpressed
	m_vpNetworks.push_back(new CEGFRTraffickingNetwork());
	m_vpMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	int nChemicals = m_vpNetworks[oldcnt]->GetNumberOfChemicals();
	m_vpCellObservers.push_back(new CellAverageObserver(nChemicals,intTime,1));
	m_vpRunnables.push_back(new CRunnable());
	m_vpRunnables[newcnt]->SetComponents(m_vpNetworks[oldcnt],m_vpMovers[oldcnt],m_vpCellObservers[newcnt]);
	// attach the observer
	m_vpEnsembleRunPlotters.push_back(new GnuPlotterEnsembleRunDirectorObserver());
	m_vpEnsembleRunPlotters[newcnt]->SetTitle("EGFR overexpressed, EGF at 100 ng/ml : ODE");
	m_vpEnsembleRunPlotters[newcnt]->FixRunnable(newcnt);
	m_vpEnsembleRunPlotters[newcnt]->AddChemicalToList(58);
	m_vpEnsembleRunPlotters[newcnt]->AddChemicalToList(59);
	this->Attach(m_vpEnsembleRunPlotters[newcnt]);
	oldcnt++;
	newcnt++;
	
	// EGF at 100 ng/ml, EGFR overexpressed, Cdc42 wt overexpressed
	m_vpNetworks.push_back(new CEGFRTraffickingNetwork());
	m_vpMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	nChemicals = m_vpNetworks[oldcnt]->GetNumberOfChemicals();
	m_vpCellObservers.push_back(new CellAverageObserver(nChemicals,intTime,1));
	m_vpRunnables.push_back(new CRunnable());
	m_vpRunnables[newcnt]->SetComponents(m_vpNetworks[oldcnt],m_vpMovers[oldcnt],m_vpCellObservers[newcnt]);
	// attach the observer
	m_vpEnsembleRunPlotters.push_back(new GnuPlotterEnsembleRunDirectorObserver());
	m_vpEnsembleRunPlotters[newcnt]->SetTitle("EGFR + wt Cdc42, EGF at 100 ng/ml : ODE");
	m_vpEnsembleRunPlotters[newcnt]->FixRunnable(newcnt);
	m_vpEnsembleRunPlotters[newcnt]->AddChemicalToList(58);
	m_vpEnsembleRunPlotters[newcnt]->AddChemicalToList(59);
	this->Attach(m_vpEnsembleRunPlotters[newcnt]);
	oldcnt++;
	newcnt++;
	
	// EGF at 100 ng/ml, EGFR overexpressed + Cdc42(Q61L)
	m_vpNetworks.push_back(new CEGFRTraffickingNetwork());
	m_vpMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	nChemicals = m_vpNetworks[oldcnt]->GetNumberOfChemicals();
	m_vpCellObservers.push_back(new CellAverageObserver(nChemicals,intTime,1));
	m_vpRunnables.push_back(new CRunnable());
	m_vpRunnables[newcnt]->SetComponents(m_vpNetworks[oldcnt],m_vpMovers[oldcnt],m_vpCellObservers[newcnt]);
	// attach the observer
	m_vpEnsembleRunPlotters.push_back(new GnuPlotterEnsembleRunDirectorObserver());
	m_vpEnsembleRunPlotters[newcnt]->SetTitle("EGFR + Cdc42(Q61L), EGF at 100 ng/ml : ODE");
	m_vpEnsembleRunPlotters[newcnt]->FixRunnable(newcnt);
	m_vpEnsembleRunPlotters[newcnt]->AddChemicalToList(58);
	m_vpEnsembleRunPlotters[newcnt]->AddChemicalToList(59);
	this->Attach(m_vpEnsembleRunPlotters[newcnt]);
	oldcnt++;
	newcnt++;
	
	// EGF at 100 ng/ml, EGFR overexpressed + Cdc42(T17N)
	m_vpNetworks.push_back(new CEGFRTraffickingNetwork());
	m_vpMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	nChemicals = m_vpNetworks[oldcnt]->GetNumberOfChemicals();
	m_vpCellObservers.push_back(new CellAverageObserver(nChemicals,intTime,1));
	m_vpRunnables.push_back(new CRunnable());
	m_vpRunnables[newcnt]->SetComponents(m_vpNetworks[oldcnt],m_vpMovers[oldcnt],m_vpCellObservers[newcnt]);
	// attach the observer
	m_vpEnsembleRunPlotters.push_back(new GnuPlotterEnsembleRunDirectorObserver());
	m_vpEnsembleRunPlotters[newcnt]->SetTitle("EGFR + Cdc42(T17N), EGF at 100 ng/ml : ODE");
	m_vpEnsembleRunPlotters[newcnt]->FixRunnable(newcnt);
	m_vpEnsembleRunPlotters[newcnt]->AddChemicalToList(58);
	m_vpEnsembleRunPlotters[newcnt]->AddChemicalToList(59);
	this->Attach(m_vpEnsembleRunPlotters[newcnt]);
	oldcnt++;
	newcnt++;
	
	
	// EGF at 100 ng/ml, EGFR overexpressed + Cdc42dL8
	m_vpNetworks.push_back(new CEGFRTraffickingNetwork());
	m_vpMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	nChemicals = m_vpNetworks[oldcnt]->GetNumberOfChemicals();
	m_vpCellObservers.push_back(new CellAverageObserver(nChemicals,intTime,1));
	m_vpRunnables.push_back(new CRunnable());
	m_vpRunnables[newcnt]->SetComponents(m_vpNetworks[oldcnt],m_vpMovers[oldcnt],m_vpCellObservers[newcnt]);
	// attach the observer
	m_vpEnsembleRunPlotters.push_back(new GnuPlotterEnsembleRunDirectorObserver());
	m_vpEnsembleRunPlotters[newcnt]->SetTitle("EGFR + Cdc42(dL8), EGF at 100 ng/ml : ODE");
	m_vpEnsembleRunPlotters[newcnt]->FixRunnable(newcnt);
	m_vpEnsembleRunPlotters[newcnt]->AddChemicalToList(58);
	m_vpEnsembleRunPlotters[newcnt]->AddChemicalToList(59);
	this->Attach(m_vpEnsembleRunPlotters[newcnt]);
	oldcnt++;
	newcnt++;

	// EGF at 100 ng/ml, EGFR overexpressed + Cdc42Lss
	m_vpNetworks.push_back(new CEGFRTraffickingNetwork());
	m_vpMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	nChemicals = m_vpNetworks[oldcnt]->GetNumberOfChemicals();
	m_vpCellObservers.push_back(new CellAverageObserver(nChemicals,intTime,1));
	m_vpRunnables.push_back(new CRunnable());
	m_vpRunnables[newcnt]->SetComponents(m_vpNetworks[oldcnt],m_vpMovers[oldcnt],m_vpCellObservers[newcnt]);
	// attach the observer
	m_vpEnsembleRunPlotters.push_back(new GnuPlotterEnsembleRunDirectorObserver());
	m_vpEnsembleRunPlotters[newcnt]->SetTitle("EGFR + Cdc42(Lss), EGF at 100 ng/ml : ODE");
	m_vpEnsembleRunPlotters[newcnt]->FixRunnable(newcnt);
	m_vpEnsembleRunPlotters[newcnt]->AddChemicalToList(58);
	m_vpEnsembleRunPlotters[newcnt]->AddChemicalToList(59);
	this->Attach(m_vpEnsembleRunPlotters[newcnt]);
	oldcnt++;
	newcnt++;

	// EGF at 100 ng/ml, EGFR overexpressed + Cdc42(Q61L/dL8)
	m_vpNetworks.push_back(new CEGFRTraffickingNetwork());
	m_vpMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	nChemicals = m_vpNetworks[oldcnt]->GetNumberOfChemicals();
	m_vpCellObservers.push_back(new CellAverageObserver(nChemicals,intTime,1));
	m_vpRunnables.push_back(new CRunnable());
	m_vpRunnables[newcnt]->SetComponents(m_vpNetworks[oldcnt],m_vpMovers[oldcnt],m_vpCellObservers[newcnt]);
	// attach the observer
	m_vpEnsembleRunPlotters.push_back(new GnuPlotterEnsembleRunDirectorObserver());
	m_vpEnsembleRunPlotters[newcnt]->SetTitle("EGFR + Cdc42(Q61L/dL8), EGF at 100 ng/ml : ODE");
	m_vpEnsembleRunPlotters[newcnt]->FixRunnable(newcnt);
	m_vpEnsembleRunPlotters[newcnt]->AddChemicalToList(58);
	m_vpEnsembleRunPlotters[newcnt]->AddChemicalToList(59);
	this->Attach(m_vpEnsembleRunPlotters[newcnt]);
	oldcnt++;
	newcnt++;

	// EGF at 100 ng/ml, EGFR overexpressed + Cdc42(Q61L/Lss)
	m_vpNetworks.push_back(new CEGFRTraffickingNetwork());
	m_vpMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	nChemicals = m_vpNetworks[oldcnt]->GetNumberOfChemicals();
	m_vpCellObservers.push_back(new CellAverageObserver(nChemicals,intTime,1));
	m_vpRunnables.push_back(new CRunnable());
	m_vpRunnables[newcnt]->SetComponents(m_vpNetworks[oldcnt],m_vpMovers[oldcnt],m_vpCellObservers[newcnt]);
	// attach the observer
	m_vpEnsembleRunPlotters.push_back(new GnuPlotterEnsembleRunDirectorObserver());
	m_vpEnsembleRunPlotters[newcnt]->SetTitle("EGFR + Cdc42(Q61L/Lss), EGF at 100 ng/ml : ODE");
	m_vpEnsembleRunPlotters[newcnt]->FixRunnable(newcnt);
	m_vpEnsembleRunPlotters[newcnt]->AddChemicalToList(58);
	m_vpEnsembleRunPlotters[newcnt]->AddChemicalToList(59);
	this->Attach(m_vpEnsembleRunPlotters[newcnt]);
	oldcnt++;
	newcnt++;
		
	// EGF at 100 ng/ml, EGFR overexpressed + Cdc42(F28L)
	m_vpNetworks.push_back(new CEGFRTraffickingNetwork());
	m_vpMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	nChemicals = m_vpNetworks[oldcnt]->GetNumberOfChemicals();
	m_vpCellObservers.push_back(new CellAverageObserver(nChemicals,intTime,1));
	m_vpRunnables.push_back(new CRunnable());
	m_vpRunnables[newcnt]->SetComponents(m_vpNetworks[oldcnt],m_vpMovers[oldcnt],m_vpCellObservers[newcnt]);
	// attach the observer
	m_vpEnsembleRunPlotters.push_back(new GnuPlotterEnsembleRunDirectorObserver());
	m_vpEnsembleRunPlotters[newcnt]->SetTitle("EGFR + Cdc42(F28L), EGF at 100 ng/ml : ODE");
	m_vpEnsembleRunPlotters[newcnt]->FixRunnable(newcnt);
	m_vpEnsembleRunPlotters[newcnt]->AddChemicalToList(58);
	m_vpEnsembleRunPlotters[newcnt]->AddChemicalToList(59);
	this->Attach(m_vpEnsembleRunPlotters[newcnt]);
	oldcnt++;
	newcnt++;
	
	// EGF at 100 ng/ml, EGFR overexpressed + Cdc42(F28L/dL8)
	m_vpNetworks.push_back(new CEGFRTraffickingNetwork());
	m_vpMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	nChemicals = m_vpNetworks[oldcnt]->GetNumberOfChemicals();
	m_vpCellObservers.push_back(new CellAverageObserver(nChemicals,intTime,1));
	m_vpRunnables.push_back(new CRunnable());
	m_vpRunnables[newcnt]->SetComponents(m_vpNetworks[oldcnt],m_vpMovers[oldcnt],m_vpCellObservers[newcnt]);
	// attach the observer
	m_vpEnsembleRunPlotters.push_back(new GnuPlotterEnsembleRunDirectorObserver());
	m_vpEnsembleRunPlotters[newcnt]->SetTitle("EGFR + Cdc42(F28L/dL8), EGF at 100 ng/ml : ODE");
	m_vpEnsembleRunPlotters[newcnt]->FixRunnable(newcnt);
	m_vpEnsembleRunPlotters[newcnt]->AddChemicalToList(58);
	m_vpEnsembleRunPlotters[newcnt]->AddChemicalToList(59);
	this->Attach(m_vpEnsembleRunPlotters[newcnt]);
	oldcnt++;
	newcnt++;
	
	// EGF at 100 ng/ml, EGFR overexpressed + Cdc42(F28L/Lss)
	m_vpNetworks.push_back(new CEGFRTraffickingNetwork());
	m_vpMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	nChemicals = m_vpNetworks[oldcnt]->GetNumberOfChemicals();
	m_vpCellObservers.push_back(new CellAverageObserver(nChemicals,intTime,1));
	m_vpRunnables.push_back(new CRunnable());
	m_vpRunnables[newcnt]->SetComponents(m_vpNetworks[oldcnt],m_vpMovers[oldcnt],m_vpCellObservers[newcnt]);
	// create an observer for the runnable
	m_vpEnsembleRunPlotters.push_back(new GnuPlotterEnsembleRunDirectorObserver());
	m_vpEnsembleRunPlotters[newcnt]->SetTitle("EGFR + Cdc42(F28L/Lss), EGF at 100 ng/ml : ODE");
	m_vpEnsembleRunPlotters[newcnt]->FixRunnable(newcnt);
	m_vpEnsembleRunPlotters[newcnt]->AddChemicalToList(58);
	m_vpEnsembleRunPlotters[newcnt]->AddChemicalToList(59);
	this->Attach(m_vpEnsembleRunPlotters[newcnt]);
	
	
	// allocate space to accumulate statistics
	SumAllocate();

	// Define runs
	DefineRuns();

	// Define experiments
	DefineExperiments();

	// Load in the ensemble info
	LoadEnsembleInfo("ensemble.par");
}

CEGFRTraffickingEnsembleDirector::~CEGFRTraffickingEnsembleDirector(void)
{
	for(int i = 0; i < m_vpEnsembleRunPlotters.size(); i++)
	{
		this->Detach(m_vpEnsembleRunPlotters[i]);
	}
	for(i = 0; i < m_vpEnsembleDataPlotters.size(); i++)
	{
		this->Detach(m_vpEnsembleDataPlotters[i]);
	}
}


void CEGFRTraffickingEnsembleDirector::DefineRuns()
{
	int cnt = 0;
	// 100,000 receptors, EGF at 100 ng/ml
	m_vpRunnables[cnt]->GetReactionNetwork()->RemoveReaction(64);
	m_vpRunnables[cnt]->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(1.2e+007);
	m_vpRunnables[cnt]->GetReactionNetwork()->GetChemical(2)->SetInitialAmount(100000);
	m_vpRunnables[cnt]->GetReactionNetwork()->ChemicalReset();
	cnt++;

	
	// 100,000 receptors, EGF at 100 ng/ml, Cdc42wt 2-fold overexpressed
	m_vpRunnables[cnt]->GetReactionNetwork()->RemoveReaction(64);
	m_vpRunnables[cnt]->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(1.2e+007);
	m_vpRunnables[cnt]->GetReactionNetwork()->GetChemical(2)->SetInitialAmount(100000);
	m_vpRunnables[cnt]->GetReactionNetwork()->GetChemical(35)->SetInitialAmount(2*600000);
	m_vpRunnables[cnt]->GetReactionNetwork()->ChemicalReset();
	cnt++;
	
	// 100,000 receptors, EGF at 100 ng/ml, Cdc42(Q61L)
	m_vpRunnables[cnt]->GetReactionNetwork()->RemoveReaction(64);
	m_vpRunnables[cnt]->GetReactionNetwork()->RemoveReaction(59);
	m_vpRunnables[cnt]->GetReactionNetwork()->RemoveReaction(58);
	m_vpRunnables[cnt]->GetReactionNetwork()->RemoveReaction(25);
	m_vpRunnables[cnt]->GetReactionNetwork()->RemoveReaction(24);
	m_vpRunnables[cnt]->GetReactionNetwork()->RemoveReaction(17);
	m_vpRunnables[cnt]->GetReactionNetwork()->RemoveReaction(16);
	m_vpRunnables[cnt]->GetReactionNetwork()->RemoveReaction(6);
	m_vpRunnables[cnt]->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(1.2e+007);
	m_vpRunnables[cnt]->GetReactionNetwork()->GetChemical(2)->SetInitialAmount(100000);
	// start with all mutant 42 active
	m_vpRunnables[cnt]->GetReactionNetwork()->GetChemical(35)->SetInitialAmount(0.0);
	m_vpRunnables[cnt]->GetReactionNetwork()->GetChemical(36)->SetInitialAmount(2*600000);
	m_vpRunnables[cnt]->GetReactionNetwork()->ChemicalReset();
	cnt++;

	// 100,000 receptors, EGF at 100 ng/ml, Cdc42(T17N)
	m_vpRunnables[cnt]->GetReactionNetwork()->RemoveReaction(64);
	m_vpRunnables[cnt]->GetReactionNetwork()->RemoveReaction(5);
	m_vpRunnables[cnt]->GetReactionNetwork()->RemoveReaction(4);
	m_vpRunnables[cnt]->GetReactionNetwork()->RemoveReaction(3);
	m_vpRunnables[cnt]->GetReactionNetwork()->RemoveReaction(2);
	m_vpRunnables[cnt]->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(1.2e+007);
	m_vpRunnables[cnt]->GetReactionNetwork()->GetChemical(2)->SetInitialAmount(100000);
	m_vpRunnables[cnt]->GetReactionNetwork()->GetChemical(35)->SetInitialAmount(2*600000);
	m_vpRunnables[cnt]->GetReactionNetwork()->ChemicalReset();
	cnt++;

	// 100,000 receptors, EGF at 100 ng/ml, Cdc42dL8
	m_vpRunnables[cnt]->GetReactionNetwork()->RemoveReaction(64);
	m_vpRunnables[cnt]->GetReactionNetwork()->RemoveReaction(22);
	m_vpRunnables[cnt]->GetReactionNetwork()->RemoveReaction(20);
	m_vpRunnables[cnt]->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(1.2e+007);
	m_vpRunnables[cnt]->GetReactionNetwork()->GetChemical(2)->SetInitialAmount(100000);
	// start with all 42 active
	m_vpRunnables[cnt]->GetReactionNetwork()->GetChemical(35)->SetInitialAmount(2*600000);
	m_vpRunnables[cnt]->GetReactionNetwork()->ChemicalReset();
	cnt++;

	// 100,000 receptors, EGF at 100 ng/ml, Cdc42Lss
	m_vpRunnables[cnt]->GetReactionNetwork()->RemoveReaction(64);
	m_vpRunnables[cnt]->GetReactionNetwork()->RemoveReaction(55);
	m_vpRunnables[cnt]->GetReactionNetwork()->RemoveReaction(54);
	m_vpRunnables[cnt]->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(1.2e+007);
	m_vpRunnables[cnt]->GetReactionNetwork()->GetChemical(2)->SetInitialAmount(100000);
	// start with all 42 active
	m_vpRunnables[cnt]->GetReactionNetwork()->GetChemical(35)->SetInitialAmount(2*600000);
	m_vpRunnables[cnt]->GetReactionNetwork()->ChemicalReset();
	cnt++;

	// 100,000 receptors, EGF at 100 ng/ml, Cdc42(Q61L/dL8)
	m_vpRunnables[cnt]->GetReactionNetwork()->RemoveReaction(64);
	m_vpRunnables[cnt]->GetReactionNetwork()->RemoveReaction(59);
	m_vpRunnables[cnt]->GetReactionNetwork()->RemoveReaction(58);
	m_vpRunnables[cnt]->GetReactionNetwork()->RemoveReaction(25);
	m_vpRunnables[cnt]->GetReactionNetwork()->RemoveReaction(24);
	m_vpRunnables[cnt]->GetReactionNetwork()->RemoveReaction(22);
	m_vpRunnables[cnt]->GetReactionNetwork()->RemoveReaction(20);
	m_vpRunnables[cnt]->GetReactionNetwork()->RemoveReaction(17);
	m_vpRunnables[cnt]->GetReactionNetwork()->RemoveReaction(16);
	m_vpRunnables[cnt]->GetReactionNetwork()->RemoveReaction(6);
	m_vpRunnables[cnt]->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(1.2e+007);
	m_vpRunnables[cnt]->GetReactionNetwork()->GetChemical(2)->SetInitialAmount(100000);
	// start with all 42 active
	m_vpRunnables[cnt]->GetReactionNetwork()->GetChemical(35)->SetInitialAmount(0.0);
	m_vpRunnables[cnt]->GetReactionNetwork()->GetChemical(36)->SetInitialAmount(2*600000);
	m_vpRunnables[cnt]->GetReactionNetwork()->ChemicalReset();
	cnt++;

	// 100,000 receptors, EGF at 100 ng/ml, Cdc42(Q61L/Lss)
	m_vpRunnables[cnt]->GetReactionNetwork()->RemoveReaction(64);
	m_vpRunnables[cnt]->GetReactionNetwork()->RemoveReaction(59);
	m_vpRunnables[cnt]->GetReactionNetwork()->RemoveReaction(58);
	m_vpRunnables[cnt]->GetReactionNetwork()->RemoveReaction(55);
	m_vpRunnables[cnt]->GetReactionNetwork()->RemoveReaction(54);
	m_vpRunnables[cnt]->GetReactionNetwork()->RemoveReaction(25);
	m_vpRunnables[cnt]->GetReactionNetwork()->RemoveReaction(24);
	m_vpRunnables[cnt]->GetReactionNetwork()->RemoveReaction(17);
	m_vpRunnables[cnt]->GetReactionNetwork()->RemoveReaction(16);
	m_vpRunnables[cnt]->GetReactionNetwork()->RemoveReaction(6);
	m_vpRunnables[cnt]->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(1.2e+007);
	m_vpRunnables[cnt]->GetReactionNetwork()->GetChemical(2)->SetInitialAmount(100000);
	// start with all 42 active
	m_vpRunnables[cnt]->GetReactionNetwork()->GetChemical(35)->SetInitialAmount(0.0);
	m_vpRunnables[cnt]->GetReactionNetwork()->GetChemical(36)->SetInitialAmount(2*600000);
	m_vpRunnables[cnt]->GetReactionNetwork()->ChemicalReset();
	cnt++;

	// 100,000 receptors, EGF at 100 ng/ml, Cdc42(F28L)
	m_vpRunnables[cnt]->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(1.2e+007);
	m_vpRunnables[cnt]->GetReactionNetwork()->GetChemical(2)->SetInitialAmount(100000);
	// start with all 42 active
	m_vpRunnables[cnt]->GetReactionNetwork()->GetChemical(35)->SetInitialAmount(0.0);
	m_vpRunnables[cnt]->GetReactionNetwork()->GetChemical(36)->SetInitialAmount(2*600000);
	m_vpRunnables[cnt]->GetReactionNetwork()->ChemicalReset();
	cnt++;

	// 100,000 receptors, EGF at 100 ng/ml, Cdc42(F28L/dL8)
	m_vpRunnables[cnt]->GetReactionNetwork()->RemoveReaction(22);
	m_vpRunnables[cnt]->GetReactionNetwork()->RemoveReaction(20);
	m_vpRunnables[cnt]->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(1.2e+007);
	m_vpRunnables[cnt]->GetReactionNetwork()->GetChemical(2)->SetInitialAmount(100000);
	// start with all 42 active
	m_vpRunnables[cnt]->GetReactionNetwork()->GetChemical(35)->SetInitialAmount(0.0);
	m_vpRunnables[cnt]->GetReactionNetwork()->GetChemical(36)->SetInitialAmount(2*600000);
	m_vpRunnables[cnt]->GetReactionNetwork()->ChemicalReset();
	cnt++;

	// 100,000 receptors, EGF at 100 ng/ml, Cdc42(F28L/Lss)
	m_vpRunnables[cnt]->GetReactionNetwork()->RemoveReaction(55);
	m_vpRunnables[cnt]->GetReactionNetwork()->RemoveReaction(54);
	m_vpRunnables[cnt]->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(1.2e+007);
	m_vpRunnables[cnt]->GetReactionNetwork()->GetChemical(2)->SetInitialAmount(100000);
	// start with all 42 active
	m_vpRunnables[cnt]->GetReactionNetwork()->GetChemical(35)->SetInitialAmount(0.0);
	m_vpRunnables[cnt]->GetReactionNetwork()->GetChemical(36)->SetInitialAmount(2*600000);
	m_vpRunnables[cnt]->GetReactionNetwork()->ChemicalReset();
	cnt++;


	return;
}

void CEGFRTraffickingEnsembleDirector::DefineExperiments()
{	
	/*
	// 3T3 cells
	// 100,000 receptors, EGF at 100 nM
	m_vpMinimizables[0]->GetExperiment()->GetReactionNetwork()->RemoveReaction(64);
	m_vpMinimizables[0]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(7.2e+007);
	m_vpMinimizables[0]->GetExperiment()->GetReactionNetwork()->GetChemical(2)->SetInitialAmount(100000);
	m_vpMinimizables[0]->GetExperiment()->GetReactionNetwork()->ChemicalReset();

	// No EGF, 20% of receptors on surface initially occupied
	m_vpMinimizables[1]->GetExperiment()->GetReactionNetwork()->RemoveReaction(64);
	m_vpMinimizables[1]->GetExperiment()->GetReactionNetwork()->GetChemical(2)->SetInitialAmount(80000.0);
	m_vpMinimizables[1]->GetExperiment()->GetReactionNetwork()->GetChemical(3)->SetInitialAmount(20000.0);
	m_vpMinimizables[1]->GetExperiment()->GetReactionNetwork()->ChemicalReset();

	// 100,000 receptors assumed, EGF at 100 ng/ml
	m_vpMinimizables[2]->GetExperiment()->GetReactionNetwork()->RemoveReaction(64);
	m_vpMinimizables[2]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(1.2e+007);
	m_vpMinimizables[2]->GetExperiment()->GetReactionNetwork()->GetChemical(2)->SetInitialAmount(100000);
	m_vpMinimizables[2]->GetExperiment()->GetReactionNetwork()->ChemicalReset();

	// 275,000 receptors assumed, EGF at 100 ng/ml
	m_vpMinimizables[3]->GetExperiment()->GetReactionNetwork()->RemoveReaction(64);
	m_vpMinimizables[3]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(1.2e+007);
	m_vpMinimizables[3]->GetExperiment()->GetReactionNetwork()->GetChemical(2)->SetInitialAmount(275000);
	m_vpMinimizables[3]->GetExperiment()->GetReactionNetwork()->ChemicalReset();
	*/
	// CHO cells
	// 80,000 receptors assumed, EGF at 5 ng/ml
	m_vpMinimizables[0]->GetExperiment()->GetReactionNetwork()->RemoveReaction(64);
	m_vpMinimizables[0]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(600000.0);
	m_vpMinimizables[0]->GetExperiment()->GetReactionNetwork()->GetChemical(2)->SetInitialAmount(80000.0);
	m_vpMinimizables[0]->GetExperiment()->GetReactionNetwork()->ChemicalReset();

	// 82,000 receptors, EGF at 100 nM
	m_vpMinimizables[1]->GetExperiment()->GetReactionNetwork()->RemoveReaction(64);
	m_vpMinimizables[1]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(7.2e+007);
	m_vpMinimizables[1]->GetExperiment()->GetReactionNetwork()->GetChemical(2)->SetInitialAmount(82000);
	m_vpMinimizables[1]->GetExperiment()->GetReactionNetwork()->ChemicalReset();

	// 82,000 receptors, EGF at 10 nM
	m_vpMinimizables[2]->GetExperiment()->GetReactionNetwork()->RemoveReaction(64);
	m_vpMinimizables[2]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(7.2e+006);
	m_vpMinimizables[2]->GetExperiment()->GetReactionNetwork()->GetChemical(2)->SetInitialAmount(82000);
	m_vpMinimizables[2]->GetExperiment()->GetReactionNetwork()->ChemicalReset();

	// 82,000 receptors, EGF at 1 nM
	m_vpMinimizables[3]->GetExperiment()->GetReactionNetwork()->RemoveReaction(64);	
	m_vpMinimizables[3]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(7.2e+005);
	m_vpMinimizables[3]->GetExperiment()->GetReactionNetwork()->GetChemical(2)->SetInitialAmount(82000);
	m_vpMinimizables[3]->GetExperiment()->GetReactionNetwork()->ChemicalReset();

	// 80,000 receptors assumed, EGF at 100 ng/ml
	m_vpMinimizables[4]->GetExperiment()->GetReactionNetwork()->RemoveReaction(64);
	m_vpMinimizables[4]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(1.2e+007);
	m_vpMinimizables[4]->GetExperiment()->GetReactionNetwork()->GetChemical(2)->SetInitialAmount(80000);
	m_vpMinimizables[4]->GetExperiment()->GetReactionNetwork()->ChemicalReset();
	
	// 80,000 receptors assumed, EGF at 100 ng/ml, Y1045F can't bind to Cbl
	m_vpMinimizables[5]->GetExperiment()->GetReactionNetwork()->RemoveReaction(64);
	m_vpMinimizables[5]->GetExperiment()->GetReactionNetwork()->RemoveReaction(42);
	m_vpMinimizables[5]->GetExperiment()->GetReactionNetwork()->RemoveReaction(41);
	m_vpMinimizables[5]->GetExperiment()->GetReactionNetwork()->RemoveReaction(40);	
	m_vpMinimizables[5]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(1.2e+007);
	m_vpMinimizables[5]->GetExperiment()->GetReactionNetwork()->GetChemical(2)->SetInitialAmount(80000);
	m_vpMinimizables[5]->GetExperiment()->GetReactionNetwork()->ChemicalReset();
}
