// EGFRTraffickingMinimizableDirector.cpp: implementation of the CEGFRTraffickingMinimizableDirector class.
//
//////////////////////////////////////////////////////////////////////

#include "EGFRTraffickingMinimizableDirector.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

CEGFRTraffickingMinimizableDirector::CEGFRTraffickingMinimizableDirector()
{
	// create networks,experiments,observers,movers,minimizables
	double maxSimTime = 241.0;
	double stepSize = 0.0001;
	double frequency = 1.0;
	int nCells = 1;
	double moveTol = 1.0e-06;

	m_dGammaSquared = 1.0e-08;
	
	// flags for all minimizables
	bool rateFlag = true;
	bool chemFlag = false;
	bool logsFlag = false;
	double timeWeight = 1.0;
	double rateWeight = 0.0;
	double chemWeight = 0.0;

	/*
	// CHO cells
	// expt. 0 - CHO cells transfected with ? receptors, treated with EGF at 5 ng/ml
	//		concentration
	_networkList.push_back(new CEGFRTraffickingNetwork());
	_experimentList.push_back(new Experiment(_networkList[0],"EGF at 5 ng/ml, Bao 2000"));
	// put data files here
	_experimentList[0]->AddDataFileToList("../DataFiles/TimeSeries/InternalizedEGFREGFYarden.dat");
	// mover and plotter
	_moverList.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	_plotterList.push_back(new GnuPlotterTimeSeriesObserver());
	// title
	_plotterList[0]->SetTitle("EGFR Trafficking Network:EGF at 5 ng/ml (Bao 2000):ODE");
	// minimizable
	_minimizableList.push_back(new SingleNetworkMinimizable());
	// parameters
	_minimizableList[0]->Initialize(_experimentList[0],_moverList[0],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	_minimizableList[0]->SetRateConstantsWeight(0.0);
	// attach observer
	_minimizableList[0]->Attach(_plotterList[0]);

	// expt. 1 - CHO cells transfected with 8.2(7) X 10^4 receptors, treated 
	//		with EGF at 100 nM concentration
	_networkList.push_back(new CEGFRTraffickingNetwork());
	_experimentList.push_back(new Experiment(_networkList[1],"EGF at 100 nM, Davis 1992"));
	// put data files here
	_experimentList[1]->AddDataFileToList("../DataFiles/TimeSeries/SurfaceEGFREGFDavis100nM.dat");
	// mover and plotter
	_moverList.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	_plotterList.push_back(new GnuPlotterTimeSeriesObserver());
	// title
	_plotterList[1]->SetTitle("EGFR Trafficking Network:EGF at 100 nM (Davis 1992):ODE");
	// minimizable
	_minimizableList.push_back(new SingleNetworkMinimizable());
	// parameters
	_minimizableList[1]->Initialize(_experimentList[1],_moverList[1],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	_minimizableList[1]->GetConversionFactor(4)->SetFactorFixed(true);
	_minimizableList[1]->GetConversionFactor(4)->SetFactorValue(100.0/82000.0);
	_minimizableList[1]->SetRateConstantsWeight(0.0);
	// attach observer
	_minimizableList[1]->Attach(_plotterList[1]);

	// expt. 2 - CHO cells transfected with 8.2(7) X 10^4 receptors, treated 
	//		with EGF at 10 nM concentration
	_networkList.push_back(new CEGFRTraffickingNetwork());
	_experimentList.push_back(new Experiment(_networkList[2],"EGF at 10 nM, Davis 1992"));
	// put data files here
	_experimentList[2]->AddDataFileToList("../DataFiles/TimeSeries/SurfaceEGFREGFDavis10nM.dat");
	// mover and plotter
	_moverList.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	_plotterList.push_back(new GnuPlotterTimeSeriesObserver());
	// title
	_plotterList[2]->SetTitle("EGFR Trafficking Network:EGF at 10 nM (Davis 1992):ODE");
	// minimizable
	_minimizableList.push_back(new SingleNetworkMinimizable());
	// parameters
	_minimizableList[2]->Initialize(_experimentList[2],_moverList[2],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	_minimizableList[2]->GetConversionFactor(4)->SetFactorFixed(true);
	_minimizableList[2]->GetConversionFactor(4)->SetFactorValue(100.0/82000.0);
	_minimizableList[2]->SetRateConstantsWeight(0.0);
	// attach observer
	_minimizableList[2]->Attach(_plotterList[2]);

	// expt. 3 - CHO cells transfected with 8.2(7) X 10^4 receptors, treated 
	//		with EGF at 1 nM concentration
	_networkList.push_back(new CEGFRTraffickingNetwork());
	_experimentList.push_back(new Experiment(_networkList[3],"EGF at 1 nM, Davis 1992"));
	// put data files here
	_experimentList[3]->AddDataFileToList("../DataFiles/TimeSeries/SurfaceEGFREGFDavis1nM.dat");
	// mover and plotter
	_moverList.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	_plotterList.push_back(new GnuPlotterTimeSeriesObserver());
	// title
	_plotterList[3]->SetTitle("EGFR Trafficking Network:EGF at 1 nM (Davis 1992):ODE");
	// minimizable
	_minimizableList.push_back(new SingleNetworkMinimizable());
	// parameters
	_minimizableList[3]->Initialize(_experimentList[3],_moverList[3],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	_minimizableList[3]->GetConversionFactor(4)->SetFactorFixed(true);
	_minimizableList[3]->GetConversionFactor(4)->SetFactorValue(100.0/82000.0);
	_minimizableList[3]->SetRateConstantsWeight(0.0);
	// attach observer
	_minimizableList[3]->Attach(_plotterList[3]);
	
	// expt. 4 - CHO cells transfected with ? EGFR and treated with EGF at 
	//		100 ng/ml concentration
	_networkList.push_back(new CEGFRTraffickingNetwork());
	_experimentList.push_back(new Experiment(_networkList[4],"EGF at 100 ng/ml, Levkowitz 1999"));
	// put data files here
	_experimentList[4]->AddDataFileToList("../DataFiles/TimeSeries/SurfaceEGFREGFLevkowitz.dat");
	// mover and plotter
	_moverList.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	_plotterList.push_back(new GnuPlotterTimeSeriesObserver());
	// title
	_plotterList[4]->SetTitle("EGFR Trafficking Network:EGF at 100 ng/ml (Levkowitz 1999):ODE");
	// minimizable
	_minimizableList.push_back(new SingleNetworkMinimizable());
	// parameters
	_minimizableList[4]->Initialize(_experimentList[4],_moverList[4],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	_minimizableList[4]->GetConversionFactor(4)->SetFactorFixed(true);
	_minimizableList[4]->GetConversionFactor(4)->SetFactorValue(100.0/80000.0);
	_minimizableList[4]->SetRateConstantsWeight(0.0);
	// attach observer
	_minimizableList[4]->Attach(_plotterList[4]);
	*/
	
	// NIH-3T3 cells
	// expt. 0 - NIH-3T3 cells transfected with 1.0(5) X 10^5 receptors, treated 
	//		with EGF at 100 nM concentration
	_networkList.push_back(new CEGFRTraffickingNetwork());
	_experimentList.push_back(new Experiment(_networkList[0],"EGF at 100 nM, Helin 1991"));
	// put data files here
	_experimentList[0]->AddDataFileToList("../DataFiles/TimeSeries/SurfaceEGFREGFHelin100nM.dat");
	// mover and plotter
	_moverList.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	_plotterList.push_back(new GnuPlotterTimeSeriesObserver());
	// title
	_plotterList[0]->SetTitle("EGFR Trafficking Network:EGF at 100 nM (Helin 1991):ODE");
	// minimizable
	_minimizableList.push_back(new SingleNetworkMinimizable());
	// parameters
	_minimizableList[0]->Initialize(_experimentList[0],_moverList[0],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	_minimizableList[0]->GetConversionFactor(4)->SetFactorFixed(true);
	_minimizableList[0]->GetConversionFactor(4)->SetFactorValue(100.0/100000.0);
	_minimizableList[0]->SetRateConstantsWeight(0.0);
	// attach observer
	_minimizableList[0]->Attach(_plotterList[0]);

	// expt. 1 - NIH-3T3's transfected w/ wild-type EGFR; measurements made
	//		with 10-30% of receptors initially occupied; cells express 
	//		1.0(5) X 10^5 receptors
	_networkList.push_back(new CEGFRTraffickingNetwork());
	_experimentList.push_back(new Experiment(_networkList[1],"20 Percent Initial Occupancy, Helin 1991"));
	// put data files here
	_experimentList[1]->AddDataFileToList("../DataFiles/TimeSeries/EGFHelinOccupied.dat");
	// mover and plotter
	_moverList.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	_plotterList.push_back(new GnuPlotterTimeSeriesObserver());
	// title
	_plotterList[1]->SetTitle("EGFR Trafficking Network:20 Percent Initial EGFR Occupancy (Helin 1991):ODE");
	// minimizable
	_minimizableList.push_back(new SingleNetworkMinimizable());
	// parameters
	_minimizableList[1]->Initialize(_experimentList[1],_moverList[1],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	_minimizableList[1]->GetConversionFactor(3)->SetFactorFixed(true);
	_minimizableList[1]->GetConversionFactor(3)->SetFactorValue(100.0/20000.0);
	_minimizableList[1]->SetRateConstantsWeight(0.0);
	// attach observer
	_minimizableList[1]->Attach(_plotterList[1]);

	// expt. 2 - NIH-3T3's transfected with wt EGFR; 1 X 10^5 receptors, EGF of
	//		100 ng/ml
	_networkList.push_back(new CEGFRTraffickingNetwork());
	_experimentList.push_back(new Experiment(_networkList[2],"EGF at 100 ng/ml wt1, Carter 1998"));
	// put data files here
	_experimentList[2]->AddDataFileToList("../DataFiles/TimeSeries/SurfaceEGFREGFwt1Carter.dat");
	// mover and plotter
	_moverList.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	_plotterList.push_back(new GnuPlotterTimeSeriesObserver());
	// title
	_plotterList[2]->SetTitle("EGFR Trafficking Network:EGF at 100 ng/ml, wt1 (Carter 1998):ODE");
	// minimizable
	_minimizableList.push_back(new SingleNetworkMinimizable());
	// parameters
	_minimizableList[2]->Initialize(_experimentList[2],_moverList[2],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	_minimizableList[2]->GetConversionFactor(4)->SetFactorFixed(true);
	_minimizableList[2]->GetConversionFactor(4)->SetFactorValue(100.0/100000.0);
	_minimizableList[2]->SetRateConstantsWeight(0.0);
	// attach observer
	_minimizableList[2]->Attach(_plotterList[2]);

	// expt. 3 - NIH-3T3's transfected with wt EGFR; 2.75 X 10^5 receptors, EGF of
	//		100 ng/ml
	_networkList.push_back(new CEGFRTraffickingNetwork());
	_experimentList.push_back(new Experiment(_networkList[3],"EGF at 100 ng/ml wt2, Carter 1998"));
	// put data files here
	_experimentList[3]->AddDataFileToList("../DataFiles/TimeSeries/SurfaceEGFREGFwt2Carter.dat");
	// mover and plotter
	_moverList.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	_plotterList.push_back(new GnuPlotterTimeSeriesObserver());
	// title
	_plotterList[3]->SetTitle("EGFR Trafficking Network:EGF at 100 ng/ml, wt2 (Carter 1998):ODE");
	// minimizable
	_minimizableList.push_back(new SingleNetworkMinimizable());
	// parameters
	_minimizableList[3]->Initialize(_experimentList[3],_moverList[3],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	_minimizableList[3]->GetConversionFactor(4)->SetFactorFixed(true);
	_minimizableList[3]->GetConversionFactor(4)->SetFactorValue(100.0/275000.0);
	_minimizableList[3]->SetRateConstantsWeight(0.0);
	// attach observer
	_minimizableList[3]->Attach(_plotterList[3]);
	
	// allocate the master residuals list
	int masterResidualsSize = 0;
	for(int i = 0; i < _minimizableList.size(); i++)
	{
		int subRes = _minimizableList[i]->GetNResiduals();
		masterResidualsSize += subRes;
		cout << subRes << " residuals in minimizable " << i << endl;
	}
	if(m_dGammaSquared > 0.0)
	{
		masterResidualsSize += 1;
	}
	Allocate(masterResidualsSize);

	cout << "Master Residuals size : " << masterResidualsSize << endl;

	// define the experiments
	DefineExperiments();
}

CEGFRTraffickingMinimizableDirector::~CEGFRTraffickingMinimizableDirector()
{
	for(int i = 0; i < _minimizableList.size(); i++)
	{
		_minimizableList[i]->Detach(_plotterList[i]);
	}
	for(i = 0; i < _plotterList.size(); i++)
	{
		delete _plotterList[i];
	}
}

void CEGFRTraffickingMinimizableDirector::DefineExperiments()
{	
	/*
	// CHO cells
	// 80,000 receptors assumed, EGF at 5 ng/ml
	_minimizableList[0]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(600000.0);
	_minimizableList[0]->GetExperiment()->GetReactionNetwork()->GetChemical(2)->SetInitialAmount(80000.0);
	_minimizableList[0]->GetExperiment()->GetReactionNetwork()->ChemicalReset();

	// 82,000 receptors, EGF at 100 nM
	_minimizableList[1]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(7.2e+007);
	_minimizableList[1]->GetExperiment()->GetReactionNetwork()->GetChemical(2)->SetInitialAmount(82000);
	_minimizableList[1]->GetExperiment()->GetReactionNetwork()->ChemicalReset();

	// 82,000 receptors, EGF at 10 nM
	_minimizableList[2]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(7.2e+006);
	_minimizableList[2]->GetExperiment()->GetReactionNetwork()->GetChemical(2)->SetInitialAmount(82000);
	_minimizableList[2]->GetExperiment()->GetReactionNetwork()->ChemicalReset();

	// 82,000 receptors, EGF at 1 nM
	_minimizableList[3]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(7.2e+005);
	_minimizableList[3]->GetExperiment()->GetReactionNetwork()->GetChemical(2)->SetInitialAmount(82000);
	_minimizableList[3]->GetExperiment()->GetReactionNetwork()->ChemicalReset();

	// 80,000 receptors assumed, EGF at 100 ng/ml
	_minimizableList[4]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(1.2e+007);
	_minimizableList[4]->GetExperiment()->GetReactionNetwork()->GetChemical(2)->SetInitialAmount(80000);
	_minimizableList[4]->GetExperiment()->GetReactionNetwork()->ChemicalReset();
	*/
	
	// 3T3 cells
	// 100,000 receptors, EGF at 100 nM
	_minimizableList[0]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(7.2e+007);
	_minimizableList[0]->GetExperiment()->GetReactionNetwork()->GetChemical(2)->SetInitialAmount(100000);
	_minimizableList[0]->GetExperiment()->GetReactionNetwork()->ChemicalReset();

	// No EGF, 20% of receptors on surface initially occupied
	_minimizableList[1]->GetExperiment()->GetReactionNetwork()->GetChemical(2)->SetInitialAmount(80000.0);
	_minimizableList[1]->GetExperiment()->GetReactionNetwork()->GetChemical(3)->SetInitialAmount(20000.0);
	_minimizableList[1]->GetExperiment()->GetReactionNetwork()->ChemicalReset();

	// 100,000 receptors assumed, EGF at 100 ng/ml
	_minimizableList[2]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(1.2e+007);
	_minimizableList[2]->GetExperiment()->GetReactionNetwork()->GetChemical(2)->SetInitialAmount(100000);
	_minimizableList[2]->GetExperiment()->GetReactionNetwork()->ChemicalReset();

	// 275,000 receptors assumed, EGF at 100 ng/ml
	_minimizableList[3]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(1.2e+007);
	_minimizableList[3]->GetExperiment()->GetReactionNetwork()->GetChemical(2)->SetInitialAmount(275000);
	_minimizableList[3]->GetExperiment()->GetReactionNetwork()->ChemicalReset();
	
}

double CEGFRTraffickingMinimizableDirector::GetParameter(int parIndex)
{
	// for this director, everyone has the same parameters so any set 
	// can be returned
	return _minimizableList[0]->GetParameter(parIndex);
}

int CEGFRTraffickingMinimizableDirector::GetNParameters()
{
	// ditto as for GetParameters()
	return _minimizableList[0]->GetNParameters();
}
