// EGFRTraffickingNetwork.cpp: implementation of the CEGFRTraffickingNetwork class.
//
//////////////////////////////////////////////////////////////////////

#include "EGFRTraffickingNetwork.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

CEGFRTraffickingNetwork::CEGFRTraffickingNetwork()
{
	// CFactor = #molecules/1 uM
	double CFactor = 600000;
	double SecPerMin = 60.0;

	// chemical species

	// EGF/EGFR
	// 0
	Chemical *EGF = new Chemical(chemicals.size(),0.0,"EGF");
	chemicals.push_back(EGF);

	Chemical *DegradedEGF = new Chemical(chemicals.size(),0.0,"DegradedEGF");
	chemicals.push_back(DegradedEGF);

	Chemical *EndosomalEGF = new Chemical(chemicals.size(),0.0,"EndosomalEGF");
	chemicals.push_back(EndosomalEGF);

	// two species of EGFR - coated pit and non coated pit
	Chemical *CPFreePMEGFR = new Chemical(chemicals.size(),0.0,"CPFreePMEGFR");
	chemicals.push_back(CPFreePMEGFR);

	Chemical *NonCPFreePMEGFR = new Chemical(chemicals.size(),0.0,"NonCPFreePMEGFR");
	chemicals.push_back(NonCPFreePMEGFR);

	Chemical *CPBoundPMEGFR = new Chemical(chemicals.size(),0.0,"CPBoundPMEGFR");
	chemicals.push_back(CPBoundPMEGFR);

	Chemical *NonCPBoundPMEGFR = new Chemical(chemicals.size(),0.0,"NonCPBoundPMEGFR");
	chemicals.push_back(NonCPBoundPMEGFR);
	
	Chemical *DegradedEGFR = new Chemical(chemicals.size(),0.0,"DegradedEGFR");
	chemicals.push_back(DegradedEGFR);

	Chemical *CPBoundPMEGFRCoolCbl = new Chemical(chemicals.size(),0.0,"CPBoundPMEGFRCoolCbl");
	chemicals.push_back(CPBoundPMEGFRCoolCbl);

	Chemical *NonCPBoundPMEGFRCoolCbl = new Chemical(chemicals.size(),0.0,"NonCPBoundPMEGFRCoolCbl");
	chemicals.push_back(NonCPBoundPMEGFRCoolCbl);

	// 10
	Chemical *CPBoundPMEGFRCoolCblActive = new Chemical(chemicals.size(),0.0,"CPBoundPMEGFRCoolCblActive");
	chemicals.push_back(CPBoundPMEGFRCoolCblActive);

	Chemical *NonCPBoundPMEGFRCoolCblActive = new Chemical(chemicals.size(),0.0,"NonCPBoundPMEGFRCoolCblActive");
	chemicals.push_back(NonCPBoundPMEGFRCoolCblActive);

	Chemical *UbiCPBoundPMEGFRCoolCblActive = new Chemical(chemicals.size(),0.0,"UbiCPBoundPMEGFRCoolCblActive");
	chemicals.push_back(UbiCPBoundPMEGFRCoolCblActive);

	Chemical *UbiNonCPBoundPMEGFRCoolCblActive = new Chemical(chemicals.size(),0.0,"UbiNonCPBoundPMEGFRCoolCblActive");
	chemicals.push_back(UbiNonCPBoundPMEGFRCoolCblActive);

	Chemical *NonCoatedBoundEGFR = new Chemical(chemicals.size(),0.0,"NonCoatedBoundEGFR");
	chemicals.push_back(NonCoatedBoundEGFR);

	Chemical *NonCoatedBoundEGFRCoolCblActive = new Chemical(chemicals.size(),0.0,"NonCoatedBoundEGFRCoolCblActive");
	chemicals.push_back(NonCoatedBoundEGFRCoolCblActive);

	Chemical *NonCoatedUbiBoundEGFRCoolCblActive = new Chemical(chemicals.size(),0.0,"NonCoatedUbiBoundEGFRCoolCblActive");
	chemicals.push_back(NonCoatedUbiBoundEGFRCoolCblActive);

	Chemical *ProtoCCVEGFR = new Chemical(chemicals.size(),0.0,"ProtoCCVEGFR");
	chemicals.push_back(ProtoCCVEGFR);

	Chemical *ProtoCCVEGFRCoolCblActive = new Chemical(chemicals.size(),0.0,"ProtoCCVEGFRCoolCblActive");
	chemicals.push_back(ProtoCCVEGFRCoolCblActive);

	Chemical *ProtoCCVUbiEGFRCoolCblActive = new Chemical(chemicals.size(),0.0,"ProtoCCVUbiEGFRCoolCblActive");
	chemicals.push_back(ProtoCCVUbiEGFRCoolCblActive);

	// 20
	Chemical *CCVEGFR = new Chemical(chemicals.size(),0.0,"CCVEGFR");
	chemicals.push_back(CCVEGFR);

	Chemical *CCVEGFRCoolCblActive = new Chemical(chemicals.size(),0.0,"CCVEGFRCoolCblActive");
	chemicals.push_back(CCVEGFRCoolCblActive);

	Chemical *CCVUbiEGFRCoolCblActive = new Chemical(chemicals.size(),0.0,"CCVUbiEGFRCoolCblActive");
	chemicals.push_back(CCVUbiEGFRCoolCblActive);

	Chemical *CCVEGFRACK2 = new Chemical(chemicals.size(),0.0,"CCVEGFRACK2");
	chemicals.push_back(CCVEGFRACK2);

	Chemical *CCVEGFRCoolCblActiveACK2 = new Chemical(chemicals.size(),0.0,"CCVEGFRCoolCblActiveACK2");
	chemicals.push_back(CCVEGFRCoolCblActiveACK2);

	Chemical *CCVUbiEGFRCoolCblActiveACK2 = new Chemical(chemicals.size(),0.0,"CCVUbiEGFRCoolCblActiveACK2");
	chemicals.push_back(CCVUbiEGFRCoolCblActiveACK2);

	Chemical *DeliveredEGFRACK2 = new Chemical(chemicals.size(),0.0,"DeliveredEGFRACK2");
	chemicals.push_back(DeliveredEGFRACK2);

	Chemical *DeliveredEGFRCoolCblActiveACK2 = new Chemical(chemicals.size(),0.0,"DeliveredEGFRCoolCblActiveACK2");
	chemicals.push_back(DeliveredEGFRCoolCblActiveACK2);

	Chemical *DeliveredUbiEGFRCoolCblActiveACK2 = new Chemical(chemicals.size(),0.0,"DeliveredUbiEGFRCoolCblActiveACK2");
	chemicals.push_back(DeliveredUbiEGFRCoolCblActiveACK2);

	Chemical *DeliveredEGFR = new Chemical(chemicals.size(),0.0,"DeliveredEGFR");
	chemicals.push_back(DeliveredEGFR);

	// 30
	Chemical *DeliveredEGFRCoolCblActive = new Chemical(chemicals.size(),0.0,"DeliveredEGFRCoolCblActive");
	chemicals.push_back(DeliveredEGFRCoolCblActive);

	Chemical *DeliveredUbiEGFRCoolCblActive = new Chemical(chemicals.size(),0.0,"DeliveredUbiEGFRCoolCblActive");
	chemicals.push_back(DeliveredUbiEGFRCoolCblActive);

	Chemical *BoundEndoEGFR = new Chemical(chemicals.size(),0.0,"BoundEndoEGFR");
	chemicals.push_back(BoundEndoEGFR);

	Chemical *UbiBoundEndoEGFR = new Chemical(chemicals.size(),0.0,"UbiBoundEndoEGFR");
	chemicals.push_back(UbiBoundEndoEGFR);

	Chemical *FreeEndoEGFR = new Chemical(chemicals.size(),0.0,"FreeEndoEGFR");
	chemicals.push_back(FreeEndoEGFR);

	Chemical *UbiFreeEndoEGFR = new Chemical(chemicals.size(),0.0,"UbiFreeEndoEGFR");
	chemicals.push_back(UbiFreeEndoEGFR);

	Chemical *BoundEndoEGFRCoolCblActive = new Chemical(chemicals.size(),0.0,"BoundEndoEGFRCoolCblActive");
	chemicals.push_back(BoundEndoEGFRCoolCblActive);

	Chemical *FreeEndoEGFRCoolCblActive = new Chemical(chemicals.size(),0.0,"FreeEndoEGFRCoolCblActive");
	chemicals.push_back(FreeEndoEGFRCoolCblActive);

	Chemical *UbiBoundEndoEGFRCoolCblActive = new Chemical(chemicals.size(),0.0,"UbiBoundEndoEGFRCoolCblActive");
	chemicals.push_back(UbiBoundEndoEGFRCoolCblActive);

	Chemical *UbiFreeEndoEGFRCoolCblActive = new Chemical(chemicals.size(),0.0,"UbiFreeEndoEGFRCoolCblActive");
	chemicals.push_back(UbiFreeEndoEGFRCoolCblActive);

	// 40
	Chemical *UbiFreeLysoEGFR = new Chemical(chemicals.size(),0.0,"UbiFreeLysoEGFR");
	chemicals.push_back(UbiFreeLysoEGFR);

	Chemical *EndosomalVesicle = new Chemical(chemicals.size(),0.0,"EndosomalVesicle");
	chemicals.push_back(EndosomalVesicle);

	Chemical *LysosomalVesicle = new Chemical(chemicals.size(),0.0,"LysosomalVesicle");
	chemicals.push_back(LysosomalVesicle);

	Chemical *ProtoRecyclingVesicle = new Chemical(chemicals.size(),0.0,"ProtoRecyclingVesicle");
	chemicals.push_back(ProtoRecyclingVesicle);

	Chemical *RecyclingVesicle = new Chemical(chemicals.size(),0.0,"RecyclingVesicle");
	chemicals.push_back(RecyclingVesicle);

	Chemical *Cdc42GAP = new Chemical(chemicals.size(),0.1*CFactor,"Cdc42GAP");
	chemicals.push_back(Cdc42GAP);

	// Cdc42 alone
	Chemical *Cdc42GDP = new Chemical(chemicals.size(),0.1*CFactor,"Cdc42GDP");
	chemicals.push_back(Cdc42GDP);

	Chemical *Cdc42GTP = new Chemical(chemicals.size(),0.0,"Cdc42GTP");
	chemicals.push_back(Cdc42GTP);

	Chemical *GolgiCdc42GDP = new Chemical(chemicals.size(),0.1*CFactor,"GolgiCdc42GDP");
	chemicals.push_back(GolgiCdc42GDP);

	Chemical *GolgiCdc42GTP = new Chemical(chemicals.size(),0.1*CFactor,"GolgiCdc42GTP");
	chemicals.push_back(GolgiCdc42GTP);

	// 50
	Chemical *EndoCdc42GDP = new Chemical(chemicals.size(),0.1*CFactor,"EndoCdc42GDP");
	chemicals.push_back(EndoCdc42GDP);

	// ACK and 42
	Chemical *ACK2 = new Chemical(chemicals.size(),1200,"ACK2");
	chemicals.push_back(ACK2);

	Chemical *ACK242GTP = new Chemical(chemicals.size(),0.0,"ACK242GTP");
	chemicals.push_back(ACK242GTP);

	Chemical *ACK2Active42GTP = new Chemical(chemicals.size(),0.0,"ACK2Active42GTP");
	chemicals.push_back(ACK2Active42GTP);

	Chemical *ACK2Active = new Chemical(chemicals.size(),0.0,"ACK2Active");
	chemicals.push_back(ACK2Active);

	Chemical *EndoACK2Active = new Chemical(chemicals.size(),0.0,"EndoACK2Active");
	chemicals.push_back(EndoACK2Active);

	Chemical *LysoACK2Active = new Chemical(chemicals.size(),0.0,"LysoACK2Active");
	chemicals.push_back(LysoACK2Active);

	Chemical *YPPTase1 = new Chemical(chemicals.size(),0.1*CFactor,"YPPTase1");
	chemicals.push_back(YPPTase1);

	// COP complex
	Chemical *COPI = new Chemical(chemicals.size(),0.1*CFactor,"COPI");
	chemicals.push_back(COPI);

	Chemical *EndoCOPI = new Chemical(chemicals.size(),0.0,"EndoCOPI");
	chemicals.push_back(EndoCOPI);

	// 60
	Chemical *GolgiCOPI42GTP = new Chemical(chemicals.size(),0.0,"GolgiCOPI42GTP");
	chemicals.push_back(GolgiCOPI42GTP);

	Chemical *EndoCOPI42GTP = new Chemical(chemicals.size(),0.0,"EndoCOPI42GTP");
	chemicals.push_back(EndoCOPI42GTP);

	Chemical *EndoCOPI42GDP = new Chemical(chemicals.size(),0.0,"EndoCOPI42GDP");
	chemicals.push_back(EndoCOPI42GDP);

	// Cool,Cbl,42
	Chemical *Cool1Cbl = new Chemical(chemicals.size(),0.1*CFactor,"Cool1Cbl");
	chemicals.push_back(Cool1Cbl);

	Chemical *Cool1CblActive = new Chemical(chemicals.size(),0.0,"Cool1CblActive");
	chemicals.push_back(Cool1CblActive);

	Chemical *Cool1Cbl42GTP = new Chemical(chemicals.size(),0.0,"Cool1Cbl42GTP");
	chemicals.push_back(Cool1Cbl42GTP);

	Chemical *Cool1CblActive42GTP = new Chemical(chemicals.size(),0.0,"Cool1CblActive42GTP");
	chemicals.push_back(Cool1CblActive42GTP);
		
	// 67
	std::vector<Chemical *> vec1;
	vec1.push_back(CPFreePMEGFR);
	vec1.push_back(NonCPFreePMEGFR);
	vec1.push_back(CPBoundPMEGFR);
	vec1.push_back(NonCPBoundPMEGFR);
	vec1.push_back(CPBoundPMEGFRCoolCbl);
	vec1.push_back(NonCPBoundPMEGFRCoolCbl);
	vec1.push_back(CPBoundPMEGFRCoolCblActive);
	vec1.push_back(NonCPBoundPMEGFRCoolCblActive);
	vec1.push_back(UbiCPBoundPMEGFRCoolCblActive);
	vec1.push_back(UbiNonCPBoundPMEGFRCoolCblActive);
	vec1.push_back(ProtoCCVEGFR);
	vec1.push_back(ProtoCCVEGFRCoolCblActive);
	vec1.push_back(ProtoCCVUbiEGFRCoolCblActive);
	CAlgebraicChemical *TotalPMEGFR = new CSumChemical(chemicals.size(),"TotalPMEGFR",vec1);
	TotalPMEGFR->SetAll();
	chemicals.push_back(TotalPMEGFR);
	this->AddAlgebraicIndex(TotalPMEGFR);

	// 68
	std::vector<Chemical *> vec1a;
	vec1a.push_back(CPBoundPMEGFR);
	vec1a.push_back(NonCPBoundPMEGFR);
	vec1a.push_back(CPBoundPMEGFRCoolCbl);
	vec1a.push_back(NonCPBoundPMEGFRCoolCbl);
	vec1a.push_back(CPBoundPMEGFRCoolCblActive);
	vec1a.push_back(NonCPBoundPMEGFRCoolCblActive);
	vec1a.push_back(UbiCPBoundPMEGFRCoolCblActive);
	vec1a.push_back(UbiNonCPBoundPMEGFRCoolCblActive);
	vec1a.push_back(ProtoCCVEGFR);
	vec1a.push_back(ProtoCCVEGFRCoolCblActive);
	vec1a.push_back(ProtoCCVUbiEGFRCoolCblActive);
	CAlgebraicChemical *TotalBoundPMEGFR = new CSumChemical(chemicals.size(),"TotalBoundPMEGFR",vec1a);
	TotalBoundPMEGFR->SetAll();
	chemicals.push_back(TotalBoundPMEGFR);
	this->AddAlgebraicIndex(TotalBoundPMEGFR);
	
	// 69
	std::vector<Chemical *> vec2;
	vec2.push_back(CCVEGFR);
	vec2.push_back(CCVEGFRCoolCblActive);
	vec2.push_back(CCVUbiEGFRCoolCblActive);
	vec2.push_back(CCVEGFRACK2);
	vec2.push_back(CCVEGFRCoolCblActiveACK2);
	vec2.push_back(CCVUbiEGFRCoolCblActiveACK2);
	vec2.push_back(NonCoatedBoundEGFR);
	vec2.push_back(NonCoatedBoundEGFRCoolCblActive);
	vec2.push_back(NonCoatedUbiBoundEGFRCoolCblActive);
	vec2.push_back(DeliveredEGFRACK2);
	vec2.push_back(DeliveredEGFRCoolCblActiveACK2);
	vec2.push_back(DeliveredUbiEGFRCoolCblActiveACK2);
	vec2.push_back(DeliveredEGFR);
	vec2.push_back(DeliveredEGFRCoolCblActive);
	vec2.push_back(DeliveredUbiEGFRCoolCblActive);
	vec2.push_back(BoundEndoEGFR);
	vec2.push_back(BoundEndoEGFRCoolCblActive);
	vec2.push_back(UbiBoundEndoEGFR);
	vec2.push_back(UbiBoundEndoEGFRCoolCblActive);
	vec2.push_back(EndosomalEGF);
	CAlgebraicChemical *TotalInternalEGF = new CSumChemical(chemicals.size(),"TotalInternalEGF",vec2);
	TotalInternalEGF->SetAll();
	chemicals.push_back(TotalInternalEGF);
	this->AddAlgebraicIndex(TotalInternalEGF);

	// 70
	std::vector<Chemical *> vec3;
	vec3.push_back(CCVEGFR);
	vec3.push_back(CCVEGFRCoolCblActive);
	vec3.push_back(CCVUbiEGFRCoolCblActive);
	vec3.push_back(CCVEGFRACK2);
	vec3.push_back(CCVEGFRCoolCblActiveACK2);
	vec3.push_back(CCVUbiEGFRCoolCblActiveACK2);
	vec3.push_back(NonCoatedBoundEGFR);
	vec3.push_back(NonCoatedBoundEGFRCoolCblActive);
	vec3.push_back(NonCoatedUbiBoundEGFRCoolCblActive);
	vec3.push_back(DeliveredEGFRACK2);
	vec3.push_back(DeliveredEGFRCoolCblActiveACK2);
	vec3.push_back(DeliveredUbiEGFRCoolCblActiveACK2);
	vec3.push_back(DeliveredEGFR);
	vec3.push_back(DeliveredEGFRCoolCblActive);
	vec3.push_back(DeliveredUbiEGFRCoolCblActive);
	vec3.push_back(BoundEndoEGFR);
	vec3.push_back(UbiBoundEndoEGFR);
	vec3.push_back(BoundEndoEGFRCoolCblActive);
	vec3.push_back(UbiBoundEndoEGFRCoolCblActive);
	vec3.push_back(FreeEndoEGFR);
	vec3.push_back(UbiFreeEndoEGFR);
	vec3.push_back(FreeEndoEGFRCoolCblActive);
	vec3.push_back(UbiFreeEndoEGFRCoolCblActive);
	vec3.push_back(UbiFreeLysoEGFR);
	vec3.push_back(ProtoRecyclingVesicle);
	vec3.push_back(RecyclingVesicle);
	vec3.push_back(EndosomalVesicle);
	vec3.push_back(LysosomalVesicle);
	CAlgebraicChemical *TotalInternalEGFR = new CSumChemical(chemicals.size(),"TotalInternalEGFR",vec3);
	TotalInternalEGFR->SetAll();
	chemicals.push_back(TotalInternalEGFR);
	this->AddAlgebraicIndex(TotalInternalEGFR);
	
	std::vector<Chemical *> vec4;
	vec4.push_back(CCVEGFR);
	vec4.push_back(CCVEGFRCoolCblActive);
	vec4.push_back(CCVUbiEGFRCoolCblActive);
	vec4.push_back(CCVEGFRACK2);
	vec4.push_back(CCVEGFRCoolCblActiveACK2);
	vec4.push_back(CCVUbiEGFRCoolCblActiveACK2);
	CAlgebraicChemical *TotalCCVEGFR = new CSumChemical(chemicals.size(),"TotalCCVEGFR",vec4);
	TotalCCVEGFR->SetAll();
	chemicals.push_back(TotalCCVEGFR);
	this->AddAlgebraicIndex(TotalCCVEGFR);

	std::vector<Chemical *> vec5;
	vec5.push_back(FreeEndoEGFR);
	vec5.push_back(UbiFreeEndoEGFR);
	vec5.push_back(FreeEndoEGFRCoolCblActive);
	vec5.push_back(UbiFreeEndoEGFRCoolCblActive);
	vec5.push_back(BoundEndoEGFR);
	vec5.push_back(UbiBoundEndoEGFR);
	vec5.push_back(BoundEndoEGFRCoolCblActive);
	vec5.push_back(UbiBoundEndoEGFRCoolCblActive);
	vec5.push_back(EndosomalVesicle);
	vec5.push_back(ProtoRecyclingVesicle);
	vec5.push_back(RecyclingVesicle);
	CAlgebraicChemical *TotalEndoEGFR = new CSumChemical(chemicals.size(),"TotalEndoEGFR",vec5);
	TotalEndoEGFR->SetAll();
	chemicals.push_back(TotalEndoEGFR);
	this->AddAlgebraicIndex(TotalEndoEGFR);


	Chemical *ACK242GDP= new Chemical(chemicals.size(),0.0,"ACK242GDP");
	chemicals.push_back(ACK242GDP);

	Chemical *ACK2Active42GDP = new Chemical(chemicals.size(),0.0,"ACK2Active42GDP");
	chemicals.push_back(ACK2Active42GDP);

	Chemical *Cool1Cbl42GDP = new Chemical(chemicals.size(),0.0,"Cool1Cbl42GDP");
	chemicals.push_back(Cool1Cbl42GDP);

	Chemical *Cool1CblActive42GDP = new Chemical(chemicals.size(),0.0,"Cool1CblActive42GDP");
	chemicals.push_back(Cool1CblActive42GDP);

	// 77
	std::vector<Chemical *> vec7;
	vec7.push_back(CPFreePMEGFR);
	vec7.push_back(NonCPFreePMEGFR);
	vec7.push_back(CPBoundPMEGFR);
	vec7.push_back(NonCPBoundPMEGFR);
	vec7.push_back(CPBoundPMEGFRCoolCbl);
	vec7.push_back(NonCPBoundPMEGFRCoolCbl);
	vec7.push_back(CPBoundPMEGFRCoolCblActive);
	vec7.push_back(NonCPBoundPMEGFRCoolCblActive);
	vec7.push_back(UbiCPBoundPMEGFRCoolCblActive);
	vec7.push_back(UbiNonCPBoundPMEGFRCoolCblActive);
	vec7.push_back(ProtoCCVEGFR);
	vec7.push_back(ProtoCCVEGFRCoolCblActive);
	vec7.push_back(ProtoCCVUbiEGFRCoolCblActive);
	vec7.push_back(CCVEGFR);
	vec7.push_back(CCVEGFRCoolCblActive);
	vec7.push_back(CCVUbiEGFRCoolCblActive);
	vec7.push_back(CCVEGFRACK2);
	vec7.push_back(CCVEGFRCoolCblActiveACK2);
	vec7.push_back(CCVUbiEGFRCoolCblActiveACK2);
	vec7.push_back(NonCoatedBoundEGFR);
	vec7.push_back(NonCoatedBoundEGFRCoolCblActive);
	vec7.push_back(NonCoatedUbiBoundEGFRCoolCblActive);
	vec7.push_back(DeliveredEGFRACK2);
	vec7.push_back(DeliveredEGFRCoolCblActiveACK2);
	vec7.push_back(DeliveredUbiEGFRCoolCblActiveACK2);
	vec7.push_back(DeliveredEGFR);
	vec7.push_back(DeliveredEGFRCoolCblActive);
	vec7.push_back(DeliveredUbiEGFRCoolCblActive);
	vec7.push_back(BoundEndoEGFR);
	vec7.push_back(UbiBoundEndoEGFR);
	vec7.push_back(BoundEndoEGFRCoolCblActive);
	vec7.push_back(UbiBoundEndoEGFRCoolCblActive);
	vec7.push_back(FreeEndoEGFR);
	vec7.push_back(UbiFreeEndoEGFR);
	vec7.push_back(FreeEndoEGFRCoolCblActive);
	vec7.push_back(UbiFreeEndoEGFRCoolCblActive);
	vec7.push_back(UbiFreeLysoEGFR);
	vec7.push_back(ProtoRecyclingVesicle);
	vec7.push_back(RecyclingVesicle);
	vec7.push_back(EndosomalVesicle);
	vec7.push_back(LysosomalVesicle);
	CAlgebraicChemical *TotalEGFR = new CSumChemical(chemicals.size(),"TotalEGFR",vec7);
	TotalEGFR->SetAll();
	chemicals.push_back(TotalEGFR);
	this->AddAlgebraicIndex(TotalEGFR);

	std::vector<Chemical *> vec8;
	vec8.push_back(UbiCPBoundPMEGFRCoolCblActive);
	vec8.push_back(UbiNonCPBoundPMEGFRCoolCblActive);
	vec8.push_back(ProtoCCVUbiEGFRCoolCblActive);
	vec8.push_back(CCVUbiEGFRCoolCblActive);
	vec8.push_back(CCVUbiEGFRCoolCblActiveACK2);
	vec8.push_back(DeliveredUbiEGFRCoolCblActiveACK2);
	vec8.push_back(DeliveredUbiEGFRCoolCblActive);
	vec8.push_back(UbiBoundEndoEGFRCoolCblActive);
	vec8.push_back(UbiFreeEndoEGFRCoolCblActive);
	vec8.push_back(UbiBoundEndoEGFR);
	vec8.push_back(UbiFreeEndoEGFR);
	vec8.push_back(EndosomalVesicle);
	vec8.push_back(LysosomalVesicle);
	vec8.push_back(UbiFreeLysoEGFR);
	CAlgebraicChemical *TotalUbiEGFR = new CSumChemical(chemicals.size(),"TotalUbiEGFR",vec8);
	TotalUbiEGFR->SetAll();
	chemicals.push_back(TotalUbiEGFR);
	this->AddAlgebraicIndex(TotalUbiEGFR);

	Chemical *AP2 = new Chemical(chemicals.size(),1200,"AP2");
	chemicals.push_back(AP2);

	// 80
	Chemical *RasGDP = new Chemical(chemicals.size(),30000,"RasGDP");
	chemicals.push_back(RasGDP);

	Chemical *RasGTP = new Chemical(chemicals.size(),0.0,"RasGTP");
	chemicals.push_back(RasGTP);

	Chemical *Erk = new Chemical(chemicals.size(),30000,"Erk");
	chemicals.push_back(Erk);

	Chemical *ErkP = new Chemical(chemicals.size(),0.0,"ErkP");
	chemicals.push_back(ErkP);

	Chemical *RasGAP = new Chemical(chemicals.size(),30000,"RasGAP");
	chemicals.push_back(RasGAP);

	// 85
	Chemical *PP2A = new Chemical(chemicals.size(),30000,"PP2A");
	chemicals.push_back(PP2A);

	// rate constants
	// EGF binding/unbinding
	// 0
	RateConstant *kbEGF = new RateConstant(1.0e-07,"kbEGF");
	rateConstants.push_back(kbEGF);

	RateConstant *kuEGF = new RateConstant(0.02,0.02*0.2,"kuEGF");
	rateConstants.push_back(kuEGF);

	// EGF dissociation in endosomes
	RateConstant *kuEndoEGF = new RateConstant(0.1,0.1*0.2,"kuEndoEGF");
	rateConstants.push_back(kuEndoEGF);

	// 42 activation
	RateConstant *kEGFR42 = new RateConstant(0.2,"kEGFR42");
	rateConstants.push_back(kEGFR42);

	RateConstant *KmEGFR42 = new RateConstant(CFactor,"KmEGFR42");
	rateConstants.push_back(KmEGFR42);

	// Gapping of 42
	RateConstant *kGAP = new RateConstant(0.1,"kGAP");
	rateConstants.push_back(kGAP);

	RateConstant *KmGAP = new RateConstant(2.9*CFactor,"KmGAP");
	rateConstants.push_back(KmGAP);

	// binding/unbinding of AP-2
	RateConstant *kbAP2 = new RateConstant(1.0e-07,"kbAP2");
	rateConstants.push_back(kbAP2);

	RateConstant *kuAP2 = new RateConstant(0.02,"kuAP2");
	rateConstants.push_back(kuAP2);

	// allow possibility of different endocytic rates depending upon 
	// whether receptor is ubiquitinated or not 

	RateConstant *kEndo1 = new RateConstant(3.0,"kEndo1");
	rateConstants.push_back(kEndo1);
	
	// 10
	RateConstant *kEndo2 = new RateConstant(3.0,"kEndo2");
	rateConstants.push_back(kEndo2);

	RateConstant *kSlowEndo = new RateConstant(0.02,0.02*0.2,"kSlowEndo");
	rateConstants.push_back(kSlowEndo);

	// ACK2 binding/unbinding to 42

	RateConstant *kbACKActive = new RateConstant(1.0e-07,"kbACKActive");
	rateConstants.push_back(kbACKActive);

	RateConstant *kuACKActive = new RateConstant(0.02,"kuACKActive");
	rateConstants.push_back(kuACKActive);

	RateConstant *kbACK2 = new RateConstant(1.0e-07,"kbACK2");
	rateConstants.push_back(kbACK2);

	RateConstant *kuACK2 = new RateConstant(0.02,"kuACK2");
	rateConstants.push_back(kuACK2);

	RateConstant *kuACK242GDP = new RateConstant(0.1,"kuACK242GDP");
	rateConstants.push_back(kuACK242GDP);

	RateConstant *kuACK2Active42GDP = new RateConstant(0.1,"kuACK2Active42GDP");
	rateConstants.push_back(kuACK2Active42GDP);
	
	// ACK2 activation
	
	RateConstant *kACK2 = new RateConstant(5.0,"kACK2");
	rateConstants.push_back(kACK2);

	// ACK2 dephosphorylation by PPtase

	RateConstant *kdACK2 = new RateConstant(0.1,"kdACK2");
	rateConstants.push_back(kdACK2);

	// 20
	RateConstant *KmdACK2 = new RateConstant(CFactor,"KmdACK2");
	rateConstants.push_back(KmdACK2);

	// ACK2 binding/unbinding to the CCV

	RateConstant *kbACK2CCV = new RateConstant(1.0e-07,"kbACK2CCV");
	rateConstants.push_back(kbACK2CCV);

	RateConstant *kuACK2CCV = new RateConstant(0.02,"kuACK2CCV");
	rateConstants.push_back(kuACK2CCV);

	// Delivery of ACK-bound CCVs

	RateConstant *kTrans = new RateConstant(1.5,"kTrans");
	rateConstants.push_back(kTrans);

	// Delivery of non clathrin-coated vesicles
	RateConstant *kSlowTrans = new RateConstant(0.05,0.05*0.2,"kSlowTrans");
	rateConstants.push_back(kSlowTrans);

	// Endosomal to lysosomal transfer

	RateConstant *kEndoLyso = new RateConstant(1.5,"kEndoLyso");
	rateConstants.push_back(kEndoLyso);

	// Degradation of EGF

	RateConstant *kdegEGF = new RateConstant(0.25,"kdegEGF");
	rateConstants.push_back(kdegEGF);

	// Proteolysis of EGFR

	RateConstant *kProt = new RateConstant(2.5,"kProt");
	rateConstants.push_back(kProt);

	// Cbl binding to the receptor
	
	RateConstant *kbCbl = new RateConstant(1.0e-07,"kbCbl");
	rateConstants.push_back(kbCbl);

	// Cbl unbinding from a ubiquitinated receptor
	
	RateConstant *kuCblUbi = new RateConstant(1.0e-02,"kuCblUbi");
	rateConstants.push_back(kuCblUbi);

	// Cbl when bound to EGF receptor - activation and ubiquitination
	// 30
	RateConstant *kCbl = new RateConstant(5.0,"kCbl");
	rateConstants.push_back(kCbl);

	RateConstant *kUbi = new RateConstant(5.0,"kUbi");
	rateConstants.push_back(kUbi);

	// Cool/Cbl and 42 binding/unbinding

	RateConstant *kbCbl42 = new RateConstant(1.0e-07,"kbCbl42");
	rateConstants.push_back(kbCbl42);

	RateConstant *kuCbl42 = new RateConstant(0.02,"kuCbl42");
	rateConstants.push_back(kuCbl42);

	RateConstant *kbCblActive42 = new RateConstant(1.0e-07,"kbCblActive42");
	rateConstants.push_back(kbCblActive42);

	RateConstant *kuCblActive42 = new RateConstant(0.02,"kuCblActive42");
	rateConstants.push_back(kuCblActive42);

	RateConstant *kuCool1Cbl42GDP = new RateConstant(0.1,"kuCool1Cbl42GDP");
	rateConstants.push_back(kuCool1Cbl42GDP);

	RateConstant *kuCool1CblActive42GDP = new RateConstant(0.1,"kuCool1CblActive42GDP");
	rateConstants.push_back(kuCool1CblActive42GDP);

	RateConstant *kbCOPI = new RateConstant(1.0e-07,"kbCOPI");
	rateConstants.push_back(kbCOPI);

	RateConstant *kuCOPI = new RateConstant(0.02,"kuCOPI");
	rateConstants.push_back(kuCOPI);

	RateConstant *kRec = new RateConstant(0.5,"kRec");
	rateConstants.push_back(kRec);

	// rapid recyling from non-clathrin coated pathway

	RateConstant *kFastRec = new RateConstant(2.0,"kFastRec");
	rateConstants.push_back(kFastRec);

	// autoactivation of F28

	RateConstant *kF28 = new RateConstant(10.0,"kF28");
	rateConstants.push_back(kF28);

	// transition parameters between the two pools
	RateConstant *k12 = new RateConstant(0.1,"k12");
	rateConstants.push_back(k12);

	RateConstant *k21 = new RateConstant(0.01,"k21");
	rateConstants.push_back(k21);

	RateConstant *K = new RateConstant(10000,"K");
	rateConstants.push_back(K);

	RateConstant *kbEV = new RateConstant(1.0e-07,"kbEV");
	rateConstants.push_back(kbEV);

	RateConstant *kuEV = new RateConstant(0.2,"kuEV");
	rateConstants.push_back(kuEV);

	RateConstant *ktACK2 = new RateConstant(2.0,"ktACK2");
	rateConstants.push_back(ktACK2);

	RateConstant *kt42 = new RateConstant(2.0,"kt42");
	rateConstants.push_back(kt42);

	RateConstant *ktCOPI = new RateConstant(2.0,"ktCOPI");
	rateConstants.push_back(ktCOPI);

	RateConstant *ktg42 = new RateConstant(2.0,"ktg42");
	rateConstants.push_back(ktg42);

	RateConstant *kbRV = new RateConstant(1.0e-07,"kbRV");
	rateConstants.push_back(kbRV);

	RateConstant *kuRV = new RateConstant(0.2,"kuRV");
	rateConstants.push_back(kuRV);

	// MAPK cascade

	RateConstant *kRas = new RateConstant(1.1,"kRas");
	rateConstants.push_back(kRas);

	RateConstant *KmRas = new RateConstant(60000,"KmRas");
	rateConstants.push_back(KmRas);

	RateConstant *kRasGAP = new RateConstant(0.5,"kRasGAP");
	rateConstants.push_back(kRasGAP);

	RateConstant *KmRasGAP = new RateConstant(60000,"KmRasGAP");
	rateConstants.push_back(KmRasGAP);

	RateConstant *kErk = new RateConstant(1.1,"kErk");
	rateConstants.push_back(kErk);

	RateConstant *KmErk = new RateConstant(60000,"KmErk");
	rateConstants.push_back(KmErk);

	RateConstant *kdErk = new RateConstant(0.5,"kdErk");
	rateConstants.push_back(kdErk);

	RateConstant *KmdErk = new RateConstant(60000,"KmdErk");
	rateConstants.push_back(KmdErk);

	RateConstant *kErkRas = new RateConstant(1.1,"kErkRas");
	rateConstants.push_back(kErkRas);

	RateConstant *KmErkRas = new RateConstant(60000,"KmErkRas");
	rateConstants.push_back(KmErkRas);


	// reactions
	// 0
	// EGF binding/unbinding
	Reaction *EGFBinding1 = new ReceptorBindingReaction(EGF,CPFreePMEGFR,CPBoundPMEGFR,kbEGF,"EGFBinding1");
	reactions.push_back(EGFBinding1);

	Reaction *EGFBinding2 = new ReceptorBindingReaction(EGF,NonCPFreePMEGFR,NonCPBoundPMEGFR,kbEGF,"EGFBinding2");
	reactions.push_back(EGFBinding2);

	Reaction *EGFUnbinding1 = new ReceptorUnbindingReaction(CPBoundPMEGFR,CPFreePMEGFR,EGF,kuEGF,"EGFUnbinding1");
	reactions.push_back(EGFUnbinding1);

	Reaction *EGFUnbinding2 = new ReceptorUnbindingReaction(NonCPBoundPMEGFR,NonCPFreePMEGFR,EGF,kuEGF,"EGFUnbinding2");
	reactions.push_back(EGFUnbinding2);

	// transitions between the two pools
	Reaction *CPToNonCP1 = new TransformationReaction(CPFreePMEGFR,NonCPFreePMEGFR,k21,"CPToNonCP1");
	reactions.push_back(CPToNonCP1);

	Reaction *CPToNonCP2 = new TransformationReaction(CPBoundPMEGFR,NonCPBoundPMEGFR,k21,"CPToNonCP2");
	reactions.push_back(CPToNonCP2);
	
	Reaction *CPToNonCP3 = new TransformationReaction(CPBoundPMEGFRCoolCbl,NonCPBoundPMEGFRCoolCbl,k21,"CPToNonCP3");
	reactions.push_back(CPToNonCP3);
	
	Reaction *CPToNonCP4 = new TransformationReaction(CPBoundPMEGFRCoolCblActive,NonCPBoundPMEGFRCoolCblActive,k21,"CPToNonCP4");
	reactions.push_back(CPToNonCP4);

	Reaction *CPToNonCP5 = new TransformationReaction(UbiCPBoundPMEGFRCoolCblActive,UbiNonCPBoundPMEGFRCoolCblActive,k21,"CPToNonCP5");
	reactions.push_back(CPToNonCP5);
	
	// transitions between the two pools
	Reaction *NonCPToCP1 = new CPoolTransitionReaction(NonCPFreePMEGFR,CPFreePMEGFR,k12,K,"NonCPToCP1");
	reactions.push_back(NonCPToCP1);

	// 10
	Reaction *NonCPToCP2 = new CPoolTransitionReaction(NonCPBoundPMEGFR,CPBoundPMEGFR,k12,K,"NonCPToCP2");
	reactions.push_back(NonCPToCP2);
	
	Reaction *NonCPToCP3 = new CPoolTransitionReaction(NonCPBoundPMEGFRCoolCbl,CPBoundPMEGFRCoolCbl,k12,K,"NonCPToCP3");
	reactions.push_back(NonCPToCP3);
	
	Reaction *NonCPToCP4 = new CPoolTransitionReaction(NonCPBoundPMEGFRCoolCblActive,CPBoundPMEGFRCoolCblActive,k12,K,"NonCPToCP4");
	reactions.push_back(NonCPToCP4);

	Reaction *NonCPToCP5 = new CPoolTransitionReaction(UbiNonCPBoundPMEGFRCoolCblActive,UbiCPBoundPMEGFRCoolCblActive,k12,K,"NonCPToCP5");
	reactions.push_back(NonCPToCP5);


	// 42 activation - PM

	Reaction *Cdc42PMActivation1 = new MichaelisMentenGProteinActivationReaction(CPBoundPMEGFR,Cdc42GDP,Cdc42GTP,kEGFR42,KmEGFR42,"Cdc42PMActivation1");
	reactions.push_back(Cdc42PMActivation1);

	Reaction *Cdc42PMActivation2 = new MichaelisMentenGProteinActivationReaction(CPBoundPMEGFRCoolCbl,Cdc42GDP,Cdc42GTP,kEGFR42,KmEGFR42,"Cdc42PMActivation2");
	reactions.push_back(Cdc42PMActivation2);

	Reaction *Cdc42PMActivation3 = new MichaelisMentenGProteinActivationReaction(CPBoundPMEGFRCoolCblActive,Cdc42GDP,Cdc42GTP,kEGFR42,KmEGFR42,"Cdc42PMActivation3");
	reactions.push_back(Cdc42PMActivation3);

	Reaction *Cdc42PMActivation4 = new MichaelisMentenGProteinActivationReaction(UbiCPBoundPMEGFRCoolCblActive,Cdc42GDP,Cdc42GTP,kEGFR42,KmEGFR42,"Cdc42PMActivation4");
	reactions.push_back(Cdc42PMActivation4);

	Reaction *Cdc42PMActivation5 = new MichaelisMentenGProteinActivationReaction(NonCPBoundPMEGFR,Cdc42GDP,Cdc42GTP,kEGFR42,KmEGFR42,"Cdc42PMActivation5");
	reactions.push_back(Cdc42PMActivation5);

	Reaction *Cdc42PMActivation6 = new MichaelisMentenGProteinActivationReaction(NonCPBoundPMEGFRCoolCbl,Cdc42GDP,Cdc42GTP,kEGFR42,KmEGFR42,"Cdc42PMActivation6");
	reactions.push_back(Cdc42PMActivation6);

	// 20
	Reaction *Cdc42PMActivation7 = new MichaelisMentenGProteinActivationReaction(NonCPBoundPMEGFRCoolCblActive,Cdc42GDP,Cdc42GTP,kEGFR42,KmEGFR42,"Cdc42PMActivation7");
	reactions.push_back(Cdc42PMActivation7);

	Reaction *Cdc42PMActivation8 = new MichaelisMentenGProteinActivationReaction(UbiNonCPBoundPMEGFRCoolCblActive,Cdc42GDP,Cdc42GTP,kEGFR42,KmEGFR42,"Cdc42PMActivation8");
	reactions.push_back(Cdc42PMActivation8);

	// 42 activation - Golgi

	Reaction *Cdc42GolgiActivation1 = new MichaelisMentenGProteinActivationReaction(CPBoundPMEGFR,GolgiCdc42GDP,GolgiCdc42GTP,kEGFR42,KmEGFR42,"Cdc42GolgiActivation1");
	reactions.push_back(Cdc42GolgiActivation1);

	Reaction *Cdc42GolgiActivation2 = new MichaelisMentenGProteinActivationReaction(CPBoundPMEGFRCoolCbl,GolgiCdc42GDP,GolgiCdc42GTP,kEGFR42,KmEGFR42,"Cdc42GolgiActivation2");
	reactions.push_back(Cdc42GolgiActivation2);

	Reaction *Cdc42GolgiActivation3 = new MichaelisMentenGProteinActivationReaction(CPBoundPMEGFRCoolCblActive,GolgiCdc42GDP,GolgiCdc42GTP,kEGFR42,KmEGFR42,"Cdc42GolgiActivation3");
	reactions.push_back(Cdc42GolgiActivation3);

	Reaction *Cdc42GolgiActivation4 = new MichaelisMentenGProteinActivationReaction(UbiCPBoundPMEGFRCoolCblActive,GolgiCdc42GDP,GolgiCdc42GTP,kEGFR42,KmEGFR42,"Cdc42GolgiActivation4");
	reactions.push_back(Cdc42GolgiActivation4);

	Reaction *Cdc42GolgiActivation5 = new MichaelisMentenGProteinActivationReaction(NonCPBoundPMEGFR,GolgiCdc42GDP,GolgiCdc42GTP,kEGFR42,KmEGFR42,"Cdc42GolgiActivation5");
	reactions.push_back(Cdc42GolgiActivation5);

	Reaction *Cdc42GolgiActivation6 = new MichaelisMentenGProteinActivationReaction(NonCPBoundPMEGFRCoolCbl,GolgiCdc42GDP,GolgiCdc42GTP,kEGFR42,KmEGFR42,"Cdc42GolgiActivation6");
	reactions.push_back(Cdc42GolgiActivation6);

	Reaction *Cdc42GolgiActivation7 = new MichaelisMentenGProteinActivationReaction(NonCPBoundPMEGFRCoolCblActive,GolgiCdc42GDP,GolgiCdc42GTP,kEGFR42,KmEGFR42,"Cdc42GolgiActivation7");
	reactions.push_back(Cdc42GolgiActivation7);

	Reaction *Cdc42GolgiActivation8 = new MichaelisMentenGProteinActivationReaction(UbiNonCPBoundPMEGFRCoolCblActive,GolgiCdc42GDP,GolgiCdc42GTP,kEGFR42,KmEGFR42,"Cdc42GolgiActivation8");
	reactions.push_back(Cdc42GolgiActivation8);


	// gapping of free 42
	// 30
	Reaction *Cdc42GAPHydrolysis1 = new MichaelisMentenGProteinDeactivationReaction(Cdc42GAP,Cdc42GTP,Cdc42GDP,kGAP,KmGAP,"Cdc42GAPHydrolysis1");
	reactions.push_back(Cdc42GAPHydrolysis1);

	Reaction *Cdc42GAPHydrolysis2 = new MichaelisMentenGProteinDeactivationReaction(Cdc42GAP,GolgiCdc42GTP,GolgiCdc42GDP,kGAP,KmGAP,"Cdc42GAPHydrolysis2"); 
	reactions.push_back(Cdc42GAPHydrolysis2);

	// assembly of proto CCV
	Reaction *Proto1 = new HeterodimerizationReaction(CPBoundPMEGFR,AP2,ProtoCCVEGFR,kbAP2,"Proto1");
	reactions.push_back(Proto1);

	Reaction *Proto2 = new HeterodimerizationReaction(CPBoundPMEGFRCoolCblActive,AP2,ProtoCCVEGFRCoolCblActive,kbAP2,"Proto2");
	reactions.push_back(Proto2);

	Reaction *Proto3 = new HeterodimerizationReaction(UbiCPBoundPMEGFRCoolCblActive,AP2,ProtoCCVUbiEGFRCoolCblActive,kbAP2,"Proto3");
	reactions.push_back(Proto3);

	// endocytosis
	Reaction *Endocytosis1 = new TransformationReaction(ProtoCCVEGFR,CCVEGFR,kEndo1,"Endocytosis1");
	reactions.push_back(Endocytosis1);

	Reaction *Endocytosis2 = new TransformationReaction(ProtoCCVEGFRCoolCblActive,CCVEGFRCoolCblActive,kEndo1,"Endocytosis2");
	reactions.push_back(Endocytosis2);

	Reaction *Endocytosis3 = new TransformationReaction(ProtoCCVUbiEGFRCoolCblActive,CCVUbiEGFRCoolCblActive,kEndo2,"Endocytosis3");
	reactions.push_back(Endocytosis3);

	Reaction *SlowEndo1 = new TransformationReaction(NonCPBoundPMEGFR,NonCoatedBoundEGFR,kSlowEndo,"SlowEndo1");
	reactions.push_back(SlowEndo1);

	Reaction *SlowEndo2 = new TransformationReaction(NonCPBoundPMEGFRCoolCblActive,NonCoatedBoundEGFRCoolCblActive,kSlowEndo,"SlowEndo1");
	reactions.push_back(SlowEndo2);

	// 40
	Reaction *SlowEndo3 = new TransformationReaction(UbiNonCPBoundPMEGFRCoolCblActive,NonCoatedUbiBoundEGFRCoolCblActive,kSlowEndo,"SlowEndo3");
	reactions.push_back(SlowEndo3);

	// ACK2 and 42 cycle
	Reaction *ACK42Binding = new HeterodimerizationReaction(ACK2,Cdc42GTP,ACK242GTP,kbACK2,"ACK42Binding");
	reactions.push_back(ACK42Binding);

	Reaction *ACK42Unbinding = new HeterodimerDissociationReaction(ACK242GTP,ACK2,Cdc42GTP,kuACK2,"ACK42Unbinding");
	reactions.push_back(ACK42Unbinding);

	Reaction *ACK2Active42Binding = new HeterodimerizationReaction(ACK2Active,Cdc42GTP,ACK2Active42GTP,kbACKActive,"ACK2Active42Binding");
	reactions.push_back(ACK2Active42Binding);

	Reaction *ACK2Active42Unbinding = new HeterodimerDissociationReaction(ACK2Active42GTP,ACK2Active,Cdc42GTP,kuACKActive,"ACK2Active42Unbinding");
	reactions.push_back(ACK2Active42Unbinding);

	Reaction *ACK2Activation = new TransformationReaction(ACK242GTP,ACK2Active42GTP,kACK2,"ACK2Activation");
	reactions.push_back(ACK2Activation);

	Reaction *ACK2Deactivation = new MichaelisMentenDephosphorylationReaction(YPPTase1,ACK2Active,ACK2,kdACK2,KmdACK2,"ACK2Deactivation");
	reactions.push_back(ACK2Deactivation);

	Reaction *ACK242GAPing = new MichaelisMentenGProteinDeactivationReaction(Cdc42GAP,ACK242GTP,ACK242GDP,kGAP,KmGAP,"ACK242GAPing");
	reactions.push_back(ACK242GAPing);

	Reaction *ACK2Active42GAPing = new MichaelisMentenGProteinDeactivationReaction(Cdc42GAP,ACK2Active42GTP,ACK2Active42GDP,kGAP,KmGAP,"ACK2Active42GAPing");
	reactions.push_back(ACK2Active42GAPing);

	Reaction *ACK242GDPRelease = new HeterodimerDissociationReaction(ACK242GDP,ACK2,Cdc42GDP,kuACK242GDP,"ACK242GDPRelease");
	reactions.push_back(ACK242GDPRelease);

	// 50
	Reaction *ACK2Active42GDPRelease = new HeterodimerDissociationReaction(ACK2Active42GDP,ACK2Active,Cdc42GDP,kuACK2Active42GDP,"ACK2Active42GDPRelease");
	reactions.push_back(ACK2Active42GDPRelease);

	// Cool/Cbl and 42 cycle
	Reaction *CoolCbl42Binding = new HeterodimerizationReaction(Cool1Cbl,Cdc42GTP,Cool1Cbl42GTP,kbCbl42,"CoolCbl42Binding");
	reactions.push_back(CoolCbl42Binding);

	Reaction *CoolCbl42Unbinding = new HeterodimerDissociationReaction(Cool1Cbl42GTP,Cool1Cbl,Cdc42GTP,kuCbl42,"CoolCbl42Unbinding");
	reactions.push_back(CoolCbl42Unbinding);

	Reaction *CoolCblActive42Binding = new HeterodimerizationReaction(Cool1CblActive,Cdc42GTP,Cool1CblActive42GTP,kbCblActive42,"CoolCblActive42Binding");
	reactions.push_back(CoolCblActive42Binding);

	Reaction *CoolCblActive42Unbinding = new HeterodimerDissociationReaction(Cool1CblActive42GTP,Cool1CblActive,Cdc42GTP,kuCblActive42,"CoolCblActive42Unbinding");
	reactions.push_back(CoolCblActive42Unbinding);

	Reaction *CoolCbl42GAPing = new MichaelisMentenGProteinDeactivationReaction(Cdc42GAP,Cool1Cbl42GTP,Cool1Cbl42GDP,kGAP,KmGAP,"CoolCbl42GAPing");
	reactions.push_back(CoolCbl42GAPing);

	Reaction *CoolCblActive42GAPing = new MichaelisMentenGProteinDeactivationReaction(Cdc42GAP,Cool1CblActive42GTP,Cool1CblActive42GDP,kGAP,KmGAP,"CoolCblActive42GAPing");
	reactions.push_back(CoolCblActive42GAPing);

	Reaction *CoolCbl42GDPRelease = new HeterodimerDissociationReaction(Cool1Cbl42GDP,Cool1Cbl,Cdc42GDP,kuCool1Cbl42GDP,"CoolCbl42GDPRelease");
	reactions.push_back(CoolCbl42GDPRelease);
	
	Reaction *CoolCblActive42GDPRelease = new HeterodimerDissociationReaction(Cool1CblActive42GDP,Cool1CblActive,Cdc42GDP,kuCool1CblActive42GDP,"CoolCblActive42GDPRelease");
	reactions.push_back(CoolCblActive42GDPRelease);

	// transfer to endosomes

	Reaction *ACKBinding1 = new HeterodimerizationReaction(ACK2Active,CCVEGFR,CCVEGFRACK2,kbACK2CCV,"ACKBinding1");
	reactions.push_back(ACKBinding1);

	// 60
	Reaction *ACKBinding2 = new HeterodimerizationReaction(ACK2Active,CCVEGFRCoolCblActive,CCVEGFRCoolCblActiveACK2,kbACK2CCV,"ACKBinding2");
	reactions.push_back(ACKBinding2);
	
	Reaction *ACKBinding3 = new HeterodimerizationReaction(ACK2Active,CCVUbiEGFRCoolCblActive,CCVUbiEGFRCoolCblActiveACK2,kbACK2CCV,"ACKBinding3");
	reactions.push_back(ACKBinding3);

	Reaction *Delivery1 = new TransformationReaction(CCVEGFRACK2,DeliveredEGFRACK2,kTrans,"Delivery1");
	reactions.push_back(Delivery1);

	Reaction *Delivery2 = new TransformationReaction(CCVEGFRCoolCblActiveACK2,DeliveredEGFRCoolCblActiveACK2,kTrans,"Delivery2");
	reactions.push_back(Delivery2);

	Reaction *Delivery3 = new TransformationReaction(CCVUbiEGFRCoolCblActiveACK2,DeliveredUbiEGFRCoolCblActiveACK2,kTrans,"Delivery3");
	reactions.push_back(Delivery3);

	Reaction *Delivery4 = new TransformationReaction(CCVEGFR,DeliveredEGFR,kTrans,"Delivery4");
	reactions.push_back(Delivery4);

	Reaction *Delivery5 = new TransformationReaction(CCVEGFRCoolCblActive,DeliveredEGFRCoolCblActive,kTrans,"Delivery5");
	reactions.push_back(Delivery5);

	Reaction *Delivery6 = new TransformationReaction(CCVUbiEGFRCoolCblActive,DeliveredUbiEGFRCoolCblActive,kTrans,"Delivery6");
	reactions.push_back(Delivery6);

	Reaction *ACKRelease1 = new HeterodimerDissociationReaction(DeliveredEGFRACK2,DeliveredEGFR,EndoACK2Active,kuACK2CCV,"ACKRelease1");
	reactions.push_back(ACKRelease1);

	Reaction *ACKRelease2 = new HeterodimerDissociationReaction(DeliveredEGFRCoolCblActiveACK2,DeliveredEGFRCoolCblActive,EndoACK2Active,kuACK2CCV,"ACKRelease2");
	reactions.push_back(ACKRelease2);

	// 70
	Reaction *ACKRelease3 = new HeterodimerDissociationReaction(DeliveredUbiEGFRCoolCblActiveACK2,DeliveredUbiEGFRCoolCblActive,EndoACK2Active,kuACK2CCV,"ACKRelease3");
	reactions.push_back(ACKRelease3);

	Reaction *SlowSort1 = new TransformationReaction(NonCoatedBoundEGFR,BoundEndoEGFR,kSlowTrans,"SlowSort1");
	reactions.push_back(SlowSort1);

	Reaction *SlowSort2 = new TransformationReaction(NonCoatedBoundEGFRCoolCblActive,BoundEndoEGFRCoolCblActive,kSlowTrans,"SlowSort2");
	reactions.push_back(SlowSort2);

	Reaction *SlowSort3 = new TransformationReaction(NonCoatedUbiBoundEGFRCoolCblActive,UbiBoundEndoEGFRCoolCblActive,kSlowTrans,"SlowSort3");
	reactions.push_back(SlowSort3);

	// fusion with endosome, AP2 release
	Reaction *EndoFusion1 = new HeterodimerDissociationReaction(DeliveredEGFR,BoundEndoEGFR,AP2,kuAP2,"EndoFusion1");
	reactions.push_back(EndoFusion1);

	Reaction *EndoFusion2 = new HeterodimerDissociationReaction(DeliveredEGFRCoolCblActive,BoundEndoEGFRCoolCblActive,AP2,kuAP2,"EndoFusion2");
	reactions.push_back(EndoFusion2);

	Reaction *EndoFusion3 = new HeterodimerDissociationReaction(DeliveredUbiEGFRCoolCblActive,UbiBoundEndoEGFRCoolCblActive,AP2,kuAP2,"EndoFusion3");
	reactions.push_back(EndoFusion3);

	// Formation of sorting vesicles and lysosomal transfer

	Reaction *SortingVesicleFormation = new HeterodimerizationReaction(UbiFreeEndoEGFR,EndoACK2Active,EndosomalVesicle,kbEV,"SortingVesicleFormation");
	reactions.push_back(SortingVesicleFormation);

	Reaction *LysosomalTransfer = new TransformationReaction(EndosomalVesicle,LysosomalVesicle,kEndoLyso,"LysosomalTransfer");
	reactions.push_back(LysosomalTransfer);

	Reaction *LysosomalFusion = new HeterodimerDissociationReaction(LysosomalVesicle,LysoACK2Active,UbiFreeLysoEGFR,kuEV,"LysosomalFusion");
	reactions.push_back(LysosomalFusion);

	// 80
	Reaction *ACK2Recycling = new TransformationReaction(LysoACK2Active,EndoACK2Active,ktACK2,"ACK2Recycling");
	reactions.push_back(ACK2Recycling);


	// EGF dissociation/degradation in endosomes
	Reaction *EGFDissociation1 = new ReceptorUnbindingReaction(BoundEndoEGFR,FreeEndoEGFR,EndosomalEGF,kuEndoEGF,"EGFDissociation1");
	reactions.push_back(EGFDissociation1);

	Reaction *EGFDissociation2 = new ReceptorUnbindingReaction(UbiBoundEndoEGFR,UbiFreeEndoEGFR,EndosomalEGF,kuEndoEGF,"EGFDissociation2");
	reactions.push_back(EGFDissociation2);

	Reaction *EGFDissociation3 = new ReceptorUnbindingReaction(BoundEndoEGFRCoolCblActive,FreeEndoEGFRCoolCblActive,EndosomalEGF,kuEndoEGF,"EGFDissociation3");
	reactions.push_back(EGFDissociation3);

	Reaction *EGFDissociation4 = new ReceptorUnbindingReaction(UbiBoundEndoEGFRCoolCblActive,UbiFreeEndoEGFRCoolCblActive,EndosomalEGF,kuEndoEGF,"EGFDissociation4");
	reactions.push_back(EGFDissociation4);

	Reaction *LigandDegradation = new TransformationReaction(EndosomalEGF,DegradedEGF,kdegEGF,"EGFDegradation");
	reactions.push_back(LigandDegradation);

	// CoolCbl binding to receptor
	Reaction *EGFRCoolCblBinding1 = new HeterodimerizationReaction(CPBoundPMEGFR,Cool1Cbl,CPBoundPMEGFRCoolCbl,kbCbl,"InactiveCblBinding1");
	reactions.push_back(EGFRCoolCblBinding1);

	Reaction *EGFRCoolCblBinding2 = new HeterodimerizationReaction(NonCPBoundPMEGFR,Cool1Cbl,NonCPBoundPMEGFRCoolCbl,kbCbl,"InactiveCblBinding2");
	reactions.push_back(EGFRCoolCblBinding2);

	Reaction *EGFRCoolCblActiveBinding1 = new HeterodimerizationReaction(CPBoundPMEGFR,Cool1CblActive,CPBoundPMEGFRCoolCblActive,kbCbl,"ActiveCblBinding1");
	reactions.push_back(EGFRCoolCblActiveBinding1);

	Reaction *EGFRCoolCblActiveBinding2 = new HeterodimerizationReaction(NonCPBoundPMEGFR,Cool1CblActive,NonCPBoundPMEGFRCoolCblActive,kbCbl,"ActiveCblBinding2");
	reactions.push_back(EGFRCoolCblActiveBinding2);

	// 90
	Reaction *EndoCoolCblActiveBinding = new HeterodimerizationReaction(BoundEndoEGFR,Cool1CblActive,BoundEndoEGFRCoolCblActive,kbCbl,"EndoActiveCblBinding");
	reactions.push_back(EndoCoolCblActiveBinding);

	// CoolCbl phosphorylation
	Reaction *EGFRCoolCblActivation1 = new TransformationReaction(CPBoundPMEGFRCoolCbl,CPBoundPMEGFRCoolCblActive,kCbl,"EGFRCoolCblActivation1");
	reactions.push_back(EGFRCoolCblActivation1);

	Reaction *EGFRCoolCblActivation2 = new TransformationReaction(NonCPBoundPMEGFRCoolCbl,NonCPBoundPMEGFRCoolCblActive,kCbl,"EGFRCoolCblActivation2");
	reactions.push_back(EGFRCoolCblActivation2);

	// ubiquitination 
	Reaction *MembraneUbi1 = new TransformationReaction(CPBoundPMEGFRCoolCblActive,UbiCPBoundPMEGFRCoolCblActive,kUbi,"MembraneUbi1");
	reactions.push_back(MembraneUbi1);

	Reaction *MembraneUbi2 = new TransformationReaction(NonCPBoundPMEGFRCoolCblActive,UbiNonCPBoundPMEGFRCoolCblActive,kUbi,"MembraneUbi2");
	reactions.push_back(MembraneUbi2);

	Reaction *ProtoUbi = new TransformationReaction(ProtoCCVEGFRCoolCblActive,ProtoCCVUbiEGFRCoolCblActive,kUbi,"ProtoUbi");
	reactions.push_back(ProtoUbi);

	Reaction *VesicleUbi = new TransformationReaction(CCVEGFRCoolCblActive,CCVUbiEGFRCoolCblActive,kUbi,"VesicleUbi");
	reactions.push_back(VesicleUbi);

	Reaction *VesicleUbi2 = new TransformationReaction(CCVEGFRCoolCblActiveACK2,CCVUbiEGFRCoolCblActiveACK2,kUbi,"VesicleUbi2");
	reactions.push_back(VesicleUbi2);

	Reaction *DeliveredUbi1 = new TransformationReaction(DeliveredEGFRCoolCblActiveACK2,DeliveredUbiEGFRCoolCblActiveACK2,kUbi,"DeliveredUbi1");
	reactions.push_back(DeliveredUbi1);

	Reaction *DeliveredUbi2 = new TransformationReaction(DeliveredEGFRCoolCblActive,DeliveredUbiEGFRCoolCblActive,kUbi,"DeliveredUbi2");
	reactions.push_back(DeliveredUbi2);

	// 100
	Reaction *NonCoatedUbi = new TransformationReaction(NonCoatedBoundEGFRCoolCblActive,NonCoatedUbiBoundEGFRCoolCblActive,kUbi,"NonCoatedUbi");
	reactions.push_back(NonCoatedUbi);

	Reaction *EndoUbi1 = new TransformationReaction(BoundEndoEGFRCoolCblActive,UbiBoundEndoEGFRCoolCblActive,kUbi,"EndoUbi1");
	reactions.push_back(EndoUbi1);

	Reaction *EndoUbi2 = new TransformationReaction(FreeEndoEGFRCoolCblActive,UbiFreeEndoEGFRCoolCblActive,kUbi,"EndoUbi2");
	reactions.push_back(EndoUbi2);

	// CoolCbl release

	Reaction *CoolCblDissociation1 = new HeterodimerDissociationReaction(UbiBoundEndoEGFRCoolCblActive,UbiBoundEndoEGFR,Cool1CblActive,kuCblUbi,"CoolCblDissociation1");
	reactions.push_back(CoolCblDissociation1);

	Reaction *CoolCblDissociation2 = new HeterodimerDissociationReaction(UbiFreeEndoEGFRCoolCblActive,UbiFreeEndoEGFR,Cool1CblActive,kuCblUbi,"CoolCblDissociation2");
	reactions.push_back(CoolCblDissociation2);

	// EGFR proteolysis 
	Reaction *FreeEGFRProteolysis = new TransformationReaction(UbiFreeLysoEGFR,DegradedEGFR,kProt,"FreeEGFRProteolysis");
	reactions.push_back(FreeEGFRProteolysis);

	// 42 movement between Golgi and Endosomes
	Reaction *Cdc42COPIBinding = new HeterodimerizationReaction(GolgiCdc42GTP,COPI,GolgiCOPI42GTP,kbCOPI,"Cdc42COPIBinding");
	reactions.push_back(Cdc42COPIBinding);

	Reaction *Endosomal42Transfer = new TransformationReaction(GolgiCOPI42GTP,EndoCOPI42GTP,kt42,"Endosomal42Transfer");
	reactions.push_back(Endosomal42Transfer);

	Reaction *Endosomal42COPIGAPing = new MichaelisMentenGProteinDeactivationReaction(Cdc42GAP,EndoCOPI42GTP,EndoCOPI42GDP,kGAP,KmGAP,"Endosomal42COPIGAPing");
	reactions.push_back(Endosomal42COPIGAPing);

	Reaction *Endosomal42COPIFusion = new HeterodimerDissociationReaction(EndoCOPI42GDP,EndoCOPI,EndoCdc42GDP,kuCOPI,"Endosomal42COPIFusion");
	reactions.push_back(Endosomal42COPIFusion);

	// 110
	Reaction *COPIRecycling = new TransformationReaction(EndoCOPI,COPI,ktCOPI,"COPIRecycling");
	reactions.push_back(COPIRecycling);

	Reaction *Cdc42Recycling = new TransformationReaction(EndoCdc42GDP,GolgiCdc42GDP,ktg42,"Cdc42Recycling");
	reactions.push_back(Cdc42Recycling);

	// assembly of recycling vesicle
	Reaction *ProtoRVFormation = new HeterodimerizationReaction(EndoCdc42GDP,FreeEndoEGFR,ProtoRecyclingVesicle,kbRV,"ProtoRVFormation");
	reactions.push_back(ProtoRVFormation);

	Reaction *RVFormation = new HeterodimerDissociationReaction(ProtoRecyclingVesicle,RecyclingVesicle,EndoCdc42GDP,kuRV,"RVFormation");
	reactions.push_back(RVFormation);
	
	// recycling

	Reaction *Recycling = new TransformationReaction(RecyclingVesicle,NonCPFreePMEGFR,kRec,"Recycling1");
	reactions.push_back(Recycling);

	// auto-activation (used w/ fast cycler, comment out otherwise)
	// 115
	Reaction *AutoActivation = new TransformationReaction(Cdc42GDP,Cdc42GTP,kF28,"AutoActivation");
	reactions.push_back(AutoActivation);
	
	Reaction *RapidRec1 = new TransformationReaction(NonCoatedBoundEGFR,NonCPBoundPMEGFR,kFastRec,"RapidRec1");
	reactions.push_back(RapidRec1);

	Reaction *RapidRec2 = new TransformationReaction(NonCoatedBoundEGFRCoolCblActive,NonCPBoundPMEGFRCoolCblActive,kFastRec,"RapidRec2");
	reactions.push_back(RapidRec2);

	Reaction *RapidRec3 = new TransformationReaction(NonCoatedUbiBoundEGFRCoolCblActive,UbiNonCPBoundPMEGFRCoolCblActive,kFastRec,"RapidRec3");
	reactions.push_back(RapidRec3);

	// MAPK cascade
	Reaction *RasActivation1 = new MichaelisMentenGProteinActivationReaction(CPBoundPMEGFR,RasGDP,RasGTP,kRas,KmRas,"RasActivation1");
	reactions.push_back(RasActivation1);

	// 120
	Reaction *RasActivation2 = new MichaelisMentenGProteinActivationReaction(NonCPBoundPMEGFR,RasGDP,RasGTP,kRas,KmRas,"RasActivation2");
	reactions.push_back(RasActivation2);

	Reaction *RasDeactivation = new MichaelisMentenGProteinDeactivationReaction(RasGAP,RasGTP,RasGDP,kRasGAP,KmRasGAP,"RasDeactivation");
	reactions.push_back(RasDeactivation);

	Reaction *ErkActivation = new MichaelisMentenPhosphorylationReaction(RasGTP,Erk,ErkP,kErk,KmErk,"ErkActivation");
	reactions.push_back(ErkActivation);

	Reaction *ErkDeactivation = new MichaelisMentenDephosphorylationReaction(PP2A,ErkP,Erk,kdErk,KmdErk,"ErkDeactivation");
	reactions.push_back(ErkDeactivation);

	Reaction *ErkFeedback = new MichaelisMentenProteinProteinDeactivationReaction(ErkP,RasGTP,RasGDP,kErkRas,KmErkRas,"ErkFeedback");
	reactions.push_back(ErkFeedback);
}

CEGFRTraffickingNetwork::~CEGFRTraffickingNetwork()
{

}
