// EGFRTraffickingPredictionNetwork.cpp: implementation of the CEGFRTraffickingPredictionNetwork class.
//
//////////////////////////////////////////////////////////////////////

#include "EGFRTraffickingPredictionNetwork.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

CEGFRTraffickingPredictionNetwork::CEGFRTraffickingPredictionNetwork()
{
	// CFactor = #molecules/1 uM
	double CFactor = 600000;
	double SecPerMin = 60.0;

	// chemical species

	// EGF/EGFR
	// 0
	Chemical *EGF = new Chemical(chemicals.size(),0.0,"EGF");
	chemicals.push_back(EGF);

	Chemical *DegradedEGF = new Chemical(chemicals.size(),0.0,"DegradedEGF");
	chemicals.push_back(DegradedEGF);

	Chemical *FreePMEGFR = new Chemical(chemicals.size(),0.0,"FreePMEGFR");
	chemicals.push_back(FreePMEGFR);

	Chemical *BoundPMEGFR = new Chemical(chemicals.size(),0.0,"BoundPMEGFR");
	chemicals.push_back(BoundPMEGFR);
	
	Chemical *DegradedEGFR = new Chemical(chemicals.size(),0.0,"DegradedEGFR");
	chemicals.push_back(DegradedEGFR);

	Chemical *BoundPMEGFRCoolCbl = new Chemical(chemicals.size(),0.0,"BoundPMEGFRCoolCbl");
	chemicals.push_back(BoundPMEGFRCoolCbl);

	Chemical *BoundPMEGFRCoolCblActive = new Chemical(chemicals.size(),0.0,"BoundPMEGFRCoolCblActive");
	chemicals.push_back(BoundPMEGFRCoolCblActive);

	Chemical *UbiBoundPMEGFRCoolCblActive = new Chemical(chemicals.size(),0.0,"UbiBoundPMEGFRCoolCblActive");
	chemicals.push_back(UbiBoundPMEGFRCoolCblActive);

	Chemical *CCVEGFR = new Chemical(chemicals.size(),0.0,"CCVEGFR");
	chemicals.push_back(CCVEGFR);

	Chemical *CCVEGFRCoolCblActive = new Chemical(chemicals.size(),0.0,"CCVEGFRCoolCblActive");
	chemicals.push_back(CCVEGFRCoolCblActive);

	// 10
	Chemical *CCVUbiEGFRCoolCblActive = new Chemical(chemicals.size(),0.0,"CCVUbiEGFRCoolCblActive");
	chemicals.push_back(CCVUbiEGFRCoolCblActive);

	Chemical *CCVEGFRACK2 = new Chemical(chemicals.size(),0.0,"CCVEGFRACK2");
	chemicals.push_back(CCVEGFRACK2);

	Chemical *CCVEGFRCoolCblActiveACK2 = new Chemical(chemicals.size(),0.0,"CCVEGFRCoolCblActiveACK2");
	chemicals.push_back(CCVEGFRCoolCblActiveACK2);

	Chemical *CCVUbiEGFRCoolCblActiveACK2 = new Chemical(chemicals.size(),0.0,"CCVUbiEGFRCoolCblActiveACK2");
	chemicals.push_back(CCVUbiEGFRCoolCblActiveACK2);

	Chemical *SortedEGFRACK2 = new Chemical(chemicals.size(),0.0,"SortedEGFRACK2");
	chemicals.push_back(SortedEGFRACK2);

	Chemical *SortedEGFRCoolCblActiveACK2 = new Chemical(chemicals.size(),0.0,"SortedEGFRCoolCblActiveACK2");
	chemicals.push_back(SortedEGFRCoolCblActiveACK2);

	Chemical *SortedUbiEGFRCoolCblActiveACK2 = new Chemical(chemicals.size(),0.0,"SortedUbiEGFRCoolCblActiveACK2");
	chemicals.push_back(SortedUbiEGFRCoolCblActiveACK2);

	Chemical *BoundEndoEGFR = new Chemical(chemicals.size(),0.0,"BoundEndoEGFR");
	chemicals.push_back(BoundEndoEGFR);

	Chemical *BoundEndoEGFRCoolCblActive = new Chemical(chemicals.size(),0.0,"BoundEndoEGFRCoolCblActive");
	chemicals.push_back(BoundEndoEGFRCoolCblActive);

	Chemical *UbiBoundEndoEGFRCoolCblActive = new Chemical(chemicals.size(),0.0,"UbiBoundEndoEGFRCoolCblActive");
	chemicals.push_back(UbiBoundEndoEGFRCoolCblActive);

	// 20
	Chemical *UbiBoundLysoEGFR = new Chemical(chemicals.size(),0.0,"UbiBoundLysoEGFR");
	chemicals.push_back(UbiBoundLysoEGFR);

	Chemical *UbiFreeLysoEGFR = new Chemical(chemicals.size(),0.0,"UbiFreeLysoEGFR");
	chemicals.push_back(UbiFreeLysoEGFR);

	Chemical *UbiBoundLysoEGFRCoolCblActive = new Chemical(chemicals.size(),0.0,"UbiBoundLysoEGFRCoolCblActive");
	chemicals.push_back(UbiBoundLysoEGFRCoolCblActive);

	Chemical *UbiFreeLysoEGFRCoolCblActive = new Chemical(chemicals.size(),0.0,"UbiFreeLysoEGFRCoolCblActive");
	chemicals.push_back(UbiFreeLysoEGFRCoolCblActive);

	Chemical *COPIEndoBoundEGFR = new Chemical(chemicals.size(),0.0,"COPIEndoBoundEGFR");
	chemicals.push_back(COPIEndoBoundEGFR);

	Chemical *COPIEndoBoundEGFRCoolCblActive = new Chemical(chemicals.size(),0.0,"COPIEndoBoundEGFRCoolCblActive");
	chemicals.push_back(COPIEndoBoundEGFRCoolCblActive);

	Chemical *RecyclingVesicle1 = new Chemical(chemicals.size(),0.0,"RecyclingVesicle1");
	chemicals.push_back(RecyclingVesicle1);

	Chemical *RecyclingVesicle2 = new Chemical(chemicals.size(),0.0,"RecyclingVesicle2");
	chemicals.push_back(RecyclingVesicle2);

	Chemical *RecycledVesicle1 = new Chemical(chemicals.size(),0.0,"RecycledVesicle1");
	chemicals.push_back(RecycledVesicle1);

	Chemical *RecycledVesicle2 = new Chemical(chemicals.size(),0.0,"RecycledVesicle2");
	chemicals.push_back(RecycledVesicle2);

	// 30
	Chemical *Vesicle1Cdc42GDP = new Chemical(chemicals.size(),0.0,"Vesicle1Cdc42GDP");
	chemicals.push_back(Vesicle1Cdc42GDP);

	Chemical *Vesicle2Cdc42GDP = new Chemical(chemicals.size(),0.0,"Vesicle2Cdc42GDP");
	chemicals.push_back(Vesicle2Cdc42GDP);

	Chemical *COPIPMBoundEGFR = new Chemical(chemicals.size(),0.0,"COPIPMBoundEGFR");
	chemicals.push_back(COPIPMBoundEGFR);

	Chemical *COPIPMBoundEGFRCoolCblActive = new Chemical(chemicals.size(),0.0,"COPIPMBoundEGFRCoolCblActive");
	chemicals.push_back(COPIPMBoundEGFRCoolCblActive);

	Chemical *Cdc42GAP = new Chemical(chemicals.size(),CFactor,"Cdc42GAP");
	chemicals.push_back(Cdc42GAP);

	// Cdc42 alone
	Chemical *Cdc42GDP = new Chemical(chemicals.size(),CFactor,"Cdc42GDP");
	chemicals.push_back(Cdc42GDP);

	Chemical *Cdc42GTP = new Chemical(chemicals.size(),0.0,"Cdc42GTP");
	chemicals.push_back(Cdc42GTP);

	// ACK and 42
	Chemical *ACK2 = new Chemical(chemicals.size(),CFactor,"ACK2");
	chemicals.push_back(ACK2);

	Chemical *ACK242GTP = new Chemical(chemicals.size(),0.0,"ACK242GTP");
	chemicals.push_back(ACK242GTP);

	Chemical *ACK2Active42GTP = new Chemical(chemicals.size(),0.0,"ACK2Active42GTP");
	chemicals.push_back(ACK2Active42GTP);

	// 40
	Chemical *ACK2Active = new Chemical(chemicals.size(),0.0,"ACK2Active");
	chemicals.push_back(ACK2Active);

	Chemical *YPPTase1 = new Chemical(chemicals.size(),CFactor,"YPPTase1");
	chemicals.push_back(YPPTase1);

	// Free COP complex
	Chemical *COPI = new Chemical(chemicals.size(),10*CFactor,"COPI");
	chemicals.push_back(COPI);

	// Cool,Cbl,42
	Chemical *Cool1Cbl = new Chemical(chemicals.size(),CFactor,"Cool1Cbl");
	chemicals.push_back(Cool1Cbl);

	Chemical *Cool1CblActive = new Chemical(chemicals.size(),0.0,"Cool1CblActive");
	chemicals.push_back(Cool1CblActive);

	Chemical *Cool1Cbl42GTP = new Chemical(chemicals.size(),0.0,"Cool1Cbl42GTP");
	chemicals.push_back(Cool1Cbl42GTP);

	Chemical *Cool1CblActive42GTP = new Chemical(chemicals.size(),0.0,"Cool1CblActive42GTP");
	chemicals.push_back(Cool1CblActive42GTP);
		
	// 47
	std::vector<Chemical *> vec1;
	vec1.push_back(FreePMEGFR);
	vec1.push_back(BoundPMEGFR);
	vec1.push_back(BoundPMEGFRCoolCbl);
	vec1.push_back(BoundPMEGFRCoolCblActive);
	vec1.push_back(UbiBoundPMEGFRCoolCblActive);
	CAlgebraicChemical *TotalPMEGFR = new CSumChemical(chemicals.size(),"TotalPMEGFR",vec1);
	TotalPMEGFR->SetAll();
	chemicals.push_back(TotalPMEGFR);
	this->AddAlgebraicIndex(TotalPMEGFR);

	std::vector<Chemical *> vec1a;
	vec1a.push_back(BoundPMEGFR);
	vec1a.push_back(BoundPMEGFRCoolCbl);
	vec1a.push_back(BoundPMEGFRCoolCblActive);
	vec1a.push_back(UbiBoundPMEGFRCoolCblActive);
	CAlgebraicChemical *TotalBoundPMEGFR = new CSumChemical(chemicals.size(),"TotalBoundPMEGFR",vec1a);
	TotalBoundPMEGFR->SetAll();
	chemicals.push_back(TotalBoundPMEGFR);
	this->AddAlgebraicIndex(TotalBoundPMEGFR);
	
	std::vector<Chemical *> vec2;
	vec2.push_back(CCVEGFR);
	vec2.push_back(CCVEGFRCoolCblActive);
	vec2.push_back(CCVUbiEGFRCoolCblActive);
	vec2.push_back(CCVEGFRACK2);
	vec2.push_back(CCVEGFRCoolCblActiveACK2);
	vec2.push_back(CCVUbiEGFRCoolCblActiveACK2);
	vec2.push_back(SortedEGFRACK2);
	vec2.push_back(SortedEGFRCoolCblActiveACK2);
	vec2.push_back(SortedUbiEGFRCoolCblActiveACK2);
	vec2.push_back(BoundEndoEGFR);
	vec2.push_back(BoundEndoEGFRCoolCblActive);
	vec2.push_back(UbiBoundEndoEGFRCoolCblActive);
	vec2.push_back(UbiBoundLysoEGFR);
	vec2.push_back(UbiBoundLysoEGFRCoolCblActive);
	vec2.push_back(COPIEndoBoundEGFR);
	vec2.push_back(COPIEndoBoundEGFRCoolCblActive);
	vec2.push_back(RecyclingVesicle1);
	vec2.push_back(RecyclingVesicle2);
	vec2.push_back(RecycledVesicle1);
	vec2.push_back(RecycledVesicle2);
	vec2.push_back(Vesicle1Cdc42GDP);
	vec2.push_back(Vesicle2Cdc42GDP);
	vec2.push_back(COPIPMBoundEGFR);
	vec2.push_back(COPIPMBoundEGFRCoolCblActive);
	CAlgebraicChemical *TotalInternalEGF = new CSumChemical(chemicals.size(),"TotalInternalEGF",vec2);
	TotalInternalEGF->SetAll();
	chemicals.push_back(TotalInternalEGF);
	this->AddAlgebraicIndex(TotalInternalEGF);

	// 50
	std::vector<Chemical *> vec3;
	vec3.push_back(CCVEGFR);
	vec3.push_back(CCVEGFRCoolCblActive);
	vec3.push_back(CCVUbiEGFRCoolCblActive);
	vec3.push_back(CCVEGFRACK2);
	vec3.push_back(CCVEGFRCoolCblActiveACK2);
	vec3.push_back(CCVUbiEGFRCoolCblActiveACK2);
	vec3.push_back(SortedEGFRACK2);
	vec3.push_back(SortedEGFRCoolCblActiveACK2);
	vec3.push_back(SortedUbiEGFRCoolCblActiveACK2);
	vec3.push_back(BoundEndoEGFR);
	vec3.push_back(BoundEndoEGFRCoolCblActive);
	vec3.push_back(UbiBoundEndoEGFRCoolCblActive);
	vec3.push_back(UbiBoundLysoEGFR);
	vec3.push_back(UbiBoundLysoEGFRCoolCblActive);
	vec3.push_back(UbiFreeLysoEGFR);
	vec3.push_back(UbiFreeLysoEGFRCoolCblActive);
	vec3.push_back(COPIEndoBoundEGFR);
	vec3.push_back(COPIEndoBoundEGFRCoolCblActive);
	vec3.push_back(RecyclingVesicle1);
	vec3.push_back(RecyclingVesicle2);
	vec3.push_back(RecycledVesicle1);
	vec3.push_back(RecycledVesicle2);
	vec3.push_back(Vesicle1Cdc42GDP);
	vec3.push_back(Vesicle2Cdc42GDP);
	vec3.push_back(COPIPMBoundEGFR);
	vec3.push_back(COPIPMBoundEGFRCoolCblActive);
	CAlgebraicChemical *TotalInternalEGFR = new CSumChemical(chemicals.size(),"TotalInternalEGFR",vec3);
	TotalInternalEGFR->SetAll();
	chemicals.push_back(TotalInternalEGFR);
	this->AddAlgebraicIndex(TotalInternalEGFR);
	
	std::vector<Chemical *> vec4;
	vec4.push_back(CCVEGFR);
	vec4.push_back(CCVEGFRCoolCblActive);
	vec4.push_back(CCVUbiEGFRCoolCblActive);
	vec4.push_back(CCVEGFRACK2);
	vec4.push_back(CCVEGFRCoolCblActiveACK2);
	vec4.push_back(CCVUbiEGFRCoolCblActiveACK2);
	CAlgebraicChemical *TotalCCVEGFR = new CSumChemical(chemicals.size(),"TotalCCVEGFR",vec4);
	TotalCCVEGFR->SetAll();
	chemicals.push_back(TotalCCVEGFR);
	this->AddAlgebraicIndex(TotalCCVEGFR);

	std::vector<Chemical *> vec5;
	vec5.push_back(SortedEGFRACK2);
	vec5.push_back(SortedEGFRCoolCblActiveACK2);
	vec5.push_back(SortedUbiEGFRCoolCblActiveACK2);
	vec5.push_back(BoundEndoEGFR);
	vec5.push_back(BoundEndoEGFRCoolCblActive);
	vec5.push_back(UbiBoundEndoEGFRCoolCblActive);
	CAlgebraicChemical *TotalEndoEGFR = new CSumChemical(chemicals.size(),"TotalEndoEGFR",vec5);
	TotalEndoEGFR->SetAll();
	chemicals.push_back(TotalEndoEGFR);
	this->AddAlgebraicIndex(TotalEndoEGFR);

	std::vector<Chemical *> vec6;
	vec6.push_back(UbiBoundLysoEGFR);
	vec6.push_back(UbiBoundLysoEGFRCoolCblActive);
	vec6.push_back(UbiFreeLysoEGFR);
	vec6.push_back(UbiFreeLysoEGFRCoolCblActive);
	CAlgebraicChemical *TotalLysoEGFR = new CSumChemical(chemicals.size(),"TotalLysoEGFR",vec6);
	TotalLysoEGFR->SetAll();
	chemicals.push_back(TotalLysoEGFR);
	this->AddAlgebraicIndex(TotalLysoEGFR);

	Chemical *ACK242GDP= new Chemical(chemicals.size(),0.0,"ACK242GDP");
	chemicals.push_back(ACK242GDP);

	Chemical *ACK2Active42GDP = new Chemical(chemicals.size(),0.0,"ACK2Active42GDP");
	chemicals.push_back(ACK2Active42GDP);

	Chemical *Cool1Cbl42GDP = new Chemical(chemicals.size(),0.0,"Cool1Cbl42GDP");
	chemicals.push_back(Cool1Cbl42GDP);

	Chemical *Cool1CblActive42GDP = new Chemical(chemicals.size(),0.0,"Cool1CblActive42GDP");
	chemicals.push_back(Cool1CblActive42GDP);


	// mutant Cdc42
	Chemical *MutRecyclingVesicle1 = new Chemical(chemicals.size(),0.0,"MutRecyclingVesicle1");
	chemicals.push_back(MutRecyclingVesicle1);

	Chemical *MutRecyclingVesicle2 = new Chemical(chemicals.size(),0.0,"MutRecyclingVesicle2");
	chemicals.push_back(MutRecyclingVesicle2);

	// 60
	Chemical *MutRecycledVesicle1 = new Chemical(chemicals.size(),0.0,"MutRecycledVesicle1");
	chemicals.push_back(MutRecycledVesicle1);

	Chemical *MutRecycledVesicle2 = new Chemical(chemicals.size(),0.0,"MutRecycledVesicle2");
	chemicals.push_back(MutRecycledVesicle2);

	Chemical *MutVesicle1Cdc42GDP = new Chemical(chemicals.size(),0.0,"MutVesicle1Cdc42GDP");
	chemicals.push_back(MutVesicle1Cdc42GDP);

	Chemical *MutVesicle2Cdc42GDP = new Chemical(chemicals.size(),0.0,"MutVesicle2Cdc42GDP");
	chemicals.push_back(MutVesicle2Cdc42GDP);

	Chemical *MutCdc42GDP = new Chemical(chemicals.size(),0.0,"MutCdc42GDP");
	chemicals.push_back(MutCdc42GDP);

	Chemical *MutCdc42GTP = new Chemical(chemicals.size(),0.0,"MutCdc42GTP");
	chemicals.push_back(MutCdc42GTP);

	Chemical *MutACK242GTP = new Chemical(chemicals.size(),0.0,"ACK242GTP");
	chemicals.push_back(MutACK242GTP);

	Chemical *MutACK2Active42GTP = new Chemical(chemicals.size(),0.0,"MutACK2Active42GTP");
	chemicals.push_back(MutACK2Active42GTP);

	Chemical *MutCool1Cbl42GTP = new Chemical(chemicals.size(),0.0,"MutCool1Cbl42GTP");
	chemicals.push_back(MutCool1Cbl42GTP);

	Chemical *MutCool1CblActive42GTP = new Chemical(chemicals.size(),0.0,"MutCool1CblActive42GTP");
	chemicals.push_back(MutCool1CblActive42GTP);

	// 70
	Chemical *MutACK242GDP= new Chemical(chemicals.size(),0.0,"MutACK242GDP");
	chemicals.push_back(MutACK242GDP);

	Chemical *MutACK2Active42GDP = new Chemical(chemicals.size(),0.0,"MutACK2Active42GDP");
	chemicals.push_back(MutACK2Active42GDP);

	Chemical *MutCool1Cbl42GDP = new Chemical(chemicals.size(),0.0,"MutCool1Cbl42GDP");
	chemicals.push_back(MutCool1Cbl42GDP);

	Chemical *MutCool1CblActive42GDP = new Chemical(chemicals.size(),0.0,"MutCool1CblActive42GDP");
	chemicals.push_back(MutCool1CblActive42GDP);

	std::vector<Chemical *> vec7;
	vec7.push_back(CCVEGFR);
	vec7.push_back(CCVEGFRCoolCblActive);
	vec7.push_back(CCVUbiEGFRCoolCblActive);
	vec7.push_back(CCVEGFRACK2);
	vec7.push_back(CCVEGFRCoolCblActiveACK2);
	vec7.push_back(CCVUbiEGFRCoolCblActiveACK2);
	vec7.push_back(SortedEGFRACK2);
	vec7.push_back(SortedEGFRCoolCblActiveACK2);
	vec7.push_back(SortedUbiEGFRCoolCblActiveACK2);
	vec7.push_back(BoundEndoEGFR);
	vec7.push_back(BoundEndoEGFRCoolCblActive);
	vec7.push_back(UbiBoundEndoEGFRCoolCblActive);
	vec7.push_back(UbiBoundLysoEGFR);
	vec7.push_back(UbiBoundLysoEGFRCoolCblActive);
	vec7.push_back(COPIEndoBoundEGFR);
	vec7.push_back(COPIEndoBoundEGFRCoolCblActive);
	vec7.push_back(RecyclingVesicle1);
	vec7.push_back(MutRecyclingVesicle1);
	vec7.push_back(RecyclingVesicle2);
	vec7.push_back(MutRecyclingVesicle2);
	vec7.push_back(RecycledVesicle1);
	vec7.push_back(MutRecycledVesicle1);
	vec7.push_back(RecycledVesicle2);
	vec7.push_back(MutRecycledVesicle2);
	vec7.push_back(Vesicle1Cdc42GDP);
	vec7.push_back(MutVesicle1Cdc42GDP);
	vec7.push_back(Vesicle2Cdc42GDP);
	vec7.push_back(MutVesicle2Cdc42GDP);
	vec7.push_back(COPIPMBoundEGFR);
	vec7.push_back(COPIPMBoundEGFRCoolCblActive);
	CAlgebraicChemical *MutTotalInternalEGF = new CSumChemical(chemicals.size(),"MutTotalInternalEGF",vec7);
	MutTotalInternalEGF->SetAll();
	chemicals.push_back(MutTotalInternalEGF);
	this->AddAlgebraicIndex(MutTotalInternalEGF);

	std::vector<Chemical *> vec8;
	vec8.push_back(CCVEGFR);
	vec8.push_back(CCVEGFRCoolCblActive);
	vec8.push_back(CCVUbiEGFRCoolCblActive);
	vec8.push_back(CCVEGFRACK2);
	vec8.push_back(CCVEGFRCoolCblActiveACK2);
	vec8.push_back(CCVUbiEGFRCoolCblActiveACK2);
	vec8.push_back(SortedEGFRACK2);
	vec8.push_back(SortedEGFRCoolCblActiveACK2);
	vec8.push_back(SortedUbiEGFRCoolCblActiveACK2);
	vec8.push_back(BoundEndoEGFR);
	vec8.push_back(BoundEndoEGFRCoolCblActive);
	vec8.push_back(UbiBoundEndoEGFRCoolCblActive);
	vec8.push_back(UbiBoundLysoEGFR);
	vec8.push_back(UbiBoundLysoEGFRCoolCblActive);
	vec8.push_back(UbiFreeLysoEGFR);
	vec8.push_back(UbiFreeLysoEGFRCoolCblActive);
	vec8.push_back(COPIEndoBoundEGFR);
	vec8.push_back(COPIEndoBoundEGFRCoolCblActive);
	vec8.push_back(RecyclingVesicle1);
	vec8.push_back(MutRecyclingVesicle1);
	vec8.push_back(RecyclingVesicle2);
	vec8.push_back(MutRecyclingVesicle2);
	vec8.push_back(RecycledVesicle1);
	vec8.push_back(MutRecycledVesicle1);
	vec8.push_back(RecycledVesicle2);
	vec8.push_back(MutRecycledVesicle2);
	vec8.push_back(Vesicle1Cdc42GDP);
	vec8.push_back(MutVesicle1Cdc42GDP);
	vec8.push_back(Vesicle2Cdc42GDP);
	vec8.push_back(MutVesicle2Cdc42GDP);
	vec8.push_back(COPIPMBoundEGFR);
	vec8.push_back(COPIPMBoundEGFRCoolCblActive);
	CAlgebraicChemical *MutTotalInternalEGFR = new CSumChemical(chemicals.size(),"MutTotalInternalEGFR",vec8);
	MutTotalInternalEGFR->SetAll();
	chemicals.push_back(MutTotalInternalEGFR);
	this->AddAlgebraicIndex(MutTotalInternalEGFR);
	

	std::vector<Chemical *> vec9;
	vec9.push_back(FreePMEGFR);
	vec9.push_back(BoundPMEGFR);
	vec9.push_back(BoundPMEGFRCoolCbl);
	vec9.push_back(BoundPMEGFRCoolCblActive);
	vec9.push_back(UbiBoundPMEGFRCoolCblActive);
	vec9.push_back(CCVEGFR);
	vec9.push_back(CCVEGFRCoolCblActive);
	vec9.push_back(CCVUbiEGFRCoolCblActive);
	vec9.push_back(CCVEGFRACK2);
	vec9.push_back(CCVEGFRCoolCblActiveACK2);
	vec9.push_back(CCVUbiEGFRCoolCblActiveACK2);
	vec9.push_back(SortedEGFRACK2);
	vec9.push_back(SortedEGFRCoolCblActiveACK2);
	vec9.push_back(SortedUbiEGFRCoolCblActiveACK2);
	vec9.push_back(BoundEndoEGFR);
	vec9.push_back(BoundEndoEGFRCoolCblActive);
	vec9.push_back(UbiBoundEndoEGFRCoolCblActive);
	vec9.push_back(UbiBoundLysoEGFR);
	vec9.push_back(UbiBoundLysoEGFRCoolCblActive);
	vec9.push_back(UbiFreeLysoEGFR);
	vec9.push_back(UbiFreeLysoEGFRCoolCblActive);
	vec9.push_back(COPIEndoBoundEGFR);
	vec9.push_back(COPIEndoBoundEGFRCoolCblActive);
	vec9.push_back(RecyclingVesicle1);
	vec9.push_back(MutRecyclingVesicle1);
	vec9.push_back(RecyclingVesicle2);
	vec9.push_back(MutRecyclingVesicle2);
	vec9.push_back(RecycledVesicle1);
	vec9.push_back(MutRecycledVesicle1);
	vec9.push_back(RecycledVesicle2);
	vec9.push_back(MutRecycledVesicle2);
	vec9.push_back(Vesicle1Cdc42GDP);
	vec9.push_back(MutVesicle1Cdc42GDP);
	vec9.push_back(Vesicle2Cdc42GDP);
	vec9.push_back(MutVesicle2Cdc42GDP);
	vec9.push_back(COPIPMBoundEGFR);
	vec9.push_back(COPIPMBoundEGFRCoolCblActive);
	CAlgebraicChemical *MutTotalEGFR = new CSumChemical(chemicals.size(),"MutTotalIEGFR",vec9);
	MutTotalEGFR->SetAll();
	chemicals.push_back(MutTotalEGFR);
	this->AddAlgebraicIndex(MutTotalEGFR);

	// rate constants
	// EGF binding/unbinding
	RateConstant *kbEGF = new RateConstant(1.0e-07,"kbEGF");
	rateConstants.push_back(kbEGF);

	RateConstant *kuEGF = new RateConstant(0.02,"kuEGF");
	rateConstants.push_back(kuEGF);

	// 42 activation
	RateConstant *kEGFR42 = new RateConstant(0.02*SecPerMin,"kEGFR42");
	rateConstants.push_back(kEGFR42);

	RateConstant *KmEGFR42 = new RateConstant(CFactor,"KmEGFR42");
	rateConstants.push_back(KmEGFR42);

	// Gapping of 42
	RateConstant *kGAP = new RateConstant(0.01*SecPerMin,"kGAP");
	rateConstants.push_back(kGAP);

	RateConstant *KmGAP = new RateConstant(2.9*CFactor,"KmGAP");
	rateConstants.push_back(KmGAP);

	// allow possibility of different endocytic rates depending upon 
	// whether receptor is ubiquitinated or not 

	RateConstant *kEndo1 = new RateConstant(1.0/15.0,"kEndo1");
	rateConstants.push_back(kEndo1);
	
	RateConstant *kEndo2 = new RateConstant(1.0/15.0,"kEndo2");
	rateConstants.push_back(kEndo2);

	// ACK2 binding/unbinding to 42

	RateConstant *kbACKActive = new RateConstant(1.0e-07,"kbACKActive");
	rateConstants.push_back(kbACKActive);

	RateConstant *kuACKActive = new RateConstant(0.02,"kuACKActive");
	rateConstants.push_back(kuACKActive);

	RateConstant *kbACK2 = new RateConstant(1.0e-07,"kbACK2");
	rateConstants.push_back(kbACK2);

	RateConstant *kuACK2 = new RateConstant(0.02,"kuACK2");
	rateConstants.push_back(kuACK2);

	RateConstant *kuACK242GDP = new RateConstant(0.1,"kuACK242GDP");
	rateConstants.push_back(kuACK242GDP);

	RateConstant *kuACK2Active42GDP = new RateConstant(0.1,"kuACK2Active42GDP");
	rateConstants.push_back(kuACK2Active42GDP);
	
	// ACK2 activation
	
	RateConstant *kACK2 = new RateConstant(0.5*SecPerMin,"kACK2");
	rateConstants.push_back(kACK2);

	// ACK2 dephosphorylation by PPtase

	RateConstant *kdACK2 = new RateConstant(0.1*SecPerMin,"kdACK2");
	rateConstants.push_back(kdACK2);

	RateConstant *KmdACK2 = new RateConstant(CFactor,"KmdACK2");
	rateConstants.push_back(KmdACK2);

	// ACK2 binding/unbinding to the CCV

	RateConstant *kbACK2CCV = new RateConstant(1.0e-07,"kbACK2CCV");
	rateConstants.push_back(kbACK2CCV);

	RateConstant *kuACK2CCV = new RateConstant(0.02,"kuACK2CCV");
	rateConstants.push_back(kuACK2CCV);

	// Sorting of ACK-bound CCVs

	RateConstant *kSort = new RateConstant(0.25*SecPerMin,"kSort");
	rateConstants.push_back(kSort);

	// Endosomal to lysosomal transfer

	RateConstant *kEndoLyso = new RateConstant(0.25*SecPerMin,"kEndoLyso");
	rateConstants.push_back(kEndoLyso);

	// Degradation of EGF

	RateConstant *kdegEGF = new RateConstant(0.25*SecPerMin,"kdegEGF");
	rateConstants.push_back(kdegEGF);

	// Proteolysis of EGFR

	RateConstant *kProt = new RateConstant(0.25*SecPerMin,"kProt");
	rateConstants.push_back(kProt);

	// Cbl binding to the receptor
	
	RateConstant *kbCbl = new RateConstant(1.0e-07,"kbCbl");
	rateConstants.push_back(kbCbl);

	// Cbl unbinding from a ubiquitinated receptor
	
	RateConstant *kuCblUbi = new RateConstant(1.0e-02,"kuCblUbi");
	rateConstants.push_back(kuCblUbi);

	// Cbl when bound to EGF receptor - activation and ubiquitination

	RateConstant *kCbl = new RateConstant(0.1/SecPerMin,"kCbl");
	rateConstants.push_back(kCbl);

	RateConstant *kUbi = new RateConstant(0.05/SecPerMin,"kUbi");
	rateConstants.push_back(kUbi);

	// Cool/Cbl and 42 binding/unbinding

	RateConstant *kbCbl42 = new RateConstant(1.0e-07,"kbCbl42");
	rateConstants.push_back(kbCbl42);

	RateConstant *kuCbl42 = new RateConstant(0.02,"kuCbl42");
	rateConstants.push_back(kuCbl42);

	RateConstant *kbCblActive42 = new RateConstant(1.0e-07,"kbCblActive42");
	rateConstants.push_back(kbCblActive42);

	RateConstant *kuCblActive42 = new RateConstant(0.02,"kuCblActive42");
	rateConstants.push_back(kuCblActive42);

	RateConstant *kuCool1Cbl42GDP = new RateConstant(0.1,"kuCool1Cbl42GDP");
	rateConstants.push_back(kuCool1Cbl42GDP);

	RateConstant *kuCool1CblActive42GDP = new RateConstant(0.1,"kuCool1CblActive42GDP");
	rateConstants.push_back(kuCool1CblActive42GDP);

	// COPI binding to EGFR

	RateConstant *kbCOPI = new RateConstant(1.0e-07,"kbCOPI");
	rateConstants.push_back(kbCOPI);

	// Active 42 binding to recycling vesicle

	RateConstant *kb42COPI = new RateConstant(2.0e-07,"kb42COPI");
	rateConstants.push_back(kb42COPI);

	// Inactive 42 unbinding

	RateConstant *ku42COPI = new RateConstant(0.02,"ku42COPI");
	rateConstants.push_back(ku42COPI);

	// COPI unbinding from recycled vesicle

	RateConstant *kuCOPI = new RateConstant(0.02,"kuCOPI");
	rateConstants.push_back(kuCOPI);

	// COPI-mediated recycling

	RateConstant *kRec = new RateConstant(25.0/SecPerMin,"kRec");
	rateConstants.push_back(kRec);

	
	// reactions
	// 0
	// EGF binding/unbinding
	Reaction *EGFBinding = new ReceptorBindingReaction(EGF,FreePMEGFR,BoundPMEGFR,kbEGF,"EGFBinding");
	reactions.push_back(EGFBinding);

	Reaction *EGFUnbinding = new ReceptorUnbindingReaction(BoundPMEGFR,FreePMEGFR,EGF,kuEGF,"EGFUnbinding");
	reactions.push_back(EGFUnbinding);

	// 42 activation

	Reaction *Cdc42PMActivation1 = new MichaelisMentenGProteinActivationReaction(BoundPMEGFR,Cdc42GDP,Cdc42GTP,kEGFR42,KmEGFR42,"Cdc42PMActivation1");
	reactions.push_back(Cdc42PMActivation1);

	Reaction *Cdc42PMActivation2 = new MichaelisMentenGProteinActivationReaction(BoundPMEGFRCoolCbl,Cdc42GDP,Cdc42GTP,kEGFR42,KmEGFR42,"Cdc42PMActivation2");
	reactions.push_back(Cdc42PMActivation2);

	Reaction *Cdc42PMActivation3 = new MichaelisMentenGProteinActivationReaction(BoundPMEGFRCoolCblActive,Cdc42GDP,Cdc42GTP,kEGFR42,KmEGFR42,"Cdc42PMActivation3");
	reactions.push_back(Cdc42PMActivation3);

	Reaction *Cdc42PMActivation4 = new MichaelisMentenGProteinActivationReaction(UbiBoundPMEGFRCoolCblActive,Cdc42GDP,Cdc42GTP,kEGFR42,KmEGFR42,"Cdc42PMActivation4");
	reactions.push_back(Cdc42PMActivation4);

	// gapping of free 42

	Reaction *Cdc42GAPHydrolysis = new MichaelisMentenGProteinActivationReaction(Cdc42GAP,Cdc42GTP,Cdc42GDP,kGAP,KmGAP,"Cdc42GAPHydrolysis");
	reactions.push_back(Cdc42GAPHydrolysis);

	// endocytosis

	Reaction *Endocytosis1 = new TransformationReaction(BoundPMEGFR,CCVEGFR,kEndo1,"Endocytosis1");
	reactions.push_back(Endocytosis1);

	Reaction *Endocytosis2 = new TransformationReaction(BoundPMEGFRCoolCblActive,CCVEGFRCoolCblActive,kEndo1,"Endocytosis2");
	reactions.push_back(Endocytosis2);

	Reaction *Endocytosis3 = new TransformationReaction(UbiBoundPMEGFRCoolCblActive,CCVUbiEGFRCoolCblActive,kEndo2,"Endocytosis3");
	reactions.push_back(Endocytosis3);

	// ACK2 and 42 cycle
	// 10
	Reaction *ACK42Binding = new HeterodimerizationReaction(ACK2,Cdc42GTP,ACK242GTP,kbACK2,"ACK42Binding");
	reactions.push_back(ACK42Binding);

	Reaction *ACK42Unbinding = new HeterodimerDissociationReaction(ACK242GTP,ACK2,Cdc42GTP,kuACK2,"ACK42Unbinding");
	reactions.push_back(ACK42Unbinding);

	Reaction *ACK2Active42Binding = new HeterodimerizationReaction(ACK2Active,Cdc42GTP,ACK2Active42GTP,kbACKActive,"ACK2Active42Binding");
	reactions.push_back(ACK2Active42Binding);

	Reaction *ACK2Active42Unbinding = new HeterodimerDissociationReaction(ACK2Active42GTP,ACK2Active,Cdc42GTP,kuACKActive,"ACK2Active42Unbinding");
	reactions.push_back(ACK2Active42Unbinding);

	Reaction *ACK2Activation = new TransformationReaction(ACK242GTP,ACK2Active42GTP,kACK2,"ACK2Activation");
	reactions.push_back(ACK2Activation);

	Reaction *ACK2Deactivation = new MichaelisMentenDephosphorylationReaction(YPPTase1,ACK2Active,ACK2,kdACK2,KmdACK2,"ACK2Deactivation");
	reactions.push_back(ACK2Deactivation);

	Reaction *ACK242GAPing = new MichaelisMentenGProteinDeactivationReaction(Cdc42GAP,ACK242GTP,ACK242GDP,kGAP,KmGAP,"ACK242GAPing");
	reactions.push_back(ACK242GAPing);

	Reaction *ACK2Active42GAPing = new MichaelisMentenGProteinDeactivationReaction(Cdc42GAP,ACK2Active42GTP,ACK2Active42GDP,kGAP,KmGAP,"ACK2Active42GAPing");
	reactions.push_back(ACK2Active42GAPing);

	Reaction *ACK242GDPRelease = new HeterodimerDissociationReaction(ACK242GDP,ACK2,Cdc42GDP,kuACK242GDP,"ACK242GDPRelease");
	reactions.push_back(ACK242GDPRelease);

	Reaction *ACK2Active42GDPRelease = new HeterodimerDissociationReaction(ACK2Active42GDP,ACK2Active,Cdc42GDP,kuACK2Active42GDP,"ACK2Active42GDPRelease");
	reactions.push_back(ACK2Active42GDPRelease);

	// Cool/Cbl and 42 cycle
	// 20
	Reaction *CoolCbl42Binding = new HeterodimerizationReaction(Cool1Cbl,Cdc42GTP,Cool1Cbl42GTP,kbCbl42,"CoolCbl42Binding");
	reactions.push_back(CoolCbl42Binding);

	Reaction *CoolCbl42Unbinding = new HeterodimerDissociationReaction(Cool1Cbl42GTP,Cool1Cbl,Cdc42GTP,kuCbl42,"CoolCbl42Unbinding");
	reactions.push_back(CoolCbl42Unbinding);

	Reaction *CoolCblActive42Binding = new HeterodimerizationReaction(Cool1CblActive,Cdc42GTP,Cool1CblActive42GTP,kbCblActive42,"CoolCblActive42Binding");
	reactions.push_back(CoolCblActive42Binding);

	Reaction *CoolCblActive42Unbinding = new HeterodimerDissociationReaction(Cool1CblActive42GTP,Cool1CblActive,Cdc42GTP,kuCblActive42,"CoolCblActive42Unbinding");
	reactions.push_back(CoolCblActive42Unbinding);

	Reaction *CoolCbl42GAPing = new MichaelisMentenGProteinDeactivationReaction(Cdc42GAP,Cool1Cbl42GTP,Cool1Cbl42GDP,kGAP,KmGAP,"CoolCbl42GAPing");
	reactions.push_back(CoolCbl42GAPing);

	Reaction *CoolCblActive42GAPing = new MichaelisMentenGProteinDeactivationReaction(Cdc42GAP,Cool1CblActive42GTP,Cool1CblActive42GDP,kGAP,KmGAP,"CoolCblActive42GAPing");
	reactions.push_back(CoolCblActive42GAPing);

	Reaction *CoolCbl42GDPRelease = new HeterodimerDissociationReaction(Cool1Cbl42GDP,Cool1Cbl,Cdc42GDP,kuCool1Cbl42GDP,"CoolCbl42GDPRelease");
	reactions.push_back(CoolCbl42GDPRelease);

	Reaction *CoolCblActive42GDPRelease = new HeterodimerDissociationReaction(Cool1CblActive42GDP,Cool1CblActive,Cdc42GDP,kuCool1CblActive42GDP,"CoolCblActive42GDPRelease");
	reactions.push_back(CoolCblActive42GDPRelease);

	// sorting

	Reaction *ACKBinding1 = new HeterodimerizationReaction(ACK2Active,CCVEGFR,CCVEGFRACK2,kbACK2CCV,"ACKBinding1");
	reactions.push_back(ACKBinding1);

	Reaction *ACKBinding2 = new HeterodimerizationReaction(ACK2Active,CCVEGFRCoolCblActive,CCVEGFRCoolCblActiveACK2,kbACK2CCV,"ACKBinding2");
	reactions.push_back(ACKBinding2);
	// 30
	Reaction *ACKBinding3 = new HeterodimerizationReaction(ACK2Active,CCVUbiEGFRCoolCblActive,CCVUbiEGFRCoolCblActiveACK2,kbACK2CCV,"ACKBinding3");
	reactions.push_back(ACKBinding3);

	Reaction *Sorting1 = new TransformationReaction(CCVEGFRACK2,SortedEGFRACK2,kSort,"Sorting1");
	reactions.push_back(Sorting1);

	Reaction *Sorting2 = new TransformationReaction(CCVEGFRCoolCblActiveACK2,SortedEGFRCoolCblActiveACK2,kSort,"Sorting2");
	reactions.push_back(Sorting2);

	Reaction *Sorting3 = new TransformationReaction(CCVUbiEGFRCoolCblActiveACK2,SortedUbiEGFRCoolCblActiveACK2,kSort,"Sorting3");
	reactions.push_back(Sorting3);

	Reaction *ACKRelease1 = new HeterodimerDissociationReaction(SortedEGFRACK2,BoundEndoEGFR,ACK2Active,kuACK2CCV,"ACKRelease1");
	reactions.push_back(ACKRelease1);

	Reaction *ACKRelease2 = new HeterodimerDissociationReaction(SortedEGFRCoolCblActiveACK2,BoundEndoEGFRCoolCblActive,ACK2Active,kuACK2CCV,"ACKRelease2");
	reactions.push_back(ACKRelease2);

	Reaction *ACKRelease3 = new HeterodimerDissociationReaction(SortedUbiEGFRCoolCblActiveACK2,UbiBoundEndoEGFRCoolCblActive,ACK2Active,kuACK2CCV,"ACKRelease3");
	reactions.push_back(ACKRelease3);

	// Transfer to lysosomes

	Reaction *LysosomalTransfer = new TransformationReaction(UbiBoundEndoEGFRCoolCblActive,UbiBoundLysoEGFRCoolCblActive,kEndoLyso,"LysosomalTransfer");
	reactions.push_back(LysosomalTransfer);

	// EGF degradation

	Reaction *LigandDegradation1 = new ReceptorUnbindingReaction(UbiBoundLysoEGFR,UbiFreeLysoEGFR,DegradedEGF,kdegEGF,"EGFDegradation1");
	reactions.push_back(LigandDegradation1);

	Reaction *LigandDegradation2 = new ReceptorUnbindingReaction(UbiBoundLysoEGFRCoolCblActive,UbiFreeLysoEGFRCoolCblActive,DegradedEGF,kdegEGF,"EGFDegradation2");
	reactions.push_back(LigandDegradation2);

	// CoolCbl binding to receptor
	// 40
	Reaction *EGFRCoolCblBinding = new HeterodimerizationReaction(BoundPMEGFR,Cool1Cbl,BoundPMEGFRCoolCbl,kbCbl,"InactiveCblBinding");
	reactions.push_back(EGFRCoolCblBinding);

	Reaction *EGFRCoolCblActiveBinding = new HeterodimerizationReaction(BoundPMEGFR,Cool1CblActive,BoundPMEGFRCoolCblActive,kbCbl,"ActiveCblBinding");
	reactions.push_back(EGFRCoolCblActiveBinding);

	// CoolCbl phosphorylation

	Reaction *EGFRCoolCblActivation = new TransformationReaction(BoundPMEGFRCoolCbl,BoundPMEGFRCoolCblActive,kCbl,"EGFRCoolCblActivation");
	reactions.push_back(EGFRCoolCblActivation);

	// ubiquitination 
	Reaction *MembraneUbi = new TransformationReaction(BoundPMEGFRCoolCblActive,UbiBoundPMEGFRCoolCblActive,kUbi,"MembraneUbi");
	reactions.push_back(MembraneUbi);

	Reaction *VesicleUbi = new TransformationReaction(CCVEGFRCoolCblActive,CCVUbiEGFRCoolCblActive,kUbi,"VesicleUbi");
	reactions.push_back(VesicleUbi);

	Reaction *EndoUbi = new TransformationReaction(BoundEndoEGFRCoolCblActive,UbiBoundEndoEGFRCoolCblActive,kUbi,"EndoUbi");
	reactions.push_back(EndoUbi);

	// CoolCbl release

	Reaction *CoolCblDissociation1 = new HeterodimerDissociationReaction(UbiBoundLysoEGFRCoolCblActive,UbiBoundLysoEGFR,Cool1CblActive,kuCblUbi,"CoolCblDissociation1");
	reactions.push_back(CoolCblDissociation1);

	Reaction *CoolCblDissociation2 = new HeterodimerDissociationReaction(UbiFreeLysoEGFRCoolCblActive,UbiFreeLysoEGFR,Cool1CblActive,kuCblUbi,"CoolCblDissociation2");
	reactions.push_back(CoolCblDissociation2);

	// EGFR proteolysis 

	Reaction *FreeEGFRProteolysis = new TransformationReaction(UbiFreeLysoEGFR,DegradedEGFR,kProt,"FreeEGFRProteolysis");
	reactions.push_back(FreeEGFRProteolysis);

	// assembly of recycling vesicle

	Reaction *COPIBinding1 = new HeterodimerizationReaction(COPI,BoundEndoEGFR,COPIEndoBoundEGFR,kbCOPI,"COPIBinding1");
	reactions.push_back(COPIBinding1);
	// 50
	Reaction *COPIBinding2 = new HeterodimerizationReaction(COPI,BoundEndoEGFRCoolCblActive,COPIEndoBoundEGFRCoolCblActive,kbCOPI,"COPIBinding2");
	reactions.push_back(COPIBinding2);

	Reaction *VesicleAssembly1 = new HeterodimerizationReaction(COPIEndoBoundEGFR,Cdc42GTP,RecyclingVesicle1,kb42COPI,"VesicleAssembly1");
	reactions.push_back(VesicleAssembly1);

	Reaction *VesicleAssembly2 = new HeterodimerizationReaction(COPIEndoBoundEGFRCoolCblActive,Cdc42GTP,RecyclingVesicle2,kb42COPI,"VesicleAssembly2");
	reactions.push_back(VesicleAssembly2);

	// recycling

	Reaction *Recycling1 = new TransformationReaction(RecyclingVesicle1,RecycledVesicle1,kRec,"Recycling1");
	reactions.push_back(Recycling1);

	Reaction *Recycling2 = new TransformationReaction(RecyclingVesicle2,RecycledVesicle2,kRec,"Recycling2");
	reactions.push_back(Recycling2);

	// uncoating and fusion

	Reaction *VesicleGAPing1 = new MichaelisMentenTransformationReaction(Cdc42GAP,RecycledVesicle1,Vesicle1Cdc42GDP,kGAP,KmGAP,"VesicleGAPing1");
	reactions.push_back(VesicleGAPing1);

	Reaction *VesicleGAPing2 = new MichaelisMentenTransformationReaction(Cdc42GAP,RecycledVesicle2,Vesicle2Cdc42GDP,kGAP,KmGAP,"VesicleGAPing2");
	reactions.push_back(VesicleGAPing2);

	Reaction *Cdc42COPIUnbinding1 = new HeterodimerDissociationReaction(Vesicle1Cdc42GDP,COPIPMBoundEGFR,Cdc42GDP,ku42COPI,"Cdc42COPIUnbinding1");
	reactions.push_back(Cdc42COPIUnbinding1);

	Reaction *Cdc42COPIUnbinding2 = new HeterodimerDissociationReaction(Vesicle2Cdc42GDP,COPIPMBoundEGFRCoolCblActive,Cdc42GDP,ku42COPI,"Cdc42COPIUnbinding2");
	reactions.push_back(Cdc42COPIUnbinding2);

	Reaction *VesicleFusion1 = new HeterodimerDissociationReaction(COPIPMBoundEGFR,COPI,BoundPMEGFR,kuCOPI,"VesicleFusion1");
	reactions.push_back(VesicleFusion1);

	// 60
	Reaction *VesicleFusion2 = new HeterodimerDissociationReaction(COPIPMBoundEGFRCoolCblActive,COPI,BoundPMEGFRCoolCblActive,kuCOPI,"VesicleFusion2");
	reactions.push_back(VesicleFusion2);

	
	// reactions with mutant 42

	Reaction *MutACK42Binding = new HeterodimerizationReaction(ACK2,MutCdc42GTP,MutACK242GTP,kbACK2,"MutACK42Binding");
	reactions.push_back(MutACK42Binding);

	Reaction *MutACK42Unbinding = new HeterodimerDissociationReaction(MutACK242GTP,ACK2,MutCdc42GTP,kuACK2,"MutACK42Unbinding");
	reactions.push_back(MutACK42Unbinding);

	Reaction *MutACK2Active42Binding = new HeterodimerizationReaction(ACK2Active,MutCdc42GTP,MutACK2Active42GTP,kbACKActive,"MutACK2Active42Binding");
	reactions.push_back(MutACK2Active42Binding);

	Reaction *MutACK2Active42Unbinding = new HeterodimerDissociationReaction(MutACK2Active42GTP,ACK2Active,MutCdc42GTP,kuACKActive,"MutACK2Active42Unbinding");
	reactions.push_back(MutACK2Active42Unbinding);

	Reaction *MutACK2Activation = new TransformationReaction(MutACK242GTP,MutACK2Active42GTP,kACK2,"MutACK2Activation");
	reactions.push_back(MutACK2Activation);

	Reaction *MutACK242GAPing = new MichaelisMentenGProteinDeactivationReaction(Cdc42GAP,MutACK242GTP,MutACK242GDP,kGAP,KmGAP,"MutACK242GAPing");
	reactions.push_back(MutACK242GAPing);

	Reaction *MutACK2Active42GAPing = new MichaelisMentenGProteinDeactivationReaction(Cdc42GAP,MutACK2Active42GTP,MutACK2Active42GDP,kGAP,KmGAP,"MutACK2Active42GAPing");
	reactions.push_back(MutACK2Active42GAPing);

	Reaction *MutACK242GDPRelease = new HeterodimerDissociationReaction(MutACK242GDP,ACK2,MutCdc42GDP,kuACK242GDP,"MutACK242GDPRelease");
	reactions.push_back(MutACK242GDPRelease);

	Reaction *MutACK2Active42GDPRelease = new HeterodimerDissociationReaction(MutACK2Active42GDP,ACK2Active,MutCdc42GDP,kuACK2Active42GDP,"MutACK2Active42GDPRelease");
	reactions.push_back(MutACK2Active42GDPRelease);
	// 70
	Reaction *MutCoolCbl42Binding = new HeterodimerizationReaction(Cool1Cbl,MutCdc42GTP,MutCool1Cbl42GTP,kbCbl42,"MutCoolCbl42Binding");
	reactions.push_back(MutCoolCbl42Binding);

	Reaction *MutCoolCbl42Unbinding = new HeterodimerDissociationReaction(MutCool1Cbl42GTP,Cool1Cbl,MutCdc42GTP,kuCbl42,"MutCoolCbl42Unbinding");
	reactions.push_back(MutCoolCbl42Unbinding);

	Reaction *MutCoolCblActive42Binding = new HeterodimerizationReaction(Cool1CblActive,MutCdc42GTP,MutCool1CblActive42GTP,kbCblActive42,"MutCoolCblActive42Binding");
	reactions.push_back(MutCoolCblActive42Binding);

	Reaction *MutCoolCblActive42Unbinding = new HeterodimerDissociationReaction(MutCool1CblActive42GTP,Cool1CblActive,MutCdc42GTP,kuCblActive42,"MutCoolCblActive42Unbinding");
	reactions.push_back(MutCoolCblActive42Unbinding);

	Reaction *MutCoolCbl42GAPing = new MichaelisMentenGProteinDeactivationReaction(Cdc42GAP,MutCool1Cbl42GTP,MutCool1Cbl42GDP,kGAP,KmGAP,"MutCoolCbl42GAPing");
	reactions.push_back(MutCoolCbl42GAPing);

	Reaction *MutCoolCblActive42GAPing = new MichaelisMentenGProteinDeactivationReaction(Cdc42GAP,MutCool1CblActive42GTP,MutCool1CblActive42GDP,kGAP,KmGAP,"MutCoolCblActive42GAPing");
	reactions.push_back(MutCoolCblActive42GAPing);

	Reaction *MutCoolCbl42GDPRelease = new HeterodimerDissociationReaction(MutCool1Cbl42GDP,Cool1Cbl,MutCdc42GDP,kuCool1Cbl42GDP,"MutCoolCbl42GDPRelease");
	reactions.push_back(MutCoolCbl42GDPRelease);

	Reaction *MutCoolCblActive42GDPRelease = new HeterodimerDissociationReaction(MutCool1CblActive42GDP,Cool1CblActive,MutCdc42GDP,kuCool1CblActive42GDP,"MutCoolCblActive42GDPRelease");
	reactions.push_back(MutCoolCblActive42GDPRelease);

	Reaction *MutVesicleAssembly1 = new HeterodimerizationReaction(COPIEndoBoundEGFR,MutCdc42GTP,MutRecyclingVesicle1,kb42COPI,"MutVesicleAssembly1");
	reactions.push_back(MutVesicleAssembly1);

	Reaction *MutVesicleAssembly2 = new HeterodimerizationReaction(COPIEndoBoundEGFRCoolCblActive,MutCdc42GTP,MutRecyclingVesicle2,kb42COPI,"MutVesicleAssembly2");
	reactions.push_back(MutVesicleAssembly2);
	// 80
	Reaction *MutRecycling1 = new TransformationReaction(MutRecyclingVesicle1,MutRecycledVesicle1,kRec,"MutRecycling1");
	reactions.push_back(MutRecycling1);

	Reaction *MutRecycling2 = new TransformationReaction(MutRecyclingVesicle2,MutRecycledVesicle2,kRec,"MutRecycling2");
	reactions.push_back(MutRecycling2);

	Reaction *MutVesicleGAPing1 = new MichaelisMentenTransformationReaction(Cdc42GAP,MutRecycledVesicle1,MutVesicle1Cdc42GDP,kGAP,KmGAP,"MutVesicleGAPing1");
	reactions.push_back(MutVesicleGAPing1);

	Reaction *MutVesicleGAPing2 = new MichaelisMentenTransformationReaction(Cdc42GAP,MutRecycledVesicle2,MutVesicle2Cdc42GDP,kGAP,KmGAP,"MutVesicleGAPing2");
	reactions.push_back(MutVesicleGAPing2);

	Reaction *MutCdc42COPIUnbinding1 = new HeterodimerDissociationReaction(MutVesicle1Cdc42GDP,COPIPMBoundEGFR,MutCdc42GDP,ku42COPI,"MutCdc42COPIUnbinding1");
	reactions.push_back(MutCdc42COPIUnbinding1);

	Reaction *MutCdc42COPIUnbinding2 = new HeterodimerDissociationReaction(MutVesicle2Cdc42GDP,COPIPMBoundEGFRCoolCblActive,MutCdc42GDP,ku42COPI,"MutCdc42COPIUnbinding2");
	reactions.push_back(MutCdc42COPIUnbinding2);
	
	// activation by receptor
	Reaction *MutCdc42PMActivation1 = new MichaelisMentenGProteinActivationReaction(BoundPMEGFR,MutCdc42GDP,MutCdc42GTP,kEGFR42,KmEGFR42,"MutCdc42PMActivation1");
	reactions.push_back(MutCdc42PMActivation1);

	Reaction *MutCdc42PMActivation2 = new MichaelisMentenGProteinActivationReaction(BoundPMEGFRCoolCbl,MutCdc42GDP,MutCdc42GTP,kEGFR42,KmEGFR42,"MutCdc42PMActivation2");
	reactions.push_back(MutCdc42PMActivation2);

	Reaction *MutCdc42PMActivation3 = new MichaelisMentenGProteinActivationReaction(BoundPMEGFRCoolCblActive,MutCdc42GDP,MutCdc42GTP,kEGFR42,KmEGFR42,"MutCdc42PMActivation3");
	reactions.push_back(MutCdc42PMActivation3);

	Reaction *MutCdc42PMActivation4 = new MichaelisMentenGProteinActivationReaction(UbiBoundPMEGFRCoolCblActive,MutCdc42GDP,MutCdc42GTP,kEGFR42,KmEGFR42,"MutCdc42PMActivation4");
	reactions.push_back(MutCdc42PMActivation4);
	
	Reaction *MutCdc42GAPHydrolysis = new MichaelisMentenGProteinActivationReaction(Cdc42GAP,MutCdc42GTP,MutCdc42GDP,kGAP,KmGAP,"MutCdc42GAPHydrolysis");
	reactions.push_back(MutCdc42GAPHydrolysis);

	// 91
	// autoactivation (fast cycler)
	Reaction *AutoActivation = new TransformationReaction(MutCdc42GDP,MutCdc42GTP,kEGFR42,"AutoActivation");
	reactions.push_back(AutoActivation);
	

}

CEGFRTraffickingPredictionNetwork::~CEGFRTraffickingPredictionNetwork()
{

}
