// EGFRTraffickingRunDirector.cpp: implementation of the CEGFRTraffickingRunDirector class.
//
//////////////////////////////////////////////////////////////////////

#include "EGFRTraffickingRunDirector.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

CEGFRTraffickingRunDirector::CEGFRTraffickingRunDirector()
{
	double maxSimTime = 240.0;
	int intTime = (int) maxSimTime + 2;
	double stepSize = 0.001;
	double frequency = 1.0;
	double moveTol = 1.0e-06;
	
	int cnt = 0;
	
	// EGF at 100 ng/ml, 8000 EGFRs
	m_vpRxnNetworks.push_back(new CEGFRTraffickingNetwork());
	//m_vpRxnMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	m_vpRxnMovers.push_back(new CStiffBulirschStoerMover(frequency,stepSize,moveTol));
	int nChemicals = m_vpRxnNetworks[cnt]->GetNumberOfChemicals();
	m_vpCellObservers.push_back(new CellAverageObserver(nChemicals,intTime,1));
	m_vpRunnables.push_back(new CRunnable());
	m_vpRunnables[cnt]->SetComponents(m_vpRxnNetworks[cnt],m_vpRxnMovers[cnt],m_vpCellObservers[cnt]);
	// create an observer for the runnable
	m_vpGnuPlotters.push_back(new GnuPlotterRunnableObserver());

	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(70);
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(71);
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(72);
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(77);
	/*
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(32);
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(33);
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(34);
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(35);
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(55);
	*/
	// attach the observer
	m_vpRunnables[cnt]->Attach(m_vpGnuPlotters[cnt]);
	cnt++;

	/*
	// EGF at 100 ng/ml, 50000 EGFRs
	m_vpRxnNetworks.push_back(new CEGFRTraffickingNetwork());
	m_vpRxnMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	nChemicals = m_vpRxnNetworks[cnt]->GetNumberOfChemicals();
	m_vpCellObservers.push_back(new CellAverageObserver(nChemicals,intTime,1));
	m_vpRunnables.push_back(new CRunnable());
	m_vpRunnables[cnt]->SetComponents(m_vpRxnNetworks[cnt],m_vpRxnMovers[cnt],m_vpCellObservers[cnt]);
	// create an observer for the runnable
	m_vpGnuPlotters.push_back(new GnuPlotterRunnableObserver());
	
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(54);
	
	// attach the observer
	m_vpRunnables[cnt]->Attach(m_vpGnuPlotters[cnt]);
	cnt++;

	// EGF at 100 ng/ml, 100000 EGFRs
	m_vpRxnNetworks.push_back(new CEGFRTraffickingNetwork());
	m_vpRxnMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	nChemicals = m_vpRxnNetworks[cnt]->GetNumberOfChemicals();
	m_vpCellObservers.push_back(new CellAverageObserver(nChemicals,intTime,1));
	m_vpRunnables.push_back(new CRunnable());
	m_vpRunnables[cnt]->SetComponents(m_vpRxnNetworks[cnt],m_vpRxnMovers[cnt],m_vpCellObservers[cnt]);
	// create an observer for the runnable
	m_vpGnuPlotters.push_back(new GnuPlotterRunnableObserver());
	
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(54);
	
	// attach the observer
	m_vpRunnables[cnt]->Attach(m_vpGnuPlotters[cnt]);
	cnt++;

	// EGF at 100 ng/ml, 300000 EGFRs
	m_vpRxnNetworks.push_back(new CEGFRTraffickingNetwork());
	m_vpRxnMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	nChemicals = m_vpRxnNetworks[cnt]->GetNumberOfChemicals();
	m_vpCellObservers.push_back(new CellAverageObserver(nChemicals,intTime,1));
	m_vpRunnables.push_back(new CRunnable());
	m_vpRunnables[cnt]->SetComponents(m_vpRxnNetworks[cnt],m_vpRxnMovers[cnt],m_vpCellObservers[cnt]);
	// create an observer for the runnable
	m_vpGnuPlotters.push_back(new GnuPlotterRunnableObserver());
	
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(54);
	
	// attach the observer
	m_vpRunnables[cnt]->Attach(m_vpGnuPlotters[cnt]);
	cnt++;
	*/
	/*
	// EGF at 100 ng/ml, EGFR overexpressed
	m_vpRxnNetworks.push_back(new CEGFRTraffickingNetwork());
	m_vpRxnMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	int nChemicals = m_vpRxnNetworks[cnt]->GetNumberOfChemicals();
	m_vpCellObservers.push_back(new CellAverageObserver(nChemicals,intTime,1));
	m_vpRunnables.push_back(new CRunnable());
	m_vpRunnables[cnt]->SetComponents(m_vpRxnNetworks[cnt],m_vpRxnMovers[cnt],m_vpCellObservers[cnt]);
	// create an observer for the runnable
	m_vpGnuPlotters.push_back(new GnuPlotterRunnableObserver());
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(1);
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(47);
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(49);
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(58);
	// attach the observer
	m_vpRunnables[cnt]->Attach(m_vpGnuPlotters[cnt]);
	cnt++;

	
	// EGF at 100 ng/ml, EGFR overexpressed, Cdc42 wt overexpressed
	m_vpRxnNetworks.push_back(new CEGFRTraffickingNetwork());
	m_vpRxnMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	nChemicals = m_vpRxnNetworks[cnt]->GetNumberOfChemicals();
	m_vpCellObservers.push_back(new CellAverageObserver(nChemicals,intTime,1));
	m_vpRunnables.push_back(new CRunnable());
	m_vpRunnables[cnt]->SetComponents(m_vpRxnNetworks[cnt],m_vpRxnMovers[cnt],m_vpCellObservers[cnt]);
	// create an observer for the runnable
	m_vpGnuPlotters.push_back(new GnuPlotterRunnableObserver());
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(1);
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(47);
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(49);
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(58);
	// attach the observer
	m_vpRunnables[cnt]->Attach(m_vpGnuPlotters[cnt]);
	cnt++;
	
	// EGF at 100 ng/ml, EGFR overexpressed + Cdc42(Q61L)
	m_vpRxnNetworks.push_back(new CEGFRTraffickingNetwork());
	m_vpRxnMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	nChemicals = m_vpRxnNetworks[cnt]->GetNumberOfChemicals();
	m_vpCellObservers.push_back(new CellAverageObserver(nChemicals,intTime,1));
	m_vpRunnables.push_back(new CRunnable());
	m_vpRunnables[cnt]->SetComponents(m_vpRxnNetworks[cnt],m_vpRxnMovers[cnt],m_vpCellObservers[cnt]);
	// create an observer for the runnable
	m_vpGnuPlotters.push_back(new GnuPlotterRunnableObserver());
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(1);
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(47);
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(49);
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(58);
	// attach the observer
	m_vpRunnables[cnt]->Attach(m_vpGnuPlotters[cnt]);
	cnt++;
	
	// EGF at 100 ng/ml, EGFR overexpressed + Cdc42(T17N)
	m_vpRxnNetworks.push_back(new CEGFRTraffickingNetwork());
	m_vpRxnMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	nChemicals = m_vpRxnNetworks[cnt]->GetNumberOfChemicals();
	m_vpCellObservers.push_back(new CellAverageObserver(nChemicals,intTime,1));
	m_vpRunnables.push_back(new CRunnable());
	m_vpRunnables[cnt]->SetComponents(m_vpRxnNetworks[cnt],m_vpRxnMovers[cnt],m_vpCellObservers[cnt]);
	// create an observer for the runnable
	m_vpGnuPlotters.push_back(new GnuPlotterRunnableObserver());
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(1);
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(47);
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(49);
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(58);
	// attach the observer
	m_vpRunnables[cnt]->Attach(m_vpGnuPlotters[cnt]);
	cnt++;

	// EGF at 100 ng/ml, EGFR overexpressed + Cdc42dL8
	m_vpRxnNetworks.push_back(new CEGFRTraffickingNetwork());
	m_vpRxnMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	nChemicals = m_vpRxnNetworks[cnt]->GetNumberOfChemicals();
	m_vpCellObservers.push_back(new CellAverageObserver(nChemicals,intTime,1));
	m_vpRunnables.push_back(new CRunnable());
	m_vpRunnables[cnt]->SetComponents(m_vpRxnNetworks[cnt],m_vpRxnMovers[cnt],m_vpCellObservers[cnt]);
	// create an observer for the runnable
	m_vpGnuPlotters.push_back(new GnuPlotterRunnableObserver());
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(1);
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(47);
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(49);
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(58);
	// attach the observer
	m_vpRunnables[cnt]->Attach(m_vpGnuPlotters[cnt]);
	cnt++;

	// EGF at 100 ng/ml, EGFR overexpressed + Cdc42Lss
	m_vpRxnNetworks.push_back(new CEGFRTraffickingNetwork());
	m_vpRxnMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	nChemicals = m_vpRxnNetworks[cnt]->GetNumberOfChemicals();
	m_vpCellObservers.push_back(new CellAverageObserver(nChemicals,intTime,1));
	m_vpRunnables.push_back(new CRunnable());
	m_vpRunnables[cnt]->SetComponents(m_vpRxnNetworks[cnt],m_vpRxnMovers[cnt],m_vpCellObservers[cnt]);
	// create an observer for the runnable
	m_vpGnuPlotters.push_back(new GnuPlotterRunnableObserver());
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(1);
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(47);
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(49);
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(58);
	// attach the observer
	m_vpRunnables[cnt]->Attach(m_vpGnuPlotters[cnt]);
	cnt++;

	// EGF at 100 ng/ml, EGFR overexpressed + Cdc42(Q61L/dL8)
	m_vpRxnNetworks.push_back(new CEGFRTraffickingNetwork());
	m_vpRxnMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	nChemicals = m_vpRxnNetworks[cnt]->GetNumberOfChemicals();
	m_vpCellObservers.push_back(new CellAverageObserver(nChemicals,intTime,1));
	m_vpRunnables.push_back(new CRunnable());
	m_vpRunnables[cnt]->SetComponents(m_vpRxnNetworks[cnt],m_vpRxnMovers[cnt],m_vpCellObservers[cnt]);
	// create an observer for the runnable
	m_vpGnuPlotters.push_back(new GnuPlotterRunnableObserver());
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(1);
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(47);
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(49);
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(58);
	// attach the observer
	m_vpRunnables[cnt]->Attach(m_vpGnuPlotters[cnt]);
	cnt++;

	// EGF at 100 ng/ml, EGFR overexpressed + Cdc42(Q61L/Lss)
	m_vpRxnNetworks.push_back(new CEGFRTraffickingNetwork());
	m_vpRxnMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	nChemicals = m_vpRxnNetworks[cnt]->GetNumberOfChemicals();
	m_vpCellObservers.push_back(new CellAverageObserver(nChemicals,intTime,1));
	m_vpRunnables.push_back(new CRunnable());
	m_vpRunnables[cnt]->SetComponents(m_vpRxnNetworks[cnt],m_vpRxnMovers[cnt],m_vpCellObservers[cnt]);
	// create an observer for the runnable
	m_vpGnuPlotters.push_back(new GnuPlotterRunnableObserver());
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(1);
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(47);
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(49);
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(58);
	// attach the observer
	m_vpRunnables[cnt]->Attach(m_vpGnuPlotters[cnt]);
	cnt++;

	
	// EGF at 100 ng/ml, EGFR overexpressed + Cdc42(F28L)
	m_vpRxnNetworks.push_back(new CEGFRTraffickingNetwork());
	m_vpRxnMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	nChemicals = m_vpRxnNetworks[cnt]->GetNumberOfChemicals();
	m_vpCellObservers.push_back(new CellAverageObserver(nChemicals,intTime,1));
	m_vpRunnables.push_back(new CRunnable());
	m_vpRunnables[cnt]->SetComponents(m_vpRxnNetworks[cnt],m_vpRxnMovers[cnt],m_vpCellObservers[cnt]);
	// create an observer for the runnable
	m_vpGnuPlotters.push_back(new GnuPlotterRunnableObserver());
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(1);
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(47);
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(49);
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(58);
	// attach the observer
	m_vpRunnables[cnt]->Attach(m_vpGnuPlotters[cnt]);
	cnt++;

	// EGF at 100 ng/ml, EGFR overexpressed + Cdc42(F28L/dL8)
	m_vpRxnNetworks.push_back(new CEGFRTraffickingNetwork());
	m_vpRxnMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	nChemicals = m_vpRxnNetworks[cnt]->GetNumberOfChemicals();
	m_vpCellObservers.push_back(new CellAverageObserver(nChemicals,intTime,1));
	m_vpRunnables.push_back(new CRunnable());
	m_vpRunnables[cnt]->SetComponents(m_vpRxnNetworks[cnt],m_vpRxnMovers[cnt],m_vpCellObservers[cnt]);
	// create an observer for the runnable
	m_vpGnuPlotters.push_back(new GnuPlotterRunnableObserver());
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(1);
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(47);
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(49);
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(58);
	// attach the observer
	m_vpRunnables[cnt]->Attach(m_vpGnuPlotters[cnt]);
	cnt++;
	
	// EGF at 100 ng/ml, EGFR overexpressed + Cdc42(F28L/Lss)
	m_vpRxnNetworks.push_back(new CEGFRTraffickingNetwork());
	m_vpRxnMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	nChemicals = m_vpRxnNetworks[cnt]->GetNumberOfChemicals();
	m_vpCellObservers.push_back(new CellAverageObserver(nChemicals,intTime,1));
	m_vpRunnables.push_back(new CRunnable());
	m_vpRunnables[cnt]->SetComponents(m_vpRxnNetworks[cnt],m_vpRxnMovers[cnt],m_vpCellObservers[cnt]);
	// create an observer for the runnable
	m_vpGnuPlotters.push_back(new GnuPlotterRunnableObserver());
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(1);
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(47);
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(49);
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(58);
	// attach the observer
	m_vpRunnables[cnt]->Attach(m_vpGnuPlotters[cnt]);
	cnt++;
	*/
	DefineRuns();
}

CEGFRTraffickingRunDirector::~CEGFRTraffickingRunDirector()
{

}

void CEGFRTraffickingRunDirector::DefineRuns()
{
	// set parameters in the runnables to those read from a previous
	// optimization pass; assumes all runnables have same number of 
	// rate constants
	ParameterReader *pReader = new ParameterReader("traffic_restart.par");
	int nRC = m_vpRunnables[0]->GetReactionNetwork()->GetNumberOfRateConstants();
	for(int j = 0; j < nRC; j++)
	{
		double rate = pReader->ReadParameter();
		for(int i = 0; i < m_vpRunnables.size(); i++)
		{
			m_vpRunnables[i]->GetReactionNetwork()->GetRateConstant(j)->SetRateConstant(rate);
		}
	}

	m_vpRunnables[0]->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(1.2e+007);
	m_vpRunnables[0]->GetReactionNetwork()->GetChemical(3)->SetInitialAmount(8000);
	m_vpRunnables[0]->GetReactionNetwork()->GetChemical(45)->SetInitialAmount(pReader->ReadParameter());
	m_vpRunnables[0]->GetReactionNetwork()->GetChemical(46)->SetInitialAmount(pReader->ReadParameter());
	m_vpRunnables[0]->GetReactionNetwork()->GetChemical(48)->SetInitialAmount(pReader->ReadParameter());
	m_vpRunnables[0]->GetReactionNetwork()->GetChemical(51)->SetInitialAmount(pReader->ReadParameter());
	m_vpRunnables[0]->GetReactionNetwork()->GetChemical(57)->SetInitialAmount(pReader->ReadParameter());
	m_vpRunnables[0]->GetReactionNetwork()->GetChemical(58)->SetInitialAmount(pReader->ReadParameter());
	m_vpRunnables[0]->GetReactionNetwork()->GetChemical(63)->SetInitialAmount(pReader->ReadParameter());
	m_vpRunnables[0]->GetReactionNetwork()->GetChemical(71)->SetInitialAmount(pReader->ReadParameter());	
	m_vpRunnables[0]->GetReactionNetwork()->ChemicalReset();
	m_vpGnuPlotters[0]->SetTitle("100 ng/ml EGF + 8000 EGFRs");

	delete pReader;

	/*
	m_vpRunnables[1]->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(1.2e+007);
	m_vpRunnables[1]->GetReactionNetwork()->GetChemical(3)->SetInitialAmount(50000);
	m_vpRunnables[1]->GetReactionNetwork()->ChemicalReset();
	m_vpGnuPlotters[1]->SetTitle("100 ng/ml EGF + 50000 EGFRs");
	
	m_vpRunnables[2]->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(1.2e+007);
	m_vpRunnables[2]->GetReactionNetwork()->GetChemical(3)->SetInitialAmount(100000);
	m_vpRunnables[2]->GetReactionNetwork()->ChemicalReset();
	m_vpGnuPlotters[2]->SetTitle("100 ng/ml EGF + 100000 EGFRs");
	
	m_vpRunnables[3]->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(1.2e+007);
	m_vpRunnables[3]->GetReactionNetwork()->GetChemical(3)->SetInitialAmount(300000);
	m_vpRunnables[3]->GetReactionNetwork()->ChemicalReset();
	m_vpGnuPlotters[3]->SetTitle("100 ng/ml EGF + 300000 EGFRs");
	*/
	/*
	// 100,000 receptors, EGF at 100 ng/ml
	m_vpRunnables[0]->GetReactionNetwork()->RemoveReaction(64);
	m_vpRunnables[0]->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(1.2e+007);
	m_vpRunnables[0]->GetReactionNetwork()->GetChemical(2)->SetInitialAmount(100000);
	m_vpRunnables[0]->GetReactionNetwork()->ChemicalReset();
	m_vpGnuPlotters[0]->SetTitle("100 ng/ml EGF + EGFR");
	
	// 100,000 receptors, EGF at 100 ng/ml, Cdc42wt 2-fold overexpressed
	m_vpRunnables[1]->GetReactionNetwork()->RemoveReaction(64);
	m_vpRunnables[1]->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(1.2e+007);
	m_vpRunnables[1]->GetReactionNetwork()->GetChemical(2)->SetInitialAmount(100000);
	m_vpRunnables[1]->GetReactionNetwork()->GetChemical(35)->SetInitialAmount(2*600000);
	m_vpRunnables[1]->GetReactionNetwork()->ChemicalReset();
	m_vpGnuPlotters[1]->SetTitle("100 ng/ml EGF + EGFR + Cdc42wt");

	// 100,000 receptors, EGF at 100 ng/ml, Cdc42(Q61L)
	m_vpRunnables[2]->GetReactionNetwork()->RemoveReaction(64);
	m_vpRunnables[2]->GetReactionNetwork()->RemoveReaction(59);
	m_vpRunnables[2]->GetReactionNetwork()->RemoveReaction(58);
	m_vpRunnables[2]->GetReactionNetwork()->RemoveReaction(25);
	m_vpRunnables[2]->GetReactionNetwork()->RemoveReaction(24);
	m_vpRunnables[2]->GetReactionNetwork()->RemoveReaction(17);
	m_vpRunnables[2]->GetReactionNetwork()->RemoveReaction(16);
	m_vpRunnables[2]->GetReactionNetwork()->RemoveReaction(6);
	m_vpRunnables[2]->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(1.2e+007);
	m_vpRunnables[2]->GetReactionNetwork()->GetChemical(2)->SetInitialAmount(100000);
	// start with all mutant 42 active
	m_vpRunnables[2]->GetReactionNetwork()->GetChemical(35)->SetInitialAmount(0.0);
	m_vpRunnables[2]->GetReactionNetwork()->GetChemical(36)->SetInitialAmount(2*600000);
	m_vpRunnables[2]->GetReactionNetwork()->ChemicalReset();
	m_vpGnuPlotters[2]->SetTitle("100 ng/ml EGF + EGFR + Cdc42(Q61L)");

	// 100,000 receptors, EGF at 100 ng/ml, Cdc42(T17N)
	m_vpRunnables[3]->GetReactionNetwork()->RemoveReaction(64);
	m_vpRunnables[3]->GetReactionNetwork()->RemoveReaction(5);
	m_vpRunnables[3]->GetReactionNetwork()->RemoveReaction(4);
	m_vpRunnables[3]->GetReactionNetwork()->RemoveReaction(3);
	m_vpRunnables[3]->GetReactionNetwork()->RemoveReaction(2);
	m_vpRunnables[3]->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(1.2e+007);
	m_vpRunnables[3]->GetReactionNetwork()->GetChemical(2)->SetInitialAmount(100000);
	m_vpRunnables[3]->GetReactionNetwork()->GetChemical(35)->SetInitialAmount(2*600000);
	m_vpRunnables[3]->GetReactionNetwork()->ChemicalReset();
	m_vpGnuPlotters[3]->SetTitle("100 ng/ml EGF + EGFR + Cdc42(T17N)");

	// 100,000 receptors, EGF at 100 ng/ml, Cdc42dL8
	m_vpRunnables[4]->GetReactionNetwork()->RemoveReaction(64);
	m_vpRunnables[4]->GetReactionNetwork()->RemoveReaction(22);
	m_vpRunnables[4]->GetReactionNetwork()->RemoveReaction(20);
	m_vpRunnables[4]->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(1.2e+007);
	m_vpRunnables[4]->GetReactionNetwork()->GetChemical(2)->SetInitialAmount(100000);
	// start with all 42 active
	m_vpRunnables[4]->GetReactionNetwork()->GetChemical(35)->SetInitialAmount(2*600000);
	m_vpRunnables[4]->GetReactionNetwork()->ChemicalReset();
	m_vpGnuPlotters[4]->SetTitle("100 ng/ml EGF + EGFR + Cdc42dL8");

	// 100,000 receptors, EGF at 100 ng/ml, Cdc42Lss
	m_vpRunnables[5]->GetReactionNetwork()->RemoveReaction(64);
	m_vpRunnables[5]->GetReactionNetwork()->RemoveReaction(55);
	m_vpRunnables[5]->GetReactionNetwork()->RemoveReaction(54);
	m_vpRunnables[5]->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(1.2e+007);
	m_vpRunnables[5]->GetReactionNetwork()->GetChemical(2)->SetInitialAmount(100000);
	// start with all 42 active
	m_vpRunnables[5]->GetReactionNetwork()->GetChemical(35)->SetInitialAmount(2*600000);
	m_vpRunnables[5]->GetReactionNetwork()->ChemicalReset();
	m_vpGnuPlotters[5]->SetTitle("100 ng/ml EGF + EGFR + Cdc42Lss");

	// 100,000 receptors, EGF at 100 ng/ml, Cdc42(Q61L/dL8)
	m_vpRunnables[6]->GetReactionNetwork()->RemoveReaction(64);
	m_vpRunnables[6]->GetReactionNetwork()->RemoveReaction(59);
	m_vpRunnables[6]->GetReactionNetwork()->RemoveReaction(58);
	m_vpRunnables[6]->GetReactionNetwork()->RemoveReaction(25);
	m_vpRunnables[6]->GetReactionNetwork()->RemoveReaction(24);
	m_vpRunnables[6]->GetReactionNetwork()->RemoveReaction(22);
	m_vpRunnables[6]->GetReactionNetwork()->RemoveReaction(20);
	m_vpRunnables[6]->GetReactionNetwork()->RemoveReaction(17);
	m_vpRunnables[6]->GetReactionNetwork()->RemoveReaction(16);
	m_vpRunnables[6]->GetReactionNetwork()->RemoveReaction(6);
	m_vpRunnables[6]->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(1.2e+007);
	m_vpRunnables[6]->GetReactionNetwork()->GetChemical(2)->SetInitialAmount(100000);
	// start with all 42 active
	m_vpRunnables[6]->GetReactionNetwork()->GetChemical(35)->SetInitialAmount(0.0);
	m_vpRunnables[6]->GetReactionNetwork()->GetChemical(36)->SetInitialAmount(2*600000);
	m_vpRunnables[6]->GetReactionNetwork()->ChemicalReset();
	m_vpGnuPlotters[6]->SetTitle("100 ng/ml EGF + EGFR + Cdc42(Q61L/dL8)");


	// 100,000 receptors, EGF at 100 ng/ml, Cdc42(Q61L/Lss)
	m_vpRunnables[7]->GetReactionNetwork()->RemoveReaction(64);
	m_vpRunnables[7]->GetReactionNetwork()->RemoveReaction(59);
	m_vpRunnables[7]->GetReactionNetwork()->RemoveReaction(58);
	m_vpRunnables[7]->GetReactionNetwork()->RemoveReaction(55);
	m_vpRunnables[7]->GetReactionNetwork()->RemoveReaction(54);
	m_vpRunnables[7]->GetReactionNetwork()->RemoveReaction(25);
	m_vpRunnables[7]->GetReactionNetwork()->RemoveReaction(24);
	m_vpRunnables[7]->GetReactionNetwork()->RemoveReaction(17);
	m_vpRunnables[7]->GetReactionNetwork()->RemoveReaction(16);
	m_vpRunnables[7]->GetReactionNetwork()->RemoveReaction(6);
	m_vpRunnables[7]->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(1.2e+007);
	m_vpRunnables[7]->GetReactionNetwork()->GetChemical(2)->SetInitialAmount(100000);
	// start with all 42 active
	m_vpRunnables[7]->GetReactionNetwork()->GetChemical(35)->SetInitialAmount(0.0);
	m_vpRunnables[7]->GetReactionNetwork()->GetChemical(36)->SetInitialAmount(2*600000);
	m_vpRunnables[7]->GetReactionNetwork()->ChemicalReset();
	m_vpGnuPlotters[7]->SetTitle("100 ng/ml EGF + EGFR + Cdc42(Q61L/Lss)");


	// 100,000 receptors, EGF at 100 ng/ml, Cdc42(F28L)
	m_vpRunnables[8]->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(1.2e+007);
	m_vpRunnables[8]->GetReactionNetwork()->GetChemical(2)->SetInitialAmount(100000);
	// start with all 42 active
	m_vpRunnables[8]->GetReactionNetwork()->GetChemical(35)->SetInitialAmount(0.0);
	m_vpRunnables[8]->GetReactionNetwork()->GetChemical(36)->SetInitialAmount(2*600000);
	m_vpRunnables[8]->GetReactionNetwork()->ChemicalReset();
	m_vpGnuPlotters[8]->SetTitle("100 ng/ml EGF + EGFR + Cdc42(F28L)");

	
	// 100,000 receptors, EGF at 100 ng/ml, Cdc42(F28L/dL8)
	m_vpRunnables[9]->GetReactionNetwork()->RemoveReaction(22);
	m_vpRunnables[9]->GetReactionNetwork()->RemoveReaction(20);
	m_vpRunnables[9]->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(1.2e+007);
	m_vpRunnables[9]->GetReactionNetwork()->GetChemical(2)->SetInitialAmount(100000);
	// start with all 42 active
	m_vpRunnables[9]->GetReactionNetwork()->GetChemical(35)->SetInitialAmount(0.0);
	m_vpRunnables[9]->GetReactionNetwork()->GetChemical(36)->SetInitialAmount(2*600000);
	m_vpRunnables[9]->GetReactionNetwork()->ChemicalReset();
	m_vpGnuPlotters[9]->SetTitle("100 ng/ml EGF + EGFR + Cdc42(F28L/dL8)");

	
	// 100,000 receptors, EGF at 100 ng/ml, Cdc42(F28L/Lss)
	m_vpRunnables[10]->GetReactionNetwork()->RemoveReaction(55);
	m_vpRunnables[10]->GetReactionNetwork()->RemoveReaction(54);
	m_vpRunnables[10]->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(1.2e+007);
	m_vpRunnables[10]->GetReactionNetwork()->GetChemical(2)->SetInitialAmount(100000);
	// start with all 42 active
	m_vpRunnables[10]->GetReactionNetwork()->GetChemical(35)->SetInitialAmount(0.0);
	m_vpRunnables[10]->GetReactionNetwork()->GetChemical(36)->SetInitialAmount(2*600000);
	m_vpRunnables[10]->GetReactionNetwork()->ChemicalReset();
	m_vpGnuPlotters[10]->SetTitle("100 ng/ml EGF + EGFR + Cdc42(F28L/Lss)");
	*/
}