// ExampleNetwork.cpp: implementation of the CExampleNetwork class.
//
//////////////////////////////////////////////////////////////////////

#include "ExampleNetwork.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

CExampleNetwork::CExampleNetwork()
{
	double CFactor = 600000;
	double SecPerMin = 60.0;

	Chemical *Ligand = new Chemical(chemicals.size(),0.0,"Ligand");
	chemicals.push_back(Ligand);

	Chemical *FreeReceptor = new Chemical(chemicals.size(),1000,"FreeReceptor");
	chemicals.push_back(FreeReceptor);

	Chemical *BoundReceptor = new Chemical(chemicals.size(),0.0,"BoundReceptor");
	chemicals.push_back(BoundReceptor);

	Chemical *InactiveGEF = new Chemical(chemicals.size(),10000,"InactiveGEF");
	chemicals.push_back(InactiveGEF);

	Chemical *ActiveGEF = new Chemical(chemicals.size(),0.0,"ActiveGEF");
	chemicals.push_back(ActiveGEF);

	Chemical *SmallGGDP = new Chemical(chemicals.size(),10000,"SmallGGDP");
	chemicals.push_back(SmallGGDP);

	Chemical *SmallGGTP = new Chemical(chemicals.size(),0.0,"SmallGGTP");
	chemicals.push_back(SmallGGTP);

	RateConstant *k_b = new RateConstant(0.1*SecPerMin,"k_b");
	rateConstants.push_back(k_b);

	RateConstant *k_GEF = new RateConstant(0.05*SecPerMin,"k_GEF");
	rateConstants.push_back(k_GEF);

	RateConstant *Km_GEF = new RateConstant(CFactor*0.5,"Km_GEF");
	rateConstants.push_back(Km_GEF);

	RateConstant *k_G = new RateConstant(0.075*SecPerMin,"k_G");
	rateConstants.push_back(k_G);

	RateConstant *Km_G = new RateConstant(CFactor*0.25,"Km_G");
	rateConstants.push_back(Km_G);

	Reaction *LigandBinding = new HeterodimerizationReaction(Ligand,FreeReceptor,BoundReceptor,k_b,"LigandBinding");
	reactions.push_back(LigandBinding);

	Reaction *GEFActivation = new MichaelisMentenPhosphorylationReaction(BoundReceptor,InactiveGEF,ActiveGEF,k_GEF,Km_GEF,"GEFActivation");
	reactions.push_back(GEFActivation);

	Reaction *SmallGActivation = new MichaelisMentenGProteinActivationReaction(ActiveGEF,SmallGGDP,SmallGGTP,k_G,Km_G,"GProteinActivation");
	reactions.push_back(SmallGActivation);
}

CExampleNetwork::~CExampleNetwork()
{

}
