// ExampleNetworkMinimizableDirector.cpp: implementation of the CExampleNetworkMinimizableDirector class.
//
//////////////////////////////////////////////////////////////////////

#include "ExampleNetworkMinimizableDirector.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

CExampleNetworkMinimizableDirector::CExampleNetworkMinimizableDirector()
{
// create networks,experiments,observers,movers,minimizables
	double maxSimTime = 91.0;
	double stepSize = 0.001;
	double frequency = 1.0;
	int nCells = 1;
	double moveTol = 0.0001;
	
	// flags for all minimizables
	bool rateFlag = true;
	bool chemFlag = false;
	bool logsFlag = false;
	double timeWeight = 1.0;
	double rateWeight = 0.0;
	double chemWeight = 0.0;

	// expt. 1 - 1000 ligand molecules
	// networks and data
	_networkList.push_back(new CExampleNetwork());
	_experimentList.push_back(new Experiment(_networkList[0],"Ligand Stimulation"));
	// put data files here
	_experimentList[0]->AddDataFileToList("ExampleNetwork.dat");
	// mover and plotter
	_moverList.push_back(new CQualityControlRungeKuttaMover(frequency,stepSize,moveTol));
	_plotterList.push_back(new GnuPlotterTimeSeriesObserver());
	// title
	_plotterList[0]->SetTitle("G Protein Activation by RTK");
	// minimizable
	_minimizableList.push_back(new SingleNetworkMinimizable());
	// parameters
	_minimizableList[0]->Initialize(_experimentList[0],_moverList[0],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	_minimizableList[0]->SetRateConstantsWeight(0.0);
	// attach observer
	_minimizableList[0]->Attach(_plotterList[0]);

	// allocate the master residuals list
	int masterResidualsSize = 0;
	for(int i = 0; i < _minimizableList.size(); i++)
	{
		masterResidualsSize += _minimizableList[i]->GetNResiduals();
	}
	Allocate(masterResidualsSize);

	cout << "Master Residuals size : " << masterResidualsSize << endl;

	// define the experiments
	DefineExperiments();
}

CExampleNetworkMinimizableDirector::~CExampleNetworkMinimizableDirector()
{
	for(int i = 0; i < _minimizableList.size(); i++)
	{
		_minimizableList[i]->Detach(_plotterList[i]);
	}
	for(i = 0; i < _plotterList.size(); i++)
	{
		delete _plotterList[i];
	}
}

void CExampleNetworkMinimizableDirector::DefineExperiments()
{
	_minimizableList[0]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(1000.0);
	_minimizableList[0]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->Reset();

}

double CExampleNetworkMinimizableDirector::GetParameter(int parIndex)
{
	// for this director, everyone has the same parameters so any set 
	// can be returned
	return _minimizableList[0]->GetParameter(parIndex);
}

int CExampleNetworkMinimizableDirector::GetNParameters()
{
	// ditto as for GetParameters()
	return _minimizableList[0]->GetNParameters();
}

