// ForestNitrogenCycleNetwork.cpp: implementation of the CForestNitrogenCycleNetwork class.
//
//////////////////////////////////////////////////////////////////////

#include "ForestNitrogenCycleNetwork.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

CForestNitrogenCycleNetwork::CForestNitrogenCycleNetwork()
{
	// "Chemicals" - these are actual dynamical variables
	Chemical *AboveGroundBiomass = new Chemical(chemicals.size(),351.0,"AboveGroundBiomass");
	chemicals.push_back(AboveGroundBiomass);
	
	Chemical *BelowGroundBiomass = new Chemical(chemicals.size(),181.0,"BelowGroundBiomass");
	chemicals.push_back(BelowGroundBiomass);

	Chemical *ForestFloor = new Chemical(chemicals.size(),1256.0,"ForestFloor");
	chemicals.push_back(ForestFloor);

	// "Chemicals" - forcing function with time evolution defined externally
	Chemical *IP = new Chemical(chemicals.size(),0.0,"IP");
	chemicals.push_back(IP);

	// Rate Parameters - assume 20% relative error
	// Units are kg/ha/day
	RateConstant *k1 = new RateConstant(4.51,0.2*4.51,"k1");
	rateConstants.push_back(k1);

	RateConstant *k2 = new RateConstant(0.39,0.2*0.39,"k2");
	rateConstants.push_back(k2);

	RateConstant *k3 = new RateConstant(6.63,0.2*6.63,"k3");
	rateConstants.push_back(k3);

	RateConstant *k4 = new RateConstant(0.35,0.2*0.35,"k4");
	rateConstants.push_back(k4);

	RateConstant *k56 = new RateConstant(0.595,0.2*0.595,"k56");
	rateConstants.push_back(k56);

	RateConstant *k7 = new RateConstant(5.8,0.2*5.8,"k7");
	rateConstants.push_back(k7);

	std::vector<RateConstant *> rVec;
	rVec.push_back(k3);
	rVec.push_back(k4);
	rVec.push_back(k7);
	std::vector<Chemical *> cVec;
	cVec.push_back(ForestFloor);

	// Special chemical for this network
	Chemical *MDO = new CMDOChemical(chemicals.size(),"MDO",cVec,rVec);
	chemicals.push_back(MDO);

	// "Reactions" - relationships between the dynamicals
	// Affecting AboveGroundBiomass
	Reaction *AGB1 = new CConstantSourceReaction(AboveGroundBiomass,k1,"AGB1");
	reactions.push_back(AGB1);

	Reaction *AGB2 = new CConstantSourceReaction(AboveGroundBiomass,k2,"AGB2");
	reactions.push_back(AGB2);

	Reaction *AGB3 = new CNormalizedLinearAttenuator(AboveGroundBiomass,AboveGroundBiomass,k1,"AGB3");
	reactions.push_back(AGB3);
	
	// BelowGroundBiomass
	Reaction *BGB1 = new CConstantSourceReaction(BelowGroundBiomass,k3,"BGB1");
	reactions.push_back(BGB1);

	Reaction *BGB2 = new CConstantSinkReaction(BelowGroundBiomass,k1,"BGB2");
	reactions.push_back(BGB2);

	Reaction *BGB3 = new CConstantSinkReaction(BelowGroundBiomass,k2,"BGB3");
	reactions.push_back(BGB3);

	Reaction *BGB4 = new CConstantSourceReaction(BelowGroundBiomass,k4,"BGB4");
	reactions.push_back(BGB4);

	Reaction *BGB5 = new CNormalizedLinearAttenuator(BelowGroundBiomass,BelowGroundBiomass,k56,"BGB5");
	reactions.push_back(BGB5);

	// ForestFloor
	Reaction *FF1 = new CChemicalSource(ForestFloor,IP,"FF1");
	reactions.push_back(FF1);

	Reaction *FF2 = new CNormalizedLinearAmplifier(AboveGroundBiomass,ForestFloor,k1,"FF2");
	reactions.push_back(FF2);

	Reaction *FF3 = new CNormalizedLinearAmplifier(BelowGroundBiomass,ForestFloor,k56,"FF3");
	reactions.push_back(FF3);

	Reaction *FF4 = new CNormalizedLinearAttenuator(ForestFloor,ForestFloor,k7,"FF4");
	reactions.push_back(FF4);

}

CForestNitrogenCycleNetwork::~CForestNitrogenCycleNetwork()
{

}
