// ForestNitrogenCyclingMinimizableDirector.cpp: implementation of the CForestNitrogenCyclingMinimizableDirector class.
//
//////////////////////////////////////////////////////////////////////

#include "ForestNitrogenCyclingMinimizableDirector.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

CForestNitrogenCyclingMinimizableDirector::CForestNitrogenCyclingMinimizableDirector()
{
	// create networks,experiments,observers,movers,minimizables
	double maxSimTime = 385.0;
	double stepSize = 0.0001;
	double frequency = 1.0;
	int nCells = 1;
	double moveTol = 1.0e-06;

	m_dGammaSquared = 0.0;
	
	// flags for all minimizables
	bool rateFlag = true;
	bool chemFlag = false;
	bool logsFlag = false;
	double timeWeight = 1.0;
	double rateWeight = 1.0;
	double chemWeight = 0.0;

	// expt. 0 - Monthly precipitation data
	// networks and data
	_networkList.push_back(new CForestNitrogenCycleNetwork());
	_experimentList.push_back(new Experiment(_networkList[0],"Hubbard Brook 1"));
	// put data files here
	_experimentList[0]->AddDataFileToList("MonthlyMDO.dat");
	// forcing files
	_experimentList[0]->AddForcingFileToList("MonthlyIP.dat");
	// mover and plotter
	_moverList.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	_plotterList.push_back(new GnuPlotterTimeSeriesObserver());
	// title
	_plotterList[0]->SetTitle("Forest N Cycling Network : Hubbard Brook Experimental Forest : ODE");
	// minimizable
	_minimizableList.push_back(new SingleNetworkMinimizable());
	// parameters
	_minimizableList[0]->Initialize(_experimentList[0],_moverList[0],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	_minimizableList[0]->GetConversionFactor(0)->SetFactorFixed(true);
	_minimizableList[0]->GetConversionFactor(0)->SetFactorValue(1.0);
	_minimizableList[0]->GetConversionFactor(1)->SetFactorFixed(true);
	_minimizableList[0]->GetConversionFactor(1)->SetFactorValue(1.0);
	_minimizableList[0]->GetConversionFactor(2)->SetFactorFixed(true);
	_minimizableList[0]->GetConversionFactor(2)->SetFactorValue(1.0);
	_minimizableList[0]->GetConversionFactor(3)->SetFactorFixed(true);
	_minimizableList[0]->GetConversionFactor(3)->SetFactorValue(1.0);
	_minimizableList[0]->GetConversionFactor(4)->SetFactorFixed(true);
	_minimizableList[0]->GetConversionFactor(4)->SetFactorValue(1.0);
	// attach observer
	_minimizableList[0]->Attach(_plotterList[0]);

		
	// allocate the master residuals list
	int masterResidualsSize = 0;
	for(int i = 0; i < _minimizableList.size(); i++)
	{
		int subRes = _minimizableList[i]->GetNResiduals();
		masterResidualsSize += subRes;
		cout << subRes << " residuals in minimizable " << i << endl;
	}
	if(m_dGammaSquared > 0.0)
	{
		masterResidualsSize += 1;
	}
	Allocate(masterResidualsSize);

	cout << "Master Residuals size : " << masterResidualsSize << endl;

	// define the experiments
	DefineExperiments();

}

CForestNitrogenCyclingMinimizableDirector::~CForestNitrogenCyclingMinimizableDirector()
{
	for(int i = 0; i < _minimizableList.size(); i++)
	{
		_minimizableList[i]->Detach(_plotterList[i]);
	}
	for(i = 0; i < _plotterList.size(); i++)
	{
		delete _plotterList[i];
	}

}

void CForestNitrogenCyclingMinimizableDirector::DefineExperiments()
{

}

double CForestNitrogenCyclingMinimizableDirector::GetParameter(int parIndex)
{
	// for this director, everyone has the same parameters so any set 
	// can be returned
	return _minimizableList[0]->GetParameter(parIndex);
}

int CForestNitrogenCyclingMinimizableDirector::GetNParameters()
{
	// ditto as for GetParameters()
	return _minimizableList[0]->GetNParameters();
}
