// GnuPlotterParameterScatterPlot.cpp: implementation of the GnuPlotterParameterScatterPlot class.
//
//////////////////////////////////////////////////////////////////////

#include "GnuPlotterParameterScatterPlot.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

GnuPlotterParameterScatterPlot::GnuPlotterParameterScatterPlot()
{

}

GnuPlotterParameterScatterPlot::~GnuPlotterParameterScatterPlot()
{

}

void GnuPlotterParameterScatterPlot::Update(Subject *theChangedSubject)
{
	// static cast may be dangerous
	CStochasticSensitivityAnalysis *analysis = (CStochasticSensitivityAnalysis *)theChangedSubject;
	int nParams = analysis->GetEnsemble()->at(0)->GetParameterSize();

	// get a pointer to the eigenvector matrix and create a temp array
	// to compute the eigenparameters; reserve a special one for the 
	// minimum (first member of the ensemble) so we can use it to 
	// center the parameter sets
	double *eigenPar = new double[nParams];
	double *minEigen = new double[nParams];
	for(int m = 0; m < nParams; m++)
	{
		minEigen[m] = 0.0;
		eigenPar[m] = 0.0;
	}
	
	// set the plot title
	char titlestring[100];
	char commandstring[1000];
	sprintf(titlestring,"set title \"%s\"\n",title);
	SendPlotCommand(titlestring);
	SendPlotCommand("set grid\n");
	//SendPlotCommand("set nokey\n");
	SendPlotCommand("set xlabel \"i\"\n");
	SendPlotCommand("set ylabel \"Displacement of Eigenparameter from Minimum\"\n");

	// write the experimental data to the temporary file
	freopen(buffername,"w",buffer);

	// now print the rest of the members of the ensemble, no newline separation so 
	// they are all printed in the same color
	for(m = 0; m < nParams; m++)
	{
		minEigen[m] = 0.0;
	}
	// compute eigenparameters
	for(int j = 0; j < nParams; j++)
	{
		double parameter = log(analysis->GetEnsemble()->at(0)->GetParameter(j));
		for(int k = 0; k < nParams; k++)
		{
			minEigen[k] += parameter*(analysis->GetEigenvectorMatrix()[j][k]);
		}
	}	
	for(j = 0; j < nParams; j++)
	{
		fprintf(buffer,"%i\t\t%e\n",j,0);
	}

	
	for(int i = 1; i < analysis->GetEnsemble()->size(); i++)
	{
		// zero the eigenparameters
		for(int m = 0; m < nParams; m++)
		{
			eigenPar[m] = 0.0;
		}
		// compute eigenparameters
		for(int j = 0; j < nParams; j++)
		{
			double parameter = log(analysis->GetEnsemble()->at(i)->GetParameter(j));
			for(int k = 0; k < nParams; k++)
			{
				eigenPar[k] += parameter*(analysis->GetEigenvectorMatrix()[j][k]);
			}
		}
		// now print the eigenparameters
		for(j = 0; j < nParams; j++)
		{
			fprintf(buffer,"%i\t\t%e\n",j,eigenPar[j]-minEigen[j]);
		}
	}
	fprintf(buffer,"\n\n");
	fflush(buffer);

	
	// now print the random walk prediction, centered at the minimum 
	// (which is zero)
	double randVal = analysis->GetRWValue();
	fprintf(buffer,"%i\t\t%e\t\t%e\n",nParams+1,0.0,sqrt(randVal));
	fprintf(buffer,"\n\n");
	fflush(buffer);
	
	// now start sending plot strings
	sprintf(commandstring,"plot \"%s\" index 0 t \"parameters\" w points, \"%s\" index 1 t \"RW estimate\" w errorbars\n",buffername,buffername);
	
	//sprintf(commandstring,"plot \"%s\" index 0 t \"parameters\" w points\n",buffername);
	
	// change single backslashes to forward slashes to keep windows happy
#ifdef _WIN32
	int iterator = 0;
	while(commandstring[iterator] != '\0')
	{
		if(commandstring[iterator] == '\\') {commandstring[iterator] = '/';}
		iterator++;
	}
#endif

	SendPlotCommand(commandstring);

	delete [] eigenPar;
	delete [] minEigen;

	return;
}
