// LaubLoomisDictyNetwork.cpp: implementation of the CLaubLoomisDictyNetwork class.
//
//////////////////////////////////////////////////////////////////////

#include "LaubLoomisDictyNetwork.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

CLaubLoomisDictyNetwork::CLaubLoomisDictyNetwork()
{
	// #molecules/uM
	double CFactor = 300000; 
	double SecPerMin = 60.0;

	// chemical species
	Chemical *ACA = new Chemical(chemicals.size(),1.0*CFactor,"ACA");
	chemicals.push_back(ACA);

	Chemical *PKA = new Chemical(chemicals.size(),1.0*CFactor,"PKA");
	chemicals.push_back(PKA);

	Chemical *ERK2 = new Chemical(chemicals.size(),1.5*CFactor,"ERK2");
	chemicals.push_back(ERK2);

	Chemical *REGA = new Chemical(chemicals.size(),2.5*CFactor,"REGA");
	chemicals.push_back(REGA);

	Chemical *cAMPi = new Chemical(chemicals.size(),1.0*CFactor,"cAMPi");
	chemicals.push_back(cAMPi);

	Chemical *cAMPe = new Chemical(chemicals.size(),0.1*CFactor,"cAMPe");
	chemicals.push_back(cAMPe);

	Chemical *CAR1 = new Chemical(chemicals.size(),1.5*CFactor,"CAR1");
	chemicals.push_back(CAR1);

	// rate constants
	RateConstant *k1 = new RateConstant(2.0,"k1");
	rateConstants.push_back(k1);

	RateConstant *k2 = new RateConstant(0.9/CFactor,"k2");
	rateConstants.push_back(k2);

	RateConstant *k3 = new RateConstant(2.5,"k3");
	rateConstants.push_back(k3);

	RateConstant *k4 = new RateConstant(1.5,"k4");
	rateConstants.push_back(k4);

	RateConstant *k5 = new RateConstant(0.6,"k5");
	rateConstants.push_back(k5);

	RateConstant *k6 = new RateConstant(0.8/CFactor,"k6");
	rateConstants.push_back(k6);

	RateConstant *k7 = new RateConstant(1.0*CFactor,"k7");
	rateConstants.push_back(k7);

	RateConstant *k8 = new RateConstant(1.3/CFactor,"k8");
	rateConstants.push_back(k8);

	RateConstant *k9 = new RateConstant(0.3,"k9");
	rateConstants.push_back(k9);

	RateConstant *k10 = new RateConstant(0.8/CFactor,"k10");
	rateConstants.push_back(k10);

	RateConstant *k11 = new RateConstant(0.7,"k11");
	rateConstants.push_back(k11);

	RateConstant *k12 = new RateConstant(4.9,"k12");
	rateConstants.push_back(k12);

	RateConstant *k13 = new RateConstant(23.0,"k13");
	rateConstants.push_back(k13);

	RateConstant *k14 = new RateConstant(4.5,"k14");
	rateConstants.push_back(k14);

	// reactions

	Reaction *ACACreation = new GenerationReaction(CAR1,ACA,k1,"ACACreation");
	reactions.push_back(ACACreation);

	Reaction *ACADestruction = new CFirstOrderDestructionReaction(PKA,ACA,k2,"ACADestruction");
	reactions.push_back(ACADestruction);

	Reaction *PKACreation = new GenerationReaction(cAMPi,PKA,k3,"PKACreation");
	reactions.push_back(PKACreation);

	Reaction *PKADegradation = new UnstableProteinDegradationReaction(PKA,k4,"PKADegradation");
	reactions.push_back(PKADegradation);

	Reaction *ERK2Creation = new GenerationReaction(CAR1,ERK2,k5,"ERK2Creation");
	reactions.push_back(ERK2Creation);

	Reaction *ERK2Destruction = new CFirstOrderDestructionReaction(PKA,ERK2,k6,"ERK2Destruction");
	reactions.push_back(ERK2Destruction);

	Reaction *REGACreation = new CConstantSourceReaction(REGA,k7,"REGACreation");
	reactions.push_back(REGACreation);

	Reaction *REGADestruction = new CFirstOrderDestructionReaction(ERK2,REGA,k8,"REGADestruction");
	reactions.push_back(REGADestruction);

	Reaction *cAMPiCreation = new GenerationReaction(ACA,cAMPi,k9,"cAMPiCreation");
	reactions.push_back(cAMPiCreation);

	Reaction *cAMPiDestruction = new CFirstOrderDestructionReaction(REGA,cAMPi,k10,"cAMPiDestruction");
	reactions.push_back(cAMPiDestruction);

	Reaction *cAMPeCreation = new GenerationReaction(ACA,cAMPe,k11,"cAMPeCreation");
	reactions.push_back(cAMPeCreation);

	Reaction *cAMPeDestruction = new UnstableProteinDegradationReaction(cAMPe,k12,"cAMPeDegradation");
	reactions.push_back(cAMPeDestruction);

	Reaction *CAR1Creation = new GenerationReaction(cAMPe,CAR1,k13,"CAR1Creation");
	reactions.push_back(CAR1Creation);

	Reaction *CAR1Degradation = new UnstableProteinDegradationReaction(CAR1,k14,"CAR1Degradation");
	reactions.push_back(CAR1Degradation);
}

CLaubLoomisDictyNetwork::~CLaubLoomisDictyNetwork()
{

}
