#include "LaubLoomisDictyNetworkEnsembleDirector.h"

CLaubLoomisDictyNetworkEnsembleDirector::CLaubLoomisDictyNetworkEnsembleDirector(int ensembleSize)
:CEnsembleCombinationDirector(ensembleSize)
{
	double maxSimTime = 91.0;
	int intTime = (int) (maxSimTime + 2);
	double stepSize = 0.0001;
	double frequency = 1.0;
	double moveTol = 1.0e-6;
	bool rateFlag = true;
	bool chemFlag = false;
	bool logsFlag = false;
	double timeWeight = 1.0;
	double rateWeight = 0.0;
	double chemWeight = 0.0;
	int nCells = 1;

	int cnt = 0;

	// expt. 1 - Roos 1977
	// networks and data
	m_vpNetworks.push_back(new CLaubLoomisDictyNetwork());
	m_vpExperiments.push_back(new Experiment(m_vpNetworks[cnt],"Roos et. al. 1977"));
	// put data files here
	m_vpExperiments[cnt]->AddDataFileToList("../DataFiles/TimeSeries/cAMPiRoos.dat");
	// mover and plotter
	m_vpMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	// minimizable
	m_vpMinimizables.push_back(new SingleNetworkMinimizable());
	// parameters
	m_vpMinimizables[cnt]->Initialize(m_vpExperiments[cnt],m_vpMovers[cnt],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	m_vpMinimizables[cnt]->SetRateConstantsWeight(0.0);
	// attach observer
	m_vpEnsembleDataPlotters.push_back(new GnuPlotterEnsembleDataDirectorObserver());
	m_vpEnsembleDataPlotters[0]->SetTitle("D. discoideum cAMP Production : Roos et. al. 1977 : ODE");
	m_vpEnsembleDataPlotters[0]->FixMinimizable(0);
	this->Attach(m_vpEnsembleDataPlotters[0]);
	cnt++;

	// allocate space to accumulate statistics
	SumAllocate();

	// Define runs
	DefineRuns();

	// Define experiments
	DefineExperiments();

	// Load in the ensemble info
	LoadEnsembleInfo("ensemble.par");
}

CLaubLoomisDictyNetworkEnsembleDirector::~CLaubLoomisDictyNetworkEnsembleDirector(void)
{
	for(int i = 0; i < m_vpEnsembleRunPlotters.size(); i++)
	{
		this->Detach(m_vpEnsembleRunPlotters[i]);
	}
	for(i = 0; i < m_vpEnsembleDataPlotters.size(); i++)
	{
		this->Detach(m_vpEnsembleDataPlotters[i]);
	}
}

void CLaubLoomisDictyNetworkEnsembleDirector::DefineRuns()
{
	return;
}

void CLaubLoomisDictyNetworkEnsembleDirector::DefineExperiments()
{	
	return;
}
