// LaubLoomisDictyRunDirector.cpp: implementation of the CLaubLoomisDictyRunDirector class.
//
//////////////////////////////////////////////////////////////////////

#include "LaubLoomisDictyRunDirector.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

CLaubLoomisDictyRunDirector::CLaubLoomisDictyRunDirector()
{
	double maxSimTime = 300.0;
	int intTime = (int) maxSimTime + 2;
	double stepSize = 0.001;
	double frequency = 1.0;
	double moveTol = 1.0e-06;

	int cnt = 0;

	// spontaneous oscillations
	m_vpRxnNetworks.push_back(new CLaubLoomisDictyNetwork());
	m_vpRxnMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	int nChemicals = m_vpRxnNetworks[cnt]->GetNumberOfChemicals();
	m_vpCellObservers.push_back(new CellAverageObserver(nChemicals,intTime,1));
	m_vpRunnables.push_back(new CRunnable());
	m_vpRunnables[cnt]->SetComponents(m_vpRxnNetworks[cnt],m_vpRxnMovers[cnt],m_vpCellObservers[cnt]);
	// create an observer for the runnable
	m_vpGnuPlotters.push_back(new GnuPlotterRunnableObserver());
	m_vpGnuPlotters[cnt]->SetTitle("cAMP Signaling in D. discoideum : Laub and Loomis : Spontaneous Oscillations");
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(0);
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(1);
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(2);
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(3);
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(4);
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(5);
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(6);
	// attach the observer
	m_vpRunnables[cnt]->Attach(m_vpGnuPlotters[cnt]);
	cnt++;

	// external cAMP spike at t=0
	m_vpRxnNetworks.push_back(new CLaubLoomisDictyNetwork());
	m_vpRxnMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	nChemicals = m_vpRxnNetworks[cnt]->GetNumberOfChemicals();
	m_vpCellObservers.push_back(new CellAverageObserver(nChemicals,intTime,1));
	m_vpRunnables.push_back(new CRunnable());
	m_vpRunnables[cnt]->SetComponents(m_vpRxnNetworks[cnt],m_vpRxnMovers[cnt],m_vpCellObservers[cnt]);
	// create an observer for the runnable
	m_vpGnuPlotters.push_back(new GnuPlotterRunnableObserver());
	m_vpGnuPlotters[cnt]->SetTitle("cAMP Signaling in D. discoideum : Laub and Loomis : 20 uM cAMPe Spike");
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(0);
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(1);
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(2);
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(3);
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(4);
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(5);
	m_vpGnuPlotters[cnt]->AddChemicalNumberToList(6);
	// attach the observer
	m_vpRunnables[cnt]->Attach(m_vpGnuPlotters[cnt]);
	cnt++;

	// define runs
	DefineRuns();

}

CLaubLoomisDictyRunDirector::~CLaubLoomisDictyRunDirector()
{


}

void CLaubLoomisDictyRunDirector::DefineRuns()
{
	// set parameters in the runnables to those read from a previous
	// optimization pass; assumes all runnables have same number of 
	// rate constants
	ParameterReader *pReader = new ParameterReader("LLconvert.par");
	int nRC = m_vpRunnables[0]->GetReactionNetwork()->GetNumberOfRateConstants();
	for(int j = 0; j < nRC; j++)
	{
		double rate = pReader->ReadParameter();
		for(int i = 0; i < m_vpRunnables.size(); i++)
		{
			m_vpRunnables[i]->GetReactionNetwork()->GetRateConstant(j)->SetRateConstant(rate);
		}
	}
	delete pReader;

	
	m_vpRunnables[1]->GetReactionNetwork()->GetChemical(5)->SetInitialAmount(20*300000.0);
	m_vpRunnables[1]->GetReactionNetwork()->GetChemical(5)->Reset();

}
