// MartielGoldbeterDictyNetwork.cpp: implementation of the CMartielGoldbeterDictyNetwork class.
//
//////////////////////////////////////////////////////////////////////

#include "MartielGoldbeterDictyNetwork.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

CMartielGoldbeterDictyNetwork::CMartielGoldbeterDictyNetwork()
{
	// #molecules/uM
	double CFactor = 300000;
	double SecPerMin = 60.0;

	// chemical species
	Chemical *R = new Chemical(chemicals.size(),1.0*CFactor,"R");
	chemicals.push_back(R);

	Chemical *D = new Chemical(chemicals.size(),0.0,"D");
	chemicals.push_back(D);

	Chemical *BoundR = new Chemical(chemicals.size(),0.0,"BoundR");
	chemicals.push_back(BoundR);

	Chemical *BoundD = new Chemical(chemicals.size(),0.0,"BoundD");
	chemicals.push_back(BoundD);

	Chemical *E = new Chemical(chemicals.size(),0.0,"E");
	chemicals.push_back(E);

	Chemical *C = new Chemical(chemicals.size(),(1.0/15.0)*CFactor,"C");
	chemicals.push_back(C);

	Chemical *cAMPi = new Chemical(chemicals.size(),0.0,"cAMPi");
	chemicals.push_back(cAMPi);

	Chemical *cAMPe = new Chemical(chemicals.size(),0.0,"cAMPe");
	chemicals.push_back(cAMPe);

	// rate constants
	RateConstant *kp1 = new RateConstant(0.036,"kp1");
	rateConstants.push_back(kp1);

	RateConstant *km1 = new RateConstant(0.36,"km1");
	rateConstants.push_back(km1);

	RateConstant *kp2 = new RateConstant(0.666,"kp2");
	rateConstants.push_back(kp2);

	RateConstant *km2 = new RateConstant(0.00333,"km2");
	rateConstants.push_back(km2);

	RateConstant *a1 = new RateConstant(1.0,"a1");
	rateConstants.push_back(a1);

	RateConstant *d1 = new RateConstant(30000,"d1");
	rateConstants.push_back(d1);

	RateConstant *a2 = new RateConstant(1.0,"a2");
	rateConstants.push_back(a2);

	RateConstant *d2 = new RateConstant(3000,"d2");
	rateConstants.push_back(d2);

	RateConstant *a3 = new RateConstant(1.0,"a3");
	rateConstants.push_back(a3);

	RateConstant *d3 = new RateConstant(30000,"d3");
	rateConstants.push_back(d3);

	RateConstant *k4 = new RateConstant(1.0,"k4");
	rateConstants.push_back(k4);

	RateConstant *k5 = new RateConstant(10.0,"k5");
	rateConstants.push_back(k5);

	RateConstant *ki = new RateConstant(1.7,"ki");
	rateConstants.push_back(ki);

	RateConstant *kt = new RateConstant(0.9,"kt");
	rateConstants.push_back(kt);

	RateConstant *ke = new RateConstant(5.4,"ke");
	rateConstants.push_back(ke);

	// reactions
	Reaction *FreeDesensitization = new TransformationReaction(R,D,kp1,"FreeDesensitization");
	reactions.push_back(FreeDesensitization);

	Reaction *FreeResensitization = new TransformationReaction(D,R,km1,"FreeResensitization");
	reactions.push_back(FreeResensitization);

	Reaction *RBindingcAMP = new HeterodimerizationReaction(R,cAMPe,BoundR,a1,"RBindingcAMP");
	reactions.push_back(RBindingcAMP);

	Reaction *RUnbindingcAMP = new HeterodimerDissociationReaction(BoundR,R,cAMPe,d1,"RUnbindingcAMP");
	reactions.push_back(RUnbindingcAMP);

	Reaction *DBindingcAMP = new HeterodimerizationReaction(D,cAMPe,BoundD,a2,"DBindingcAMP");
	reactions.push_back(DBindingcAMP);

	Reaction *DUnbindingcAMP = new HeterodimerDissociationReaction(BoundD,D,cAMPe,d2,"DUnbindingcAMP");
	reactions.push_back(DUnbindingcAMP);

	Reaction *BoundDesensitization = new TransformationReaction(BoundR,BoundD,kp2,"BoundDesensitization");
	reactions.push_back(BoundDesensitization);

	Reaction *BoundResensitization = new TransformationReaction(BoundD,BoundR,km2,"BoundResensitization");
	reactions.push_back(BoundResensitization);

	Reaction *ComplexFormation = new CTrimerFormation(BoundR,BoundR,C,E,a3,"ComplexFormation");
	reactions.push_back(ComplexFormation);

	Reaction *ComplexDissociation = new CTrimerDissociation(E,BoundR,BoundR,C,d3,"ComplexDissociation");
	reactions.push_back(ComplexDissociation);

	Reaction *ComplexcAMPProduction = new GenerationReaction(E,cAMPi,k4,"ComplexcAMPProduction");
	reactions.push_back(ComplexcAMPProduction);

	Reaction *CyclasecAMPProduction = new GenerationReaction(C,cAMPi,k5,"CyclasecAMPProduction");
	reactions.push_back(CyclasecAMPProduction);

	Reaction *InternalHydrolysis = new UnstableProteinDegradationReaction(cAMPi,ki,"InternalHydrolysis");
	reactions.push_back(InternalHydrolysis);

	Reaction *cAMPTransport = new ChemicalTransportReaction(cAMPi,cAMPe,kt,"cAMPTransport");
	reactions.push_back(cAMPTransport);

	Reaction *ExternalHydrolysis = new UnstableProteinDegradationReaction(cAMPe,ke,"ExternalHydrolysis");
	reactions.push_back(ExternalHydrolysis);
}

CMartielGoldbeterDictyNetwork::~CMartielGoldbeterDictyNetwork()
{

}
