// NormalizedLinearAttenuator.cpp: implementation of the CNormalizedLinearAttenuator class.
//
//////////////////////////////////////////////////////////////////////

#include "NormalizedLinearAttenuator.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

CNormalizedLinearAttenuator::CNormalizedLinearAttenuator(Chemical *InputChemical, Chemical *OutputChemical, RateConstant *k_atten, std::string reactionName)
:Reaction(reactionName)
{
	// stoichiometry
	this->InputChemical = chemicals.size();
	chemicals.push_back(InputChemical);
	numberOfEachChemicalChangedByReaction.push_back(0);

	this->OutputChemical = chemicals.size();
	chemicals.push_back(OutputChemical);
	numberOfEachChemicalChangedByReaction.push_back(-1);

	// rates
	this->k_atten = rateConstants.size();
	rateConstants.push_back(k_atten);

	// put enough dummy chemicalJacobian elements on the vector 
	// - they are recomputed every time you ask for the chemicalJacobian
	chemicalJacobian.push_back(new JElement(-1,-1));

	this->SetTeXForm();
}

CNormalizedLinearAttenuator::~CNormalizedLinearAttenuator()
{
	
}

double CNormalizedLinearAttenuator::GetRate() const
{
	return ((rateConstants[k_atten]->GetValue())/(chemicals[InputChemical]->GetInitialAmount()))*chemicals[InputChemical]->GetAmount();
}

void CNormalizedLinearAttenuator::SetTeXForm()
{
	strstream stream;
	// TeX form of the reaction
	stream << rateConstants[k_atten]->GetTeXName().c_str();
	stream << "{ " << chemicals[InputChemical]->GetTeXName().c_str() << " \\over ";
	stream << chemicals[InputChemical]->GetTeXName().c_str() << "_0 }";
	stream << ends;
	// set the TeX string equal to what's in the stream
	m_sTeXForm = stream.str();
	// allow memory to be freed
	stream.rdbuf()->freeze(0);
}

std::vector<Reaction::JElement *> *CNormalizedLinearAttenuator::GetChemicalJacobian()
{
	chemicalJacobian[0]->SetWithRespectTo(chemicals[InputChemical]->GetChemicalNumber());
	chemicalJacobian[0]->SetJValue((rateConstants[k_atten]->GetValue())/(chemicals[InputChemical]->GetInitialAmount()));
	
	return &chemicalJacobian;
}
