// OneGeneInhibitoryNetworkRunDirector.cpp: implementation of the COneGeneInhibitoryNetworkRunDirector class.
//
//////////////////////////////////////////////////////////////////////

#include "OneGeneInhibitoryNetworkRunDirector.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

COneGeneInhibitoryNetworkRunDirector::COneGeneInhibitoryNetworkRunDirector()
{
	double maxSimTime = 120.0;
	int intTime = (int) maxSimTime + 2;
	double stepSize = 0.001;
	double frequency = 1.0;
	double moveTol = 1.0e-06;

	// unbound promoter, diff eq.
	m_vpRxnNetworks.push_back(new OneGeneInhibitoryNetwork());
	m_vpRxnMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	int nChemicals = m_vpRxnNetworks[0]->GetNumberOfChemicals();
	m_vpCellObservers.push_back(new CellAverageObserver(nChemicals,intTime,1));
	m_vpRunnables.push_back(new CRunnable());
	m_vpRunnables[0]->SetComponents(m_vpRxnNetworks[0],m_vpRxnMovers[0],m_vpCellObservers[0]);
	// create an observer for the runnable
	m_vpGnuPlotters.push_back(new GnuPlotterRunnableObserver());
	m_vpGnuPlotters[0]->AddChemicalNumberToList(2);
	m_vpGnuPlotters[0]->AddChemicalNumberToList(3);
	// attach the observer
	m_vpRunnables[0]->Attach(m_vpGnuPlotters[0]);

	// define runs
	DefineRuns();

}

COneGeneInhibitoryNetworkRunDirector::~COneGeneInhibitoryNetworkRunDirector()
{

}

void COneGeneInhibitoryNetworkRunDirector::DefineRuns()
{
	// set parameters in the runnables to those read from a previous
	// optimization pass; assumes all runnables have same number of 
	// rate constants
	ParameterReader *pReader = new ParameterReader("softExample.par");
	int nRC = m_vpRunnables[0]->GetReactionNetwork()->GetNumberOfRateConstants();
	for(int j = 0; j < nRC; j++)
	{
		double rate = pReader->ReadParameter();
		for(int i = 0; i < m_vpRunnables.size(); i++)
		{
			m_vpRunnables[i]->GetReactionNetwork()->GetRateConstant(j)->SetRateConstant(rate);
		}
	}
	delete pReader;

	// specific to this simulation
	// 1 free promoter
	m_vpRunnables[0]->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(1.0);
	m_vpRunnables[0]->GetReactionNetwork()->GetChemical(0)->Reset();
	m_vpRunnables[0]->GetReactionNetwork()->GetChemical(1)->SetInitialAmount(0.0);
	m_vpRunnables[0]->GetReactionNetwork()->GetChemical(1)->Reset();
	m_vpGnuPlotters[0]->SetTitle("Promoter Binding, ODE");

}