// PC12AlternateEnsembleDirector.cpp: implementation of the CPC12AlternateEnsembleDirector class.
//
//////////////////////////////////////////////////////////////////////

#include "PC12AlternateEnsembleDirector.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

CPC12AlternateEnsembleDirector::CPC12AlternateEnsembleDirector(int ensembleSize)
:CEnsembleCombinationDirector(ensembleSize)
{
	double maxSimTime = 91.0;
	int intTime = (int) (maxSimTime + 2);
	double stepSize = 0.0001;
	double frequency = 1.0;
	double moveTol = 1.0e-6;
	bool rateFlag = true;
	bool chemFlag = false;
	bool logsFlag = false;
	double timeWeight = 1.0;
	double rateWeight = 0.0;
	double chemWeight = 0.0;
	int nCells = 1;

	// expt. 1 - EGF at 100 ng/ml, Traverse 1994 data
	m_vpNetworks.push_back(new CAlternateErkSubnetwork());
	m_vpExperiments.push_back(new Experiment(m_vpNetworks[0],"EGF Stimulation 100 ng/ml - Traverse 1994"));
	// data files
	m_vpExperiments[0]->AddDataFileToList("../DataFiles/TimeSeries/ErkMekTraverse2EGF.dat");
	m_vpExperiments[0]->AddDataFileToList("../DataFiles/TimeSeries/Raf1LandrethEGF.dat");
	//m_vpExperiments[0]->AddDataFileToList("../DataFiles/TimeSeries/PIP2PIP3DownwardEGF.dat");
	m_vpMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	// minimizable
	m_vpMinimizables.push_back(new SingleNetworkMinimizable());
	// parameters
	m_vpMinimizables[0]->Initialize(m_vpExperiments[0],m_vpMovers[0],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	m_vpMinimizables[0]->SetRateConstantsWeight(0.0);
	// attach observer
	//m_vpEnsembleDataPlotters.push_back(new GnuPlotterEnsembleDataDirectorObserver());
	//m_vpEnsembleDataPlotters[0]->SetTitle("MAPK Cascade : EGF at 100 ng/ml, T 94 : ODE");
	//m_vpEnsembleDataPlotters[0]->FixMinimizable(0);
	//this->Attach(m_vpEnsembleDataPlotters[0]);
	
	// expt. 2 - EGF at 100 ng/ml, Yao 1995 data
	m_vpNetworks.push_back(new CAlternateErkSubnetwork());
	m_vpExperiments.push_back(new Experiment(m_vpNetworks[1],"EGF Stimulation 100 ng/ml - Yao 1995"));
	// data files
	m_vpExperiments[1]->AddDataFileToList("../DataFiles/TimeSeries/Erk1HYaoEGF.dat");
	//m_vpExperiments[0]->AddDataFileToList("../DataFiles/TimeSeries/PIP2PIP3DownwardEGF.dat");
	m_vpMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	// minimizable
	m_vpMinimizables.push_back(new SingleNetworkMinimizable());
	// parameters
	m_vpMinimizables[1]->Initialize(m_vpExperiments[1],m_vpMovers[1],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	m_vpMinimizables[1]->SetRateConstantsWeight(0.0);
	// attach observer
	//m_vpEnsembleDataPlotters.push_back(new GnuPlotterEnsembleDataDirectorObserver());
	//m_vpEnsembleDataPlotters[1]->SetTitle("MAPK Cascade : EGF at 100 ng/ml, Yao 95 : ODE");
	//m_vpEnsembleDataPlotters[1]->FixMinimizable(1);
	//this->Attach(m_vpEnsembleDataPlotters[1]);


	// expt. 3 - NGF at 50 ng/ml, Traverse 1994 Data
	// networks and data
	m_vpNetworks.push_back(new CAlternateErkSubnetwork());
	m_vpExperiments.push_back(new Experiment(m_vpNetworks[2],"NGF Stimulation 50 ng/ml - Traverse 1994"));
	// data
	m_vpExperiments[2]->AddDataFileToList("../DataFiles/TimeSeries/ErkMekTraverse2NGF.dat");
	m_vpExperiments[2]->AddDataFileToList("../DataFiles/TimeSeries/RasGreen1NGF.dat");
	m_vpExperiments[2]->AddDataFileToList("../DataFiles/TimeSeries/Rap1YorkNGF.dat");
	//m_vpExperiments[1]->AddDataFileToList("../DataFiles/TimeSeries/PIP2PIP3DownwardNGF.dat");
	m_vpMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	// minimizable
	m_vpMinimizables.push_back(new SingleNetworkMinimizable());
	// parameters
	m_vpMinimizables[2]->Initialize(m_vpExperiments[2],m_vpMovers[2],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	// one scaling factor is fixed
	m_vpMinimizables[2]->GetConversionFactor(11)->SetFactorFixed(true);
	m_vpMinimizables[2]->GetConversionFactor(11)->SetFactorValue(1.0/(0.2*600000*0.1));
	// THESE TWO LINES FOR PI3K-
	m_vpMinimizables[1]->GetConversionFactor(24)->SetFactorFixed(true);
	m_vpMinimizables[1]->GetConversionFactor(24)->SetFactorValue(1.0/(0.2*600000*0.1));
	m_vpMinimizables[2]->SetRateConstantsWeight(0.0);
	// attach observer
	//m_vpEnsembleDataPlotters.push_back(new GnuPlotterEnsembleDataDirectorObserver());
	//m_vpEnsembleDataPlotters[2]->SetTitle("MAPK Cascade : NGF at 50 ng/ml, T 94: ODE");
	//m_vpEnsembleDataPlotters[2]->FixMinimizable(2);
	//this->Attach(m_vpEnsembleDataPlotters[2]);

	// expt. 4 - NGF at 50 ng/ml, Yao 1994 Data
	// networks and data
	m_vpNetworks.push_back(new CAlternateErkSubnetwork());
	m_vpExperiments.push_back(new Experiment(m_vpNetworks[3],"NGF Stimulation 50 ng/ml - Yao 1994"));
	// data
	m_vpExperiments[3]->AddDataFileToList("../DataFiles/TimeSeries/Erk1HYaoNGF.dat");
	//m_vpExperiments[1]->AddDataFileToList("../DataFiles/TimeSeries/PIP2PIP3DownwardNGF.dat");
	m_vpMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	// minimizable
	m_vpMinimizables.push_back(new SingleNetworkMinimizable());
	// parameters
	m_vpMinimizables[3]->Initialize(m_vpExperiments[3],m_vpMovers[3],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	// one scaling factor is fixed
	m_vpMinimizables[3]->GetConversionFactor(11)->SetFactorFixed(true);
	m_vpMinimizables[3]->GetConversionFactor(11)->SetFactorValue(1.0/(0.2*600000*0.1));
	// THESE TWO LINES FOR PI3K-
	m_vpMinimizables[1]->GetConversionFactor(24)->SetFactorFixed(true);
	m_vpMinimizables[1]->GetConversionFactor(24)->SetFactorValue(1.0/(0.2*600000*0.1));
	m_vpMinimizables[3]->SetRateConstantsWeight(0.0);
	// attach observer
	//m_vpEnsembleDataPlotters.push_back(new GnuPlotterEnsembleDataDirectorObserver());
	//m_vpEnsembleDataPlotters[3]->SetTitle("MAPK Cascade : NGF at 50 ng/ml, Yao 95: ODE");
	//m_vpEnsembleDataPlotters[3]->FixMinimizable(3);
	//this->Attach(m_vpEnsembleDataPlotters[3]);

	// expt. 5 - EGF at 30 ng/ml
	// networks and data
	m_vpNetworks.push_back(new CAlternateErkSubnetwork());
	m_vpExperiments.push_back(new Experiment(m_vpNetworks[4],"EGF Stimulation 30 ng/ml"));
	// put data files here
	m_vpExperiments[4]->AddDataFileToList("../DataFiles/TimeSeries/RasGreen1EGF.dat");
	// m_vpExperiments[1]->AddDataFileToList("../DataFiles/TimeSeries/BRafJohnson1EGF.dat");
	// mover and plotter
	m_vpMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	// minimizable
	m_vpMinimizables.push_back(new SingleNetworkMinimizable());
	// parameters
	m_vpMinimizables[4]->Initialize(m_vpExperiments[4],m_vpMovers[4],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	m_vpMinimizables[4]->GetConversionFactor(11)->SetFactorFixed(true);
	m_vpMinimizables[4]->GetConversionFactor(11)->SetFactorValue(1.0/(0.2*600000*0.1));
	m_vpMinimizables[4]->SetRateConstantsWeight(0.0);
	// attach observer
	//m_vpEnsembleDataPlotters.push_back(new GnuPlotterEnsembleDataDirectorObserver());
	//m_vpEnsembleDataPlotters[4]->SetTitle("MAPK Cascade : EGF at 30 ng/ml : ODE");
	//m_vpEnsembleDataPlotters[4]->FixMinimizable(4);
	//this->Attach(m_vpEnsembleDataPlotters[4]);
	
	// expt. 6 - NGF at 100 ng/ml
	// networks and data
	m_vpNetworks.push_back(new CAlternateErkSubnetwork());
	m_vpExperiments.push_back(new Experiment(m_vpNetworks[5],"NGF Stimulation 100 ng/ml"));
	// data
	m_vpExperiments[5]->AddDataFileToList("../DataFiles/TimeSeries/Raf1LandrethNGF.dat");
	m_vpExperiments[5]->AddDataFileToList("../DataFiles/TimeSeries/BRafLandrethNGF.dat");
	// mover and plotter
	m_vpMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	// minimizable
	m_vpMinimizables.push_back(new SingleNetworkMinimizable());
	// parameters
	m_vpMinimizables[5]->Initialize(m_vpExperiments[5],m_vpMovers[5],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	m_vpMinimizables[5]->SetRateConstantsWeight(0.0);
	// attach observer
	//m_vpEnsembleDataPlotters.push_back(new GnuPlotterEnsembleDataDirectorObserver());
	//m_vpEnsembleDataPlotters[5]->SetTitle("MAPK Cascade : NGF at 100 ng/ml : ODE");
	//m_vpEnsembleDataPlotters[5]->FixMinimizable(5);
	//this->Attach(m_vpEnsembleDataPlotters[5]);
	
	// expt. 7 - EGF at 100 ng/ml + 50-fold overexpression of HER
	// networks and data
	m_vpNetworks.push_back(new CAlternateErkSubnetwork());
	m_vpExperiments.push_back(new Experiment(m_vpNetworks[6],"EGF at 100 ng/ml, 50-fold HER Overexpression"));
	// data
	m_vpExperiments[6]->AddDataFileToList("../DataFiles/TimeSeries/ErkMekTraverseHERover.dat");
	m_vpMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	// minimizable
	m_vpMinimizables.push_back(new SingleNetworkMinimizable());
	// parameters
	m_vpMinimizables[6]->Initialize(m_vpExperiments[6],m_vpMovers[6],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	m_vpMinimizables[6]->SetRateConstantsWeight(0.0);
	// attach observer
	//m_vpEnsembleDataPlotters.push_back(new GnuPlotterEnsembleDataDirectorObserver());
	//m_vpEnsembleDataPlotters[6]->SetTitle("MAPK Cascade : EGF at 100 ng/ml, 50-fold HER Overexpression : ODE");
	//m_vpEnsembleDataPlotters[6]->FixMinimizable(6);
	//this->Attach(m_vpEnsembleDataPlotters[6]);

	// runnable 0 - 50 ng/ml NGF + DN Rap1
	m_vpNetworks.push_back(new CAlternateErkSubnetwork());
	m_vpMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	int nChemicals = m_vpNetworks[7]->GetNumberOfChemicals();
	m_vpCellObservers.push_back(new CellAverageObserver(nChemicals,61,1));
	m_vpRunnables.push_back(new CRunnable());
	m_vpRunnables[0]->SetComponents(m_vpNetworks[7],m_vpMovers[7],m_vpCellObservers[0]);
	//m_vpEnsembleRunPlotters.push_back(new GnuPlotterEnsembleRunDirectorObserver());
	//m_vpEnsembleRunPlotters[0]->SetTitle("MAPK Cascade : 50 ng/ml NGF + DN Rap1 : ODE");
	//m_vpEnsembleRunPlotters[0]->FixRunnable(0);
	//m_vpEnsembleRunPlotters[0]->AddChemicalToList(20);
	//this->Attach(m_vpEnsembleRunPlotters[0]);

	// runnable 1 - 50 ng/ml NGF + DN Ras 
	m_vpNetworks.push_back(new CAlternateErkSubnetwork());
	m_vpMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	nChemicals = m_vpNetworks[8]->GetNumberOfChemicals();
	m_vpCellObservers.push_back(new CellAverageObserver(nChemicals,61,1));
	m_vpRunnables.push_back(new CRunnable());
	m_vpRunnables[1]->SetComponents(m_vpNetworks[8],m_vpMovers[8],m_vpCellObservers[1]);
	//m_vpEnsembleRunPlotters.push_back(new GnuPlotterEnsembleRunDirectorObserver());
	//m_vpEnsembleRunPlotters[1]->SetTitle("MAPK Cascade : 50 ng/ml NGF + DN Ras : ODE");
	//m_vpEnsembleRunPlotters[1]->FixRunnable(1);
	//m_vpEnsembleRunPlotters[1]->AddChemicalToList(20);
	//this->Attach(m_vpEnsembleRunPlotters[1]);

	// runnable 2 - 100 ng/ml EGF alone
	m_vpNetworks.push_back(new CAlternateErkSubnetwork());
	m_vpMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	nChemicals = m_vpNetworks[9]->GetNumberOfChemicals();
	m_vpCellObservers.push_back(new CellAverageObserver(nChemicals,121,1));
	m_vpRunnables.push_back(new CRunnable());
	m_vpRunnables[2]->SetComponents(m_vpNetworks[9],m_vpMovers[9],m_vpCellObservers[2]);
	//m_vpEnsembleRunPlotters.push_back(new GnuPlotterEnsembleRunDirectorObserver());
	//m_vpEnsembleRunPlotters[2]->SetTitle("MAPK Cascade : 100 ng/ml EGF : ODE");
	//m_vpEnsembleRunPlotters[2]->FixRunnable(2);
	//m_vpEnsembleRunPlotters[2]->AddChemicalToList(20);
	//this->Attach(m_vpEnsembleRunPlotters[2]);

	// allocate space to accumulate statistics
	SumAllocate();

	// Define runs
	DefineRuns();

	// Define experiments
	DefineExperiments();

	// Load in the ensemble info
	LoadEnsembleInfo("ensemble.par");

}

CPC12AlternateEnsembleDirector::~CPC12AlternateEnsembleDirector()
{
	for(int i = 0; i < m_vpEnsembleRunPlotters.size(); i++)
	{
		this->Detach(m_vpEnsembleRunPlotters[i]);
	}
	for(i = 0; i < m_vpEnsembleDataPlotters.size(); i++)
	{
		this->Detach(m_vpEnsembleDataPlotters[i]);
	}


}

void CPC12AlternateEnsembleDirector::DefineRuns()
{	
	// NGF, 50 ng/ml + DN Rap1
	m_vpRunnables[0]->GetReactionNetwork()->RemoveReaction(18);
	m_vpRunnables[0]->GetReactionNetwork()->GetChemical(1)->SetInitialAmount(228000.0);
	m_vpRunnables[0]->GetReactionNetwork()->GetChemical(1)->Reset();

	// NGF, 50 ng/ml + DN Ras
	m_vpRunnables[1]->GetReactionNetwork()->RemoveReaction(7);
	m_vpRunnables[1]->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(0.0);
	m_vpRunnables[1]->GetReactionNetwork()->GetChemical(0)->Reset();
	m_vpRunnables[1]->GetReactionNetwork()->GetChemical(1)->SetInitialAmount(228000.0);
	m_vpRunnables[1]->GetReactionNetwork()->GetChemical(1)->Reset();

	// EGF, 100 ng/ml
	m_vpRunnables[2]->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(10002000.0);
	m_vpRunnables[2]->GetReactionNetwork()->GetChemical(0)->Reset();
	m_vpRunnables[2]->GetReactionNetwork()->GetChemical(1)->SetInitialAmount(0.0);
	m_vpRunnables[2]->GetReactionNetwork()->GetChemical(1)->Reset();
	
	return;
}

void CPC12AlternateEnsembleDirector::DefineExperiments()
{
	// 100 ng/ml EGF, 0 NGF
	m_vpMinimizables[0]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(10002000.0);
	m_vpMinimizables[0]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->Reset();
	m_vpMinimizables[0]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->SetInitialAmount(0.0);
	m_vpMinimizables[0]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->Reset();	
	
	// 100 ng/ml EGF, 0 NGF
	m_vpMinimizables[1]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(10002000.0);
	m_vpMinimizables[1]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->Reset();
	m_vpMinimizables[1]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->SetInitialAmount(0.0);
	m_vpMinimizables[1]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->Reset();	

	// 0 EGF, 50 ng/ml NGF
	m_vpMinimizables[2]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(0.0);
	m_vpMinimizables[2]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->Reset();
	m_vpMinimizables[2]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->SetInitialAmount(228000.0);
	m_vpMinimizables[2]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->Reset();	

	// 0 EGF, 50 ng/ml NGF
	m_vpMinimizables[3]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(0.0);
	m_vpMinimizables[3]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->Reset();
	m_vpMinimizables[3]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->SetInitialAmount(228000.0);
	m_vpMinimizables[3]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->Reset();	
	
	// 30 ng/ml EGF, 0 NGF
	m_vpMinimizables[4]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(3000600);
	m_vpMinimizables[4]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->Reset();
	m_vpMinimizables[4]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->SetInitialAmount(0.0);
	m_vpMinimizables[4]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->Reset();	
	
	// 0 EGF, 100 ng/ml NGF
	m_vpMinimizables[5]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(0.0);
	m_vpMinimizables[5]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->Reset();
	m_vpMinimizables[5]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->SetInitialAmount(456000.0);
	m_vpMinimizables[5]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->Reset();	
	
	// 100 ng/ml EGF, 0 ng/ml NGF, 50-fold HER overexpression
	m_vpMinimizables[6]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(10002000.0);
	m_vpMinimizables[6]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->Reset();
	m_vpMinimizables[6]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->SetInitialAmount(0.0);
	m_vpMinimizables[6]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->Reset();	
	double EGFR = m_vpMinimizables[6]->GetExperiment()->GetReactionNetwork()->GetChemical(2)->GetInitialAmount();
	m_vpMinimizables[6]->GetExperiment()->GetReactionNetwork()->GetChemical(2)->SetInitialAmount(50*EGFR);
	m_vpMinimizables[6]->GetExperiment()->GetReactionNetwork()->GetChemical(2)->Reset();

}

