// PC12EGFNGFMinimizableDirector.cpp: implementation of the PC12EGFNGFMinimizableDirector class.
//
//////////////////////////////////////////////////////////////////////

#include "PC12EGFNGFMinimizableDirector.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

PC12EGFNGFMinimizableDirector::PC12EGFNGFMinimizableDirector()
{
	// create networks,experiments,observers,movers,minimizables
	double maxSimTime = 91.0;
	double stepSize = 0.0001;
	double frequency = 1.0;
	int nCells = 1;
	double moveTol = 1.0e-06;

	m_dGammaSquared = 1.0e-07;
	
	// flags for all minimizables
	bool rateFlag = true;
	bool chemFlag = false;
	bool logsFlag = false;
	double timeWeight = 1.0;
	double rateWeight = 0.0;
	double chemWeight = 0.0;

	int cnt = 0;

	/*
	// expt. 1 - EGF at 100 ng/ml, Traverse 1994 data
	// networks and data
	_networkList.push_back(new SmallErkSubnetwork());
	_experimentList.push_back(new Experiment(_networkList[0],"EGF Stimulation 100 ng/ml - Traverse 1994"));
	// put data files here
	_experimentList[0]->AddDataFileToList("PerfectEGF100.dat");
	// mover and plotter
	_moverList.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	//_plotterList.push_back(new GnuPlotterTimeSeriesObserver());
	// title
	//_plotterList[0]->SetTitle("Small Erk Subnetwork:EGF Stimulation 100 ng/ml:ODE");
	// minimizable
	_minimizableList.push_back(new SingleNetworkMinimizable());
	// parameters
	_minimizableList[0]->Initialize(_experimentList[0],_moverList[0],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	_minimizableList[0]->SetRateConstantsWeight(0.0);
	// attach observer
	//_minimizableList[0]->Attach(_plotterList[0]);

	
	// expt. 1 - NGF at 50 ng/ml, Traverse 1994 data
	// networks and data
	_networkList.push_back(new SmallErkSubnetwork());
	_experimentList.push_back(new Experiment(_networkList[1],"NGF Stimulation 50 ng/ml"));
	// data
	_experimentList[1]->AddDataFileToList("PerfectNGF50.dat");
	// mover and plotter
	_moverList.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	//_plotterList.push_back(new GnuPlotterTimeSeriesObserver());
	// title
	//_plotterList[1]->SetTitle("Small Erk Subnetwork:NGF Stimulation 50 ng/ml:ODE");
	// minimizable
	_minimizableList.push_back(new SingleNetworkMinimizable());
	// parameters
	_minimizableList[1]->Initialize(_experimentList[1],_moverList[1],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	_minimizableList[1]->SetRateConstantsWeight(0.0);
	// attach observer
	//_minimizableList[1]->Attach(_plotterList[1]);
	*/
	/*
	// expt. 1 - EGF at 100 ng/ml, Traverse 1994 data
	// networks and data
	_networkList.push_back(new SmallErkSubnetwork());
	_experimentList.push_back(new Experiment(_networkList[0],"EGF Stimulation 100 ng/ml - Traverse 1994"));
	// put data files here
	_experimentList[0]->AddDataFileToList("MockExpEGF100.dat");
	// mover and plotter
	_moverList.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	_plotterList.push_back(new GnuPlotterTimeSeriesObserver());
	// title
	_plotterList[0]->SetTitle("Small Erk Subnetwork:EGF Stimulation 100 ng/ml:ODE");
	// minimizable
	_minimizableList.push_back(new SingleNetworkMinimizable());
	// parameters
	_minimizableList[0]->Initialize(_experimentList[0],_moverList[0],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	_minimizableList[0]->SetRateConstantsWeight(0.0);
	// attach observer
	_minimizableList[0]->Attach(_plotterList[0]);

	
	// expt. 1 - NGF at 50 ng/ml, Traverse 1994 data
	// networks and data
	_networkList.push_back(new SmallErkSubnetwork());
	_experimentList.push_back(new Experiment(_networkList[1],"NGF Stimulation 50 ng/ml"));
	// data
	_experimentList[1]->AddDataFileToList("MockExpNGF50.dat");
	// mover and plotter
	_moverList.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	_plotterList.push_back(new GnuPlotterTimeSeriesObserver());
	// title
	_plotterList[1]->SetTitle("Small Erk Subnetwork:NGF Stimulation 50 ng/ml:ODE");
	// minimizable
	_minimizableList.push_back(new SingleNetworkMinimizable());
	// parameters
	_minimizableList[1]->Initialize(_experimentList[1],_moverList[1],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	_minimizableList[1]->SetRateConstantsWeight(0.0);
	// attach observer
	_minimizableList[1]->Attach(_plotterList[1]);
	
	// expt. 3 - EGF at 30 ng/ml
	// networks and data
	_networkList.push_back(new SmallErkSubnetwork());
	_experimentList.push_back(new Experiment(_networkList[2],"EGF Stimulation 30 ng/ml"));
	// put data files here
	_experimentList[2]->AddDataFileToList("MockExpEGF30.dat");
	// mover and plotter
	_moverList.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	_plotterList.push_back(new GnuPlotterTimeSeriesObserver());
	// title
	_plotterList[2]->SetTitle("Small Erk Subnetwork:EGF Stimulation 30 ng/ml:ODE");
	// minimizable
	_minimizableList.push_back(new SingleNetworkMinimizable());
	// parameters
	_minimizableList[2]->Initialize(_experimentList[2],_moverList[2],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	_minimizableList[2]->SetRateConstantsWeight(0.0);
	// attach observer
	_minimizableList[2]->Attach(_plotterList[2]);
	
	// expt. 4 - NGF at 100 ng/ml
	// networks and data
	_networkList.push_back(new SmallErkSubnetwork());
	_experimentList.push_back(new Experiment(_networkList[3],"NGF Stimulation 100 ng/ml"));
	// data
	_experimentList[3]->AddDataFileToList("MockExpNGF100.dat");
	// mover and plotter
	_moverList.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	_plotterList.push_back(new GnuPlotterTimeSeriesObserver());
	// title
	_plotterList[3]->SetTitle("Small Erk Subnetwork:NGF Stimulation 100 ng/ml:ODE");
	// minimizable
	_minimizableList.push_back(new SingleNetworkMinimizable());
	// parameters
	_minimizableList[3]->Initialize(_experimentList[3],_moverList[3],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	_minimizableList[3]->SetRateConstantsWeight(0.0);
	// attach observer
	_minimizableList[3]->Attach(_plotterList[3]);
	
	// expt. 5 - EGF at 100 ng/ml + 50-fold overexpression of HER
	// networks and data
	_networkList.push_back(new SmallErkSubnetwork());
	_experimentList.push_back(new Experiment(_networkList[4],"EGF at 100 ng/ml, 50-fold HER Overexpression"));
	// data
	_experimentList[4]->AddDataFileToList("MockExpEGF100HEROver.dat");
	_moverList.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	_plotterList.push_back(new GnuPlotterTimeSeriesObserver());
	// title
	_plotterList[4]->SetTitle("Small Erk Subnetwork:EGF Stimulation 100 ng/ml + 50-fold HER:ODE");
	// minimizable
	_minimizableList.push_back(new SingleNetworkMinimizable());
	// parameters
	_minimizableList[4]->Initialize(_experimentList[4],_moverList[4],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	_minimizableList[4]->SetRateConstantsWeight(0.0);
	// attach observer
	_minimizableList[4]->Attach(_plotterList[4]);
	*/
	
	// expt. 1 - EGF at 100 ng/ml, Traverse 1994 data
	// networks and data
	_networkList.push_back(new SmallErkSubnetwork());
	_experimentList.push_back(new Experiment(_networkList[cnt],"EGF Stimulation 100 ng/ml - Traverse 1994"));
	// put data files here
	_experimentList[cnt]->AddDataFileToList("../DataFiles/TimeSeries/ErkMekTraverse2EGF.dat");
	_experimentList[cnt]->AddDataFileToList("../DataFiles/TimeSeries/Raf1LandrethEGF.dat");
	//_experimentList[0]->AddDataFileToList("../DataFiles/TimeSeries/PIP2PIP3DownwardEGF.dat");
	// mover and plotter
	_moverList.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	// minimizable
	_minimizableList.push_back(new SingleNetworkMinimizable());
	// parameters
	_minimizableList[cnt]->Initialize(_experimentList[cnt],_moverList[cnt],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	_minimizableList[cnt]->SetRateConstantsWeight(0.0);
	// attach observer
	//_plotterList.push_back(new GnuPlotterTimeSeriesObserver());
	//_plotterList[0]->SetTitle("Small Erk Subnetwork:EGF Stimulation (100 ng/ml, T 1994):ODE");
	//_minimizableList[0]->Attach(_plotterList[0]);
	cnt++;
	
	// expt. 2 - EGF at 100 ng/ml, Yao 1995 data
	// networks and data
	_networkList.push_back(new SmallErkSubnetwork());
	_experimentList.push_back(new Experiment(_networkList[cnt],"EGF Stimulation 100 ng/ml - Yao 1995"));
	// put data files here
	_experimentList[cnt]->AddDataFileToList("../DataFiles/TimeSeries/Erk1HYaoEGF.dat");
	// mover and plotter
	_moverList.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	// minimizable
	_minimizableList.push_back(new SingleNetworkMinimizable());
	// parameters
	_minimizableList[cnt]->Initialize(_experimentList[cnt],_moverList[cnt],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	_minimizableList[cnt]->SetRateConstantsWeight(0.0);
	// attach observer
	//_plotterList.push_back(new GnuPlotterTimeSeriesObserver());
	//_plotterList[1]->SetTitle("Small Erk Subnetwork:EGF Stimulation (100 ng/ml, Y 1995):ODE");
	//_minimizableList[1]->Attach(_plotterList[1]);
	cnt++;
	
	// expt. 3 - NGF at 50 ng/ml, Traverse 1994 data
	// networks and data
	_networkList.push_back(new SmallErkSubnetwork());
	_experimentList.push_back(new Experiment(_networkList[cnt],"NGF Stimulation 50 ng/ml - T 1994"));
	// data
	_experimentList[cnt]->AddDataFileToList("../DataFiles/TimeSeries/ErkMekTraverse2NGF.dat");
	_experimentList[cnt]->AddDataFileToList("../DataFiles/TimeSeries/RasGreen1NGF.dat");
	_experimentList[cnt]->AddDataFileToList("../DataFiles/TimeSeries/Rap1YorkNGF.dat");
	//_experimentList[1]->AddDataFileToList("../DataFiles/TimeSeries/PIP2PIP3DownwardNGF.dat");
	// mover and plotter
	_moverList.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	// minimizable
	_minimizableList.push_back(new SingleNetworkMinimizable());
	// parameters
	_minimizableList[cnt]->Initialize(_experimentList[cnt],_moverList[cnt],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	// one scaling factor is fixed
	_minimizableList[cnt]->GetConversionFactor(11)->SetFactorFixed(true);
	_minimizableList[cnt]->GetConversionFactor(11)->SetFactorValue(1.0/(0.2*600000*0.1));
	// THESE TWO LINES FOR PI3K+
	_minimizableList[cnt]->GetConversionFactor(28)->SetFactorFixed(true);
	_minimizableList[cnt]->GetConversionFactor(28)->SetFactorValue(1.0/(0.2*600000*0.1));
	_minimizableList[cnt]->SetRateConstantsWeight(0.0);
	// attach observer
	//_plotterList.push_back(new GnuPlotterTimeSeriesObserver());
	//_plotterList[2]->SetTitle("Small Erk Subnetwork:NGF Stimulation (50 ng/ml, T 1994):ODE");
	//_minimizableList[2]->Attach(_plotterList[2]);
	cnt++;
	
	// expt. 4 - NGF at 50 ng/ml, Yao 1995 data
	// networks and data
	_networkList.push_back(new SmallErkSubnetwork());
	_experimentList.push_back(new Experiment(_networkList[cnt],"NGF Stimulation 50 ng/ml - Yao 1995"));
	// data
	_experimentList[cnt]->AddDataFileToList("../DataFiles/TimeSeries/Erk1HYaoNGF.dat");
	//_experimentList[1]->AddDataFileToList("../DataFiles/TimeSeries/PIP2PIP3DownwardNGF.dat");
	// mover and plotter
	_moverList.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	// minimizable
	_minimizableList.push_back(new SingleNetworkMinimizable());
	// parameters
	_minimizableList[cnt]->Initialize(_experimentList[cnt],_moverList[cnt],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	// one scaling factor is fixed
	_minimizableList[cnt]->GetConversionFactor(11)->SetFactorFixed(true);
	_minimizableList[cnt]->GetConversionFactor(11)->SetFactorValue(1.0/(0.2*600000*0.1));
	// THESE TWO LINES FOR PI3K+
	_minimizableList[cnt]->GetConversionFactor(28)->SetFactorFixed(true);
	_minimizableList[cnt]->GetConversionFactor(28)->SetFactorValue(1.0/(0.2*600000*0.1));
	_minimizableList[cnt]->SetRateConstantsWeight(0.0);
	// attach observer
	//_plotterList.push_back(new GnuPlotterTimeSeriesObserver());
	//_plotterList[3]->SetTitle("Small Erk Subnetwork:NGF Stimulation (50 ng/ml, Y 1995):ODE");
	//_minimizableList[3]->Attach(_plotterList[3]);
	cnt++;
	
	// expt. 3 - EGF at 30 ng/ml
	// networks and data
	_networkList.push_back(new SmallErkSubnetwork());
	_experimentList.push_back(new Experiment(_networkList[cnt],"EGF Stimulation 30 ng/ml"));
	// put data files here
	_experimentList[cnt]->AddDataFileToList("../DataFiles/TimeSeries/RasGreen1EGF.dat");
	// _experimentList[1]->AddDataFileToList("../DataFiles/TimeSeries/BRafJohnson1EGF.dat");
	// mover and plotter
	_moverList.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	// minimizable
	_minimizableList.push_back(new SingleNetworkMinimizable());
	// parameters
	_minimizableList[cnt]->Initialize(_experimentList[cnt],_moverList[cnt],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	_minimizableList[cnt]->GetConversionFactor(11)->SetFactorFixed(true);
	_minimizableList[cnt]->GetConversionFactor(11)->SetFactorValue(1.0/(0.2*600000*0.1));
	_minimizableList[cnt]->SetRateConstantsWeight(0.0);
	// attach observer
	//_plotterList.push_back(new GnuPlotterTimeSeriesObserver());
	//_plotterList[4]->SetTitle("Small Erk Subnetwork:EGF Stimulation (30 ng/ml):ODE");
	//_minimizableList[4]->Attach(_plotterList[4]);
	cnt++;
	
	// expt. 4 - NGF at 100 ng/ml
	// networks and data
	_networkList.push_back(new SmallErkSubnetwork());
	_experimentList.push_back(new Experiment(_networkList[cnt],"NGF Stimulation 100 ng/ml"));
	// data
	_experimentList[cnt]->AddDataFileToList("../DataFiles/TimeSeries/Raf1LandrethNGF.dat");
	_experimentList[cnt]->AddDataFileToList("../DataFiles/TimeSeries/BRafLandrethNGF.dat");
	// mover and plotter
	_moverList.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	// minimizable
	_minimizableList.push_back(new SingleNetworkMinimizable());
	// parameters
	_minimizableList[cnt]->Initialize(_experimentList[cnt],_moverList[cnt],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	// one scaling factor is fixed
	_minimizableList[cnt]->SetRateConstantsWeight(0.0);
	// attach observer
	//_plotterList.push_back(new GnuPlotterTimeSeriesObserver());
	//_plotterList[5]->SetTitle("Small Erk Subnetwork:NGF Stimulation (100 ng/ml):ODE");
	//_minimizableList[5]->Attach(_plotterList[5]);
	cnt++;
	
	// expt. 5 - EGF at 100 ng/ml + 50-fold overexpression of HER
	// networks and data
	_networkList.push_back(new SmallErkSubnetwork());
	_experimentList.push_back(new Experiment(_networkList[cnt],"EGF at 100 ng/ml, 50-fold HER Overexpression"));
	// data
	_experimentList[cnt]->AddDataFileToList("../DataFiles/TimeSeries/ErkMekTraverseHERover.dat");
	_moverList.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	// minimizable
	_minimizableList.push_back(new SingleNetworkMinimizable());
	// parameters
	_minimizableList[cnt]->Initialize(_experimentList[cnt],_moverList[cnt],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	_minimizableList[cnt]->SetRateConstantsWeight(0.0);
	cnt++;

	/*
	// FOR SLOPPY EVOLUTION
	// Erk in response to EGF, Yao 1995 data
	// networks and data
	_networkList.push_back(new SmallErkSubnetwork());
	_experimentList.push_back(new Experiment(_networkList[cnt],"EGF Stimulation 100 ng/ml"));
	// put data files here
	_experimentList[cnt]->AddDataFileToList("../DataFiles/TimeSeries/Erk1HYaoEGF.dat");
	// mover and plotter
	_moverList.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	// minimizable
	_minimizableList.push_back(new SingleNetworkMinimizable());
	// parameters
	_minimizableList[cnt]->Initialize(_experimentList[cnt],_moverList[cnt],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	_minimizableList[cnt]->SetRateConstantsWeight(0.0);
	// plotting
	_plotterList.push_back(new GnuPlotterTimeSeriesObserver());
	// title
	_plotterList[cnt]->SetTitle("Small Erk Subnetwork:EGF Stimulation (100 ng/ml):ODE");
	// attach observer
	_minimizableList[cnt]->Attach(_plotterList[cnt]);
	cnt++;
	
	// Erk and Ras (mutable) in response to NGF, Yao 1995 data and based on Green
	// networks and data
	_networkList.push_back(new SmallErkSubnetwork());
	_experimentList.push_back(new Experiment(_networkList[cnt],"NGF Stimulation 50 ng/ml"));
	// data
	_experimentList[cnt]->AddDataFileToList("../DataFiles/TimeSeries/Erk1HYaoNGF.dat");
	_experimentList[cnt]->AddDataFileToList("MutableRas.dat");
	// mover and plotter
	_moverList.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	// minimizable
	_minimizableList.push_back(new SingleNetworkMinimizable());
	// parameters
	_minimizableList[cnt]->Initialize(_experimentList[cnt],_moverList[cnt],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	// one scaling factor is fixed
	_minimizableList[cnt]->GetConversionFactor(11)->SetFactorFixed(true);
	_minimizableList[cnt]->GetConversionFactor(11)->SetFactorValue(1.0/(0.2*600000*0.1));
	// THESE TWO LINES FOR PI3K+
	_minimizableList[cnt]->GetConversionFactor(28)->SetFactorFixed(true);
	_minimizableList[cnt]->GetConversionFactor(28)->SetFactorValue(1.0/(0.2*600000*0.1));
	_minimizableList[cnt]->SetRateConstantsWeight(0.0);
	// plotting
	_plotterList.push_back(new GnuPlotterTimeSeriesObserver());
	// title
	_plotterList[cnt]->SetTitle("Small Erk Subnetwork:NGF Stimulation (50 ng/ml):ODE");
	// attach observer
	_minimizableList[cnt]->Attach(_plotterList[cnt]);
	// attach observer
	cnt++;
	
	// Ras in response to EGF, Green's data
	// networks and data
	_networkList.push_back(new SmallErkSubnetwork());
	_experimentList.push_back(new Experiment(_networkList[cnt],"EGF Stimulation 30 ng/ml"));
	// put data files here
	_experimentList[cnt]->AddDataFileToList("../DataFiles/TimeSeries/RasGreen1EGF.dat");
	// mover and plotter
	_moverList.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	// minimizable
	_minimizableList.push_back(new SingleNetworkMinimizable());
	// parameters
	_minimizableList[cnt]->Initialize(_experimentList[cnt],_moverList[cnt],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	_minimizableList[cnt]->GetConversionFactor(11)->SetFactorFixed(true);
	_minimizableList[cnt]->GetConversionFactor(11)->SetFactorValue(1.0/(0.2*600000*0.1));
	_minimizableList[cnt]->SetRateConstantsWeight(0.0);
	// plotting
	_plotterList.push_back(new GnuPlotterTimeSeriesObserver());
	// title
	_plotterList[cnt]->SetTitle("Small Erk Subnetwork:EGF Stimulation (30 ng/ml):ODE");
	// attach observer
	_minimizableList[cnt]->Attach(_plotterList[cnt]);
	// attach observer
	cnt++;
	*/
	// allocate the master residuals list
	int masterResidualsSize = 0;
	for(int i = 0; i < _minimizableList.size(); i++)
	{
		int subRes = _minimizableList[i]->GetNResiduals();
		masterResidualsSize += subRes;
		cout << subRes << " residuals in minimizable " << i << endl;
	}
	if(m_dGammaSquared > 0.0)
	{
		masterResidualsSize += 1;
	}
	Allocate(masterResidualsSize);

	cout << "Master Residuals size : " << masterResidualsSize << endl;

	// define the experiments
	DefineExperiments();

	// dump info about residuals
	DumpResidualInfo();
}

PC12EGFNGFMinimizableDirector::~PC12EGFNGFMinimizableDirector()
{
	for(int i = 0; i < _minimizableList.size(); i++)
	{
		if(_plotterList.size() > i)
		{
			_minimizableList[i]->Detach(_plotterList[i]);
		}
	}
	for(i = 0; i < _plotterList.size(); i++)
	{
		delete _plotterList[i];
	}
}

void PC12EGFNGFMinimizableDirector::DefineExperiments()
{
	/*
	// 100 ng/ml EGF, 0 NGF
	_minimizableList[0]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(10002000.0);
	_minimizableList[0]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->Reset();
	_minimizableList[0]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->SetInitialAmount(0.0);
	_minimizableList[0]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->Reset();
	
	// 0 EGF, 50 ng/ml NGF
	_minimizableList[1]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(0.0);
	_minimizableList[1]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->Reset();
	_minimizableList[1]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->SetInitialAmount(228000.0);
	_minimizableList[1]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->Reset();	
	*/
	/*
	// 100 ng/ml EGF, 0 NGF
	_minimizableList[0]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(10002000.0);
	_minimizableList[0]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->Reset();
	_minimizableList[0]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->SetInitialAmount(0.0);
	_minimizableList[0]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->Reset();
	
	// 0 EGF, 50 ng/ml NGF
	_minimizableList[1]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(0.0);
	_minimizableList[1]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->Reset();
	_minimizableList[1]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->SetInitialAmount(228000.0);
	_minimizableList[1]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->Reset();	
	
	// 30 ng/ml EGF, 0 NGF
	_minimizableList[2]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(3000600);
	_minimizableList[2]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->Reset();
	_minimizableList[2]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->SetInitialAmount(0.0);
	_minimizableList[2]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->Reset();	
	
	// 0 EGF, 100 ng/ml NGF
	_minimizableList[3]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(0.0);
	_minimizableList[3]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->Reset();
	_minimizableList[3]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->SetInitialAmount(456000.0);
	_minimizableList[3]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->Reset();
	
	// 100 ng/ml EGF, 0 ng/ml NGF, 50-fold HER overexpression
	_minimizableList[4]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(10002000.0);
	_minimizableList[4]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->Reset();
	_minimizableList[4]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->SetInitialAmount(0.0);
	_minimizableList[4]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->Reset();	
	double EGFR = _minimizableList[4]->GetExperiment()->GetReactionNetwork()->GetChemical(2)->GetInitialAmount();
	_minimizableList[4]->GetExperiment()->GetReactionNetwork()->GetChemical(2)->SetInitialAmount(50*EGFR);
	_minimizableList[4]->GetExperiment()->GetReactionNetwork()->GetChemical(2)->Reset();	
	*/	
	
	// 100 ng/ml EGF, 0 NGF
	_minimizableList[0]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(10002000.0);
	_minimizableList[0]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->Reset();
	_minimizableList[0]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->SetInitialAmount(0.0);
	_minimizableList[0]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->Reset();	
	
	// 0 EGF, 50 ng/ml NGF
	_minimizableList[2]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(0.0);
	_minimizableList[2]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->Reset();
	_minimizableList[2]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->SetInitialAmount(228000.0);
	_minimizableList[2]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->Reset();	
	
	// 0 EGF, 50 ng/ml NGF
	_minimizableList[1]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(0.0);
	_minimizableList[1]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->Reset();
	_minimizableList[1]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->SetInitialAmount(228000.0);
	_minimizableList[1]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->Reset();	
	
	// 30 ng/ml EGF, 0 NGF
	_minimizableList[4]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(3000600);
	_minimizableList[4]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->Reset();
	_minimizableList[4]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->SetInitialAmount(0.0);
	_minimizableList[4]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->Reset();	
	
	// 0 EGF, 100 ng/ml NGF
	_minimizableList[5]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(0.0);
	_minimizableList[5]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->Reset();
	_minimizableList[5]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->SetInitialAmount(456000.0);
	_minimizableList[5]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->Reset();
	
	// 100 ng/ml EGF, 0 ng/ml NGF, 50-fold HER overexpression
	_minimizableList[6]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(10002000.0);
	_minimizableList[6]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->Reset();
	_minimizableList[6]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->SetInitialAmount(0.0);
	_minimizableList[6]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->Reset();	
	double EGFR = _minimizableList[6]->GetExperiment()->GetReactionNetwork()->GetChemical(2)->GetInitialAmount();
	_minimizableList[6]->GetExperiment()->GetReactionNetwork()->GetChemical(2)->SetInitialAmount(50*EGFR);
	_minimizableList[6]->GetExperiment()->GetReactionNetwork()->GetChemical(2)->Reset();
	
	/*
	// SLOPPY EVOLUTION PIECE
	// 100 ng/ml EGF, 0 NGF
	_minimizableList[0]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(10002000.0);
	_minimizableList[0]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->Reset();
	_minimizableList[0]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->SetInitialAmount(0.0);
	_minimizableList[0]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->Reset();	

	// 0 EGF, 50 ng/ml NGF
	_minimizableList[1]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(0.0);
	_minimizableList[1]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->Reset();
	_minimizableList[1]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->SetInitialAmount(228000.0);
	_minimizableList[1]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->Reset();	

	// 30 ng/ml EGF, 0 NGF
	_minimizableList[2]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(3000600);
	_minimizableList[2]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->Reset();
	_minimizableList[2]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->SetInitialAmount(0.0);
	_minimizableList[2]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->Reset();	
	*/
}

double PC12EGFNGFMinimizableDirector::GetParameter(int parIndex)
{
	// for this director, everyone has the same parameters so any set 
	// can be returned
	return _minimizableList[0]->GetParameter(parIndex);
}

int PC12EGFNGFMinimizableDirector::GetNParameters()
{
	// ditto as for GetParameters()
	return _minimizableList[0]->GetNParameters();
}
