// PC12EGFNGFRunDirector.cpp: implementation of the CPC12EGFNGFRunDirector class.
//
//////////////////////////////////////////////////////////////////////

#include "PC12EGFNGFRunDirector.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

CPC12EGFNGFRunDirector::CPC12EGFNGFRunDirector()
{
	double maxSimTime = 90.0;
	int intTime = (int) maxSimTime + 2;
	double stepSize = 0.001;
	double frequency = 1.0;
	double moveTol = 1.0e-06;

	// 100 ng/ml EGF
	m_vpRxnNetworks.push_back(new SmallErkSubnetwork());
	m_vpRxnMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	int nChemicals = m_vpRxnNetworks[0]->GetNumberOfChemicals();
	m_vpCellObservers.push_back(new CellAverageObserver(nChemicals,intTime,1));
	m_vpRunnables.push_back(new CRunnable());
	m_vpRunnables[0]->SetComponents(m_vpRxnNetworks[0],m_vpRxnMovers[0],m_vpCellObservers[0]);
	// create an observer for the runnable
	m_vpGnuPlotters.push_back(new GnuPlotterRunnableObserver());
	m_vpGnuPlotters[0]->AddChemicalNumberToList(3);
	m_vpGnuPlotters[0]->AddChemicalNumberToList(7);
	m_vpGnuPlotters[0]->AddChemicalNumberToList(9);
	m_vpGnuPlotters[0]->AddChemicalNumberToList(11);
	m_vpGnuPlotters[0]->AddChemicalNumberToList(14);
	m_vpGnuPlotters[0]->AddChemicalNumberToList(18);
	m_vpGnuPlotters[0]->AddChemicalNumberToList(20);
	// attach the observer
	m_vpRunnables[0]->Attach(m_vpGnuPlotters[0]);
	
	// 50 ng/ml NGF
	m_vpRxnNetworks.push_back(new SmallErkSubnetwork());
	m_vpRxnMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	nChemicals = m_vpRxnNetworks[1]->GetNumberOfChemicals();
	m_vpCellObservers.push_back(new CellAverageObserver(nChemicals,intTime,1));
	m_vpRunnables.push_back(new CRunnable());
	m_vpRunnables[1]->SetComponents(m_vpRxnNetworks[1],m_vpRxnMovers[1],m_vpCellObservers[1]);
	// create an observer for the runnable
	m_vpGnuPlotters.push_back(new GnuPlotterRunnableObserver());
	m_vpGnuPlotters[1]->AddChemicalNumberToList(5);
	m_vpGnuPlotters[1]->AddChemicalNumberToList(7);
	m_vpGnuPlotters[1]->AddChemicalNumberToList(9);
	m_vpGnuPlotters[1]->AddChemicalNumberToList(11);
	m_vpGnuPlotters[1]->AddChemicalNumberToList(14);
	m_vpGnuPlotters[1]->AddChemicalNumberToList(16);
	m_vpGnuPlotters[1]->AddChemicalNumberToList(18);
	m_vpGnuPlotters[1]->AddChemicalNumberToList(20);
	m_vpGnuPlotters[1]->AddChemicalNumberToList(26);
	m_vpGnuPlotters[1]->AddChemicalNumberToList(28);
	// attach the observer
	m_vpRunnables[1]->Attach(m_vpGnuPlotters[1]);
	/*
	// 100 ng/ml EGF
	m_vpRxnNetworks.push_back(new SmallErkSubnetwork());
	m_vpRxnMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	int nChemicals = m_vpRxnNetworks[0]->GetNumberOfChemicals();
	m_vpCellObservers.push_back(new CellAverageObserver(nChemicals,intTime,1));
	m_vpRunnables.push_back(new CRunnable());
	m_vpRunnables[0]->SetComponents(m_vpRxnNetworks[0],m_vpRxnMovers[0],m_vpCellObservers[0]);
	// create an observer for the runnable
	m_vpGnuPlotters.push_back(new GnuPlotterRunnableObserver());
	m_vpGnuPlotters[0]->AddChemicalNumberToList(14);
	m_vpGnuPlotters[0]->AddChemicalNumberToList(18);
	m_vpGnuPlotters[0]->AddChemicalNumberToList(20);
	// attach the observer
	m_vpRunnables[0]->Attach(m_vpGnuPlotters[0]);
	
	// 50 ng/ml NGF
	m_vpRxnNetworks.push_back(new SmallErkSubnetwork());
	m_vpRxnMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	nChemicals = m_vpRxnNetworks[1]->GetNumberOfChemicals();
	m_vpCellObservers.push_back(new CellAverageObserver(nChemicals,intTime,1));
	m_vpRunnables.push_back(new CRunnable());
	m_vpRunnables[1]->SetComponents(m_vpRxnNetworks[1],m_vpRxnMovers[1],m_vpCellObservers[1]);
	// create an observer for the runnable
	m_vpGnuPlotters.push_back(new GnuPlotterRunnableObserver());
	m_vpGnuPlotters[1]->AddChemicalNumberToList(11);
	m_vpGnuPlotters[1]->AddChemicalNumberToList(18);
	m_vpGnuPlotters[1]->AddChemicalNumberToList(20);
	m_vpGnuPlotters[1]->AddChemicalNumberToList(28);
	// attach the observer
	m_vpRunnables[1]->Attach(m_vpGnuPlotters[1]);

	// 30 ng/ml EGF
	m_vpRxnNetworks.push_back(new SmallErkSubnetwork());
	m_vpRxnMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	nChemicals = m_vpRxnNetworks[2]->GetNumberOfChemicals();
	m_vpCellObservers.push_back(new CellAverageObserver(nChemicals,intTime,1));
	m_vpRunnables.push_back(new CRunnable());
	m_vpRunnables[2]->SetComponents(m_vpRxnNetworks[2],m_vpRxnMovers[2],m_vpCellObservers[2]);
	// create an observer for the runnable
	m_vpGnuPlotters.push_back(new GnuPlotterRunnableObserver());
	m_vpGnuPlotters[2]->AddChemicalNumberToList(11);
	// attach the observer
	m_vpRunnables[2]->Attach(m_vpGnuPlotters[2]);
	
	// 100 ng/ml NGF
	m_vpRxnNetworks.push_back(new SmallErkSubnetwork());
	m_vpRxnMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	nChemicals = m_vpRxnNetworks[3]->GetNumberOfChemicals();
	m_vpCellObservers.push_back(new CellAverageObserver(nChemicals,intTime,1));
	m_vpRunnables.push_back(new CRunnable());
	m_vpRunnables[3]->SetComponents(m_vpRxnNetworks[3],m_vpRxnMovers[3],m_vpCellObservers[3]);
	// create an observer for the runnable
	m_vpGnuPlotters.push_back(new GnuPlotterRunnableObserver());
	m_vpGnuPlotters[3]->AddChemicalNumberToList(14);
	m_vpGnuPlotters[3]->AddChemicalNumberToList(16);
	// attach the observer
	m_vpRunnables[3]->Attach(m_vpGnuPlotters[3]);

	// 100 ng/ml EGF + 50-fold HER overexpression
	m_vpRxnNetworks.push_back(new SmallErkSubnetwork());
	m_vpRxnMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	nChemicals = m_vpRxnNetworks[4]->GetNumberOfChemicals();
	m_vpCellObservers.push_back(new CellAverageObserver(nChemicals,intTime,1));
	m_vpRunnables.push_back(new CRunnable());
	m_vpRunnables[4]->SetComponents(m_vpRxnNetworks[4],m_vpRxnMovers[4],m_vpCellObservers[4]);
	// create an observer for the runnable
	m_vpGnuPlotters.push_back(new GnuPlotterRunnableObserver());
	m_vpGnuPlotters[4]->AddChemicalNumberToList(18);
	m_vpGnuPlotters[4]->AddChemicalNumberToList(20);
	// attach the observer
	m_vpRunnables[4]->Attach(m_vpGnuPlotters[4]);
	*/
	/*
	// 100 ng/ml EGF
	m_vpRxnNetworks.push_back(new SmallErkSubnetwork());
	m_vpRxnMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	int nChemicals = m_vpRxnNetworks[0]->GetNumberOfChemicals();
	m_vpCellObservers.push_back(new CellAverageObserver(nChemicals,intTime,1));
	m_vpRunnables.push_back(new CRunnable());
	m_vpRunnables[0]->SetComponents(m_vpRxnNetworks[0],m_vpRxnMovers[0],m_vpCellObservers[0]);
	// create an observer for the runnable
	m_vpGnuPlotters.push_back(new GnuPlotterRunnableObserver());
	//m_vpGnuPlotters[0]->AddChemicalNumberToList(11);
	m_vpGnuPlotters[0]->AddChemicalNumberToList(20);
	// attach the observer
	m_vpRunnables[0]->Attach(m_vpGnuPlotters[0]);

	// 50 ng/ml NGF
	m_vpRxnNetworks.push_back(new SmallErkSubnetwork());
	m_vpRxnMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	nChemicals = m_vpRxnNetworks[1]->GetNumberOfChemicals();
	m_vpCellObservers.push_back(new CellAverageObserver(nChemicals,intTime,1));
	m_vpRunnables.push_back(new CRunnable());
	m_vpRunnables[1]->SetComponents(m_vpRxnNetworks[1],m_vpRxnMovers[1],m_vpCellObservers[1]);
	// create an observer for the runnable
	m_vpGnuPlotters.push_back(new GnuPlotterRunnableObserver());
	//m_vpGnuPlotters[0]->AddChemicalNumberToList(11);
	m_vpGnuPlotters[1]->AddChemicalNumberToList(20);
	// attach the observer
	m_vpRunnables[1]->Attach(m_vpGnuPlotters[1]);

	// 100 ng/ml EGF + 10 uM LY
	m_vpRxnNetworks.push_back(new SmallErkSubnetwork());
	m_vpRxnMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	nChemicals = m_vpRxnNetworks[2]->GetNumberOfChemicals();
	m_vpCellObservers.push_back(new CellAverageObserver(nChemicals,intTime,1));
	m_vpRunnables.push_back(new CRunnable());
	m_vpRunnables[2]->SetComponents(m_vpRxnNetworks[2],m_vpRxnMovers[2],m_vpCellObservers[2]);
	// create an observer for the runnable
	m_vpGnuPlotters.push_back(new GnuPlotterRunnableObserver());
	//m_vpGnuPlotters[0]->AddChemicalNumberToList(11);
	m_vpGnuPlotters[2]->AddChemicalNumberToList(20);
	m_vpGnuPlotters[2]->AddChemicalNumberToList(22);
	m_vpGnuPlotters[2]->AddChemicalNumberToList(24);
	// attach the observer
	m_vpRunnables[2]->Attach(m_vpGnuPlotters[2]);

	// 50 ng/ml NGF + DN Rap1
	m_vpRxnNetworks.push_back(new SmallErkSubnetwork());
	m_vpRxnMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	nChemicals = m_vpRxnNetworks[3]->GetNumberOfChemicals();
	m_vpCellObservers.push_back(new CellAverageObserver(nChemicals,intTime,1));
	m_vpRunnables.push_back(new CRunnable());
	m_vpRunnables[3]->SetComponents(m_vpRxnNetworks[3],m_vpRxnMovers[3],m_vpCellObservers[3]);
	// create an observer for the runnable
	m_vpGnuPlotters.push_back(new GnuPlotterRunnableObserver());
	m_vpGnuPlotters[3]->AddChemicalNumberToList(20);
	// NEXT LINE FOR PI3K+ 
	m_vpGnuPlotters[3]->AddChemicalNumberToList(26);
	m_vpGnuPlotters[3]->AddChemicalNumberToList(28);
	// NEXT LINE FOR PI3K-
	//m_vpGnuPlotters[3]->AddChemicalNumberToList(24);
	// attach the observer
	m_vpRunnables[3]->Attach(m_vpGnuPlotters[3]);

	// 100 ng/ml EGF + 50-fold HER overexpression
	m_vpRxnNetworks.push_back(new SmallErkSubnetwork());
	m_vpRxnMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	nChemicals = m_vpRxnNetworks[4]->GetNumberOfChemicals();
	m_vpCellObservers.push_back(new CellAverageObserver(nChemicals,intTime,1));
	m_vpRunnables.push_back(new CRunnable());
	m_vpRunnables[4]->SetComponents(m_vpRxnNetworks[4],m_vpRxnMovers[4],m_vpCellObservers[4]);
	// create an observer for the runnable
	m_vpGnuPlotters.push_back(new GnuPlotterRunnableObserver());
	//m_vpGnuPlotters[0]->AddChemicalNumberToList(11);
	m_vpGnuPlotters[4]->AddChemicalNumberToList(20);
	// attach the observer
	m_vpRunnables[4]->Attach(m_vpGnuPlotters[4]);

	// 50 ng/ml NGF + DN Ras
	m_vpRxnNetworks.push_back(new SmallErkSubnetwork());
	m_vpRxnMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	nChemicals = m_vpRxnNetworks[5]->GetNumberOfChemicals();
	m_vpCellObservers.push_back(new CellAverageObserver(nChemicals,intTime,1));
	m_vpRunnables.push_back(new CRunnable());
	m_vpRunnables[5]->SetComponents(m_vpRxnNetworks[5],m_vpRxnMovers[5],m_vpCellObservers[5]);
	// create an observer for the runnable
	m_vpGnuPlotters.push_back(new GnuPlotterRunnableObserver());
	m_vpGnuPlotters[5]->AddChemicalNumberToList(7);
	m_vpGnuPlotters[5]->AddChemicalNumberToList(11);
	m_vpGnuPlotters[5]->AddChemicalNumberToList(20);
	// attach the observer
	m_vpRunnables[5]->Attach(m_vpGnuPlotters[5]);
	*/
	// define runs
	DefineRuns();

}

CPC12EGFNGFRunDirector::~CPC12EGFNGFRunDirector()
{

}

void CPC12EGFNGFRunDirector::DefineRuns()
{
	// set parameters in the runnables to those read from a previous
	// optimization pass; assumes all runnables have same number of 
	// rate constants
	ParameterReader *pReader = new ParameterReader("min5_wFinal.par");
	int nRC = m_vpRunnables[0]->GetReactionNetwork()->GetNumberOfRateConstants();
	for(int j = 0; j < nRC; j++)
	{
		double rate = pReader->ReadParameter();
		for(int i = 0; i < m_vpRunnables.size(); i++)
		{
			m_vpRunnables[i]->GetReactionNetwork()->GetRateConstant(j)->SetRateConstant(rate);
		}
	}
	delete pReader;

	// EGF, 100 ng/ml
	m_vpRunnables[0]->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(10002000.0);
	m_vpRunnables[0]->GetReactionNetwork()->GetChemical(0)->Reset();
	m_vpGnuPlotters[0]->SetTitle("100 ng/ml EGF");

	// NGF, 50 ng/ml
	m_vpRunnables[1]->GetReactionNetwork()->GetChemical(1)->SetInitialAmount(228000.0);
	m_vpRunnables[1]->GetReactionNetwork()->GetChemical(1)->Reset();
	m_vpGnuPlotters[1]->SetTitle("50 ng/ml NGF");

	/*
	// specific to this simulation
	// EGF, 100 ng/ml
	m_vpRunnables[0]->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(10002000.0);
	m_vpRunnables[0]->GetReactionNetwork()->GetChemical(0)->Reset();
	m_vpGnuPlotters[0]->SetTitle("100 ng/ml EGF");

	// NGF, 50 ng/ml
	m_vpRunnables[1]->GetReactionNetwork()->GetChemical(1)->SetInitialAmount(228000.0);
	m_vpRunnables[1]->GetReactionNetwork()->GetChemical(1)->Reset();
	m_vpGnuPlotters[1]->SetTitle("50 ng/ml NGF");
	
	// EGF, 30 ng/ml
	m_vpRunnables[2]->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(0.3*10002000.0);
	m_vpRunnables[2]->GetReactionNetwork()->GetChemical(0)->Reset();
	m_vpGnuPlotters[2]->SetTitle("30 ng/ml EGF");
	
	// NGF, 100 ng/ml
	m_vpRunnables[3]->GetReactionNetwork()->GetChemical(1)->SetInitialAmount(2*228000.0);
	m_vpRunnables[3]->GetReactionNetwork()->GetChemical(1)->Reset();
	m_vpGnuPlotters[3]->SetTitle("50 ng/ml NGF");
	
	// 100 ng/ml EGF + 50-fold EGFR Overexpression
	m_vpRunnables[4]->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(10002000.0);
	m_vpRunnables[4]->GetReactionNetwork()->GetChemical(0)->Reset();
	m_vpRunnables[4]->GetReactionNetwork()->GetChemical(2)->SetInitialAmount(50*80000.0);
	m_vpRunnables[4]->GetReactionNetwork()->GetChemical(2)->Reset();
	m_vpGnuPlotters[4]->SetTitle("100 ng/ml EGF + 50-Fold EGFR Overexpression");
	*/
	/*
	// EGF, 100 ng/ml
	m_vpRunnables[0]->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(10002000.0);
	m_vpRunnables[0]->GetReactionNetwork()->GetChemical(0)->Reset();
	m_vpGnuPlotters[0]->SetTitle("100 ng/ml EGF");

	// NGF, 50 ng/ml
	m_vpRunnables[1]->GetReactionNetwork()->GetChemical(1)->SetInitialAmount(228000.0);
	m_vpRunnables[1]->GetReactionNetwork()->GetChemical(1)->Reset();
	m_vpGnuPlotters[1]->SetTitle("50 ng/ml NGF");

	// EGF, 100 ng/ml + LY
	// PI3K can't be activated
	// Next two lines for PI3K+ 
	m_vpRunnables[2]->GetReactionNetwork()->RemoveReaction(17);
	m_vpRunnables[2]->GetReactionNetwork()->RemoveReaction(18);
	m_vpRunnables[2]->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(10002000.0);
	m_vpRunnables[2]->GetReactionNetwork()->GetChemical(0)->Reset();
	m_vpGnuPlotters[2]->SetTitle("100 ng/ml EGF + LY");

	// NGF, 50 ng/ml + DN Rap1
	// Next two lines for PI3K+ 
	m_vpRunnables[3]->GetReactionNetwork()->RemoveReaction(22);
	m_vpRunnables[3]->GetReactionNetwork()->GetChemical(1)->SetInitialAmount(228000.0);
	m_vpRunnables[3]->GetReactionNetwork()->GetChemical(1)->Reset();
	m_vpGnuPlotters[3]->SetTitle("50 ng/ml NGF + DN Rap1");

	// 100 ng/ml EGF + 50-fold EGFR Overexpression
	m_vpRunnables[4]->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(10002000.0);
	m_vpRunnables[4]->GetReactionNetwork()->GetChemical(0)->Reset();
	m_vpRunnables[4]->GetReactionNetwork()->GetChemical(2)->SetInitialAmount(50*80000.0);
	m_vpRunnables[4]->GetReactionNetwork()->GetChemical(2)->Reset();
	m_vpGnuPlotters[4]->SetTitle("100 ng/ml EGF + 50-Fold EGFR Overexpression");

	// NGF, 50 ng/ml + DN Ras
	// Next two lines for PI3K+
	m_vpRunnables[5]->GetReactionNetwork()->RemoveReaction(7);
	m_vpRunnables[5]->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(0.0);
	m_vpRunnables[5]->GetReactionNetwork()->GetChemical(0)->Reset();
	m_vpRunnables[5]->GetReactionNetwork()->GetChemical(1)->SetInitialAmount(228000.0);
	m_vpRunnables[5]->GetReactionNetwork()->GetChemical(1)->Reset();
	m_vpGnuPlotters[5]->SetTitle("50 ng/ml NGF + DN Ras");
	*/
}
