#include "pc12rapminusensembledirector.h"

CPC12RapMinusEnsembleDirector::CPC12RapMinusEnsembleDirector(int ensembleSize)
:CEnsembleCombinationDirector(ensembleSize)
{
double maxSimTime = 91.0;
	int intTime = (int) (maxSimTime + 2);
	double stepSize = 0.0001;
	double frequency = 1.0;
	double moveTol = 1.0e-6;
	bool rateFlag = true;
	bool chemFlag = false;
	bool logsFlag = false;
	double timeWeight = 1.0;
	double rateWeight = 0.0;
	double chemWeight = 0.0;
	int nCells = 1;

	int cnt = 0;

	// expt. 1 - EGF at 100 ng/ml, Traverse 1994 data
	m_vpNetworks.push_back(new CPC12RapMinusNetwork());
	m_vpExperiments.push_back(new Experiment(m_vpNetworks[cnt],"EGF Stimulation 100 ng/ml - Traverse 1994"));
	// data files
	m_vpExperiments[cnt]->AddDataFileToList("../DataFiles/TimeSeries/ErkMekTraverse2EGF.dat");
	m_vpExperiments[cnt]->AddDataFileToList("../DataFiles/TimeSeries/Raf1LandrethEGF.dat");
	//m_vpExperiments[0]->AddDataFileToList("../DataFiles/TimeSeries/PIP2PIP3DownwardEGF.dat");
	m_vpMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	// minimizable
	m_vpMinimizables.push_back(new SingleNetworkMinimizable());
	// parameters
	m_vpMinimizables[cnt]->Initialize(m_vpExperiments[cnt],m_vpMovers[cnt],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	m_vpMinimizables[cnt]->SetRateConstantsWeight(0.0);
	// attach observer
	//m_vpEnsembleDataPlotters.push_back(new GnuPlotterEnsembleDataDirectorObserver());
	//m_vpEnsembleDataPlotters[0]->SetTitle("MAPK Cascade : EGF at 100 ng/ml, T 94 : ODE");
	//m_vpEnsembleDataPlotters[0]->FixMinimizable(0);
	//this->Attach(m_vpEnsembleDataPlotters[0]);
	cnt++;
	
	// expt. 2 - EGF at 100 ng/ml, Yao 1995 data
	m_vpNetworks.push_back(new CPC12RapMinusNetwork());
	m_vpExperiments.push_back(new Experiment(m_vpNetworks[cnt],"EGF Stimulation 100 ng/ml - Yao 1995"));
	// data files
	m_vpExperiments[cnt]->AddDataFileToList("../DataFiles/TimeSeries/Erk1HYaoEGF.dat");
	m_vpMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	// minimizable
	m_vpMinimizables.push_back(new SingleNetworkMinimizable());
	// parameters
	m_vpMinimizables[cnt]->Initialize(m_vpExperiments[cnt],m_vpMovers[cnt],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	m_vpMinimizables[cnt]->SetRateConstantsWeight(0.0);
	// attach observer
	//m_vpEnsembleDataPlotters.push_back(new GnuPlotterEnsembleDataDirectorObserver());
	//m_vpEnsembleDataPlotters[1]->SetTitle("MAPK Cascade : EGF at 100 ng/ml, Yao 95 : ODE");
	//m_vpEnsembleDataPlotters[1]->FixMinimizable(1);
	//this->Attach(m_vpEnsembleDataPlotters[1]);
	cnt++;


	// expt. 3 - NGF at 50 ng/ml, Traverse 1994 Data
	// networks and data
	m_vpNetworks.push_back(new CPC12RapMinusNetwork());
	m_vpExperiments.push_back(new Experiment(m_vpNetworks[cnt],"NGF Stimulation 50 ng/ml - Traverse 1994"));
	// data
	m_vpExperiments[cnt]->AddDataFileToList("../DataFiles/TimeSeries/ErkMekTraverse2NGF.dat");
	m_vpExperiments[cnt]->AddDataFileToList("../DataFiles/TimeSeries/RasGreen1NGF.dat");
	m_vpMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	// minimizable
	m_vpMinimizables.push_back(new SingleNetworkMinimizable());
	// parameters
	m_vpMinimizables[cnt]->Initialize(m_vpExperiments[cnt],m_vpMovers[cnt],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	// one scaling factor is fixed
	m_vpMinimizables[cnt]->GetConversionFactor(11)->SetFactorFixed(true);
	m_vpMinimizables[cnt]->GetConversionFactor(11)->SetFactorValue(1.0/(0.2*600000*0.1));
	// THESE TWO LINES FOR PI3K+
	m_vpMinimizables[cnt]->SetRateConstantsWeight(0.0);
	// attach observer
	//m_vpEnsembleDataPlotters.push_back(new GnuPlotterEnsembleDataDirectorObserver());
	//m_vpEnsembleDataPlotters[2]->SetTitle("MAPK Cascade : NGF at 50 ng/ml, T 94: ODE");
	//m_vpEnsembleDataPlotters[2]->FixMinimizable(2);
	//this->Attach(m_vpEnsembleDataPlotters[2]);
	cnt++;

	// expt. 4 - NGF at 50 ng/ml, Yao 1994 Data
	// networks and data
	m_vpNetworks.push_back(new CPC12RapMinusNetwork());
	m_vpExperiments.push_back(new Experiment(m_vpNetworks[cnt],"NGF Stimulation 50 ng/ml - Yao 1994"));
	// data
	m_vpExperiments[cnt]->AddDataFileToList("../DataFiles/TimeSeries/Erk1HYaoNGF.dat");
	m_vpMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	// minimizable
	m_vpMinimizables.push_back(new SingleNetworkMinimizable());
	// parameters
	m_vpMinimizables[cnt]->Initialize(m_vpExperiments[cnt],m_vpMovers[cnt],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	// one scaling factor is fixed
	m_vpMinimizables[cnt]->GetConversionFactor(11)->SetFactorFixed(true);
	m_vpMinimizables[cnt]->GetConversionFactor(11)->SetFactorValue(1.0/(0.2*600000*0.1));
	m_vpMinimizables[cnt]->SetRateConstantsWeight(0.0);
	// attach observer
	//m_vpEnsembleDataPlotters.push_back(new GnuPlotterEnsembleDataDirectorObserver());
	//m_vpEnsembleDataPlotters[3]->SetTitle("MAPK Cascade : NGF at 50 ng/ml, Yao 95: ODE");
	//m_vpEnsembleDataPlotters[3]->FixMinimizable(3);
	//this->Attach(m_vpEnsembleDataPlotters[3]);
	cnt++;

	// expt. 5 - EGF at 30 ng/ml
	// networks and data
	m_vpNetworks.push_back(new CPC12RapMinusNetwork());
	m_vpExperiments.push_back(new Experiment(m_vpNetworks[cnt],"EGF Stimulation 30 ng/ml"));
	// put data files here
	m_vpExperiments[cnt]->AddDataFileToList("../DataFiles/TimeSeries/RasGreen1EGF.dat");
	// mover and plotter
	m_vpMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	// minimizable
	m_vpMinimizables.push_back(new SingleNetworkMinimizable());
	// parameters
	m_vpMinimizables[cnt]->Initialize(m_vpExperiments[cnt],m_vpMovers[cnt],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	m_vpMinimizables[cnt]->GetConversionFactor(11)->SetFactorFixed(true);
	m_vpMinimizables[cnt]->GetConversionFactor(11)->SetFactorValue(1.0/(0.2*600000*0.1));
	m_vpMinimizables[cnt]->SetRateConstantsWeight(0.0);
	// attach observer
	//m_vpEnsembleDataPlotters.push_back(new GnuPlotterEnsembleDataDirectorObserver());
	//m_vpEnsembleDataPlotters[4]->SetTitle("MAPK Cascade : EGF at 30 ng/ml : ODE");
	//m_vpEnsembleDataPlotters[4]->FixMinimizable(4);
	//this->Attach(m_vpEnsembleDataPlotters[4]);
	cnt++;
	
	// expt. 6 - NGF at 100 ng/ml
	// networks and data
	m_vpNetworks.push_back(new CPC12RapMinusNetwork());
	m_vpExperiments.push_back(new Experiment(m_vpNetworks[cnt],"NGF Stimulation 100 ng/ml"));
	// data
	m_vpExperiments[cnt]->AddDataFileToList("../DataFiles/TimeSeries/Raf1LandrethNGF.dat");
	// mover and plotter
	m_vpMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	// minimizable
	m_vpMinimizables.push_back(new SingleNetworkMinimizable());
	// parameters
	m_vpMinimizables[cnt]->Initialize(m_vpExperiments[cnt],m_vpMovers[cnt],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	m_vpMinimizables[cnt]->SetRateConstantsWeight(0.0);
	// attach observer
	//m_vpEnsembleDataPlotters.push_back(new GnuPlotterEnsembleDataDirectorObserver());
	//m_vpEnsembleDataPlotters[5]->SetTitle("MAPK Cascade : NGF at 100 ng/ml : ODE");
	//m_vpEnsembleDataPlotters[5]->FixMinimizable(5);
	//this->Attach(m_vpEnsembleDataPlotters[5]);
	cnt++;
	
	// expt. 7 - EGF at 100 ng/ml + 50-fold overexpression of HER
	// networks and data
	m_vpNetworks.push_back(new CPC12RapMinusNetwork());
	m_vpExperiments.push_back(new Experiment(m_vpNetworks[cnt],"EGF at 100 ng/ml, 50-fold HER Overexpression"));
	// data
	m_vpExperiments[cnt]->AddDataFileToList("../DataFiles/TimeSeries/ErkMekTraverseHERover.dat");
	m_vpMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	// minimizable
	m_vpMinimizables.push_back(new SingleNetworkMinimizable());
	// parameters
	m_vpMinimizables[cnt]->Initialize(m_vpExperiments[cnt],m_vpMovers[cnt],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	m_vpMinimizables[cnt]->SetRateConstantsWeight(0.0);
	// attach observer
	//m_vpEnsembleDataPlotters.push_back(new GnuPlotterEnsembleDataDirectorObserver());
	//m_vpEnsembleDataPlotters[6]->SetTitle("MAPK Cascade : EGF at 100 ng/ml, 50-fold HER Overexpression : ODE");
	//m_vpEnsembleDataPlotters[6]->FixMinimizable(6);
	//this->Attach(m_vpEnsembleDataPlotters[6]);
	cnt++;
	
	// runnable 1 - 100 ng/ml EGF + 10 uM LY
	m_vpNetworks.push_back(new CPC12RapMinusNetwork());
	m_vpMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	int nChemicals = m_vpNetworks[7]->GetNumberOfChemicals();
	m_vpCellObservers.push_back(new CellAverageObserver(nChemicals,121,1));
	m_vpRunnables.push_back(new CRunnable());
	m_vpRunnables[0]->SetComponents(m_vpNetworks[7],m_vpMovers[7],m_vpCellObservers[0]);
	//m_vpEnsembleRunPlotters.push_back(new GnuPlotterEnsembleRunDirectorObserver());
	//m_vpEnsembleRunPlotters[0]->SetTitle("MAPK Cascade : 100 ng/ml EGF + LY : ODE");
	//m_vpEnsembleRunPlotters[0]->FixRunnable(0);
	//m_vpEnsembleRunPlotters[0]->AddChemicalToList(20);
	//this->Attach(m_vpEnsembleRunPlotters[0]);

	// runnable 2 - 50 ng/ml NGF + 10 uM LY
	m_vpNetworks.push_back(new CPC12RapMinusNetwork());
	m_vpMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	nChemicals = m_vpNetworks[8]->GetNumberOfChemicals();
	m_vpCellObservers.push_back(new CellAverageObserver(nChemicals,121,1));
	m_vpRunnables.push_back(new CRunnable());
	m_vpRunnables[1]->SetComponents(m_vpNetworks[8],m_vpMovers[8],m_vpCellObservers[1]);
	//m_vpEnsembleRunPlotters.push_back(new GnuPlotterEnsembleRunDirectorObserver());
	//m_vpEnsembleRunPlotters[1]->SetTitle("MAPK Cascade : 50 ng/ml NGF + LY : ODE");
	//m_vpEnsembleRunPlotters[1]->FixRunnable(1);
	//m_vpEnsembleRunPlotters[1]->AddChemicalToList(20);
	//this->Attach(m_vpEnsembleRunPlotters[1]);

	// runnable 4 - 50 ng/ml NGF + DN Ras 
	m_vpNetworks.push_back(new CPC12RapMinusNetwork());
	m_vpMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	nChemicals = m_vpNetworks[9]->GetNumberOfChemicals();
	m_vpCellObservers.push_back(new CellAverageObserver(nChemicals,61,1));
	m_vpRunnables.push_back(new CRunnable());
	m_vpRunnables[2]->SetComponents(m_vpNetworks[9],m_vpMovers[9],m_vpCellObservers[2]);
	//m_vpEnsembleRunPlotters.push_back(new GnuPlotterEnsembleRunDirectorObserver());
	//m_vpEnsembleRunPlotters[3]->SetTitle("MAPK Cascade : 50 ng/ml NGF + DN Ras : ODE");
	//m_vpEnsembleRunPlotters[3]->FixRunnable(3);
	//m_vpEnsembleRunPlotters[3]->AddChemicalToList(20);
	//this->Attach(m_vpEnsembleRunPlotters[3]);

	// runnable 5 - 100 ng/ml EGF alone
	m_vpNetworks.push_back(new CPC12RapMinusNetwork());
	m_vpMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	nChemicals = m_vpNetworks[10]->GetNumberOfChemicals();
	m_vpCellObservers.push_back(new CellAverageObserver(nChemicals,121,1));
	m_vpRunnables.push_back(new CRunnable());
	m_vpRunnables[3]->SetComponents(m_vpNetworks[10],m_vpMovers[10],m_vpCellObservers[3]);
	//m_vpEnsembleRunPlotters.push_back(new GnuPlotterEnsembleRunDirectorObserver());
	//m_vpEnsembleRunPlotters[4]->SetTitle("MAPK Cascade : 100 ng/ml EGF : ODE");
	//m_vpEnsembleRunPlotters[4]->FixRunnable(4);
	//m_vpEnsembleRunPlotters[4]->AddChemicalToList(20);
	//this->Attach(m_vpEnsembleRunPlotters[4]);

	// allocate space to accumulate statistics
	SumAllocate();

	// Define runs
	DefineRuns();

	// Define experiments
	DefineExperiments();

	// Load in the ensemble info
	LoadEnsembleInfo("ensemble.par");
}

CPC12RapMinusEnsembleDirector::~CPC12RapMinusEnsembleDirector(void)
{
	for(int i = 0; i < m_vpEnsembleRunPlotters.size(); i++)
	{
		this->Detach(m_vpEnsembleRunPlotters[i]);
	}
	for(i = 0; i < m_vpEnsembleDataPlotters.size(); i++)
	{
		this->Detach(m_vpEnsembleDataPlotters[i]);
	}
}

void CPC12RapMinusEnsembleDirector::DefineRuns()
{
	// EGF, 100 ng/ml + LY
	m_vpRunnables[0]->GetReactionNetwork()->RemoveReaction(16);
	m_vpRunnables[0]->GetReactionNetwork()->RemoveReaction(17);
	m_vpRunnables[0]->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(10002000.0);
	m_vpRunnables[0]->GetReactionNetwork()->GetChemical(0)->Reset();
	
	// NGF, 50 ng/ml + LY
	m_vpRunnables[1]->GetReactionNetwork()->RemoveReaction(16);
	m_vpRunnables[1]->GetReactionNetwork()->RemoveReaction(17);
	m_vpRunnables[1]->GetReactionNetwork()->GetChemical(1)->SetInitialAmount(228000.0);
	m_vpRunnables[1]->GetReactionNetwork()->GetChemical(1)->Reset();

	// NGF, 50 ng/ml + DN Ras
	m_vpRunnables[2]->GetReactionNetwork()->RemoveReaction(7);
	m_vpRunnables[2]->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(0.0);
	m_vpRunnables[2]->GetReactionNetwork()->GetChemical(0)->Reset();
	m_vpRunnables[2]->GetReactionNetwork()->GetChemical(1)->SetInitialAmount(228000.0);
	m_vpRunnables[2]->GetReactionNetwork()->GetChemical(1)->Reset();

	// EGF, 100 ng/ml
	m_vpRunnables[3]->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(10002000.0);
	m_vpRunnables[3]->GetReactionNetwork()->GetChemical(0)->Reset();
	m_vpRunnables[3]->GetReactionNetwork()->GetChemical(1)->SetInitialAmount(0.0);
	m_vpRunnables[3]->GetReactionNetwork()->GetChemical(1)->Reset();
	
	return;
}

void CPC12RapMinusEnsembleDirector::DefineExperiments()
{	
	// 100 ng/ml EGF, 0 NGF
	m_vpMinimizables[0]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(10002000.0);
	m_vpMinimizables[0]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->Reset();
	m_vpMinimizables[0]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->SetInitialAmount(0.0);
	m_vpMinimizables[0]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->Reset();	
	
	// 100 ng/ml EGF, 0 NGF
	m_vpMinimizables[1]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(10002000.0);
	m_vpMinimizables[1]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->Reset();
	m_vpMinimizables[1]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->SetInitialAmount(0.0);
	m_vpMinimizables[1]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->Reset();	

	// 0 EGF, 50 ng/ml NGF
	m_vpMinimizables[2]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(0.0);
	m_vpMinimizables[2]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->Reset();
	m_vpMinimizables[2]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->SetInitialAmount(228000.0);
	m_vpMinimizables[2]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->Reset();	

	// 0 EGF, 50 ng/ml NGF
	m_vpMinimizables[3]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(0.0);
	m_vpMinimizables[3]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->Reset();
	m_vpMinimizables[3]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->SetInitialAmount(228000.0);
	m_vpMinimizables[3]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->Reset();	
	
	// 30 ng/ml EGF, 0 NGF
	m_vpMinimizables[4]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(3000600);
	m_vpMinimizables[4]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->Reset();
	m_vpMinimizables[4]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->SetInitialAmount(0.0);
	m_vpMinimizables[4]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->Reset();	
	
	// 0 EGF, 100 ng/ml NGF
	m_vpMinimizables[5]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(0.0);
	m_vpMinimizables[5]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->Reset();
	m_vpMinimizables[5]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->SetInitialAmount(456000.0);
	m_vpMinimizables[5]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->Reset();	
	
	// 100 ng/ml EGF, 0 ng/ml NGF, 50-fold HER overexpression
	m_vpMinimizables[6]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(10002000.0);
	m_vpMinimizables[6]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->Reset();
	m_vpMinimizables[6]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->SetInitialAmount(0.0);
	m_vpMinimizables[6]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->Reset();	
	double EGFR = m_vpMinimizables[6]->GetExperiment()->GetReactionNetwork()->GetChemical(2)->GetInitialAmount();
	m_vpMinimizables[6]->GetExperiment()->GetReactionNetwork()->GetChemical(2)->SetInitialAmount(50*EGFR);
	m_vpMinimizables[6]->GetExperiment()->GetReactionNetwork()->GetChemical(2)->Reset();
	
}
