#include "PC12RapMinusMinimizableDirector.h"

CPC12RapMinusMinimizableDirector::CPC12RapMinusMinimizableDirector(void)
{
	// create networks,experiments,observers,movers,minimizables
	double maxSimTime = 91.0;
	double stepSize = 0.0001;
	double frequency = 1.0;
	int nCells = 1;
	double moveTol = 1.0e-06;

	m_dGammaSquared = 0.0;
	
	// flags for all minimizables
	bool rateFlag = true;
	bool chemFlag = false;
	bool logsFlag = false;
	double timeWeight = 1.0;
	double rateWeight = 0.0;
	double chemWeight = 0.0;
	
	int cnt = 0;

	// expt. 1 - EGF at 100 ng/ml, Traverse 1994 data
	// networks and data
	_networkList.push_back(new CPC12RapMinusNetwork());
	_experimentList.push_back(new Experiment(_networkList[cnt],"EGF Stimulation 100 ng/ml - Traverse 1994"));
	// put data files here
	_experimentList[cnt]->AddDataFileToList("../DataFiles/TimeSeries/ErkMekTraverse2EGF.dat");
	_experimentList[cnt]->AddDataFileToList("../DataFiles/TimeSeries/Raf1LandrethEGF.dat");
	// mover and plotter
	_moverList.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	// minimizable
	_minimizableList.push_back(new SingleNetworkMinimizable());
	// parameters
	_minimizableList[cnt]->Initialize(_experimentList[cnt],_moverList[cnt],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	_minimizableList[cnt]->SetRateConstantsWeight(0.0);
	// attach observer
	_plotterList.push_back(new GnuPlotterTimeSeriesObserver());
	_plotterList[cnt]->SetTitle("Rap1 Minus Network:EGF Stimulation (100 ng/ml, T 1994):ODE");
	_minimizableList[cnt]->Attach(_plotterList[cnt]);
	cnt++;

	// expt. 2 - EGF at 100 ng/ml, Yao 1995 data
	// networks and data
	_networkList.push_back(new CPC12RapMinusNetwork());
	_experimentList.push_back(new Experiment(_networkList[cnt],"EGF Stimulation 100 ng/ml - Yao 1995"));
	// put data files here
	_experimentList[cnt]->AddDataFileToList("../DataFiles/TimeSeries/Erk1HYaoEGF.dat");
	// mover and plotter
	_moverList.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	// minimizable
	_minimizableList.push_back(new SingleNetworkMinimizable());
	// parameters
	_minimizableList[cnt]->Initialize(_experimentList[cnt],_moverList[cnt],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	_minimizableList[cnt]->SetRateConstantsWeight(0.0);
	// attach observer
	_plotterList.push_back(new GnuPlotterTimeSeriesObserver());
	_plotterList[cnt]->SetTitle("Rap1 Minus Network:EGF Stimulation (100 ng/ml, Y 1995):ODE");
	_minimizableList[cnt]->Attach(_plotterList[cnt]);
	cnt++;

	// expt. 3 - NGF at 50 ng/ml, Traverse 1994 data
	// networks and data
	_networkList.push_back(new CPC12RapMinusNetwork());
	_experimentList.push_back(new Experiment(_networkList[cnt],"NGF Stimulation 50 ng/ml - T 1994"));
	// data
	_experimentList[cnt]->AddDataFileToList("../DataFiles/TimeSeries/ErkMekTraverse2NGF.dat");
	_experimentList[cnt]->AddDataFileToList("../DataFiles/TimeSeries/RasGreen1NGF.dat");
	// mover and plotter
	_moverList.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	// minimizable
	_minimizableList.push_back(new SingleNetworkMinimizable());
	// parameters
	_minimizableList[cnt]->Initialize(_experimentList[cnt],_moverList[cnt],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	// one scaling factor is fixed
	_minimizableList[cnt]->GetConversionFactor(11)->SetFactorFixed(true);
	_minimizableList[cnt]->GetConversionFactor(11)->SetFactorValue(1.0/(0.2*600000*0.1));
	_minimizableList[cnt]->SetRateConstantsWeight(0.0);
	// attach observer
	_plotterList.push_back(new GnuPlotterTimeSeriesObserver());
	_plotterList[cnt]->SetTitle("Rap1 Minus Network:NGF Stimulation (50 ng/ml, T 1994):ODE");
	_minimizableList[cnt]->Attach(_plotterList[cnt]);
	cnt++;
	
	// expt. 4 - NGF at 50 ng/ml, Yao 1995 data
	// networks and data
	_networkList.push_back(new CPC12RapMinusNetwork());
	_experimentList.push_back(new Experiment(_networkList[cnt],"NGF Stimulation 50 ng/ml - Yao 1995"));
	// data
	_experimentList[cnt]->AddDataFileToList("../DataFiles/TimeSeries/Erk1HYaoNGF.dat");
	_moverList.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	// minimizable
	_minimizableList.push_back(new SingleNetworkMinimizable());
	// parameters
	_minimizableList[cnt]->Initialize(_experimentList[cnt],_moverList[cnt],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	_minimizableList[cnt]->SetRateConstantsWeight(0.0);
	// attach observer
	_plotterList.push_back(new GnuPlotterTimeSeriesObserver());
	_plotterList[cnt]->SetTitle("Rap1 Minus Network:NGF Stimulation (50 ng/ml, Y 1995):ODE");
	_minimizableList[cnt]->Attach(_plotterList[3]);
	cnt++;

	// expt. 3 - EGF at 30 ng/ml
	// networks and data
	_networkList.push_back(new CPC12RapMinusNetwork());
	_experimentList.push_back(new Experiment(_networkList[cnt],"EGF Stimulation 30 ng/ml"));
	// put data files here
	_experimentList[cnt]->AddDataFileToList("../DataFiles/TimeSeries/RasGreen1EGF.dat");
	// mover and plotter
	_moverList.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	// minimizable
	_minimizableList.push_back(new SingleNetworkMinimizable());
	// parameters
	_minimizableList[cnt]->Initialize(_experimentList[cnt],_moverList[cnt],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	_minimizableList[cnt]->GetConversionFactor(11)->SetFactorFixed(true);
	_minimizableList[cnt]->GetConversionFactor(11)->SetFactorValue(1.0/(0.2*600000*0.1));
	_minimizableList[cnt]->SetRateConstantsWeight(0.0);
	// attach observer
	_plotterList.push_back(new GnuPlotterTimeSeriesObserver());
	_plotterList[cnt]->SetTitle("Rap1 Minus Network:EGF Stimulation (30 ng/ml):ODE");
	_minimizableList[cnt]->Attach(_plotterList[cnt]);
	cnt++;
	
	
	// expt. 4 - NGF at 100 ng/ml
	// networks and data
	_networkList.push_back(new CPC12RapMinusNetwork());
	_experimentList.push_back(new Experiment(_networkList[cnt],"NGF Stimulation 100 ng/ml"));
	// data
	_experimentList[cnt]->AddDataFileToList("../DataFiles/TimeSeries/Raf1LandrethNGF.dat");
	// mover and plotter
	_moverList.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	// minimizable
	_minimizableList.push_back(new SingleNetworkMinimizable());
	// parameters
	_minimizableList[cnt]->Initialize(_experimentList[cnt],_moverList[cnt],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	_minimizableList[cnt]->SetRateConstantsWeight(0.0);
	// attach observer
	_plotterList.push_back(new GnuPlotterTimeSeriesObserver());
	_plotterList[cnt]->SetTitle("Rap1 Minus Network:NGF Stimulation (100 ng/ml):ODE");
	_minimizableList[cnt]->Attach(_plotterList[cnt]);
	cnt++;
	
	// expt. 5 - EGF at 100 ng/ml + 50-fold overexpression of HER
	// networks and data
	_networkList.push_back(new CPC12RapMinusNetwork());
	_experimentList.push_back(new Experiment(_networkList[cnt],"EGF at 100 ng/ml, 50-fold HER Overexpression"));
	// data
	_experimentList[cnt]->AddDataFileToList("../DataFiles/TimeSeries/ErkMekTraverseHERover.dat");
	_moverList.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	// minimizable
	_minimizableList.push_back(new SingleNetworkMinimizable());
	// parameters
	_minimizableList[cnt]->Initialize(_experimentList[cnt],_moverList[cnt],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	_minimizableList[cnt]->SetRateConstantsWeight(0.0);
	// attach observer
	_plotterList.push_back(new GnuPlotterTimeSeriesObserver());
	_plotterList[cnt]->SetTitle("Rap1 Minus Network:NGF Stimulation (100 ng/ml):ODE");
	_minimizableList[cnt]->Attach(_plotterList[cnt]);
	cnt++;
	

	// allocate the master residuals list
	int masterResidualsSize = 0;
	for(int i = 0; i < _minimizableList.size(); i++)
	{
		int subRes = _minimizableList[i]->GetNResiduals();
		masterResidualsSize += subRes;
		cout << subRes << " residuals in minimizable " << i << endl;
	}
	if(m_dGammaSquared > 0.0)
	{
		masterResidualsSize += 1;
	}
	Allocate(masterResidualsSize);

	cout << "Master Residuals size : " << masterResidualsSize << endl;

	// define the experiments
	DefineExperiments();

	// dump info about residuals
	//DumpResidualInfo();
}

CPC12RapMinusMinimizableDirector::~CPC12RapMinusMinimizableDirector(void)
{
	for(int i = 0; i < _minimizableList.size(); i++)
	{
		if(_plotterList.size() > i)
		{
			_minimizableList[i]->Detach(_plotterList[i]);
		}
	}
	for(i = 0; i < _plotterList.size(); i++)
	{
		delete _plotterList[i];
	}
}

void CPC12RapMinusMinimizableDirector::DefineExperiments()
{
	// 100 ng/ml EGF, 0 NGF
	_minimizableList[0]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(10002000.0);
	_minimizableList[0]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->Reset();
	_minimizableList[0]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->SetInitialAmount(0.0);
	_minimizableList[0]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->Reset();	
	
	// 100 ng/ml EGF, 0 NGF
	_minimizableList[1]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(10002000.0);
	_minimizableList[1]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->Reset();
	_minimizableList[1]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->SetInitialAmount(0.0);
	_minimizableList[1]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->Reset();	

	// 0 EGF, 50 ng/ml NGF
	_minimizableList[2]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(0.0);
	_minimizableList[2]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->Reset();
	_minimizableList[2]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->SetInitialAmount(228000.0);
	_minimizableList[2]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->Reset();	
	
	// 0 EGF, 50 ng/ml NGF
	_minimizableList[3]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(0.0);
	_minimizableList[3]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->Reset();
	_minimizableList[3]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->SetInitialAmount(228000.0);
	_minimizableList[3]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->Reset();	

	// 30 ng/ml EGF, 0 NGF
	_minimizableList[4]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(3000600);
	_minimizableList[4]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->Reset();
	_minimizableList[4]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->SetInitialAmount(0.0);
	_minimizableList[4]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->Reset();	
	
	// 0 EGF, 100 ng/ml NGF
	_minimizableList[5]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(0.0);
	_minimizableList[5]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->Reset();
	_minimizableList[5]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->SetInitialAmount(456000.0);
	_minimizableList[5]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->Reset();
	
	// 100 ng/ml EGF, 0 ng/ml NGF, 50-fold HER overexpression
	_minimizableList[6]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(10002000.0);
	_minimizableList[6]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->Reset();
	_minimizableList[6]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->SetInitialAmount(0.0);
	_minimizableList[6]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->Reset();	
	double EGFR = _minimizableList[6]->GetExperiment()->GetReactionNetwork()->GetChemical(2)->GetInitialAmount();
	_minimizableList[6]->GetExperiment()->GetReactionNetwork()->GetChemical(2)->SetInitialAmount(50*EGFR);
	_minimizableList[6]->GetExperiment()->GetReactionNetwork()->GetChemical(2)->Reset();
	
	
}

double CPC12RapMinusMinimizableDirector::GetParameter(int parIndex)
{
	// for this director, everyone has the same parameters so any set 
	// can be returned
	return _minimizableList[0]->GetParameter(parIndex);
}

int CPC12RapMinusMinimizableDirector::GetNParameters()
{
	// ditto as for GetParameters()
	return _minimizableList[0]->GetNParameters();
}
