#include "PC12RapMinusNetwork.h"

CPC12RapMinusNetwork::CPC12RapMinusNetwork(void)
{
	// CFactor = #molecules/1uM
	double CFactor = 600000.0, SecToMin = 60.0;

	// 1
	Chemical *EGF = new Chemical(chemicals.size(), 0.0, "EGF");
	chemicals.push_back(EGF);

	// 2
	Chemical *NGF = new Chemical(chemicals.size(), 0.0, "NGF");
	chemicals.push_back(NGF);

	// 3 (ref - constraint on [EGFR]_T)
	Chemical *freeEGFReceptor = new Chemical(chemicals.size(), 80000, "freeEGFReceptor");
	chemicals.push_back(freeEGFReceptor);

	// 4 (ref)
	Chemical *boundEGFReceptor = new Chemical(chemicals.size(), 0.0, "boundEGFReceptor");
	chemicals.push_back(boundEGFReceptor);

	// 5 (ref)
	Chemical *freeNGFReceptor = new Chemical(chemicals.size(), 10000, "freeNGFReceptor");
	chemicals.push_back(freeNGFReceptor);

	// 6
	Chemical *boundNGFReceptor = new Chemical(chemicals.size(), 0.0, "boundNGFReceptor");
	chemicals.push_back(boundNGFReceptor);

	// 7
	Chemical *SosInactive = new Chemical(chemicals.size(), 0.2*CFactor, "SosInactive");
	chemicals.push_back(SosInactive);
		
	// 8
	Chemical *SosActive = new Chemical(chemicals.size(), 0.0, "SosActive");
	chemicals.push_back(SosActive);

	// 9
	Chemical *P90RskInactive = new Chemical(chemicals.size(), 0.2*CFactor, "P90RskInactive");
	chemicals.push_back(P90RskInactive);

	// 10
	Chemical *P90RskActive = new Chemical(chemicals.size(), 0.0, "P90RskActive");
	chemicals.push_back(P90RskActive);

	// 11
	Chemical *RasInactive = new Chemical(chemicals.size(), 0.2*CFactor,"RasInactive");
	chemicals.push_back(RasInactive);

	// 12
	Chemical *RasActive = new Chemical(chemicals.size(), 0.0, "RasActive");
	chemicals.push_back(RasActive);

	// 13
	Chemical *RasGapActive = new Chemical(chemicals.size(), CFactor*0.2, "RasGapActive");
	chemicals.push_back(RasGapActive);

	
	// 14 (ref - constraint on [Raf1]_T = CFactor*0.003)
	Chemical *Raf1Inactive = new Chemical(chemicals.size(), CFactor*0.2, "Raf1Inactive");
	chemicals.push_back(Raf1Inactive);
		
	// 15 (ref)
	Chemical *Raf1Active = new Chemical(chemicals.size(), 0.0, "Raf1Active");
	chemicals.push_back(Raf1Active);

	// 16 (ref - constraint on [Mek]_T)
	Chemical *MekInactive = new Chemical(chemicals.size(), CFactor, "MekInactive");
	chemicals.push_back(MekInactive);

	// 17 (ref)
	Chemical *MekActive = new Chemical(chemicals.size(), 0.0, "MekActive");
	chemicals.push_back(MekActive);

	// 18 (ref - constraint on [Erk]_T)
	Chemical *ErkInactive = new Chemical(chemicals.size(), CFactor,"ErkInactive");
	chemicals.push_back(ErkInactive);

	// 19 (ref)
	Chemical *ErkActive = new Chemical(chemicals.size(), 0.0, "ErkActive");
	chemicals.push_back(ErkActive);

	// 20
	Chemical *PI3KInactive = new Chemical(chemicals.size(), 0.2*CFactor, "PI3KInactive");
	chemicals.push_back(PI3KInactive);

	// 21
	Chemical *PI3KActive = new Chemical(chemicals.size(), 0.0, "PI3KActive");
	chemicals.push_back(PI3KActive);

	// 22
	Chemical *AktInactive = new Chemical(chemicals.size(), 0.2*CFactor, "AktInactive");
	chemicals.push_back(AktInactive);

	// 23
	Chemical *AktActive = new Chemical(chemicals.size(), 0.0, "AktActive");
	chemicals.push_back(AktActive);
	
	// 24
	Chemical *PP2AActive = new Chemical(chemicals.size(), 0.2*CFactor, "PP2AActive");
	chemicals.push_back(PP2AActive);

	// 25 
	Chemical *Raf1PPtase = new Chemical(chemicals.size(), 0.2*CFactor, "Raf1PPtase");
	chemicals.push_back(Raf1PPtase);


	RateConstant *k_rb_EGF = new RateConstant(SecToMin*0.00001, "krbEGF");
	rateConstants.push_back(k_rb_EGF);
	RateConstant *k_ru_EGF = new RateConstant(SecToMin*0.01, "kruEGF");
	rateConstants.push_back(k_ru_EGF);
	RateConstant *k_rb_NGF = new RateConstant(SecToMin*0.00005, "krbNGF");
	rateConstants.push_back(k_rb_NGF);
	RateConstant *k_ru_NGF = new RateConstant(SecToMin*0.02, "kruNGF");
	rateConstants.push_back(k_ru_NGF);

	RateConstant *k_EGF = new RateConstant(SecToMin*0.2, "kEGF");
	rateConstants.push_back(k_EGF);
	RateConstant *Km_EGF = new RateConstant(CFactor*0.8333, "KmEGF");
	rateConstants.push_back(Km_EGF);
	RateConstant *k_NGF = new RateConstant(SecToMin*0.4, "kNGF");
	rateConstants.push_back(k_NGF);
	RateConstant *Km_NGF = new RateConstant(CFactor*0.8333, "KmNGF");
	rateConstants.push_back(Km_NGF);

	RateConstant *k_dSos = new RateConstant(0.01*SecToMin, "kdSos");
	rateConstants.push_back(k_dSos);
	RateConstant *Km_dSos = new RateConstant(100000.0, "KmdSos");
	rateConstants.push_back(Km_dSos);	
	RateConstant *k_Sos = new RateConstant(0.075*SecToMin, "kSos");
	rateConstants.push_back(k_Sos);
	RateConstant *Km_Sos = new RateConstant(0.25*CFactor, "KmSos");
	rateConstants.push_back(Km_Sos);

	RateConstant *k_RasGap = new RateConstant(0.2*SecToMin, "kRasGap");
	rateConstants.push_back(k_RasGap);
	RateConstant *Km_RasGap = new RateConstant(CFactor*1.0104, "KmRasGap");
	rateConstants.push_back(Km_RasGap);
	RateConstant *k_RasToRaf1 = new RateConstant(0.08*SecToMin, "kRasToRaf1");
	rateConstants.push_back(k_RasToRaf1);
	RateConstant *Km_RasToRaf1 = new RateConstant(150000.0, "KmRasToRaf1");
	rateConstants.push_back(Km_RasToRaf1);
	
	RateConstant *k_pRaf1 = new RateConstant(0.05*SecToMin, "kpRaf1");
	rateConstants.push_back(k_pRaf1);
	// (ref)
	RateConstant *Km_pRaf1 = new RateConstant(0.6*CFactor, "KmpRaf1");
	rateConstants.push_back(Km_pRaf1);

	RateConstant *k_dMek = new RateConstant(0.03*SecToMin, "kdMek");
	rateConstants.push_back(k_dMek);
	RateConstant *Km_dMek = new RateConstant(125000.0, "KmdMek");
	rateConstants.push_back(Km_dMek);
	
	RateConstant *k_pMek_Cytoplasmic = new RateConstant(0.01*SecToMin, "kpMekCytoplasmic");
	rateConstants.push_back(k_pMek_Cytoplasmic);
	// (ref)
	RateConstant *Km_pMek_Cytoplasmic = new RateConstant(125000.0, "KmpMekCytoplasmic");
	rateConstants.push_back(Km_pMek_Cytoplasmic);
	RateConstant *k_dErk = new RateConstant(0.01*SecToMin, "kdErk");
	rateConstants.push_back(k_dErk);
	RateConstant *Km_dErk = new RateConstant(300000.0, "KmdErk");
	rateConstants.push_back(Km_dErk);
	RateConstant *k_pP90Rsk = new RateConstant(0.01*SecToMin, "kpP90Rsk");
	rateConstants.push_back(k_pP90Rsk);
	RateConstant *Km_pP90Rsk = new RateConstant(300000.0, "KmpP90Rsk");
	rateConstants.push_back(Km_pP90Rsk);
		
	
	RateConstant *k_PI3K = new RateConstant(0.05*SecToMin, "kPI3K");
	rateConstants.push_back(k_PI3K);
	RateConstant *Km_PI3K = new RateConstant(100000.0, "KmPI3K");
	rateConstants.push_back(Km_PI3K);
	RateConstant *k_PI3K_Ras = new RateConstant(0.025*SecToMin, "kPI3KRas");
	rateConstants.push_back(k_PI3K_Ras);
	RateConstant *Km_PI3K_Ras = new RateConstant(300000.0, "KmPI3KRas");
	rateConstants.push_back(Km_PI3K_Ras);
	RateConstant *k_Akt = new RateConstant(0.01*SecToMin, "kAkt");
	rateConstants.push_back(k_Akt);
	RateConstant *Km_Akt = new RateConstant(300000.0, "KmAkt");
	rateConstants.push_back(Km_Akt);
	RateConstant *k_dRaf1ByAkt = new RateConstant(0.1*SecToMin, "kdRaf1ByAkt");
	rateConstants.push_back(k_dRaf1ByAkt);
	RateConstant *Km_Raf1ByAkt = new RateConstant(300000.0, "KmRaf1ByAkt"); 
	rateConstants.push_back(Km_Raf1ByAkt);
	

	RateConstant *k_dRaf1 = new RateConstant(0.1*SecToMin, "kdRaf1");
	rateConstants.push_back(k_dRaf1);
	RateConstant *Km_dRaf1 = new RateConstant(300000.0, "KmdRaf1");
	rateConstants.push_back(Km_dRaf1);


	ReceptorBindingReaction *EGFBindingReaction = new ReceptorBindingReaction(EGF, freeEGFReceptor, boundEGFReceptor, k_rb_EGF, "EGFBindingReaction");
	reactions.push_back(EGFBindingReaction);
	ReceptorUnbindingReaction *EGFUnbindingReaction = new ReceptorUnbindingReaction(boundEGFReceptor, freeEGFReceptor, EGF, k_ru_EGF, "EGFUnbindingReaction");
	reactions.push_back(EGFUnbindingReaction);
	ReceptorBindingReaction *NGFBindingReaction = new ReceptorBindingReaction(NGF, freeNGFReceptor, boundNGFReceptor, k_rb_NGF, "NGFBindingReaction");
	reactions.push_back(NGFBindingReaction);
	ReceptorUnbindingReaction *NGFUnbindingReaction = new ReceptorUnbindingReaction(boundNGFReceptor, freeNGFReceptor, NGF, k_ru_NGF, "NGFUnbindingReaction");
	reactions.push_back(NGFUnbindingReaction);

	MichaelisMentenPhosphorylationReaction *SosActivationByEGFReaction = new MichaelisMentenPhosphorylationReaction(boundEGFReceptor, SosInactive, SosActive, k_EGF, Km_EGF, "SosActivationbyEGFReaction");
	reactions.push_back(SosActivationByEGFReaction);
	MichaelisMentenPhosphorylationReaction *SosActivationByNGFReaction = new MichaelisMentenPhosphorylationReaction(boundNGFReceptor, SosInactive, SosActive, k_NGF, Km_NGF, "SosActivationbyNGFReaction");
	reactions.push_back(SosActivationByNGFReaction);
	MichaelisMentenDephosphorylationReaction *SosDeactivationReaction = new MichaelisMentenDephosphorylationReaction(P90RskActive, SosActive, SosInactive, k_dSos, Km_dSos, "SosDeactivationReaction");
	reactions.push_back(SosDeactivationReaction);
	MichaelisMentenGProteinActivationReaction *RasActivationReaction = new MichaelisMentenGProteinActivationReaction(SosActive, RasInactive, RasActive, k_Sos, Km_Sos, "RasActivationReaction");
	reactions.push_back(RasActivationReaction);
	
	MichaelisMentenGProteinDeactivationReaction *RasDeactivationReaction = new MichaelisMentenGProteinDeactivationReaction(RasGapActive, RasActive, RasInactive, k_RasGap, Km_RasGap, "RasDeactivationReaction");
	reactions.push_back(RasDeactivationReaction);
	MichaelisMentenProteinProteinActivationReaction *Raf1ByRasActivationReaction = new MichaelisMentenProteinProteinActivationReaction(RasActive, Raf1Inactive, Raf1Active, k_RasToRaf1, Km_RasToRaf1, "Raf1ByRasActivationReaction");
	reactions.push_back(Raf1ByRasActivationReaction);

	MichaelisMentenPhosphorylationReaction *MekbyRaf1ActivationReaction = new MichaelisMentenPhosphorylationReaction(Raf1Active, MekInactive, MekActive, k_pRaf1, Km_pRaf1, "MekbyRaf1ActivationReaction");
	reactions.push_back(MekbyRaf1ActivationReaction);
	MichaelisMentenPhosphorylationReaction *ErkActivationReaction = new MichaelisMentenPhosphorylationReaction(MekActive, ErkInactive, ErkActive, k_pMek_Cytoplasmic, Km_pMek_Cytoplasmic, "ErkActivationReaction");
	reactions.push_back(ErkActivationReaction);

	
	MichaelisMentenDephosphorylationReaction *MekDeactivationReaction = new MichaelisMentenDephosphorylationReaction(PP2AActive, MekActive, MekInactive, k_dMek, Km_dMek, "MekDeactivationReaction");
	reactions.push_back(MekDeactivationReaction);
	MichaelisMentenDephosphorylationReaction *ErkDeactivationReaction = new MichaelisMentenDephosphorylationReaction(PP2AActive, ErkActive, ErkInactive, k_dErk, Km_dErk, "ErkDeactivationReaction");
	reactions.push_back(ErkDeactivationReaction);

	MichaelisMentenDephosphorylationReaction *Raf1byPPtaseDeactivationReaction = new MichaelisMentenDephosphorylationReaction(Raf1PPtase, Raf1Active, Raf1Inactive, k_dRaf1, Km_dRaf1, "Raf1byPPtaseDeactivationReaction");
	reactions.push_back(Raf1byPPtaseDeactivationReaction);

	MichaelisMentenPhosphorylationReaction *P90RskActivationReaction = new MichaelisMentenPhosphorylationReaction(ErkActive, P90RskInactive, P90RskActive, k_pP90Rsk, Km_pP90Rsk, "P90RskActivationReaction");
	reactions.push_back(P90RskActivationReaction);
	
	
	MichaelisMentenPhosphorylationReaction *PI3KbyEGFRActivationReaction = new MichaelisMentenPhosphorylationReaction(boundEGFReceptor, PI3KInactive, PI3KActive, k_PI3K, Km_PI3K, "PI3KbyEGFRActivationReaction");
	reactions.push_back(PI3KbyEGFRActivationReaction);
	MichaelisMentenProteinProteinActivationReaction *PI3KbyRasActivationReaction = new MichaelisMentenProteinProteinActivationReaction(RasActive, PI3KInactive, PI3KActive, k_PI3K_Ras, Km_PI3K_Ras, "PI3KbyRasActivationReaction");
	reactions.push_back(PI3KbyRasActivationReaction);

	
	MichaelisMentenPhosphorylationReaction *AktActivationReaction = new MichaelisMentenPhosphorylationReaction(PI3KActive, AktInactive, AktActive, k_Akt, Km_Akt, "AktActivationReaction");
	reactions.push_back(AktActivationReaction);
	MichaelisMentenProteinProteinDeactivationReaction *Raf1ByAktDeactivationReaction = new MichaelisMentenProteinProteinDeactivationReaction(AktActive, Raf1Active, Raf1Inactive, k_dRaf1ByAkt, Km_Raf1ByAkt, "RafByAktDeactivationReaction");
	reactions.push_back(Raf1ByAktDeactivationReaction);	
	
}

CPC12RapMinusNetwork::~CPC12RapMinusNetwork(void)
{
}
