#pragma once
#include "../src/Minimizer.h"
#include "../src/ParameterFilter.h"
#include "../src/Rand.h"
#include "../src/MatrixOperations.h"
#include "../src_temp/ImprovedLevenbergMarquardtMinimizer.h"
#include "../src_ac/ConjugateGradientMinimizer.h"

class CPeriodicQuenchMinimizer : public Minimizer
{
public:
	CPeriodicQuenchMinimizer(int RNGSeed, CParameterFilter *pFilter, bool LMflag, int nQuench, int nSteps, double tol=1.0e-02, double T=10, double deltaX=1.0,double c=10);
	virtual ~CPeriodicQuenchMinimizer(void);
	double Minimize(double *parameters, Minimizable *minimizable);
	virtual bool AcceptMove(double Eold, double Enew);
	virtual void GenerateMove();
	void WriteQuenchedParameters(int iter, double E);
protected:
	// used to do vector copies and such
	CMatrixOperations *m_pMO;
	// RNG
	Rand *m_pRNG;
	// filter for parameters, available to derived classes for move generation
	CParameterFilter *m_pFilter;
	// minimizer to do the quenching
	Minimizer *m_pQuencher;
	// current state
	double *m_pdCurrentParameters;
	// trial state
	double *m_pdTrialParameters;
	// number of total quenches to perform
	int m_iNQuenches;
	// number of steps to perform before quenching
	int m_iNMCSteps;
	// stepsize control
	double m_dC;
	// minimum std. dev. for stepsize
	double m_dDeltaX;
	// needed for detailed balance correction
	double m_dSqrLogParDiff;
	// temperature for the thermal part of the algorithm
	double m_dTemperature;
	// self-explanatory
	double m_dAcceptanceRatio;
	// seed
	int m_iRNGSeed;
	// current energy
	double m_dECurrent;
};
