#include "pooltransitionreaction.h"

CPoolTransitionReaction::CPoolTransitionReaction(Chemical *OldPoolForm, Chemical *NewPoolForm, RateConstant *k_t, RateConstant *K, std::string reactionName)
:Reaction(reactionName)
{
	// stoichiometry
	this->OldPoolForm = chemicals.size();
	chemicals.push_back(OldPoolForm);
	numberOfEachChemicalChangedByReaction.push_back(-1);

	this->NewPoolForm = chemicals.size();
	chemicals.push_back(NewPoolForm);
	numberOfEachChemicalChangedByReaction.push_back(+1);

	// rates
	this->k_t = rateConstants.size();
	rateConstants.push_back(k_t);

	this->K = rateConstants.size();
	rateConstants.push_back(K);

	// put enough dummy chemicalJacobian elements on the vector 
	// - they are recomputed every time you ask for the chemicalJacobian
	chemicalJacobian.push_back(new JElement(-1,-1));
	chemicalJacobian.push_back(new JElement(-1,-1));

	this->SetTeXForm();
}

CPoolTransitionReaction::~CPoolTransitionReaction(void)
{
}

double CPoolTransitionReaction::GetRate() const
{
	return (rateConstants[k_t]->GetValue()*chemicals[OldPoolForm]->GetAmount())/(rateConstants[K]->GetValue() + chemicals[NewPoolForm]->GetAmount());
}

void CPoolTransitionReaction::SetTeXForm()
{
	strstream stream;
	// TeX form of the reaction
	stream << rateConstants[k_t]->GetTeXName().c_str();
	stream << " {\\left[" << chemicals[OldPoolForm]->GetTeXName().c_str() << "\\right]";
	stream << "\\over {";
	stream <<  rateConstants[K]->GetTeXName().c_str() << " + ";
	stream << "\\left[" << chemicals[NewPoolForm]->GetTeXName().c_str() << "\\right]}}";
	// add a NULL
	stream << ends;
	// set the TeX string equal to what's in the stream
	m_sTeXForm = stream.str();
	// allow memory to be freed
	stream.rdbuf()->freeze(0);
}

std::vector<Reaction::JElement *> *CPoolTransitionReaction::GetChemicalJacobian()
{
	double denom = rateConstants[K]->GetValue() + chemicals[NewPoolForm]->GetAmount();
	
	chemicalJacobian[0]->SetWithRespectTo(chemicals[OldPoolForm]->GetChemicalNumber());
	chemicalJacobian[0]->SetJValue(rateConstants[k_t]->GetValue()/denom);
	
	chemicalJacobian[1]->SetWithRespectTo(chemicals[NewPoolForm]->GetChemicalNumber());
	chemicalJacobian[1]->SetJValue(-1.0*(rateConstants[k_t]->GetValue()*chemicals[OldPoolForm]->GetAmount())/(denom*denom));

	return &chemicalJacobian;
}