#pragma once
#include "..\src\DifferentialEquationMover.h"
#include <cmath>
#include <stdlib.h>
#include <iomanip.h>
#include <mkl.h>

class CStiffBulirschStoerMover : public CDifferentialEquationMover
{
public:
	CStiffBulirschStoerMover(double frequency, double stepSize, double eps=1.0e-05);
	virtual ~CStiffBulirschStoerMover(void);
	void StiffBSStep(int nRHS, double *y, double *dydt);
	void SemiImplicitMidpoint(int nRHS, double *y, double *dydt, double **dfdy, int nStep, double *yout);
	void PolynomialExtrapolation(int nRHS, int iest, double xest, double *yest, double *yz, double *dy, double *x, double **d);
	void LUSolveLinearSystem(int nRHS, double **a, double *b);
	virtual void Move(double xInitial, double xFinal, ReactionNetwork *pReactionNetwork);
protected:
	double *m_pdError;
	double *m_pdScale;
	double m_dEps;
	double m_dLastStep,m_dNextStep,m_dInitialStepSize;
	static const double m_scdTINY;
	static const int m_sciIMAXX;
	static const int m_sciKMAXX;
	static const double m_scdSAFE1;
	static const double m_scdSAFE2;
	static const double m_scdREDMAX;
	static const double m_scdREDMIN;
	static const double m_scdSCALMX;
};
