// TauReaction.cpp: implementation of the CTauReaction class.
//
//////////////////////////////////////////////////////////////////////

#include "TauReaction.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

CTauReaction::CTauReaction(Chemical *pTau):Reaction("TauReaction")
{
	this->Tau = chemicals.size();
	chemicals.push_back(pTau);
	numberOfEachChemicalChangedByReaction.push_back(1);

	// chemical jacobian is included for class compatibility, but you 
	// should never ask for this element b/c it has no meaning!
	chemicalJacobian.push_back(new JElement(-1,-1));

	this->SetTeXForm();
}

CTauReaction::~CTauReaction()
{

}

double CTauReaction::GetRate() const
{
	return 1.0/(1.0 - chemicals[Tau]->GetAmount());
}

void CTauReaction::SetTeXForm()
{
	strstream stream;
	// TeX form of the reaction
	stream << "{1 \\over {1 - \\left [ " << chemicals[Tau]->GetTeXName().c_str();
	stream << " \\right ] }}";
	// add a NULL
	stream << ends;
	// set the TeX string equal to what's in the stream
	m_sTeXForm = stream.str();
	// allow memory to be freed
	stream.rdbuf()->freeze(0);
}

std::vector<Reaction::JElement *> *CTauReaction::GetChemicalJacobian()
{
	chemicalJacobian[0]->SetWithRespectTo(chemicals[Tau]->GetChemicalNumber());
	chemicalJacobian[0]->SetJValue(0.0);
	
	return &chemicalJacobian;
}
