// TrimerDissociation.cpp: implementation of the TrimerDissociation class.
//
//////////////////////////////////////////////////////////////////////

#include "TrimerDissociation.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

CTrimerDissociation::CTrimerDissociation(Chemical *Trimer, Chemical *A, Chemical *B, Chemical *C, RateConstant *k_d, std::string reactionName)
:Reaction(reactionName)
{
	// stoichiometry
	this->Trimer = chemicals.size();
	chemicals.push_back(Trimer);
	numberOfEachChemicalChangedByReaction.push_back(-1);

	this->A = chemicals.size();
	chemicals.push_back(A);
	numberOfEachChemicalChangedByReaction.push_back(+1);

	this->B = chemicals.size();
	chemicals.push_back(B);
	numberOfEachChemicalChangedByReaction.push_back(+1);

	this->C = chemicals.size();
	chemicals.push_back(C);
	numberOfEachChemicalChangedByReaction.push_back(+1);

	// rates
	this->k_d = rateConstants.size();
	rateConstants.push_back(k_d);

	// put enough dummy chemicalJacobian elements on the vector 
	// - they are recomputed every time you ask for the chemicalJacobian
	chemicalJacobian.push_back(new JElement(-1,-1));

	this->SetTeXForm();


}

CTrimerDissociation::~CTrimerDissociation()
{

}

double CTrimerDissociation::GetRate() const
{
	return rateConstants[k_d]->GetValue()*chemicals[Trimer]->GetAmount();
}

void CTrimerDissociation::SetTeXForm()
{
	strstream stream;
	// TeX form of the reaction
	stream << rateConstants[k_d]->GetTeXName().c_str();
	stream << "\\left [" << chemicals[Trimer]->GetTeXName().c_str();
	stream << "\\right ]";
	// add a NULL
	//int namesize = (chemicals[Generator]->GetName()).length();
	//stream << (chemicals[Generator]->GetName())[namesize];
	stream << ends;
	// set the TeX string equal to what's in the stream
	m_sTeXForm = stream.str();
	// free up the string
	stream.rdbuf()->freeze(0);
}

std::vector<Reaction::JElement *> *CTrimerDissociation::GetChemicalJacobian()
{
	chemicalJacobian[0]->SetWithRespectTo(chemicals[Trimer]->GetChemicalNumber());
	chemicalJacobian[0]->SetJValue(rateConstants[k_d]->GetValue());
	
	return &chemicalJacobian;
}