// TrimerFormation.cpp: implementation of the CTrimerFormation class.
//
//////////////////////////////////////////////////////////////////////

#include "TrimerFormation.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

CTrimerFormation::CTrimerFormation(Chemical *A, Chemical *B, Chemical *C, Chemical *Trimer, RateConstant *k_t, std::string reactionName)
:Reaction(reactionName)
{
	// stoichiometry
	this->A = chemicals.size();
	chemicals.push_back(A);
	numberOfEachChemicalChangedByReaction.push_back(-1);

	this->B = chemicals.size();
	chemicals.push_back(B);
	numberOfEachChemicalChangedByReaction.push_back(-1);

	this->C = chemicals.size();
	chemicals.push_back(C);
	numberOfEachChemicalChangedByReaction.push_back(-1);

	this->Trimer = chemicals.size();
	chemicals.push_back(Trimer);
	numberOfEachChemicalChangedByReaction.push_back(+1);

	// rates
	this->k_t = rateConstants.size();
	rateConstants.push_back(k_t);

	// put enough dummy chemicalJacobian elements on the vector 
	// - they are recomputed every time you ask for the chemicalJacobian
	chemicalJacobian.push_back(new JElement(-1,-1));
	chemicalJacobian.push_back(new JElement(-1,-1));
	chemicalJacobian.push_back(new JElement(-1,-1));

	this->SetTeXForm();

}

CTrimerFormation::~CTrimerFormation()
{

}

double CTrimerFormation::GetRate() const
{
	double amtA = chemicals[A]->GetAmount();
	double amtB = chemicals[B]->GetAmount();
	double amtC = chemicals[C]->GetAmount();
	return rateConstants[k_t]->GetValue()*amtA*amtB*amtC;
}

void CTrimerFormation::SetTeXForm()
{
	strstream stream;
	// TeX form of the reaction
	stream << rateConstants[k_t]->GetTeXName().c_str();
	stream << "\\left [" << chemicals[A]->GetTeXName().c_str();
	stream << "\\right ]";
	stream << " \\left [" << chemicals[B]->GetTeXName().c_str();
	stream << "\\right ]";
	stream << " \\left  [" << chemicals[C]->GetTeXName().c_str();
	stream << "\\right ]";
	// add a NULL
	//int namesize = (chemicals[Generator]->GetName()).length();
	//stream << (chemicals[Generator]->GetName())[namesize];
	stream << ends;
	// set the TeX string equal to what's in the stream
	m_sTeXForm = stream.str();
	// free up the string
	stream.rdbuf()->freeze(0);
}

std::vector<Reaction::JElement *> *CTrimerFormation::GetChemicalJacobian()
{
	double rate = rateConstants[k_t]->GetValue();
	double amtA = chemicals[A]->GetAmount();
	double amtB = chemicals[B]->GetAmount();
	double amtC = chemicals[C]->GetAmount();
	chemicalJacobian[0]->SetWithRespectTo(chemicals[A]->GetChemicalNumber());
	chemicalJacobian[0]->SetJValue(rate*amtB*amtC);
	chemicalJacobian[1]->SetWithRespectTo(chemicals[B]->GetChemicalNumber());
	chemicalJacobian[1]->SetJValue(rate*amtA*amtC);
	chemicalJacobian[2]->SetWithRespectTo(chemicals[C]->GetChemicalNumber());
	chemicalJacobian[2]->SetJValue(rate*amtA*amtB);
	
	return &chemicalJacobian;
}