#ifndef GENETICCODE_H_INCLUDED
#define GENETICCODE_H_INCLUDED

enum Codon {AAA, AAU, AAG, AAC,
            AUA, AUU, AUG, AUC, 
            AGA, AGU, AGG, AGC,
            ACA, ACU, ACG, ACC,
            UAU, UAC,
            UUA, UUU, UUG, UUC, 
            UGU, UGG, UGC,
            UCA, UCU, UCG, UCC,
            GAA, GAU, GAG, GAC,
            GUA, GUU, GUG, GUC,
            GGA, GGU, GGG, GGC,
            GCA, GCU, GCG, GCC,
            CAA, CAU, CAG, CAC,
            CUA, CUU, CUG, CUC,
            CGA, CGU, CGG, CGC,
            CCA, CCU, CCG, CCC,
            UAA, UAG, UGA};  // stop codons must be listed last

enum Anticodon {uuu, quu, gau, nau, cau, icg, ccg, /* UNKNOWN */
                ucu, /* UNKNOWN*/
                gga, /* ACTUALLY GGA+UGA */
                gcu, ggu, ugu, cca, qua, gag, uag, /*UNKNOWN */
                cag, aaa, gaa, gca, uuc, quc, gac, /* GAC+UAC */
                gcc, ucc, ccc, ggc, /* GGC+UGC */
                uug, cug, qug, qgg, /* UNKNOWN */
                ugg, /* UNKNOWN */
                stop};

class GeneticCode
{
public:
	~GeneticCode();
	GeneticCode();  // constructor
	Anticodon get_anticodon(Codon);  // decodes a codon
	Codon read_seq(char*);  // reads triplet codon, returns corresponding value of type Codon
	void write_seq(Codon, char*); // reads type Codon, sets string to that codon
	const int GetNumCodons() {return NUM_CODONS;}
	const int GetNumAnticodons() {return NUM_ANTICODONS;}
protected:
	static const int NUM_CODONS;
	static const int NUM_ANTICODONS;
private:
	int *code;
};

#endif
