#ifndef TRANSLATIONMODELMINIMIZABLE_H_INCLUDED
#define TRANSLATIONMODELMINIMIZABLE_H_INCLUDED

#include "GeneticCode.h"
#include "../src/NLLSMinimizable.h"
#include <fstream.h>
#include <cctype>

class TranslationModelMinimizable : public NLLSMinimizable
{
public:
	TranslationModelMinimizable(char* infilename, int ribosome_length);
	~TranslationModelMinimizable();
	double ComputeResiduals(double *parameters);
	double EntropyShift(double T);
	double F(double *parameters, double T);
	double F0(double *parameters, double T);
	int GetNParameters();  // returns number of parameters
private:
	ifstream& eatwhite(ifstream& is);
	double compute_current(double*k ,int length,int rib_size);
	void update_dens(double* n, double* k, double J, int N, int L);
	int rib_size;  // ribosome length (measured in codons)
	int num_params;
	int num_genes;  // number of genes to be used
	int num_data_sets;  // number of sets of fold change data (1 < num expt. conditions)                       
	// for expt data, 1st index is data set number and 2nd is gene number
	double** fm;  // mRNA fold changes
	double** fp;  // protein fold changes
	double** fmerr;  // errors in fm
	double** fperr;  // errors in fp
	Codon** RNAseq;  // codon sequence for each gene
	int* length;  // length of each gene sequence (# of codons)
	GeneticCode* geneticcode;  // info to read/decode genetic sequences
	double* efficiency;  // efficiency of tRNA binding for each codon (not currently in use)
        
	static const int MAX_STRING_LENGTH;
	static const double TINY;
	static const int MAX_RNA_MOLS;
	static const int MAX_RNA_LENGTH;

};

#endif
