// EGFRTraffickingCHOMinimizableDirector.cpp: implementation of the CEGFRTraffickingCHOMinimizableDirector class.
//
//////////////////////////////////////////////////////////////////////

#include "EGFRTraffickingCHOMinimizableDirector.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

CEGFRTraffickingCHOMinimizableDirector::CEGFRTraffickingCHOMinimizableDirector()
{
	// create networks,experiments,observers,movers,minimizables
	double maxSimTime = 241.0;
	double stepSize = 0.0001;
	double frequency = 1.0;
	int nCells = 1;
	double moveTol = 1.0e-06;

	m_dGammaSquared = 1.0e-07;
	
	// flags for all minimizables
	bool rateFlag = true;
	bool chemFlag = false;
	bool logsFlag = false;
	double timeWeight = 1.0;
	double rateWeight = 0.0;
	double chemWeight = 0.0;
	

	// CHO cells
	// expt. 0 - CHO cells transfected with ? receptors, treated with EGF at 5 ng/ml
	//		concentration
	_networkList.push_back(new CEGFRTraffickingNetwork());
	_experimentList.push_back(new Experiment(_networkList[0],"EGF at 5 ng/ml, Bao 2000"));
	// put data files here
	_experimentList[0]->AddDataFileToList("../DataFiles/TimeSeries/InternalizedEGFREGFYarden.dat");
	// mover and plotter
	_moverList.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	// minimizable
	_minimizableList.push_back(new SingleNetworkMinimizable());
	// parameters
	_minimizableList[0]->Initialize(_experimentList[0],_moverList[0],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	_minimizableList[0]->SetRateConstantsWeight(0.0);
	// attach observer
	
	_plotterList.push_back(new GnuPlotterTimeSeriesObserver());
	_plotterList[0]->SetTitle("EGFR Trafficking Network:EGF at 5 ng/ml (Bao 2000):ODE");
	_minimizableList[0]->Attach(_plotterList[0]);
	

	// expt. 1 - CHO cells transfected with 8.2(7) X 10^4 receptors, treated 
	//		with EGF at 100 nM concentration
	_networkList.push_back(new CEGFRTraffickingNetwork());
	_experimentList.push_back(new Experiment(_networkList[1],"EGF at 100 nM, Davis 1992"));
	// put data files here
	_experimentList[1]->AddDataFileToList("../DataFiles/TimeSeries/SurfaceEGFREGFDavis100nM.dat");
	// mover and plotter
	_moverList.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	// minimizable
	_minimizableList.push_back(new SingleNetworkMinimizable());
	// parameters
	_minimizableList[1]->Initialize(_experimentList[1],_moverList[1],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	_minimizableList[1]->GetConversionFactor(54)->SetFactorFixed(true);
	_minimizableList[1]->GetConversionFactor(54)->SetFactorValue(100.0/82000.0);
	_minimizableList[1]->SetRateConstantsWeight(0.0);
	// attach observer
	
	_plotterList.push_back(new GnuPlotterTimeSeriesObserver());
	_plotterList[1]->SetTitle("EGFR Trafficking Network:EGF at 100 nM (Davis 1992):ODE");
	_minimizableList[1]->Attach(_plotterList[1]);
	

	// expt. 2 - CHO cells transfected with 8.2(7) X 10^4 receptors, treated 
	//		with EGF at 10 nM concentration
	_networkList.push_back(new CEGFRTraffickingNetwork());
	_experimentList.push_back(new Experiment(_networkList[2],"EGF at 10 nM, Davis 1992"));
	// put data files here
	_experimentList[2]->AddDataFileToList("../DataFiles/TimeSeries/SurfaceEGFREGFDavis10nM.dat");
	// mover and plotter
	_moverList.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	// minimizable
	_minimizableList.push_back(new SingleNetworkMinimizable());
	// parameters
	_minimizableList[2]->Initialize(_experimentList[2],_moverList[2],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	_minimizableList[2]->GetConversionFactor(54)->SetFactorFixed(true);
	_minimizableList[2]->GetConversionFactor(54)->SetFactorValue(100.0/82000.0);
	_minimizableList[2]->SetRateConstantsWeight(0.0);
	// attach observer
	
	_plotterList.push_back(new GnuPlotterTimeSeriesObserver());
	_plotterList[2]->SetTitle("EGFR Trafficking Network:EGF at 10 nM (Davis 1992):ODE");
	_minimizableList[2]->Attach(_plotterList[2]);
	

	// expt. 3 - CHO cells transfected with 8.2(7) X 10^4 receptors, treated 
	//		with EGF at 1 nM concentration
	_networkList.push_back(new CEGFRTraffickingNetwork());
	_experimentList.push_back(new Experiment(_networkList[3],"EGF at 1 nM, Davis 1992"));
	// put data files here
	_experimentList[3]->AddDataFileToList("../DataFiles/TimeSeries/SurfaceEGFREGFDavis1nM.dat");
	// mover and plotter
	_moverList.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	// minimizable
	_minimizableList.push_back(new SingleNetworkMinimizable());
	// parameters
	_minimizableList[3]->Initialize(_experimentList[3],_moverList[3],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	_minimizableList[3]->GetConversionFactor(54)->SetFactorFixed(true);
	_minimizableList[3]->GetConversionFactor(54)->SetFactorValue(100.0/82000.0);
	_minimizableList[3]->SetRateConstantsWeight(0.0);
	// attach observer
	
	_plotterList.push_back(new GnuPlotterTimeSeriesObserver());
	_plotterList[3]->SetTitle("EGFR Trafficking Network:EGF at 1 nM (Davis 1992):ODE");
	_minimizableList[3]->Attach(_plotterList[3]);
	
	
	// expt. 4 - CHO cells transfected with ? EGFR and treated with EGF at 
	//		100 ng/ml concentration
	_networkList.push_back(new CEGFRTraffickingNetwork());
	_experimentList.push_back(new Experiment(_networkList[4],"EGF at 100 ng/ml, Levkowitz 1999"));
	// put data files here
	_experimentList[4]->AddDataFileToList("../DataFiles/TimeSeries/SurfaceEGFREGFLevkowitz.dat");
	// mover and plotter
	_moverList.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	// minimizable
	_minimizableList.push_back(new SingleNetworkMinimizable());
	// parameters
	_minimizableList[4]->Initialize(_experimentList[4],_moverList[4],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	_minimizableList[4]->GetConversionFactor(54)->SetFactorFixed(true);
	_minimizableList[4]->GetConversionFactor(54)->SetFactorValue(100.0/80000.0);
	_minimizableList[4]->SetRateConstantsWeight(0.0);
	// attach observer
	
	_plotterList.push_back(new GnuPlotterTimeSeriesObserver());
	_plotterList[4]->SetTitle("EGFR Trafficking Network:EGF at 100 ng/ml (Levkowitz 1999):ODE");
	_minimizableList[4]->Attach(_plotterList[4]);
	

	/*
	// expt. 5 - CHO cells transfected with ? EGFR Y1045F and treated with EGF at
	//		100 ng/ml concentration
	_networkList.push_back(new CEGFRTraffickingNetwork());
	_experimentList.push_back(new Experiment(_networkList[5],"EGF at 100 ng/ml, Y1045F EGFR, Levkowitz 1999"));
	// put data files here
	_experimentList[5]->AddDataFileToList("../DataFiles/TimeSeries/SurfaceEGFREGFY1045FLevkowitz.dat");
	// mover and plotter
	_moverList.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	// minimizable
	_minimizableList.push_back(new SingleNetworkMinimizable());
	// parameters
	_minimizableList[5]->Initialize(_experimentList[5],_moverList[5],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	_minimizableList[5]->GetConversionFactor(47)->SetFactorFixed(true);
	_minimizableList[5]->GetConversionFactor(47)->SetFactorValue(100.0/80000.0);
	_minimizableList[5]->SetRateConstantsWeight(0.0);
	// attach observer
	_plotterList.push_back(new GnuPlotterTimeSeriesObserver());
	_plotterList[5]->SetTitle("EGFR Trafficking Network:EGF at 100 ng/ml, Y1045F EGFR (Levkowitz 1999):ODE");
	_minimizableList[5]->Attach(_plotterList[5]);
	
	
	// expt. 6 - CHO cells transfected with ? EGFR K721A and treated with EGF at
	//		100 ng/ml concentration
	_networkList.push_back(new CEGFRTraffickingNetwork());
	_experimentList.push_back(new Experiment(_networkList[6],"EGF at 100 ng/ml, K721A, Levkowitz 1999"));
	// put data files here
	_experimentList[6]->AddDataFileToList("../DataFiles/TimeSeries/SurfaceEGFREGFK721ALevkowitz.dat");
	// mover and plotter
	_moverList.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	_plotterList.push_back(new GnuPlotterTimeSeriesObserver());
	// title
	_plotterList[6]->SetTitle("EGFR Trafficking Network:EGF at 100 ng/ml, K721A EGFR (Levkowitz 1999):ODE");
	// minimizable
	_minimizableList.push_back(new SingleNetworkMinimizable());
	// parameters
	_minimizableList[6]->Initialize(_experimentList[6],_moverList[6],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	_minimizableList[6]->GetConversionFactor(7)->SetFactorFixed(true);
	_minimizableList[6]->GetConversionFactor(7)->SetFactorValue(100.0/80000.0);
	_minimizableList[6]->SetRateConstantsWeight(0.0);
	// attach observer
	_minimizableList[6]->Attach(_plotterList[6]);
	*/
	
	// parameters which need a prior

	// allocate the master residuals list
	int masterResidualsSize = 0;
	for(int i = 0; i < _minimizableList.size(); i++)
	{
		int subRes = _minimizableList[i]->GetNResiduals();
		masterResidualsSize += subRes;
		cout << subRes << " residuals in minimizable " << i << endl;
	}
	// add residuals for prior parameter costs, if applicable
	masterResidualsSize += m_iPriorList.size();
	cout << m_iPriorList.size() << " parameters are constrained by a prior " << endl;
	if(m_dGammaSquared > 0.0)
	{
		masterResidualsSize += 1;
	}
	Allocate(masterResidualsSize);

	cout << "Master Residuals size : " << this->GetNResiduals() << endl;

	// define the experiments
	DefineExperiments();

}

CEGFRTraffickingCHOMinimizableDirector::~CEGFRTraffickingCHOMinimizableDirector()
{
	for(int i = 0; i < _plotterList.size(); i++)
	{
		_minimizableList[i]->Detach(_plotterList[i]);
		delete _plotterList[i];
	}
}

void CEGFRTraffickingCHOMinimizableDirector::DefineExperiments()
{	
	
	// CHO cells
	// 80,000 receptors assumed, EGF at 5 ng/ml
	_minimizableList[0]->GetExperiment()->GetReactionNetwork()->RemoveReaction(78);
	_minimizableList[0]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(600000.0);
	_minimizableList[0]->GetExperiment()->GetReactionNetwork()->GetChemical(3)->SetInitialAmount(80000.0);
	_minimizableList[0]->GetExperiment()->GetReactionNetwork()->ChemicalReset();

	// 82,000 receptors, EGF at 100 nM
	_minimizableList[1]->GetExperiment()->GetReactionNetwork()->RemoveReaction(78);
	_minimizableList[1]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(7.2e+007);
	_minimizableList[1]->GetExperiment()->GetReactionNetwork()->GetChemical(3)->SetInitialAmount(82000);
	_minimizableList[1]->GetExperiment()->GetReactionNetwork()->ChemicalReset();

	// 82,000 receptors, EGF at 10 nM
	_minimizableList[2]->GetExperiment()->GetReactionNetwork()->RemoveReaction(78);
	_minimizableList[2]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(7.2e+006);
	_minimizableList[2]->GetExperiment()->GetReactionNetwork()->GetChemical(3)->SetInitialAmount(82000);
	_minimizableList[2]->GetExperiment()->GetReactionNetwork()->ChemicalReset();

	// 82,000 receptors, EGF at 1 nM
	_minimizableList[3]->GetExperiment()->GetReactionNetwork()->RemoveReaction(78);
	_minimizableList[3]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(7.2e+005);
	_minimizableList[3]->GetExperiment()->GetReactionNetwork()->GetChemical(3)->SetInitialAmount(82000);
	_minimizableList[3]->GetExperiment()->GetReactionNetwork()->ChemicalReset();

	// 80,000 receptors assumed, EGF at 100 ng/ml
	_minimizableList[4]->GetExperiment()->GetReactionNetwork()->RemoveReaction(78);
	_minimizableList[4]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(1.2e+007);
	_minimizableList[4]->GetExperiment()->GetReactionNetwork()->GetChemical(3)->SetInitialAmount(80000);
	_minimizableList[4]->GetExperiment()->GetReactionNetwork()->ChemicalReset();
	
	/*
	// 80,000 receptors assumed, EGF at 100 ng/ml, Y1045F can't bind to Cbl
	_minimizableList[5]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(1.2e+007);
	_minimizableList[5]->GetExperiment()->GetReactionNetwork()->GetChemical(2)->SetInitialAmount(80000);
	_minimizableList[5]->GetExperiment()->GetReactionNetwork()->ChemicalReset();
	_minimizableList[5]->GetExperiment()->GetReactionNetwork()->RemoveReaction(40);
	_minimizableList[5]->GetExperiment()->GetReactionNetwork()->RemoveReaction(40);
	
	
	// 80,000 receptors assumed, EGF at 100 ng/ml, K721A is kinase dead
	_minimizableList[6]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(1.2e+007);
	_minimizableList[6]->GetExperiment()->GetReactionNetwork()->GetChemical(2)->SetInitialAmount(80000);
	_minimizableList[6]->GetExperiment()->GetReactionNetwork()->ChemicalReset();
	_minimizableList[6]->GetExperiment()->GetReactionNetwork()->RemoveReaction(2);
	_minimizableList[6]->GetExperiment()->GetReactionNetwork()->RemoveReaction(3);
	_minimizableList[6]->GetExperiment()->GetReactionNetwork()->RemoveReaction(4);
	_minimizableList[6]->GetExperiment()->GetReactionNetwork()->RemoveReaction(5);
	_minimizableList[6]->GetExperiment()->GetReactionNetwork()->RemoveReaction(6);
	_minimizableList[6]->GetExperiment()->GetReactionNetwork()->RemoveReaction(7);
	_minimizableList[6]->GetExperiment()->GetReactionNetwork()->RemoveReaction(8);
	_minimizableList[6]->GetExperiment()->GetReactionNetwork()->RemoveReaction(31);
	*/
}

double CEGFRTraffickingCHOMinimizableDirector::GetParameter(int parIndex)
{
	// for this director, everyone has the same parameters so any set 
	// can be returned
	return _minimizableList[0]->GetParameter(parIndex);
}

int CEGFRTraffickingCHOMinimizableDirector::GetNParameters()
{
	// ditto as for GetParameters()
	// return _minimizableList[0]->GetNParameters();
	return _minimizableList[0]->GetNParameters() + 8;
}

double CEGFRTraffickingCHOMinimizableDirector::ComputeResiduals(double *parameters)
{
	int lastrc = _minimizableList[0]->GetNParameters();
	// set all the ICs first
	for(int i = 0; i < 5; i++)
	{
		_minimizableList[i]->GetExperiment()->GetReactionNetwork()->GetChemical(41)->SetInitialAmount(parameters[lastrc]);
		_minimizableList[i]->GetExperiment()->GetReactionNetwork()->GetChemical(42)->SetInitialAmount(parameters[lastrc+1]);
		_minimizableList[i]->GetExperiment()->GetReactionNetwork()->GetChemical(44)->SetInitialAmount(parameters[lastrc+2]);
		_minimizableList[i]->GetExperiment()->GetReactionNetwork()->GetChemical(48)->SetInitialAmount(parameters[lastrc+3]);
		_minimizableList[i]->GetExperiment()->GetReactionNetwork()->GetChemical(49)->SetInitialAmount(parameters[lastrc+4]);
		_minimizableList[i]->GetExperiment()->GetReactionNetwork()->GetChemical(50)->SetInitialAmount(parameters[lastrc+5]);
		_minimizableList[i]->GetExperiment()->GetReactionNetwork()->GetChemical(66)->SetInitialAmount(parameters[lastrc+6]);	
		_minimizableList[i]->GetExperiment()->GetReactionNetwork()->ChemicalReset();

	}
	// now fire away
	// just sum up the costs from each director and then add the 
	// integration penalty, = (gamma^2/2)*(sum_ti)^2
	double summedCost = 0.0;
	double timeCost = 0.0;
	double pcost = 0.0;
	
	// compute the residuals/cost from each minimizable
	for(int i = 0; i < _minimizableList.size(); i++)
	{
		summedCost += _minimizableList[i]->ObjectiveFunction(parameters);
	}
	
	// load up the master list with each set of residuals
	int nextResidual = 0;
	for(i = 0; i < _minimizableList.size(); i++)
	{
		int nRes = _minimizableList[i]->GetNResiduals();
		for(int j = 0; j < nRes; j++)
		{
			residuals[nextResidual+j] = (_minimizableList[i]->GetResiduals())[j];
		}
		nextResidual += nRes;
	}
	
	// now compute the cost for deviation from guessed values, if any
	for(i = 0; i < m_iPriorList.size(); i++)
	{
		int which = m_iPriorList[i];
		//double presid = parameters[which] - _networkList[0]->GetRateConstant(which)->GetInitialValue();
		double presid = _networkList[0]->GetRateConstant(which)->GetValue() - _networkList[0]->GetRateConstant(which)->GetInitialValue();
		presid = presid/(sqrt(2.0)*_networkList[0]->GetRateConstant(which)->GetErrorInInitialValue());
		residuals[nextResidual + i] = presid;
		pcost += presid*presid;
	}
	nextResidual += m_iPriorList.size();
	
	// if the prefactor for the integration cost is > 0, compute its residual (otherwise
	// that residual shouldn't exist)
	if(m_dGammaSquared > 0.0)
	{
		double totalSteps = 0.0;
		for(int l = 0; l < _moverList.size(); l++)
		{
			totalSteps += _moverList[l]->GetTotalStepsTaken();
		}
		residuals[nResiduals - 1] = sqrt(m_dGammaSquared/2.0)*totalSteps;
		timeCost = residuals[nResiduals - 1]*residuals[nResiduals - 1];
	}
	return summedCost + pcost + timeCost;
}