// EGFRTraffickingNIH3T3MinimizableDirector.cpp: implementation of the CEGFRTraffickingNIH3T3MinimizableDirector class.
//
//////////////////////////////////////////////////////////////////////

#include "EGFRTraffickingNIH3T3MinimizableDirector.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

CEGFRTraffickingNIH3T3MinimizableDirector::CEGFRTraffickingNIH3T3MinimizableDirector()
{
	// create networks,experiments,observers,movers,minimizables
	double maxSimTime = 361.0;
	double stepSize = 0.0001;
	double frequency = 1.0;
	int nCells = 1;
	double moveTol = 1.0e-06;

	m_dGammaSquared = 0.0;
	
	// flags for all minimizables
	bool rateFlag = true;
	bool chemFlag = false;
	bool logsFlag = false;
	double timeWeight = 1.0;
	double rateWeight = 0.0;
	double chemWeight = 0.0;

	int cnt = 0;
	
	// NIH-3T3 cells
	// expt. 0 - NIH-3T3 cells transfected with 1.0(5) X 10^5 receptors, treated 
	//		with EGF at 100 nM concentration
	_networkList.push_back(new CEGFRTraffickingNetwork());
	_experimentList.push_back(new Experiment(_networkList[cnt],"EGF at 100 nM, Helin 1991"));
	// put data files here
	_experimentList[cnt]->AddDataFileToList("../DataFiles/TimeSeries/SurfaceEGFREGFHelin100nM.dat");
	_experimentList[cnt]->AddForcingFileToList("../DataFiles/TimeSeries/TwoHourEGF.dat");
	// mover and plotter
	//_moverList.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	_moverList.push_back(new CStiffBulirschStoerMover(frequency,stepSize,moveTol));
	// minimizable
	_minimizableList.push_back(new SingleNetworkMinimizable());
	// parameters
	_minimizableList[cnt]->Initialize(_experimentList[cnt],_moverList[cnt],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	_minimizableList[cnt]->GetConversionFactor(59)->SetFactorFixed(true);
	_minimizableList[cnt]->GetConversionFactor(59)->SetFactorValue(100.0/100000.0);
	_minimizableList[cnt]->SetRateConstantsWeight(0.0);
	// attach observer
	
	_plotterList.push_back(new GnuPlotterTimeSeriesObserver());
	_plotterList[cnt]->SetTitle("EGFR Trafficking Network:EGF at 100 nM (Helin 1991):ODE");
	_minimizableList[cnt]->Attach(_plotterList[cnt]);
	
	cnt++;
	
	// expt. 1 - NIH-3T3's transfected w/ wild-type EGFR; measurements made
	//		with 10-30% of receptors initially occupied; cells express 
	//		1.0(5) X 10^5 receptors
	_networkList.push_back(new CEGFRTraffickingNetwork());
	_experimentList.push_back(new Experiment(_networkList[cnt],"20 Percent Initial Occupancy, Helin 1991"));
	// put data files here
	_experimentList[cnt]->AddDataFileToList("../DataFiles/TimeSeries/EGFHelinOccupied.dat");
	// mover and plotter
	//_moverList.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	_moverList.push_back(new CStiffBulirschStoerMover(frequency,stepSize,moveTol));
	// minimizable
	_minimizableList.push_back(new SingleNetworkMinimizable());
	// parameters
	_minimizableList[cnt]->Initialize(_experimentList[cnt],_moverList[cnt],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	_minimizableList[cnt]->GetConversionFactor(60)->SetFactorFixed(true);
	_minimizableList[cnt]->GetConversionFactor(60)->SetFactorValue(100.0/20000.0);
	_minimizableList[cnt]->SetRateConstantsWeight(0.0);
	// attach observer
	
	_plotterList.push_back(new GnuPlotterTimeSeriesObserver());
	_plotterList[cnt]->SetTitle("EGFR Trafficking Network:20 Percent Initial EGFR Occupancy (Helin 1991):ODE");
	_minimizableList[cnt]->Attach(_plotterList[cnt]);
	
	cnt++;

	// expt. 2 - NIH-3T3's transfected with wt EGFR; 1 X 10^5 receptors, EGF of
	//		100 ng/ml
	_networkList.push_back(new CEGFRTraffickingNetwork());
	_experimentList.push_back(new Experiment(_networkList[cnt],"EGF at 100 ng/ml wt1, Carter 1998"));
	// put data files here
	_experimentList[cnt]->AddDataFileToList("../DataFiles/TimeSeries/SurfaceEGFREGFwt1Carter.dat");
	_experimentList[cnt]->AddForcingFileToList("../DataFiles/TimeSeries/TwoHourEGF.dat");
	// mover and plotter
	//_moverList.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	_moverList.push_back(new CStiffBulirschStoerMover(frequency,stepSize,moveTol));
	// minimizable
	_minimizableList.push_back(new SingleNetworkMinimizable());
	// parameters
	_minimizableList[cnt]->Initialize(_experimentList[cnt],_moverList[cnt],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	_minimizableList[cnt]->GetConversionFactor(59)->SetFactorFixed(true);
	_minimizableList[cnt]->GetConversionFactor(59)->SetFactorValue(100.0/100000.0);
	_minimizableList[cnt]->SetRateConstantsWeight(0.0);
	// attach observer
	
	_plotterList.push_back(new GnuPlotterTimeSeriesObserver());
	_plotterList[cnt]->SetTitle("EGFR Trafficking Network:EGF at 100 ng/ml, wt1 (Carter 1998):ODE");
	_minimizableList[cnt]->Attach(_plotterList[cnt]);
	
	cnt++;

	// expt. 3 - NIH-3T3's transfected with wt EGFR; 2.75 X 10^5 receptors, EGF of
	//		100 ng/ml
	_networkList.push_back(new CEGFRTraffickingNetwork());
	_experimentList.push_back(new Experiment(_networkList[cnt],"EGF at 100 ng/ml wt2, Carter 1998"));
	// put data files here
	_experimentList[cnt]->AddDataFileToList("../DataFiles/TimeSeries/SurfaceEGFREGFwt2Carter.dat");
	_experimentList[cnt]->AddForcingFileToList("../DataFiles/TimeSeries/TwoHourEGF.dat");
	// mover and plotter
	//_moverList.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	_moverList.push_back(new CStiffBulirschStoerMover(frequency,stepSize,moveTol));
	// minimizable
	_minimizableList.push_back(new SingleNetworkMinimizable());
	// parameters
	_minimizableList[cnt]->Initialize(_experimentList[cnt],_moverList[cnt],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	_minimizableList[cnt]->GetConversionFactor(59)->SetFactorFixed(true);
	_minimizableList[cnt]->GetConversionFactor(59)->SetFactorValue(100.0/275000.0);
	_minimizableList[cnt]->SetRateConstantsWeight(0.0);
	// attach observer
	
	_plotterList.push_back(new GnuPlotterTimeSeriesObserver());
	_plotterList[cnt]->SetTitle("EGFR Trafficking Network:EGF at 100 ng/ml, wt2 (Carter 1998):ODE");
	_minimizableList[cnt]->Attach(_plotterList[cnt]);
	
	cnt++;
	
	// expt. 4 - NIH-3T3's with native EGFR (Jin's data). EGF of 100 ng/ml
	_networkList.push_back(new CEGFRTraffickingNetwork());
	_experimentList.push_back(new Experiment(_networkList[cnt],"EGF at 100 ng/ml (Wu 2002)"));
	// put data files here
	_experimentList[cnt]->AddDataFileToList("../DataFiles/TimeSeries/TotalEGFRWuVector.dat");
	_experimentList[cnt]->AddForcingFileToList("../DataFiles/TimeSeries/TwoHourEGF.dat");
	// mover and plotter
	//_moverList.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	_moverList.push_back(new CStiffBulirschStoerMover(frequency,stepSize,moveTol));
	// minimizable
	_minimizableList.push_back(new SingleNetworkMinimizable());
	// parameters
	_minimizableList[cnt]->Initialize(_experimentList[cnt],_moverList[cnt],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	_minimizableList[cnt]->GetConversionFactor(69)->SetFactorFixed(true);
	_minimizableList[cnt]->GetConversionFactor(69)->SetFactorValue(1.0/8000.0);
	_minimizableList[cnt]->SetRateConstantsWeight(0.0);
	// attach observer
	
	_plotterList.push_back(new GnuPlotterTimeSeriesObserver());
	_plotterList[cnt]->SetTitle("EGFR Trafficking Network:EGF at 100 ng/ml, Endogenous EGFR (Wu 2002):ODE");
	_minimizableList[cnt]->Attach(_plotterList[cnt]);
	
	cnt++;

	// expt. 4 - NIH-3T3's with native EGFR and stable F28L Cdc42 (Jin's data). 
	//		EGF of 100 ng/ml
	_networkList.push_back(new CEGFRTraffickingNetwork());
	_experimentList.push_back(new Experiment(_networkList[cnt],"EGF at 100 ng/ml, stable F28L (Wu 2002)"));
	// put data files here
	_experimentList[cnt]->AddDataFileToList("../DataFiles/TimeSeries/TotalEGFRWuF28L.dat");
	_experimentList[cnt]->AddForcingFileToList("../DataFiles/TimeSeries/TwoHourEGF.dat");
	// mover and plotter
	//_moverList.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	_moverList.push_back(new CStiffBulirschStoerMover(frequency,stepSize,moveTol));
	// minimizable
	_minimizableList.push_back(new SingleNetworkMinimizable());
	// parameters
	_minimizableList[cnt]->Initialize(_experimentList[cnt],_moverList[cnt],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	_minimizableList[cnt]->GetConversionFactor(69)->SetFactorFixed(true);
	_minimizableList[cnt]->GetConversionFactor(69)->SetFactorValue(1.0/8000.0);
	_minimizableList[cnt]->SetRateConstantsWeight(0.0);
	// attach observer
	
	_plotterList.push_back(new GnuPlotterTimeSeriesObserver());
	_plotterList[cnt]->SetTitle("EGFR Trafficking Network:EGF at 100 ng/ml, stable F28L (Wu 2002):ODE");
	_minimizableList[cnt]->Attach(_plotterList[cnt]);
	
	cnt++;

	// expt. 4 - NIH-3T3's with native EGFR and stable F28L/dL8 Cdc42 (Jin's data). 
	//		EGF of 100 ng/ml
	_networkList.push_back(new CEGFRTraffickingNetwork());
	_experimentList.push_back(new Experiment(_networkList[cnt],"EGF at 100 ng/ml, stable F28L/dL8 (Wu 2002)"));
	// put data files here
	_experimentList[cnt]->AddDataFileToList("../DataFiles/TimeSeries/TotalEGFRWuF28LdL8.dat");
	_experimentList[cnt]->AddForcingFileToList("../DataFiles/TimeSeries/TwoHourEGF.dat");
	// mover and plotter
	//_moverList.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	_moverList.push_back(new CStiffBulirschStoerMover(frequency,stepSize,moveTol));
	// minimizable
	_minimizableList.push_back(new SingleNetworkMinimizable());
	// parameters
	_minimizableList[cnt]->Initialize(_experimentList[cnt],_moverList[cnt],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	_minimizableList[cnt]->GetConversionFactor(69)->SetFactorFixed(true);
	_minimizableList[cnt]->GetConversionFactor(69)->SetFactorValue(1.0/8000.0);
	_minimizableList[cnt]->SetRateConstantsWeight(0.0);
	// attach observer
	
	_plotterList.push_back(new GnuPlotterTimeSeriesObserver());
	_plotterList[cnt]->SetTitle("EGFR Trafficking Network:EGF at 100 ng/ml, stable F28L/dL8 (Wu 2002):ODE");
	_minimizableList[cnt]->Attach(_plotterList[cnt]);
	
	cnt++;

	// parameters which need a prior
	//m_iPriorList.push_back(1);
	//m_iPriorList.push_back(2);
	//m_iPriorList.push_back(11);
	//m_iPriorList.push_back(24);

	// allocate the master residuals list
	int masterResidualsSize = 0;
	for(int i = 0; i < _minimizableList.size(); i++)
	{
		int subRes = _minimizableList[i]->GetNResiduals();
		masterResidualsSize += subRes;
		cout << subRes << " residuals in minimizable " << i << endl;
	}
	// add residuals for prior parameter costs, if applicable
	masterResidualsSize += m_iPriorList.size();
	cout << m_iPriorList.size() << " parameters are constrained by a prior " << endl;
	if(m_dGammaSquared > 0.0)
	{
		masterResidualsSize += 1;
	}
	Allocate(masterResidualsSize);

	cout << "Master Residuals size : " << masterResidualsSize << endl;

	// define the experiments
	DefineExperiments();

	//DumpResidualInfo();

}

CEGFRTraffickingNIH3T3MinimizableDirector::~CEGFRTraffickingNIH3T3MinimizableDirector()
{
	for(int i = 0; i < _plotterList.size(); i++)
	{
		_minimizableList[i]->Detach(_plotterList[i]);
		delete _plotterList[i];
	}
	m_iPriorList.erase(m_iPriorList.begin(),m_iPriorList.end());
}

void CEGFRTraffickingNIH3T3MinimizableDirector::DefineExperiments()
{	
	
	// 3T3 cells
	// 100,000 receptors, EGF at 100 nM
	_minimizableList[0]->GetExperiment()->GetReactionNetwork()->RemoveReaction(98);
	_minimizableList[0]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(7.2e+007);
	_minimizableList[0]->GetExperiment()->GetReactionNetwork()->GetChemical(3)->SetInitialAmount(10000);
	_minimizableList[0]->GetExperiment()->GetReactionNetwork()->GetChemical(4)->SetInitialAmount(90000);	
	_minimizableList[0]->GetExperiment()->GetReactionNetwork()->ChemicalReset();

	// No EGF, 20% of receptors on surface initially occupied
	_minimizableList[1]->GetExperiment()->GetReactionNetwork()->RemoveReaction(98);
	_minimizableList[1]->GetExperiment()->GetReactionNetwork()->GetChemical(3)->SetInitialAmount(10000.0);
	_minimizableList[1]->GetExperiment()->GetReactionNetwork()->GetChemical(4)->SetInitialAmount(70000.0);
	_minimizableList[1]->GetExperiment()->GetReactionNetwork()->GetChemical(5)->SetInitialAmount(10000.0);
	_minimizableList[1]->GetExperiment()->GetReactionNetwork()->GetChemical(6)->SetInitialAmount(10000.0);
	_minimizableList[1]->GetExperiment()->GetReactionNetwork()->ChemicalReset();

	// 100,000 receptors assumed, EGF at 100 ng/ml
	_minimizableList[2]->GetExperiment()->GetReactionNetwork()->RemoveReaction(98);
	_minimizableList[2]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(1.2e+007);
	_minimizableList[2]->GetExperiment()->GetReactionNetwork()->GetChemical(3)->SetInitialAmount(10000);
	_minimizableList[2]->GetExperiment()->GetReactionNetwork()->GetChemical(4)->SetInitialAmount(90000);
	_minimizableList[2]->GetExperiment()->GetReactionNetwork()->ChemicalReset();

	// 275,000 receptors assumed, EGF at 100 ng/ml
	_minimizableList[3]->GetExperiment()->GetReactionNetwork()->RemoveReaction(98);
	_minimizableList[3]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(1.2e+007);
	_minimizableList[3]->GetExperiment()->GetReactionNetwork()->GetChemical(3)->SetInitialAmount(10000);
	_minimizableList[3]->GetExperiment()->GetReactionNetwork()->GetChemical(4)->SetInitialAmount(265000);
	_minimizableList[3]->GetExperiment()->GetReactionNetwork()->ChemicalReset();
	
	// 8,000 receptors assumed, EGF at 100 ng/ml
	_minimizableList[4]->GetExperiment()->GetReactionNetwork()->RemoveReaction(98);
	_minimizableList[4]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(1.2e+007);
	_minimizableList[4]->GetExperiment()->GetReactionNetwork()->GetChemical(3)->SetInitialAmount(8000);
	_minimizableList[4]->GetExperiment()->GetReactionNetwork()->GetChemical(4)->SetInitialAmount(0.0);
	_minimizableList[4]->GetExperiment()->GetReactionNetwork()->ChemicalReset();

	// 8,000 receptors assumed, EGF at 100 ng/ml, F28L 42 5-fold overexpressed
	_minimizableList[5]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(0.0);
	_minimizableList[5]->GetExperiment()->GetReactionNetwork()->GetChemical(3)->SetInitialAmount(8000);
	_minimizableList[5]->GetExperiment()->GetReactionNetwork()->GetChemical(4)->SetInitialAmount(0.0);
	// start with overexpressed, all-active 42
	_minimizableList[5]->GetExperiment()->GetReactionNetwork()->GetChemical(47)->SetInitialAmount(0.0);
	_minimizableList[5]->GetExperiment()->GetReactionNetwork()->GetChemical(48)->SetInitialAmount(0.5*600000);
	_minimizableList[5]->GetExperiment()->GetReactionNetwork()->ChemicalReset();
	
	// 8,000 receptors assumed, EGF at 100 ng/ml, F28L/dL8 42 5-fold overexpressed
	_minimizableList[6]->GetExperiment()->GetReactionNetwork()->RemoveReaction(44);
	_minimizableList[6]->GetExperiment()->GetReactionNetwork()->RemoveReaction(42);
	_minimizableList[6]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(0.0);
	_minimizableList[6]->GetExperiment()->GetReactionNetwork()->GetChemical(3)->SetInitialAmount(8000);
	_minimizableList[6]->GetExperiment()->GetReactionNetwork()->GetChemical(4)->SetInitialAmount(0.0);
	// start with all 42 active
	_minimizableList[6]->GetExperiment()->GetReactionNetwork()->GetChemical(47)->SetInitialAmount(0.0);
	_minimizableList[6]->GetExperiment()->GetReactionNetwork()->GetChemical(48)->SetInitialAmount(0.5*600000);
	_minimizableList[6]->GetExperiment()->GetReactionNetwork()->ChemicalReset();
}

double CEGFRTraffickingNIH3T3MinimizableDirector::GetParameter(int parIndex)
{
	// for this director, everyone has the same parameters so any set 
	// can be returned
	//return _minimizableList[0]->GetParameter(parIndex);
	
	if(parIndex < _minimizableList[0]->GetNParameters())
	{
		return _minimizableList[0]->GetParameter(parIndex);
	}
}

int CEGFRTraffickingNIH3T3MinimizableDirector::GetNParameters()
{
	// ditto as for GetParameters()
	//return _minimizableList[0]->GetNParameters();

	// add in chemical concentrations being optimized
	return _minimizableList[0]->GetNParameters() + 8;
}

double CEGFRTraffickingNIH3T3MinimizableDirector::ComputeResiduals(double *parameters)
{
	int lastrc = _minimizableList[0]->GetNParameters();
	// set all the ICs first
	for(int i = 0; i < 5; i++)
	{
		_minimizableList[i]->GetExperiment()->GetReactionNetwork()->GetChemical(46)->SetInitialAmount(parameters[lastrc]);
		_minimizableList[i]->GetExperiment()->GetReactionNetwork()->GetChemical(47)->SetInitialAmount(parameters[lastrc+1]);
		_minimizableList[i]->GetExperiment()->GetReactionNetwork()->GetChemical(49)->SetInitialAmount(parameters[lastrc+2]);
		_minimizableList[i]->GetExperiment()->GetReactionNetwork()->GetChemical(53)->SetInitialAmount(parameters[lastrc+3]);
		_minimizableList[i]->GetExperiment()->GetReactionNetwork()->GetChemical(54)->SetInitialAmount(parameters[lastrc+4]);
		_minimizableList[i]->GetExperiment()->GetReactionNetwork()->GetChemical(55)->SetInitialAmount(parameters[lastrc+5]);
		_minimizableList[i]->GetExperiment()->GetReactionNetwork()->GetChemical(71)->SetInitialAmount(parameters[lastrc+6]);	
		_minimizableList[i]->GetExperiment()->GetReactionNetwork()->ChemicalReset();

	}
	for(i = 5; i < 7; i++)
	{
		double mult = 1.0 + parameters[lastrc + 7];
		_minimizableList[i]->GetExperiment()->GetReactionNetwork()->GetChemical(46)->SetInitialAmount(parameters[lastrc]);
		_minimizableList[i]->GetExperiment()->GetReactionNetwork()->GetChemical(47)->SetInitialAmount(0.0);
		_minimizableList[i]->GetExperiment()->GetReactionNetwork()->GetChemical(49)->SetInitialAmount(parameters[lastrc+2]);
		_minimizableList[i]->GetExperiment()->GetReactionNetwork()->GetChemical(53)->SetInitialAmount(parameters[lastrc+3]);
		_minimizableList[i]->GetExperiment()->GetReactionNetwork()->GetChemical(54)->SetInitialAmount(parameters[lastrc+4]);
		_minimizableList[i]->GetExperiment()->GetReactionNetwork()->GetChemical(55)->SetInitialAmount(parameters[lastrc+5]);
		_minimizableList[i]->GetExperiment()->GetReactionNetwork()->GetChemical(71)->SetInitialAmount(parameters[lastrc+6]);	
		_minimizableList[i]->GetExperiment()->GetReactionNetwork()->GetChemical(48)->SetInitialAmount(mult*parameters[lastrc+1]);
		_minimizableList[i]->GetExperiment()->GetReactionNetwork()->ChemicalReset();
	}

	// now fire away
	// just sum up the costs from each director and then add the 
	// integration penalty, = (gamma^2/2)*(sum_ti)^2
	double summedCost = 0.0;
	double timeCost = 0.0;
	double pcost = 0.0;
	
	// compute the residuals/cost from each minimizable
	for(int i = 0; i < _minimizableList.size(); i++)
	{
		summedCost += _minimizableList[i]->ObjectiveFunction(parameters);
	}
	
	// load up the master list with each set of residuals
	int nextResidual = 0;
	for(i = 0; i < _minimizableList.size(); i++)
	{
		int nRes = _minimizableList[i]->GetNResiduals();
		for(int j = 0; j < nRes; j++)
		{
			residuals[nextResidual+j] = (_minimizableList[i]->GetResiduals())[j];
		}
		nextResidual += nRes;
	}
	
	// now compute the cost for deviation from guessed values, if any
	for(i = 0; i < m_iPriorList.size(); i++)
	{
		int which = m_iPriorList[i];
		double presid = _networkList[0]->GetRateConstant(which)->GetValue() - _networkList[0]->GetRateConstant(which)->GetInitialValue();
		presid = presid/(sqrt(2.0)*_networkList[0]->GetRateConstant(which)->GetErrorInInitialValue());
		residuals[nextResidual + i] = presid;
		pcost += presid*presid;
	}
	nextResidual += m_iPriorList.size();
	
	// if the prefactor for the integration cost is > 0, compute its residual (otherwise
	// that residual shouldn't exist)
	if(m_dGammaSquared > 0.0)
	{
		double totalSteps = 0.0;
		for(int l = 0; l < _moverList.size(); l++)
		{
			totalSteps += _moverList[l]->GetTotalStepsTaken();
		}
		residuals[nResiduals - 1] = sqrt(m_dGammaSquared/2.0)*totalSteps;
		timeCost = residuals[nResiduals - 1]*residuals[nResiduals - 1];
	}
	return summedCost + pcost + timeCost;
}
