// EGFRTraffickingNetwork.cpp: implementation of the CEGFRTraffickingNetwork class.
//
//////////////////////////////////////////////////////////////////////

#include "EGFRTraffickingNetwork.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

CEGFRTraffickingNetwork::CEGFRTraffickingNetwork()
{
	// CFactor = #molecules/1 uM
	double CFactor = 600000;
	double SecPerMin = 60.0;

	// chemical species

	// EGF/EGFR
	// 0
	Chemical *EGF = new Chemical(chemicals.size(),0.0,"EGF");
	chemicals.push_back(EGF);

	Chemical *DegradedEGF = new Chemical(chemicals.size(),0.0,"DegradedEGF");
	chemicals.push_back(DegradedEGF);

	Chemical *EndosomalEGF = new Chemical(chemicals.size(),0.0,"EndosomalEGF");
	chemicals.push_back(EndosomalEGF);

	// two species of EGFR - coated pit and non coated pit
	Chemical *CPFreePMEGFR = new Chemical(chemicals.size(),0.0,"CPFreePMEGFR");
	chemicals.push_back(CPFreePMEGFR);

	Chemical *NonCPFreePMEGFR = new Chemical(chemicals.size(),0.0,"NonCPFreePMEGFR");
	chemicals.push_back(NonCPFreePMEGFR);

	Chemical *CPBoundPMEGFR = new Chemical(chemicals.size(),0.0,"CPBoundPMEGFR");
	chemicals.push_back(CPBoundPMEGFR);

	Chemical *NonCPBoundPMEGFR = new Chemical(chemicals.size(),0.0,"NonCPBoundPMEGFR");
	chemicals.push_back(NonCPBoundPMEGFR);
	
	Chemical *DegradedEGFR = new Chemical(chemicals.size(),0.0,"DegradedEGFR");
	chemicals.push_back(DegradedEGFR);

	Chemical *CPBoundPMEGFRCoolCbl = new Chemical(chemicals.size(),0.0,"CPBoundPMEGFRCoolCbl");
	chemicals.push_back(CPBoundPMEGFRCoolCbl);

	Chemical *NonCPBoundPMEGFRCoolCbl = new Chemical(chemicals.size(),0.0,"NonCPBoundPMEGFRCoolCbl");
	chemicals.push_back(NonCPBoundPMEGFRCoolCbl);

	// 10
	Chemical *CPBoundPMEGFRCoolCblActive = new Chemical(chemicals.size(),0.0,"CPBoundPMEGFRCoolCblActive");
	chemicals.push_back(CPBoundPMEGFRCoolCblActive);

	Chemical *NonCPBoundPMEGFRCoolCblActive = new Chemical(chemicals.size(),0.0,"NonCPBoundPMEGFRCoolCblActive");
	chemicals.push_back(NonCPBoundPMEGFRCoolCblActive);

	Chemical *UbiCPBoundPMEGFRCoolCblActive = new Chemical(chemicals.size(),0.0,"UbiCPBoundPMEGFRCoolCblActive");
	chemicals.push_back(UbiCPBoundPMEGFRCoolCblActive);

	Chemical *UbiNonCPBoundPMEGFRCoolCblActive = new Chemical(chemicals.size(),0.0,"UbiNonCPBoundPMEGFRCoolCblActive");
	chemicals.push_back(UbiNonCPBoundPMEGFRCoolCblActive);

	Chemical *NonCoatedBoundEGFR = new Chemical(chemicals.size(),0.0,"NonCoatedBoundEGFR");
	chemicals.push_back(NonCoatedBoundEGFR);

	Chemical *NonCoatedBoundEGFRCoolCblActive = new Chemical(chemicals.size(),0.0,"NonCoatedBoundEGFRCoolCblActive");
	chemicals.push_back(NonCoatedBoundEGFRCoolCblActive);

	Chemical *NonCoatedUbiBoundEGFRCoolCblActive = new Chemical(chemicals.size(),0.0,"NonCoatedUbiBoundEGFRCoolCblActive");
	chemicals.push_back(NonCoatedUbiBoundEGFRCoolCblActive);

	Chemical *ProtoCCVEGFR = new Chemical(chemicals.size(),0.0,"ProtoCCVEGFR");
	chemicals.push_back(ProtoCCVEGFR);

	Chemical *ProtoCCVEGFRCoolCblActive = new Chemical(chemicals.size(),0.0,"ProtoCCVEGFRCoolCblActive");
	chemicals.push_back(ProtoCCVEGFRCoolCblActive);

	Chemical *ProtoCCVUbiEGFRCoolCblActive = new Chemical(chemicals.size(),0.0,"ProtoCCVUbiEGFRCoolCblActive");
	chemicals.push_back(ProtoCCVUbiEGFRCoolCblActive);

	// 20
	Chemical *CCVEGFR = new Chemical(chemicals.size(),0.0,"CCVEGFR");
	chemicals.push_back(CCVEGFR);

	Chemical *CCVEGFRCoolCblActive = new Chemical(chemicals.size(),0.0,"CCVEGFRCoolCblActive");
	chemicals.push_back(CCVEGFRCoolCblActive);

	Chemical *CCVUbiEGFRCoolCblActive = new Chemical(chemicals.size(),0.0,"CCVUbiEGFRCoolCblActive");
	chemicals.push_back(CCVUbiEGFRCoolCblActive);

	Chemical *CCVEGFRACK2 = new Chemical(chemicals.size(),0.0,"CCVEGFRACK2");
	chemicals.push_back(CCVEGFRACK2);

	Chemical *CCVEGFRCoolCblActiveACK2 = new Chemical(chemicals.size(),0.0,"CCVEGFRCoolCblActiveACK2");
	chemicals.push_back(CCVEGFRCoolCblActiveACK2);

	Chemical *CCVUbiEGFRCoolCblActiveACK2 = new Chemical(chemicals.size(),0.0,"CCVUbiEGFRCoolCblActiveACK2");
	chemicals.push_back(CCVUbiEGFRCoolCblActiveACK2);

	Chemical *SortedEGFRACK2 = new Chemical(chemicals.size(),0.0,"SortedEGFRACK2");
	chemicals.push_back(SortedEGFRACK2);

	Chemical *SortedEGFRCoolCblActiveACK2 = new Chemical(chemicals.size(),0.0,"SortedEGFRCoolCblActiveACK2");
	chemicals.push_back(SortedEGFRCoolCblActiveACK2);

	Chemical *SortedUbiEGFRCoolCblActiveACK2 = new Chemical(chemicals.size(),0.0,"SortedUbiEGFRCoolCblActiveACK2");
	chemicals.push_back(SortedUbiEGFRCoolCblActiveACK2);

	Chemical *SortedEGFR = new Chemical(chemicals.size(),0.0,"SortedEGFR");
	chemicals.push_back(SortedEGFR);

	// 30
	Chemical *SortedEGFRCoolCblActive = new Chemical(chemicals.size(),0.0,"SortedEGFRCoolCblActive");
	chemicals.push_back(SortedEGFRCoolCblActive);

	Chemical *SortedUbiEGFRCoolCblActive = new Chemical(chemicals.size(),0.0,"SortedUbiEGFRCoolCblActive");
	chemicals.push_back(SortedUbiEGFRCoolCblActive);

	Chemical *BoundEndoEGFR = new Chemical(chemicals.size(),0.0,"BoundEndoEGFR");
	chemicals.push_back(BoundEndoEGFR);

	Chemical *UbiBoundEndoEGFR = new Chemical(chemicals.size(),0.0,"UbiBoundEndoEGFR");
	chemicals.push_back(UbiBoundEndoEGFR);

	Chemical *FreeEndoEGFR = new Chemical(chemicals.size(),0.0,"FreeEndoEGFR");
	chemicals.push_back(FreeEndoEGFR);

	Chemical *UbiFreeEndoEGFR = new Chemical(chemicals.size(),0.0,"UbiFreeEndoEGFR");
	chemicals.push_back(UbiFreeEndoEGFR);

	Chemical *BoundEndoEGFRCoolCblActive = new Chemical(chemicals.size(),0.0,"BoundEndoEGFRCoolCblActive");
	chemicals.push_back(BoundEndoEGFRCoolCblActive);

	Chemical *FreeEndoEGFRCoolCblActive = new Chemical(chemicals.size(),0.0,"FreeEndoEGFRCoolCblActive");
	chemicals.push_back(FreeEndoEGFRCoolCblActive);

	Chemical *UbiBoundEndoEGFRCoolCblActive = new Chemical(chemicals.size(),0.0,"UbiBoundEndoEGFRCoolCblActive");
	chemicals.push_back(UbiBoundEndoEGFRCoolCblActive);

	Chemical *UbiFreeEndoEGFRCoolCblActive = new Chemical(chemicals.size(),0.0,"UbiFreeEndoEGFRCoolCblActive");
	chemicals.push_back(UbiFreeEndoEGFRCoolCblActive);

	// 40
	Chemical *UbiFreeLysoEGFR = new Chemical(chemicals.size(),0.0,"UbiFreeLysoEGFR");
	chemicals.push_back(UbiFreeLysoEGFR);

	Chemical *COPIEndoFreeEGFR = new Chemical(chemicals.size(),0.0,"COPIEndoFreeEGFR");
	chemicals.push_back(COPIEndoFreeEGFR);

	Chemical *RecyclingVesicle = new Chemical(chemicals.size(),0.0,"RecyclingVesicle");
	chemicals.push_back(RecyclingVesicle);

	Chemical *RecycledVesicle = new Chemical(chemicals.size(),0.0,"RecycledVesicle");
	chemicals.push_back(RecycledVesicle);

	Chemical *VesicleCdc42GDP = new Chemical(chemicals.size(),0.0,"VesicleCdc42GDP");
	chemicals.push_back(VesicleCdc42GDP);

	Chemical *COPIPMFreeEGFR = new Chemical(chemicals.size(),0.0,"COPIPMFreeEGFR");
	chemicals.push_back(COPIPMFreeEGFR);

	Chemical *Cdc42GAP = new Chemical(chemicals.size(),0.1*CFactor,"Cdc42GAP");
	chemicals.push_back(Cdc42GAP);

	// Cdc42 alone
	Chemical *Cdc42GDP = new Chemical(chemicals.size(),0.1*CFactor,"Cdc42GDP");
	chemicals.push_back(Cdc42GDP);

	Chemical *Cdc42GTP = new Chemical(chemicals.size(),0.0,"Cdc42GTP");
	chemicals.push_back(Cdc42GTP);

	// ACK and 42
	Chemical *ACK2 = new Chemical(chemicals.size(),1200,"ACK2");
	chemicals.push_back(ACK2);

	// 50
	Chemical *ACK242GTP = new Chemical(chemicals.size(),0.0,"ACK242GTP");
	chemicals.push_back(ACK242GTP);

	Chemical *ACK2Active42GTP = new Chemical(chemicals.size(),0.0,"ACK2Active42GTP");
	chemicals.push_back(ACK2Active42GTP);

	Chemical *ACK2Active = new Chemical(chemicals.size(),0.0,"ACK2Active");
	chemicals.push_back(ACK2Active);

	Chemical *YPPTase1 = new Chemical(chemicals.size(),0.1*CFactor,"YPPTase1");
	chemicals.push_back(YPPTase1);

	// Free COP complex
	Chemical *COPI = new Chemical(chemicals.size(),0.1*CFactor,"COPI");
	chemicals.push_back(COPI);

	// Cool,Cbl,42
	Chemical *Cool1Cbl = new Chemical(chemicals.size(),0.1*CFactor,"Cool1Cbl");
	chemicals.push_back(Cool1Cbl);

	Chemical *Cool1CblActive = new Chemical(chemicals.size(),0.0,"Cool1CblActive");
	chemicals.push_back(Cool1CblActive);

	Chemical *Cool1Cbl42GTP = new Chemical(chemicals.size(),0.0,"Cool1Cbl42GTP");
	chemicals.push_back(Cool1Cbl42GTP);

	Chemical *Cool1CblActive42GTP = new Chemical(chemicals.size(),0.0,"Cool1CblActive42GTP");
	chemicals.push_back(Cool1CblActive42GTP);
		
	// 59
	std::vector<Chemical *> vec1;
	vec1.push_back(CPFreePMEGFR);
	vec1.push_back(NonCPFreePMEGFR);
	vec1.push_back(CPBoundPMEGFR);
	vec1.push_back(NonCPBoundPMEGFR);
	vec1.push_back(CPBoundPMEGFRCoolCbl);
	vec1.push_back(NonCPBoundPMEGFRCoolCbl);
	vec1.push_back(CPBoundPMEGFRCoolCblActive);
	vec1.push_back(NonCPBoundPMEGFRCoolCblActive);
	vec1.push_back(UbiCPBoundPMEGFRCoolCblActive);
	vec1.push_back(UbiNonCPBoundPMEGFRCoolCblActive);
	vec1.push_back(ProtoCCVEGFR);
	vec1.push_back(ProtoCCVEGFRCoolCblActive);
	vec1.push_back(ProtoCCVUbiEGFRCoolCblActive);
	vec1.push_back(COPIPMFreeEGFR);
	CAlgebraicChemical *TotalPMEGFR = new CSumChemical(chemicals.size(),"TotalPMEGFR",vec1);
	TotalPMEGFR->SetAll();
	chemicals.push_back(TotalPMEGFR);
	this->AddAlgebraicIndex(TotalPMEGFR);

	std::vector<Chemical *> vec1a;
	vec1a.push_back(CPBoundPMEGFR);
	vec1a.push_back(NonCPBoundPMEGFR);
	vec1a.push_back(CPBoundPMEGFRCoolCbl);
	vec1a.push_back(NonCPBoundPMEGFRCoolCbl);
	vec1a.push_back(CPBoundPMEGFRCoolCblActive);
	vec1a.push_back(NonCPBoundPMEGFRCoolCblActive);
	vec1a.push_back(UbiCPBoundPMEGFRCoolCblActive);
	vec1a.push_back(UbiNonCPBoundPMEGFRCoolCblActive);
	vec1a.push_back(ProtoCCVEGFR);
	vec1a.push_back(ProtoCCVEGFRCoolCblActive);
	vec1a.push_back(ProtoCCVUbiEGFRCoolCblActive);
	CAlgebraicChemical *TotalBoundPMEGFR = new CSumChemical(chemicals.size(),"TotalBoundPMEGFR",vec1a);
	TotalBoundPMEGFR->SetAll();
	chemicals.push_back(TotalBoundPMEGFR);
	this->AddAlgebraicIndex(TotalBoundPMEGFR);
	
	std::vector<Chemical *> vec2;
	vec2.push_back(CCVEGFR);
	vec2.push_back(CCVEGFRCoolCblActive);
	vec2.push_back(CCVUbiEGFRCoolCblActive);
	vec2.push_back(CCVEGFRACK2);
	vec2.push_back(CCVEGFRCoolCblActiveACK2);
	vec2.push_back(CCVUbiEGFRCoolCblActiveACK2);
	vec2.push_back(NonCoatedBoundEGFR);
	vec2.push_back(NonCoatedBoundEGFRCoolCblActive);
	vec2.push_back(NonCoatedUbiBoundEGFRCoolCblActive);
	vec2.push_back(SortedEGFRACK2);
	vec2.push_back(SortedEGFRCoolCblActiveACK2);
	vec2.push_back(SortedUbiEGFRCoolCblActiveACK2);
	vec2.push_back(SortedEGFR);
	vec2.push_back(SortedEGFRCoolCblActive);
	vec2.push_back(SortedUbiEGFRCoolCblActive);
	vec2.push_back(BoundEndoEGFR);
	vec2.push_back(BoundEndoEGFRCoolCblActive);
	vec2.push_back(UbiBoundEndoEGFR);
	vec2.push_back(UbiBoundEndoEGFRCoolCblActive);
	vec2.push_back(EndosomalEGF);
	CAlgebraicChemical *TotalInternalEGF = new CSumChemical(chemicals.size(),"TotalInternalEGF",vec2);
	TotalInternalEGF->SetAll();
	chemicals.push_back(TotalInternalEGF);
	this->AddAlgebraicIndex(TotalInternalEGF);

	// 62
	std::vector<Chemical *> vec3;
	vec3.push_back(CCVEGFR);
	vec3.push_back(CCVEGFRCoolCblActive);
	vec3.push_back(CCVUbiEGFRCoolCblActive);
	vec3.push_back(CCVEGFRACK2);
	vec3.push_back(CCVEGFRCoolCblActiveACK2);
	vec3.push_back(CCVUbiEGFRCoolCblActiveACK2);
	vec3.push_back(NonCoatedBoundEGFR);
	vec3.push_back(NonCoatedBoundEGFRCoolCblActive);
	vec3.push_back(NonCoatedUbiBoundEGFRCoolCblActive);
	vec3.push_back(SortedEGFRACK2);
	vec3.push_back(SortedEGFRCoolCblActiveACK2);
	vec3.push_back(SortedUbiEGFRCoolCblActiveACK2);
	vec3.push_back(SortedEGFR);
	vec3.push_back(SortedEGFRCoolCblActive);
	vec3.push_back(SortedUbiEGFRCoolCblActive);
	vec3.push_back(BoundEndoEGFR);
	vec3.push_back(UbiBoundEndoEGFR);
	vec3.push_back(BoundEndoEGFRCoolCblActive);
	vec3.push_back(UbiBoundEndoEGFRCoolCblActive);
	vec3.push_back(FreeEndoEGFR);
	vec3.push_back(UbiFreeEndoEGFR);
	vec3.push_back(FreeEndoEGFRCoolCblActive);
	vec3.push_back(UbiFreeEndoEGFRCoolCblActive);
	vec3.push_back(UbiFreeLysoEGFR);
	vec3.push_back(COPIEndoFreeEGFR);
	vec3.push_back(RecyclingVesicle);
	vec3.push_back(RecycledVesicle);
	vec3.push_back(VesicleCdc42GDP);
	CAlgebraicChemical *TotalInternalEGFR = new CSumChemical(chemicals.size(),"TotalInternalEGFR",vec3);
	TotalInternalEGFR->SetAll();
	chemicals.push_back(TotalInternalEGFR);
	this->AddAlgebraicIndex(TotalInternalEGFR);
	
	std::vector<Chemical *> vec4;
	vec4.push_back(CCVEGFR);
	vec4.push_back(CCVEGFRCoolCblActive);
	vec4.push_back(CCVUbiEGFRCoolCblActive);
	vec4.push_back(CCVEGFRACK2);
	vec4.push_back(CCVEGFRCoolCblActiveACK2);
	vec4.push_back(CCVUbiEGFRCoolCblActiveACK2);
	CAlgebraicChemical *TotalCCVEGFR = new CSumChemical(chemicals.size(),"TotalCCVEGFR",vec4);
	TotalCCVEGFR->SetAll();
	chemicals.push_back(TotalCCVEGFR);
	this->AddAlgebraicIndex(TotalCCVEGFR);

	std::vector<Chemical *> vec5;
	vec5.push_back(FreeEndoEGFR);
	vec5.push_back(UbiFreeEndoEGFR);
	vec5.push_back(FreeEndoEGFRCoolCblActive);
	vec5.push_back(UbiFreeEndoEGFRCoolCblActive);
	vec5.push_back(BoundEndoEGFR);
	vec5.push_back(UbiBoundEndoEGFR);
	vec5.push_back(BoundEndoEGFRCoolCblActive);
	vec5.push_back(UbiBoundEndoEGFRCoolCblActive);
	vec5.push_back(COPIEndoFreeEGFR);
	CAlgebraicChemical *TotalEndoEGFR = new CSumChemical(chemicals.size(),"TotalEndoEGFR",vec5);
	TotalEndoEGFR->SetAll();
	chemicals.push_back(TotalEndoEGFR);
	this->AddAlgebraicIndex(TotalEndoEGFR);


	Chemical *ACK242GDP= new Chemical(chemicals.size(),0.0,"ACK242GDP");
	chemicals.push_back(ACK242GDP);

	Chemical *ACK2Active42GDP = new Chemical(chemicals.size(),0.0,"ACK2Active42GDP");
	chemicals.push_back(ACK2Active42GDP);

	Chemical *Cool1Cbl42GDP = new Chemical(chemicals.size(),0.0,"Cool1Cbl42GDP");
	chemicals.push_back(Cool1Cbl42GDP);

	Chemical *Cool1CblActive42GDP = new Chemical(chemicals.size(),0.0,"Cool1CblActive42GDP");
	chemicals.push_back(Cool1CblActive42GDP);

	// 69
	std::vector<Chemical *> vec7;
	vec7.push_back(CPFreePMEGFR);
	vec7.push_back(NonCPFreePMEGFR);
	vec7.push_back(CPBoundPMEGFR);
	vec7.push_back(NonCPBoundPMEGFR);
	vec7.push_back(CPBoundPMEGFRCoolCbl);
	vec7.push_back(NonCPBoundPMEGFRCoolCbl);
	vec7.push_back(CPBoundPMEGFRCoolCblActive);
	vec7.push_back(NonCPBoundPMEGFRCoolCblActive);
	vec7.push_back(UbiCPBoundPMEGFRCoolCblActive);
	vec7.push_back(UbiNonCPBoundPMEGFRCoolCblActive);
	vec7.push_back(ProtoCCVEGFR);
	vec7.push_back(ProtoCCVEGFRCoolCblActive);
	vec7.push_back(ProtoCCVUbiEGFRCoolCblActive);
	vec7.push_back(CCVEGFR);
	vec7.push_back(CCVEGFRCoolCblActive);
	vec7.push_back(CCVUbiEGFRCoolCblActive);
	vec7.push_back(CCVEGFRACK2);
	vec7.push_back(CCVEGFRCoolCblActiveACK2);
	vec7.push_back(CCVUbiEGFRCoolCblActiveACK2);
	vec7.push_back(NonCoatedBoundEGFR);
	vec7.push_back(NonCoatedBoundEGFRCoolCblActive);
	vec7.push_back(NonCoatedUbiBoundEGFRCoolCblActive);
	vec7.push_back(SortedEGFRACK2);
	vec7.push_back(SortedEGFRCoolCblActiveACK2);
	vec7.push_back(SortedUbiEGFRCoolCblActiveACK2);
	vec7.push_back(SortedEGFR);
	vec7.push_back(SortedEGFRCoolCblActive);
	vec7.push_back(SortedUbiEGFRCoolCblActive);
	vec7.push_back(BoundEndoEGFR);
	vec7.push_back(UbiBoundEndoEGFR);
	vec7.push_back(BoundEndoEGFRCoolCblActive);
	vec7.push_back(UbiBoundEndoEGFRCoolCblActive);
	vec7.push_back(FreeEndoEGFR);
	vec7.push_back(UbiFreeEndoEGFR);
	vec7.push_back(FreeEndoEGFRCoolCblActive);
	vec7.push_back(UbiFreeEndoEGFRCoolCblActive);
	vec7.push_back(UbiFreeLysoEGFR);
	vec7.push_back(COPIEndoFreeEGFR);
	vec7.push_back(RecyclingVesicle);
	vec7.push_back(RecycledVesicle);
	vec7.push_back(VesicleCdc42GDP);
	vec7.push_back(COPIPMFreeEGFR);
	CAlgebraicChemical *TotalEGFR = new CSumChemical(chemicals.size(),"TotalEGFR",vec7);
	TotalEGFR->SetAll();
	chemicals.push_back(TotalEGFR);
	this->AddAlgebraicIndex(TotalEGFR);

	std::vector<Chemical *> vec8;
	vec8.push_back(UbiCPBoundPMEGFRCoolCblActive);
	vec8.push_back(UbiNonCPBoundPMEGFRCoolCblActive);
	vec8.push_back(ProtoCCVUbiEGFRCoolCblActive);
	vec8.push_back(CCVUbiEGFRCoolCblActive);
	vec8.push_back(CCVUbiEGFRCoolCblActiveACK2);
	vec8.push_back(SortedUbiEGFRCoolCblActiveACK2);
	vec8.push_back(SortedUbiEGFRCoolCblActive);
	vec8.push_back(UbiBoundEndoEGFRCoolCblActive);
	vec8.push_back(UbiFreeEndoEGFRCoolCblActive);
	vec8.push_back(UbiBoundEndoEGFR);
	vec8.push_back(UbiFreeEndoEGFR);
	vec8.push_back(UbiFreeLysoEGFR);
	CAlgebraicChemical *TotalUbiEGFR = new CSumChemical(chemicals.size(),"TotalUbiEGFR",vec8);
	TotalUbiEGFR->SetAll();
	chemicals.push_back(TotalUbiEGFR);
	this->AddAlgebraicIndex(TotalUbiEGFR);

	Chemical *AP2 = new Chemical(chemicals.size(),1200,"AP2");
	chemicals.push_back(AP2);

	std::vector<Chemical *> vec9;
	vec9.push_back(COPIEndoFreeEGFR);
	vec9.push_back(RecyclingVesicle);
	vec9.push_back(RecycledVesicle);
	vec9.push_back(VesicleCdc42GDP);
	vec9.push_back(COPIPMFreeEGFR);
	CAlgebraicChemical *TotalCOPIEGFR = new CSumChemical(chemicals.size(),"TotalCOPIEGFR",vec9);
	TotalCOPIEGFR->SetAll();
	chemicals.push_back(TotalCOPIEGFR);
	this->AddAlgebraicIndex(TotalCOPIEGFR);

	// rate constants
	// EGF binding/unbinding
	// 0
	RateConstant *kbEGF = new RateConstant(1.0e-07,"kbEGF");
	rateConstants.push_back(kbEGF);

	RateConstant *kuEGF = new RateConstant(0.02,0.02*0.2,"kuEGF");
	rateConstants.push_back(kuEGF);

	// EGF dissociation in endosomes
	RateConstant *kuEndoEGF = new RateConstant(0.1,0.1*0.2,"kuEndoEGF");
	rateConstants.push_back(kuEndoEGF);

	// 42 activation
	RateConstant *kEGFR42 = new RateConstant(0.2,"kEGFR42");
	rateConstants.push_back(kEGFR42);

	RateConstant *KmEGFR42 = new RateConstant(CFactor,"KmEGFR42");
	rateConstants.push_back(KmEGFR42);

	// Gapping of 42
	RateConstant *kGAP = new RateConstant(0.1,"kGAP");
	rateConstants.push_back(kGAP);

	RateConstant *KmGAP = new RateConstant(2.9*CFactor,"KmGAP");
	rateConstants.push_back(KmGAP);

	// binding/unbinding of AP-2
	RateConstant *kbAP2 = new RateConstant(1.0e-07,"kbAP2");
	rateConstants.push_back(kbAP2);

	RateConstant *kuAP2 = new RateConstant(0.02,"kuAP2");
	rateConstants.push_back(kuAP2);

	// allow possibility of different endocytic rates depending upon 
	// whether receptor is ubiquitinated or not 

	RateConstant *kEndo1 = new RateConstant(3.0,"kEndo1");
	rateConstants.push_back(kEndo1);
	
	// 10
	RateConstant *kEndo2 = new RateConstant(3.0,"kEndo2");
	rateConstants.push_back(kEndo2);

	RateConstant *kSlowEndo = new RateConstant(0.02,0.02*0.2,"kSlowEndo");
	rateConstants.push_back(kSlowEndo);

	// ACK2 binding/unbinding to 42

	RateConstant *kbACKActive = new RateConstant(1.0e-07,"kbACKActive");
	rateConstants.push_back(kbACKActive);

	RateConstant *kuACKActive = new RateConstant(0.02,"kuACKActive");
	rateConstants.push_back(kuACKActive);

	RateConstant *kbACK2 = new RateConstant(1.0e-07,"kbACK2");
	rateConstants.push_back(kbACK2);

	RateConstant *kuACK2 = new RateConstant(0.02,"kuACK2");
	rateConstants.push_back(kuACK2);

	RateConstant *kuACK242GDP = new RateConstant(0.1,"kuACK242GDP");
	rateConstants.push_back(kuACK242GDP);

	RateConstant *kuACK2Active42GDP = new RateConstant(0.1,"kuACK2Active42GDP");
	rateConstants.push_back(kuACK2Active42GDP);
	
	// ACK2 activation
	
	RateConstant *kACK2 = new RateConstant(5.0,"kACK2");
	rateConstants.push_back(kACK2);

	// ACK2 dephosphorylation by PPtase

	RateConstant *kdACK2 = new RateConstant(0.1,"kdACK2");
	rateConstants.push_back(kdACK2);

	RateConstant *KmdACK2 = new RateConstant(CFactor,"KmdACK2");
	rateConstants.push_back(KmdACK2);

	// ACK2 binding/unbinding to the CCV

	RateConstant *kbACK2CCV = new RateConstant(1.0e-07,"kbACK2CCV");
	rateConstants.push_back(kbACK2CCV);

	RateConstant *kuACK2CCV = new RateConstant(0.02,"kuACK2CCV");
	rateConstants.push_back(kuACK2CCV);

	// Sorting of ACK-bound CCVs

	RateConstant *kSort = new RateConstant(1.5,"kSort");
	rateConstants.push_back(kSort);

	// Sorting of non clathrin-coated vesicles
	RateConstant *kSlowSort = new RateConstant(0.05,0.05*0.2,"kSlowSort");
	rateConstants.push_back(kSlowSort);

	// Endosomal to lysosomal transfer

	RateConstant *kEndoLyso = new RateConstant(1.5,"kEndoLyso");
	rateConstants.push_back(kEndoLyso);

	// Degradation of EGF

	RateConstant *kdegEGF = new RateConstant(0.25,"kdegEGF");
	rateConstants.push_back(kdegEGF);

	// Proteolysis of EGFR

	RateConstant *kProt = new RateConstant(2.5,"kProt");
	rateConstants.push_back(kProt);

	// Cbl binding to the receptor
	
	RateConstant *kbCbl = new RateConstant(1.0e-07,"kbCbl");
	rateConstants.push_back(kbCbl);

	// Cbl unbinding from a ubiquitinated receptor
	
	RateConstant *kuCblUbi = new RateConstant(1.0e-02,"kuCblUbi");
	rateConstants.push_back(kuCblUbi);

	// Cbl when bound to EGF receptor - activation and ubiquitination

	RateConstant *kCbl = new RateConstant(5.0,"kCbl");
	rateConstants.push_back(kCbl);

	RateConstant *kUbi = new RateConstant(5.0,"kUbi");
	rateConstants.push_back(kUbi);

	// Cool/Cbl and 42 binding/unbinding

	RateConstant *kbCbl42 = new RateConstant(1.0e-07,"kbCbl42");
	rateConstants.push_back(kbCbl42);

	RateConstant *kuCbl42 = new RateConstant(0.02,"kuCbl42");
	rateConstants.push_back(kuCbl42);

	RateConstant *kbCblActive42 = new RateConstant(1.0e-07,"kbCblActive42");
	rateConstants.push_back(kbCblActive42);

	RateConstant *kuCblActive42 = new RateConstant(0.02,"kuCblActive42");
	rateConstants.push_back(kuCblActive42);

	RateConstant *kuCool1Cbl42GDP = new RateConstant(0.1,"kuCool1Cbl42GDP");
	rateConstants.push_back(kuCool1Cbl42GDP);

	RateConstant *kuCool1CblActive42GDP = new RateConstant(0.1,"kuCool1CblActive42GDP");
	rateConstants.push_back(kuCool1CblActive42GDP);

	// COPI binding to EGFR

	RateConstant *kbCOPI = new RateConstant(1.0e-07,"kbCOPI");
	rateConstants.push_back(kbCOPI);

	// Active 42 binding to recycling vesicle

	RateConstant *kb42COPI = new RateConstant(2.0e-07,"kb42COPI");
	rateConstants.push_back(kb42COPI);

	// Inactive 42 unbinding

	RateConstant *ku42COPI = new RateConstant(0.02,"ku42COPI");
	rateConstants.push_back(ku42COPI);

	// COPI unbinding from recycled vesicle

	RateConstant *kuCOPI = new RateConstant(0.02,"kuCOPI");
	rateConstants.push_back(kuCOPI);

	// COPI-mediated recycling

	RateConstant *kRec = new RateConstant(0.5,"kRec");
	rateConstants.push_back(kRec);

	// rapid recyling from non-clathrin coated pathway

	RateConstant *kFastRec = new RateConstant(2.0,"kFastRec");
	rateConstants.push_back(kFastRec);

	// autoactivation of F28

	RateConstant *kF28 = new RateConstant(10.0,"kF28");
	rateConstants.push_back(kF28);

	// transition parameters between the two pools
	RateConstant *k12 = new RateConstant(0.1,"k12");
	rateConstants.push_back(k12);

	RateConstant *k21 = new RateConstant(0.01,"k21");
	rateConstants.push_back(k21);

	RateConstant *K = new RateConstant(10000,"K");
	rateConstants.push_back(K);


	// reactions
	// 0
	// EGF binding/unbinding
	Reaction *EGFBinding1 = new ReceptorBindingReaction(EGF,CPFreePMEGFR,CPBoundPMEGFR,kbEGF,"EGFBinding1");
	reactions.push_back(EGFBinding1);

	Reaction *EGFBinding2 = new ReceptorBindingReaction(EGF,NonCPFreePMEGFR,NonCPBoundPMEGFR,kbEGF,"EGFBinding2");
	reactions.push_back(EGFBinding2);

	Reaction *EGFUnbinding1 = new ReceptorUnbindingReaction(CPBoundPMEGFR,CPFreePMEGFR,EGF,kuEGF,"EGFUnbinding1");
	reactions.push_back(EGFUnbinding1);

	Reaction *EGFUnbinding2 = new ReceptorUnbindingReaction(NonCPBoundPMEGFR,NonCPFreePMEGFR,EGF,kuEGF,"EGFUnbinding2");
	reactions.push_back(EGFUnbinding2);

	// transitions between the two pools
	Reaction *CPToNonCP1 = new TransformationReaction(CPFreePMEGFR,NonCPFreePMEGFR,k21,"CPToNonCP1");
	reactions.push_back(CPToNonCP1);

	Reaction *CPToNonCP2 = new TransformationReaction(CPBoundPMEGFR,NonCPBoundPMEGFR,k21,"CPToNonCP2");
	reactions.push_back(CPToNonCP2);
	
	Reaction *CPToNonCP3 = new TransformationReaction(CPBoundPMEGFRCoolCbl,NonCPBoundPMEGFRCoolCbl,k21,"CPToNonCP3");
	reactions.push_back(CPToNonCP3);
	
	Reaction *CPToNonCP4 = new TransformationReaction(CPBoundPMEGFRCoolCblActive,NonCPBoundPMEGFRCoolCblActive,k21,"CPToNonCP4");
	reactions.push_back(CPToNonCP4);

	Reaction *CPToNonCP5 = new TransformationReaction(UbiCPBoundPMEGFRCoolCblActive,UbiNonCPBoundPMEGFRCoolCblActive,k21,"CPToNonCP5");
	reactions.push_back(CPToNonCP5);
	
	// transitions between the two pools
	Reaction *NonCPToCP1 = new CPoolTransitionReaction(NonCPFreePMEGFR,CPFreePMEGFR,k12,K,"NonCPToCP1");
	reactions.push_back(NonCPToCP1);

	// 10
	Reaction *NonCPToCP2 = new CPoolTransitionReaction(NonCPBoundPMEGFR,CPBoundPMEGFR,k12,K,"NonCPToCP2");
	reactions.push_back(NonCPToCP2);
	
	Reaction *NonCPToCP3 = new CPoolTransitionReaction(NonCPBoundPMEGFRCoolCbl,CPBoundPMEGFRCoolCbl,k12,K,"NonCPToCP3");
	reactions.push_back(NonCPToCP3);
	
	Reaction *NonCPToCP4 = new CPoolTransitionReaction(NonCPBoundPMEGFRCoolCblActive,CPBoundPMEGFRCoolCblActive,k12,K,"NonCPToCP4");
	reactions.push_back(NonCPToCP4);

	Reaction *NonCPToCP5 = new CPoolTransitionReaction(UbiNonCPBoundPMEGFRCoolCblActive,UbiCPBoundPMEGFRCoolCblActive,k12,K,"NonCPToCP5");
	reactions.push_back(NonCPToCP5);


	// 42 activation

	Reaction *Cdc42PMActivation1 = new MichaelisMentenGProteinActivationReaction(CPBoundPMEGFR,Cdc42GDP,Cdc42GTP,kEGFR42,KmEGFR42,"Cdc42PMActivation1");
	reactions.push_back(Cdc42PMActivation1);

	Reaction *Cdc42PMActivation2 = new MichaelisMentenGProteinActivationReaction(CPBoundPMEGFRCoolCbl,Cdc42GDP,Cdc42GTP,kEGFR42,KmEGFR42,"Cdc42PMActivation2");
	reactions.push_back(Cdc42PMActivation2);

	Reaction *Cdc42PMActivation3 = new MichaelisMentenGProteinActivationReaction(CPBoundPMEGFRCoolCblActive,Cdc42GDP,Cdc42GTP,kEGFR42,KmEGFR42,"Cdc42PMActivation3");
	reactions.push_back(Cdc42PMActivation3);

	Reaction *Cdc42PMActivation4 = new MichaelisMentenGProteinActivationReaction(UbiCPBoundPMEGFRCoolCblActive,Cdc42GDP,Cdc42GTP,kEGFR42,KmEGFR42,"Cdc42PMActivation4");
	reactions.push_back(Cdc42PMActivation4);

	Reaction *Cdc42PMActivation5 = new MichaelisMentenGProteinActivationReaction(NonCPBoundPMEGFR,Cdc42GDP,Cdc42GTP,kEGFR42,KmEGFR42,"Cdc42PMActivation5");
	reactions.push_back(Cdc42PMActivation5);

	Reaction *Cdc42PMActivation6 = new MichaelisMentenGProteinActivationReaction(NonCPBoundPMEGFRCoolCbl,Cdc42GDP,Cdc42GTP,kEGFR42,KmEGFR42,"Cdc42PMActivation6");
	reactions.push_back(Cdc42PMActivation6);

	// 20
	Reaction *Cdc42PMActivation7 = new MichaelisMentenGProteinActivationReaction(NonCPBoundPMEGFRCoolCblActive,Cdc42GDP,Cdc42GTP,kEGFR42,KmEGFR42,"Cdc42PMActivation7");
	reactions.push_back(Cdc42PMActivation7);

	Reaction *Cdc42PMActivation8 = new MichaelisMentenGProteinActivationReaction(UbiNonCPBoundPMEGFRCoolCblActive,Cdc42GDP,Cdc42GTP,kEGFR42,KmEGFR42,"Cdc42PMActivation8");
	reactions.push_back(Cdc42PMActivation8);


	// gapping of free 42

	Reaction *Cdc42GAPHydrolysis = new MichaelisMentenGProteinActivationReaction(Cdc42GAP,Cdc42GTP,Cdc42GDP,kGAP,KmGAP,"Cdc42GAPHydrolysis");
	reactions.push_back(Cdc42GAPHydrolysis);

	// assembly of proto CCV
	Reaction *Proto1 = new HeterodimerizationReaction(CPBoundPMEGFR,AP2,ProtoCCVEGFR,kbAP2,"Proto1");
	reactions.push_back(Proto1);

	Reaction *Proto2 = new HeterodimerizationReaction(CPBoundPMEGFRCoolCblActive,AP2,ProtoCCVEGFRCoolCblActive,kbAP2,"Proto2");
	reactions.push_back(Proto2);

	Reaction *Proto3 = new HeterodimerizationReaction(UbiCPBoundPMEGFRCoolCblActive,AP2,ProtoCCVUbiEGFRCoolCblActive,kbAP2,"Proto3");
	reactions.push_back(Proto3);

	// endocytosis
	Reaction *Endocytosis1 = new TransformationReaction(ProtoCCVEGFR,CCVEGFR,kEndo1,"Endocytosis1");
	reactions.push_back(Endocytosis1);

	Reaction *Endocytosis2 = new TransformationReaction(ProtoCCVEGFRCoolCblActive,CCVEGFRCoolCblActive,kEndo1,"Endocytosis2");
	reactions.push_back(Endocytosis2);

	Reaction *Endocytosis3 = new TransformationReaction(ProtoCCVUbiEGFRCoolCblActive,CCVUbiEGFRCoolCblActive,kEndo2,"Endocytosis3");
	reactions.push_back(Endocytosis3);

	Reaction *SlowEndo1 = new TransformationReaction(NonCPBoundPMEGFR,NonCoatedBoundEGFR,kSlowEndo,"SlowEndo1");
	reactions.push_back(SlowEndo1);

	// 30
	Reaction *SlowEndo2 = new TransformationReaction(NonCPBoundPMEGFRCoolCblActive,NonCoatedBoundEGFRCoolCblActive,kSlowEndo,"SlowEndo1");
	reactions.push_back(SlowEndo2);

	Reaction *SlowEndo3 = new TransformationReaction(UbiNonCPBoundPMEGFRCoolCblActive,NonCoatedUbiBoundEGFRCoolCblActive,kSlowEndo,"SlowEndo3");
	reactions.push_back(SlowEndo3);

	// ACK2 and 42 cycle
	Reaction *ACK42Binding = new HeterodimerizationReaction(ACK2,Cdc42GTP,ACK242GTP,kbACK2,"ACK42Binding");
	reactions.push_back(ACK42Binding);

	Reaction *ACK42Unbinding = new HeterodimerDissociationReaction(ACK242GTP,ACK2,Cdc42GTP,kuACK2,"ACK42Unbinding");
	reactions.push_back(ACK42Unbinding);

	Reaction *ACK2Active42Binding = new HeterodimerizationReaction(ACK2Active,Cdc42GTP,ACK2Active42GTP,kbACKActive,"ACK2Active42Binding");
	reactions.push_back(ACK2Active42Binding);

	Reaction *ACK2Active42Unbinding = new HeterodimerDissociationReaction(ACK2Active42GTP,ACK2Active,Cdc42GTP,kuACKActive,"ACK2Active42Unbinding");
	reactions.push_back(ACK2Active42Unbinding);

	Reaction *ACK2Activation = new TransformationReaction(ACK242GTP,ACK2Active42GTP,kACK2,"ACK2Activation");
	reactions.push_back(ACK2Activation);

	Reaction *ACK2Deactivation = new MichaelisMentenDephosphorylationReaction(YPPTase1,ACK2Active,ACK2,kdACK2,KmdACK2,"ACK2Deactivation");
	reactions.push_back(ACK2Deactivation);

	Reaction *ACK242GAPing = new MichaelisMentenGProteinDeactivationReaction(Cdc42GAP,ACK242GTP,ACK242GDP,kGAP,KmGAP,"ACK242GAPing");
	reactions.push_back(ACK242GAPing);

	Reaction *ACK2Active42GAPing = new MichaelisMentenGProteinDeactivationReaction(Cdc42GAP,ACK2Active42GTP,ACK2Active42GDP,kGAP,KmGAP,"ACK2Active42GAPing");
	reactions.push_back(ACK2Active42GAPing);

	// 40
	Reaction *ACK242GDPRelease = new HeterodimerDissociationReaction(ACK242GDP,ACK2,Cdc42GDP,kuACK242GDP,"ACK242GDPRelease");
	reactions.push_back(ACK242GDPRelease);

	Reaction *ACK2Active42GDPRelease = new HeterodimerDissociationReaction(ACK2Active42GDP,ACK2Active,Cdc42GDP,kuACK2Active42GDP,"ACK2Active42GDPRelease");
	reactions.push_back(ACK2Active42GDPRelease);

	// Cool/Cbl and 42 cycle
	Reaction *CoolCbl42Binding = new HeterodimerizationReaction(Cool1Cbl,Cdc42GTP,Cool1Cbl42GTP,kbCbl42,"CoolCbl42Binding");
	reactions.push_back(CoolCbl42Binding);

	Reaction *CoolCbl42Unbinding = new HeterodimerDissociationReaction(Cool1Cbl42GTP,Cool1Cbl,Cdc42GTP,kuCbl42,"CoolCbl42Unbinding");
	reactions.push_back(CoolCbl42Unbinding);

	Reaction *CoolCblActive42Binding = new HeterodimerizationReaction(Cool1CblActive,Cdc42GTP,Cool1CblActive42GTP,kbCblActive42,"CoolCblActive42Binding");
	reactions.push_back(CoolCblActive42Binding);

	Reaction *CoolCblActive42Unbinding = new HeterodimerDissociationReaction(Cool1CblActive42GTP,Cool1CblActive,Cdc42GTP,kuCblActive42,"CoolCblActive42Unbinding");
	reactions.push_back(CoolCblActive42Unbinding);

	Reaction *CoolCbl42GAPing = new MichaelisMentenGProteinDeactivationReaction(Cdc42GAP,Cool1Cbl42GTP,Cool1Cbl42GDP,kGAP,KmGAP,"CoolCbl42GAPing");
	reactions.push_back(CoolCbl42GAPing);

	Reaction *CoolCblActive42GAPing = new MichaelisMentenGProteinDeactivationReaction(Cdc42GAP,Cool1CblActive42GTP,Cool1CblActive42GDP,kGAP,KmGAP,"CoolCblActive42GAPing");
	reactions.push_back(CoolCblActive42GAPing);

	Reaction *CoolCbl42GDPRelease = new HeterodimerDissociationReaction(Cool1Cbl42GDP,Cool1Cbl,Cdc42GDP,kuCool1Cbl42GDP,"CoolCbl42GDPRelease");
	reactions.push_back(CoolCbl42GDPRelease);
	
	Reaction *CoolCblActive42GDPRelease = new HeterodimerDissociationReaction(Cool1CblActive42GDP,Cool1CblActive,Cdc42GDP,kuCool1CblActive42GDP,"CoolCblActive42GDPRelease");
	reactions.push_back(CoolCblActive42GDPRelease);

	// sorting

	// 50
	Reaction *ACKBinding1 = new HeterodimerizationReaction(ACK2Active,CCVEGFR,CCVEGFRACK2,kbACK2CCV,"ACKBinding1");
	reactions.push_back(ACKBinding1);

	Reaction *ACKBinding2 = new HeterodimerizationReaction(ACK2Active,CCVEGFRCoolCblActive,CCVEGFRCoolCblActiveACK2,kbACK2CCV,"ACKBinding2");
	reactions.push_back(ACKBinding2);
	
	Reaction *ACKBinding3 = new HeterodimerizationReaction(ACK2Active,CCVUbiEGFRCoolCblActive,CCVUbiEGFRCoolCblActiveACK2,kbACK2CCV,"ACKBinding3");
	reactions.push_back(ACKBinding3);

	Reaction *Sorting1 = new TransformationReaction(CCVEGFRACK2,SortedEGFRACK2,kSort,"Sorting1");
	reactions.push_back(Sorting1);

	Reaction *Sorting2 = new TransformationReaction(CCVEGFRCoolCblActiveACK2,SortedEGFRCoolCblActiveACK2,kSort,"Sorting2");
	reactions.push_back(Sorting2);

	Reaction *Sorting3 = new TransformationReaction(CCVUbiEGFRCoolCblActiveACK2,SortedUbiEGFRCoolCblActiveACK2,kSort,"Sorting3");
	reactions.push_back(Sorting3);

	Reaction *ACKRelease1 = new HeterodimerDissociationReaction(SortedEGFRACK2,SortedEGFR,ACK2Active,kuACK2CCV,"ACKRelease1");
	reactions.push_back(ACKRelease1);

	Reaction *ACKRelease2 = new HeterodimerDissociationReaction(SortedEGFRCoolCblActiveACK2,SortedEGFRCoolCblActive,ACK2Active,kuACK2CCV,"ACKRelease2");
	reactions.push_back(ACKRelease2);

	Reaction *ACKRelease3 = new HeterodimerDissociationReaction(SortedUbiEGFRCoolCblActiveACK2,SortedUbiEGFRCoolCblActive,ACK2Active,kuACK2CCV,"ACKRelease3");
	reactions.push_back(ACKRelease3);

	Reaction *SlowSort1 = new TransformationReaction(NonCoatedBoundEGFR,BoundEndoEGFR,kSlowSort,"SlowSort1");
	reactions.push_back(SlowSort1);

	// 60
	Reaction *SlowSort2 = new TransformationReaction(NonCoatedBoundEGFRCoolCblActive,BoundEndoEGFRCoolCblActive,kSlowSort,"SlowSort2");
	reactions.push_back(SlowSort2);

	Reaction *SlowSort3 = new TransformationReaction(NonCoatedUbiBoundEGFRCoolCblActive,UbiBoundEndoEGFRCoolCblActive,kSlowSort,"SlowSort3");
	reactions.push_back(SlowSort3);

	// fusion with endosome, AP2 release
	Reaction *EndoFusion1 = new HeterodimerDissociationReaction(SortedEGFR,BoundEndoEGFR,AP2,kuAP2,"EndoFusion1");
	reactions.push_back(EndoFusion1);

	Reaction *EndoFusion2 = new HeterodimerDissociationReaction(SortedEGFRCoolCblActive,BoundEndoEGFRCoolCblActive,AP2,kuAP2,"EndoFusion2");
	reactions.push_back(EndoFusion2);

	Reaction *EndoFusion3 = new HeterodimerDissociationReaction(SortedUbiEGFRCoolCblActive,UbiBoundEndoEGFRCoolCblActive,AP2,kuAP2,"EndoFusion3");
	reactions.push_back(EndoFusion3);

	// Transfer to lysosomes

	Reaction *LysosomalTransfer = new TransformationReaction(UbiFreeEndoEGFR,UbiFreeLysoEGFR,kEndoLyso,"LysosomalTransfer");
	reactions.push_back(LysosomalTransfer);

	// EGF dissociation/degradation in endosomes
	Reaction *EGFDissociation1 = new ReceptorUnbindingReaction(BoundEndoEGFR,FreeEndoEGFR,EndosomalEGF,kuEndoEGF,"EGFDissociation1");
	reactions.push_back(EGFDissociation1);

	Reaction *EGFDissociation2 = new ReceptorUnbindingReaction(UbiBoundEndoEGFR,UbiFreeEndoEGFR,EndosomalEGF,kuEndoEGF,"EGFDissociation2");
	reactions.push_back(EGFDissociation2);

	Reaction *EGFDissociation3 = new ReceptorUnbindingReaction(BoundEndoEGFRCoolCblActive,FreeEndoEGFRCoolCblActive,EndosomalEGF,kuEndoEGF,"EGFDissociation3");
	reactions.push_back(EGFDissociation3);

	Reaction *EGFDissociation4 = new ReceptorUnbindingReaction(UbiBoundEndoEGFRCoolCblActive,UbiFreeEndoEGFRCoolCblActive,EndosomalEGF,kuEndoEGF,"EGFDissociation4");
	reactions.push_back(EGFDissociation4);

	// 70
	Reaction *LigandDegradation = new TransformationReaction(EndosomalEGF,DegradedEGF,kdegEGF,"EGFDegradation");
	reactions.push_back(LigandDegradation);

	// CoolCbl binding to receptor
	Reaction *EGFRCoolCblBinding1 = new HeterodimerizationReaction(CPBoundPMEGFR,Cool1Cbl,CPBoundPMEGFRCoolCbl,kbCbl,"InactiveCblBinding1");
	reactions.push_back(EGFRCoolCblBinding1);

	Reaction *EGFRCoolCblBinding2 = new HeterodimerizationReaction(NonCPBoundPMEGFR,Cool1Cbl,NonCPBoundPMEGFRCoolCbl,kbCbl,"InactiveCblBinding2");
	reactions.push_back(EGFRCoolCblBinding2);

	Reaction *EGFRCoolCblActiveBinding1 = new HeterodimerizationReaction(CPBoundPMEGFR,Cool1CblActive,CPBoundPMEGFRCoolCblActive,kbCbl,"ActiveCblBinding1");
	reactions.push_back(EGFRCoolCblActiveBinding1);

	Reaction *EGFRCoolCblActiveBinding2 = new HeterodimerizationReaction(NonCPBoundPMEGFR,Cool1CblActive,NonCPBoundPMEGFRCoolCblActive,kbCbl,"ActiveCblBinding2");
	reactions.push_back(EGFRCoolCblActiveBinding2);

	Reaction *EndoCoolCblActiveBinding = new HeterodimerizationReaction(BoundEndoEGFR,Cool1CblActive,BoundEndoEGFRCoolCblActive,kbCbl,"EndoActiveCblBinding");
	reactions.push_back(EndoCoolCblActiveBinding);

	// CoolCbl phosphorylation
	Reaction *EGFRCoolCblActivation1 = new TransformationReaction(CPBoundPMEGFRCoolCbl,CPBoundPMEGFRCoolCblActive,kCbl,"EGFRCoolCblActivation1");
	reactions.push_back(EGFRCoolCblActivation1);

	Reaction *EGFRCoolCblActivation2 = new TransformationReaction(NonCPBoundPMEGFRCoolCbl,NonCPBoundPMEGFRCoolCblActive,kCbl,"EGFRCoolCblActivation2");
	reactions.push_back(EGFRCoolCblActivation2);

	// ubiquitination 
	Reaction *MembraneUbi1 = new TransformationReaction(CPBoundPMEGFRCoolCblActive,UbiCPBoundPMEGFRCoolCblActive,kUbi,"MembraneUbi1");
	reactions.push_back(MembraneUbi1);

	Reaction *MembraneUbi2 = new TransformationReaction(NonCPBoundPMEGFRCoolCblActive,UbiNonCPBoundPMEGFRCoolCblActive,kUbi,"MembraneUbi2");
	reactions.push_back(MembraneUbi2);

	// 80
	Reaction *ProtoUbi = new TransformationReaction(ProtoCCVEGFRCoolCblActive,ProtoCCVUbiEGFRCoolCblActive,kUbi,"ProtoUbi");
	reactions.push_back(ProtoUbi);

	Reaction *VesicleUbi = new TransformationReaction(CCVEGFRCoolCblActive,CCVUbiEGFRCoolCblActive,kUbi,"VesicleUbi");
	reactions.push_back(VesicleUbi);

	Reaction *VesicleUbi2 = new TransformationReaction(CCVEGFRCoolCblActiveACK2,CCVUbiEGFRCoolCblActiveACK2,kUbi,"VesicleUbi2");
	reactions.push_back(VesicleUbi2);

	Reaction *SortedUbi1 = new TransformationReaction(SortedEGFRCoolCblActiveACK2,SortedUbiEGFRCoolCblActiveACK2,kUbi,"SortedUbi1");
	reactions.push_back(SortedUbi1);

	Reaction *SortedUbi2 = new TransformationReaction(SortedEGFRCoolCblActive,SortedUbiEGFRCoolCblActive,kUbi,"SortedUbi2");
	reactions.push_back(SortedUbi2);

	Reaction *NonCoatedUbi = new TransformationReaction(NonCoatedBoundEGFRCoolCblActive,NonCoatedUbiBoundEGFRCoolCblActive,kUbi,"NonCoatedUbi");
	reactions.push_back(NonCoatedUbi);

	Reaction *EndoUbi1 = new TransformationReaction(BoundEndoEGFRCoolCblActive,UbiBoundEndoEGFRCoolCblActive,kUbi,"EndoUbi1");
	reactions.push_back(EndoUbi1);

	Reaction *EndoUbi2 = new TransformationReaction(FreeEndoEGFRCoolCblActive,UbiFreeEndoEGFRCoolCblActive,kUbi,"EndoUbi2");
	reactions.push_back(EndoUbi2);

	// CoolCbl release

	Reaction *CoolCblDissociation1 = new HeterodimerDissociationReaction(UbiBoundEndoEGFRCoolCblActive,UbiBoundEndoEGFR,Cool1CblActive,kuCblUbi,"CoolCblDissociation1");
	reactions.push_back(CoolCblDissociation1);

	Reaction *CoolCblDissociation2 = new HeterodimerDissociationReaction(UbiFreeEndoEGFRCoolCblActive,UbiFreeEndoEGFR,Cool1CblActive,kuCblUbi,"CoolCblDissociation2");
	reactions.push_back(CoolCblDissociation2);

	// EGFR proteolysis 
	// 90
	Reaction *FreeEGFRProteolysis = new TransformationReaction(UbiFreeLysoEGFR,DegradedEGFR,kProt,"FreeEGFRProteolysis");
	reactions.push_back(FreeEGFRProteolysis);

	// assembly of recycling vesicle
	Reaction *COPIBinding = new HeterodimerizationReaction(COPI,FreeEndoEGFR,COPIEndoFreeEGFR,kbCOPI,"COPIBinding");
	reactions.push_back(COPIBinding);

	Reaction *COPIUnbinding = new HeterodimerDissociationReaction(COPIEndoFreeEGFR,COPI,FreeEndoEGFR,kuCOPI,"COPIUnbinding");
	reactions.push_back(COPIUnbinding);
	
	Reaction *VesicleAssembly = new HeterodimerizationReaction(COPIEndoFreeEGFR,Cdc42GTP,RecyclingVesicle,kb42COPI,"VesicleAssembly1");
	reactions.push_back(VesicleAssembly);

	// recycling

	Reaction *Recycling = new TransformationReaction(RecyclingVesicle,RecycledVesicle,kRec,"Recycling1");
	reactions.push_back(Recycling);

	// uncoating and fusion

	Reaction *VesicleGAPing = new MichaelisMentenTransformationReaction(Cdc42GAP,RecycledVesicle,VesicleCdc42GDP,kGAP,KmGAP,"VesicleGAPing");
	reactions.push_back(VesicleGAPing);
	
	Reaction *Cdc42COPIUnbinding = new HeterodimerDissociationReaction(VesicleCdc42GDP,COPIPMFreeEGFR,Cdc42GDP,ku42COPI,"Cdc42COPIUnbinding");
	reactions.push_back(Cdc42COPIUnbinding);
	
	Reaction *VesicleFusion = new HeterodimerDissociationReaction(COPIPMFreeEGFR,COPI,NonCPFreePMEGFR,kuCOPI,"VesicleFusion");
	reactions.push_back(VesicleFusion);

	// auto-activation (used w/ fast cycler, comment out otherwise)
	Reaction *AutoActivation = new TransformationReaction(Cdc42GDP,Cdc42GTP,kF28,"AutoActivation");
	reactions.push_back(AutoActivation);
	
	Reaction *RapidRec1 = new TransformationReaction(NonCoatedBoundEGFR,NonCPBoundPMEGFR,kFastRec,"RapidRec1");
	reactions.push_back(RapidRec1);

	// 100
	Reaction *RapidRec2 = new TransformationReaction(NonCoatedBoundEGFRCoolCblActive,NonCPBoundPMEGFRCoolCblActive,kFastRec,"RapidRec2");
	reactions.push_back(RapidRec2);

	Reaction *RapidRec3 = new TransformationReaction(NonCoatedUbiBoundEGFRCoolCblActive,UbiNonCPBoundPMEGFRCoolCblActive,kFastRec,"RapidRec3");
	reactions.push_back(RapidRec3);

}

CEGFRTraffickingNetwork::~CEGFRTraffickingNetwork()
{

}
