// AlternateOneGeneInhibitoryNetwork.cpp: implementation of the CAlternateOneGeneInhibitoryNetwork class.
//
//////////////////////////////////////////////////////////////////////

#include "AlternateOneGeneInhibitoryNetwork.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

CAlternateOneGeneInhibitoryNetwork::CAlternateOneGeneInhibitoryNetwork()
{
	Chemical *freePromoter = new Chemical(chemicals.size(), 1.0, "freePromoter");
	chemicals.push_back(freePromoter);

	Chemical *boundPromoter = new Chemical(chemicals.size(), 0.0, "boundPromoter");
	chemicals.push_back(boundPromoter);

	Chemical *mRNA = new Chemical(chemicals.size(), 0.0, "mRNA");
	chemicals.push_back(mRNA);

	Chemical *protein = new Chemical(chemicals.size(), 0.0, "protein");
	chemicals.push_back(protein);

	Chemical *zymogen = new Chemical(chemicals.size(), 0.0, "zymogen");
	chemicals.push_back(zymogen);

	RateConstant *kb = new RateConstant(0.6, "kb");
	rateConstants.push_back(kb);
	RateConstant *ku = new RateConstant(0.15, "ku");
	rateConstants.push_back(ku);
	RateConstant *ktm = new RateConstant(10.0, "ktm");
	rateConstants.push_back(ktm);
	RateConstant *kdm = new RateConstant(0.05, "kdm");
	rateConstants.push_back(kdm);
	RateConstant *kt = new RateConstant(1.0, "kt");
	rateConstants.push_back(kt);
	RateConstant *kd = new RateConstant(0.1, "kd");
	rateConstants.push_back(kd);
	RateConstant *ktz = new RateConstant(15.0, "ktz");
	rateConstants.push_back(ktz);
	RateConstant *kdz = new RateConstant(0.02,"kdz");
	rateConstants.push_back(kdz);
	RateConstant *kpro = new RateConstant(0.05,"kpro");
	rateConstants.push_back(kpro);


	PromoterBindingReaction *bindingReaction = new PromoterBindingReaction(freePromoter, protein, boundPromoter, kb, "bindingReaction");
	reactions.push_back(bindingReaction);
	PromoterUnbindingReaction *unbindingReaction = new PromoterUnbindingReaction(boundPromoter, freePromoter, protein, ku, "unbindingReaction");
	reactions.push_back(unbindingReaction);
	TranscriptionReaction *transcriptionReaction = new TranscriptionReaction(freePromoter, mRNA, ktm, "transcriptionReaction");
	reactions.push_back(transcriptionReaction);
	RNADegradationReaction *mRNADegradationReaction = new RNADegradationReaction(mRNA, kdm, "mRNADegradationReaction");
	reactions.push_back(mRNADegradationReaction);
	ProteinTranslationReaction *translationReaction = new ProteinTranslationReaction(mRNA, protein, kt, "translationReaction");
	reactions.push_back(translationReaction);
	UnstableProteinDegradationReaction *proteinDegradationReaction = new UnstableProteinDegradationReaction(protein, kd, "proteinDegradationReaction");
	reactions.push_back(proteinDegradationReaction);
	ProteinTranslationReaction *zymogenTranslation = new ProteinTranslationReaction(mRNA, zymogen, ktz, "zymogenTranslation");
	reactions.push_back(zymogenTranslation);
	UnstableProteinDegradationReaction *zymogenDegradationReaction = new UnstableProteinDegradationReaction(zymogen, kdz, "zymogenDegradationReaction");
	reactions.push_back(zymogenDegradationReaction);
	TransformationReaction *proteolyticCleavage = new TransformationReaction(zymogen, protein, kpro, "proteolyticCleavage");
	reactions.push_back(proteolyticCleavage);

}

CAlternateOneGeneInhibitoryNetwork::~CAlternateOneGeneInhibitoryNetwork()
{

}
