// BasicMetropolisAnneal.cpp: implementation of the BasicMetropolisAnneal class.
//
//////////////////////////////////////////////////////////////////////

#include "BasicMetropolisAnneal.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

BasicMetropolisAnneal::BasicMetropolisAnneal(int nEquilibrationSteps, int RNGSeed, double alpha)
:CSimulatedAnnealingStrategy(nEquilibrationSteps,RNGSeed)
{
	this->alpha = alpha;
}

BasicMetropolisAnneal::~BasicMetropolisAnneal()
{

}

void BasicMetropolisAnneal::InitializeTemperature(double *parameters, Minimizable *minimizable)
{
	// generate a number of trial moves and set T_0 using the average of the
	// "bad" moves (EPlusBar) assuming we want an acceptance ratio of probAccept
	// this is one of the standard ways to set the initial temperature
	int nTrials = 100;
	int nBad = 0;
	double probAccept = 0.8;
	double EPlusBar = 0.0;
	
	double Eold = minimizable->ObjectiveFunction(parameters);
	double Enew = 0.0;

	double *parTrial = new double[nParameters];
	
	for(int i = 0; i < nTrials; i++)
	{
		GenerateMove(parTrial);
		Enew = minimizable->ObjectiveFunction(parTrial);
		if(Enew > Eold)
		{
			EPlusBar += Enew - Eold;
			nBad++; 
		}
	}
	EPlusBar = EPlusBar/nBad;
	
	m_dTemperature = -EPlusBar/log(probAccept);

	delete [] parTrial;
}

void BasicMetropolisAnneal::GenerateMove(double *pTrialParameters)
{
	// this stepper takes an O(p[i]) step for each parameter, which is
	// quite drastic
	for(int i = 0; i < nParameters; i++)
	{
		pTrialParameters[i] = m_pdCurrentParameters[i]*(0.5 + m_pRNG->uniform());
	}
}

bool BasicMetropolisAnneal::AcceptMove(double Eold, double Enew)
{
	double deltaE = Enew - Eold;

	if(deltaE < 0)
	{
		return true;
	}
	else
	{
		double p = m_pRNG->uniform();
		if(p < exp(-deltaE/m_dTemperature) )
		{
			return true;
		}
		else
		{
			return false;
		}
	}
}

void BasicMetropolisAnneal::Cool()
{
	m_dTemperature = alpha*m_dTemperature;
}

bool BasicMetropolisAnneal::Terminate()
{
	double ratio = (m_dEBar - m_dEBest)/m_dEBar;
	if(ratio < 0.001) 
	{
		return true;
	}
	else 
	{
		return false;
	}
}
