// CircadianCaricature.cpp: implementation of the CCircadianCaricature class.
//
//////////////////////////////////////////////////////////////////////

#include "CircadianCaricature.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

CCircadianCaricature::CCircadianCaricature()
{
	double MicroMolar = 2500000;
	
	// CHEMICALS
	// promoters
	Chemical *FreePromoterY = new Chemical(chemicals.size(),1000.0,"FreePromoterY");
	chemicals.push_back(FreePromoterY);
	Chemical *BoundPromoterY = new Chemical(chemicals.size(),0.0,"BoundPromoterY");
	chemicals.push_back(BoundPromoterY);
	Chemical *FreePromoterClk = new Chemical(chemicals.size(),1000.0,"FreePromoterClk");
	chemicals.push_back(FreePromoterClk);
	Chemical *BoundPromoterClk = new Chemical(chemicals.size(),0.0,"BoundPromoterClk");
	chemicals.push_back(BoundPromoterClk);

	// mRNA
	Chemical *YmRNA = new Chemical(chemicals.size(),0.0,"YmRNA");
	chemicals.push_back(YmRNA);
	Chemical *ClkmRNA = new Chemical(chemicals.size(), 0.0, "ClkmRNA");
	chemicals.push_back(ClkmRNA);
	
	// proteins
	Chemical *X = new Chemical(chemicals.size(),0.01*MicroMolar,"X");
	chemicals.push_back(X);
	Chemical *PhosphoX = new Chemical(chemicals.size(),0.0,"PhosphoX");
	chemicals.push_back(PhosphoX);
	Chemical *Y = new Chemical(chemicals.size(),0.0,"Y");
	chemicals.push_back(Y);
	Chemical *Clk = new Chemical(chemicals.size(),0.0,"Clk");
	chemicals.push_back(Clk);

	// RATE CONSTANTS
	RateConstant *kbPY = new RateConstant(0.5,"kbPY");
	rateConstants.push_back(kbPY);
	RateConstant *kuPY = new RateConstant(0.1,"kuPY");
	rateConstants.push_back(kuPY);
	RateConstant *kbPClk = new RateConstant(0.5,"kbPClk");
	rateConstants.push_back(kbPClk);
	RateConstant *kuPClk = new RateConstant(0.1,"kuPClk");
	rateConstants.push_back(kuPClk);
	RateConstant *ktmClk = new RateConstant(1.0,"ktmClk");
	rateConstants.push_back(ktmClk);
	RateConstant *ktlClk = new RateConstant(1/1800,"ktlClk");
	rateConstants.push_back(ktlClk);
	RateConstant *ktmY = new RateConstant(1.0,"ktmY");
	rateConstants.push_back(ktmY);
	RateConstant *ktlY = new RateConstant(1/1800,"ktlY");
	rateConstants.push_back(ktlY);
	RateConstant *kdegY = new RateConstant(0.3,"kdegY");
	rateConstants.push_back(kdegY);
	RateConstant *kdegClk = new RateConstant(0.6,"kdegClk");
	rateConstants.push_back(kdegClk);
	RateConstant *kdegmRNA = new RateConstant(0.25,"kdegmRNA");
	rateConstants.push_back(kdegmRNA);
	RateConstant *kdegPhosphoX = new RateConstant(1.0,"kdegPhosphoX");
	rateConstants.push_back(kdegPhosphoX);
	RateConstant *k2 = new RateConstant(10.0,"k2");
	rateConstants.push_back(k2);
	RateConstant *Km = new RateConstant(0.001*MicroMolar,"Km");
	rateConstants.push_back(Km);

	// REACTIONS
	Reaction *PClkBinding = new PromoterBindingReaction(X,FreePromoterClk,BoundPromoterClk,kbPClk,"PClkBinding");
	reactions.push_back(PClkBinding);
	Reaction *PClkUnbinding = new PromoterUnbindingReaction(BoundPromoterClk,FreePromoterClk,X,kuPClk,"PClkUnbinding");
	reactions.push_back(PClkUnbinding);
	Reaction *PYBinding = new PromoterBindingReaction(X,FreePromoterY,BoundPromoterY,kbPY,"PYBinding");
	reactions.push_back(PYBinding);
	Reaction *PYUnbinding = new PromoterUnbindingReaction(BoundPromoterY,FreePromoterY,X,kuPY,"PYUnbinding");
	reactions.push_back(PYUnbinding);
	Reaction *YTranscription = new TranscriptionInducedByBindingReaction(BoundPromoterY,YmRNA,ktmY,"YTranscription");
	reactions.push_back(YTranscription);
	Reaction *ClkTranscription = new TranscriptionInducedByBindingReaction(BoundPromoterClk,ClkmRNA,ktmClk,"ClkTranscription");
	reactions.push_back(ClkTranscription);
	Reaction *YTranslation = new ProteinTranslationReaction(YmRNA,Y,ktlY,"YTranslation");
	reactions.push_back(YTranslation);
	Reaction *ClkTranslation = new ProteinTranslationReaction(ClkmRNA,Clk,ktlClk,"ClkTranslation");
	reactions.push_back(ClkTranslation);
	Reaction *XPhosphorylation = new MichaelisMentenPhosphorylationReaction(Y,X,PhosphoX,k2,Km,"XPhosphorylation");
	reactions.push_back(XPhosphorylation);
	Reaction *XDegradation = new UnstableProteinDegradationReaction(PhosphoX,kdegPhosphoX,"XDegradation");
	reactions.push_back(XDegradation);
	Reaction *YmRNADegradation = new RNADegradationReaction(YmRNA,kdegmRNA,"YmRNADegradationReaction");
	reactions.push_back(YmRNADegradation);
	Reaction *YDegradation = new UnstableProteinDegradationReaction(Y,kdegY,"YDegradation");
	reactions.push_back(YDegradation);
	Reaction *ClkmRNADegradation = new RNADegradationReaction(ClkmRNA,kdegmRNA,"ClkmRNADegradationReaction");
	reactions.push_back(ClkmRNADegradation);
	Reaction *ClkDegradation = new UnstableProteinDegradationReaction(Clk,kdegClk,"ClkDegradationReaction");
	reactions.push_back(ClkDegradation);


}

CCircadianCaricature::~CCircadianCaricature()
{

}
