// EnsembleCombinationDirector.h: interface for the CEnsembleCombinationDirector class.
//
//////////////////////////////////////////////////////////////////////

#if !defined(AFX_ENSEMBLECOMBINATIONDIRECTOR_H__88C5875B_DD03_4339_BBDB_AF090CBA1D96__INCLUDED_)
#define AFX_ENSEMBLECOMBINATIONDIRECTOR_H__88C5875B_DD03_4339_BBDB_AF090CBA1D96__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#include <iomanip>
#include <iostream>
#include "..\SRC_TEMP\RunDirector.h"
#include "..\src\SingleNetworkMinimizable.h"
#include "..\src_temp\GnuPlotterEnsembleRunDirectorObserver.h"
#include "..\src_temp\GnuPlotterEnsembleDataDirectorObserver.h"
#include "..\src\ParameterReader.h"

// avoid conflicts; both files refer to one another

class GnuPlotterEnsembleRunDirectorObserver; 
class GnuPlotterEnsembleDataDirectorObserver; 

class CEnsembleCombinationDirector : public CRunDirector  
{
public:
	CEnsembleCombinationDirector(int ensembleSize);
	virtual ~CEnsembleCombinationDirector();
	void LoadEnsembleInfo(std::string parameterFile);
	void SumAllocate();
	void Execute();
	void ConvertToStatistics();
	const double **GetNoDataAverages(int index) const {return (const double **)m_vpdNoDataSumC[index];}
	const double **GetNoDataStdDevs(int index) const {return (const double **)m_vpdNoDataSumCSqr[index];}
	const double **GetDataAverages(int index) const {return (const double **)m_vpdDataSumC[index];}
	const double **GetDataStdDevs(int index) const {return (const double **)m_vpdDataSumCSqr[index];}
	// Returns a single mover associated with the networks
	virtual CReactionMover *GetMover(int moverIndex) {return m_vpMovers[moverIndex];}
	// Returns the number of experiments
	virtual int GetNExperiments() const {return m_vpExperiments.size();}
	virtual SingleNetworkMinimizable *GetMinimizable(int minIndex) {return m_vpMinimizables[minIndex];}
private:
	// Initialization of conditions for each minimizable
	virtual void DefineExperiments() = 0;
	// Initialization of conditions for the runnables
	virtual void DefineRuns() = 0;
protected:
	int m_iEnsembleSize;
	std::vector<double *> m_vpdEnsembleParameters;
	// go with runnables
	std::vector<double **> m_vpdNoDataSumC;
	std::vector<double **> m_vpdNoDataSumCSqr;
	// go with minimizables
	std::vector<double **> m_vpdDataSumC;
	std::vector<double **> m_vpdDataSumCSqr;
	std::vector<GnuPlotterEnsembleRunDirectorObserver *> m_vpEnsembleRunPlotters;
	std::vector<GnuPlotterEnsembleDataDirectorObserver *> m_vpEnsembleDataPlotters;
	// organizes the minimizables
	std::vector<SingleNetworkMinimizable *> m_vpMinimizables;
	std::vector<Experiment *> m_vpExperiments;
	std::vector<ReactionNetwork *> m_vpNetworks;
	std::vector<CReactionMover *> m_vpMovers;
};

#endif // !defined(AFX_ENSEMBLECOMBINATIONDIRECTOR_H__88C5875B_DD03_4339_BBDB_AF090CBA1D96__INCLUDED_)
