// EvolutionStrategy.h: interface for the CEvolutionStrategy class.
//
//////////////////////////////////////////////////////////////////////

#if !defined(AFX_EVOLUTIONSTRATEGY_H__CA201537_5E8F_44BF_8F51_87D452D0BB82__INCLUDED_)
#define AFX_EVOLUTIONSTRATEGY_H__CA201537_5E8F_44BF_8F51_87D452D0BB82__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#include "..\SRC\Minimizer.h"
#include "..\src\Rand.h"
#include "..\src\typedefs.h"
#include "..\src\ParameterFilter.h"
#include "EvolutionStrategyChromosome.h"

class CEvolutionStrategy : public Minimizer 
{
public:
	CEvolutionStrategy(CParameterFilter *pFilter);
	CEvolutionStrategy(CParameterFilter *pFilter, int mu, int rho, int lambda, int nGenerations, int seed);
	virtual ~CEvolutionStrategy();
	// allocates memory and sets algorithm-specific parameters
	virtual void InitializePopulation(double *parameters) = 0;
	// performs the minimization
	double Minimize(double *parameters, Minimizable *minimizable);
	// selects rho parents from the population to form one offspring
	virtual void SelectParents() = 0;
	// mutates object and strategy parameters for one offspring
	virtual void Mutation(int whichOffspring) = 0;
	// recombines object and strategy parameters for one offspring
	virtual void Recombination(int whichOffspring) = 0;
	// performs selection on the offspring to form a new population
	virtual void Select() = 0;
	// evaluates the cost for one offspring
	double EvaluateOffspring(Minimizable *minimizable, int whichOffspring);
protected:
	std::vector<CEvolutionStrategyChromosome *> m_vpPopulation;
	std::vector<CEvolutionStrategyChromosome *> m_vpOffspring;
	// size of population
	int m_iMu;
	// number of parents involved in production of one offspring
	int m_iRho;
	// size of offspring pool subject to selection
	int m_iLambda;
	// number of strategy parameters
	int m_iNStrategyParameters;
	// number of generations over which to run the algorithm
	int m_iNGenerations;
	// random number generator
	Rand *m_pRNG;
	// filter for parameters
	CParameterFilter *m_pFilter;
	// cost statistics
	double m_dAvgCost;
	// list of parent indices for offspring production
	intVector m_viParents;
};

#endif // !defined(AFX_EVOLUTIONSTRATEGY_H__CA201537_5E8F_44BF_8F51_87D452D0BB82__INCLUDED_)
