// GnuPlotterEnsembleDataDirectorObserver.cpp: implementation of the GnuPlotterEnsembleDataDirector class.
//
//////////////////////////////////////////////////////////////////////

#include "GnuPlotterEnsembleDataDirectorObserver.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

GnuPlotterEnsembleDataDirectorObserver::GnuPlotterEnsembleDataDirectorObserver()
{

}

GnuPlotterEnsembleDataDirectorObserver::~GnuPlotterEnsembleDataDirectorObserver()
{

}

void GnuPlotterEnsembleDataDirectorObserver::FixMinimizable(int whichMinimizable)
{
	m_iWhichMinimizable = whichMinimizable;
}

void GnuPlotterEnsembleDataDirectorObserver::Update(Subject *theChangedSubject)
{
	// static cast may be dangerous
	CEnsembleCombinationDirector *pDirector = (CEnsembleCombinationDirector *)theChangedSubject;
	
	// set the plot title
	char titlestring[100];
	char commandstring[2000];
	sprintf(titlestring,"set title \"%s\"\n",title);
	SendPlotCommand(titlestring);
	SendPlotCommand("set grid\n");
	SendPlotCommand("set xlabel \"time (min)\"\n");
	//SendPlotCommand("set ylabel \"[Chemical] (molecules)\"\n");
	SendPlotCommand("set ylabel \"Concentration/Activity (arb. units)\"\n");

	// get length of time for which data was recorded
	int nTS = pDirector->GetMinimizable(m_iWhichMinimizable)->GetCellObserver()->GetNumberOfTimeSteps();
	
	// write the simulation data to a temporary file
	freopen(buffername,"w",buffer);

	std::vector<int> whichSimToPrint;
	// dump blocks of data/simulation to files, separated by double newlines
	// EXPERIMENT
	int nChem = pDirector->GetMinimizable(m_iWhichMinimizable)->GetExperiment()->GetChemicalTimeSeriesData()->GetNChemicals();
	int nTimeSeries = pDirector->GetMinimizable(m_iWhichMinimizable)->GetExperiment()->GetChemicalTimeSeriesData()->GetNTimeSeries();
	int maxTime = pDirector->GetMinimizable(m_iWhichMinimizable)->GetCellObserver()->GetNumberOfTimeSteps();

	std::vector<DataPoint *> nullVector;

	for(int i = 0; i < nChem; i++)
	{
		if( (pDirector->GetMinimizable(m_iWhichMinimizable)->GetExperiment()->GetChemicalTimeSeriesData()->GetTimeSeries(i)) != (std::vector<DataPoint *>)0 )
		{
			whichSimToPrint.push_back(i);
			for(int j = 0; j < (pDirector->GetMinimizable(m_iWhichMinimizable)->GetExperiment()->GetChemicalTimeSeriesData()->GetTimeSeries(i)).size(); j++)
			{
				double time = pDirector->GetMinimizable(m_iWhichMinimizable)->GetExperiment()->GetChemicalTimeSeriesData()->GetTimeSeries(i)[j]->GetTime();
				double data = pDirector->GetMinimizable(m_iWhichMinimizable)->GetExperiment()->GetChemicalTimeSeriesData()->GetTimeSeries(i)[j]->GetDatum();
				double error = pDirector->GetMinimizable(m_iWhichMinimizable)->GetExperiment()->GetChemicalTimeSeriesData()->GetTimeSeries(i)[j]->GetError();
				fprintf(buffer,"%e\t%e\t%e\n",time,data,error);
			}
			fprintf(buffer,"\n\n");

		}
	}

	// SIMULATION
	for(i = 0; i < whichSimToPrint.size(); i++)
	{
		for(int t = 0; t < maxTime-1; t++)
		{
			int target = whichSimToPrint[i];
			double time = double (t);
			double avg = pDirector->GetDataAverages(m_iWhichMinimizable)[target][t];
			double stddev = pDirector->GetDataStdDevs(m_iWhichMinimizable)[target][t];
			fprintf(buffer,"%e\t%e\t%e\t%e\n",time,avg,avg+stddev,avg-stddev);
		}
		fprintf(buffer,"\n\n");
	}


	// now plot everything
	// first block (done this way to keep the commas straight)
	char namestring[100];
	sprintf(namestring,pDirector->GetMinimizable(m_iWhichMinimizable)->GetExperiment()->GetReactionNetwork()->GetChemical(whichSimToPrint[0])->GetName().c_str());
	sprintf(commandstring,"plot \"%s\" index 0 t \"%s\" w errorbars",buffername,namestring);
	// the rest - experiment first
	for(i = 1; i < nTimeSeries; i++)
	{
		char tempbuffer[200];
		sprintf(namestring,pDirector->GetMinimizable(m_iWhichMinimizable)->GetExperiment()->GetReactionNetwork()->GetChemical(whichSimToPrint[i])->GetName().c_str());
		sprintf(tempbuffer,",\"%s\" index %i t \"%s\" w errorbars",buffername,i,namestring);
		strcat(commandstring,tempbuffer);
	}
	// now simulation
	for(i = nTimeSeries; i < 2*nTimeSeries; i++)
	{
		char tempbuffer[200];
		sprintf(tempbuffer,",\"%s\" index %i notitle w lines lt %i lw 3",buffername,i,i-nTimeSeries+1);
		strcat(commandstring,tempbuffer);
		for(int j = 3; j < 5; j++)
		{
			sprintf(tempbuffer,",\"%s\" index %i u 1:%i notitle w lines lt %i",buffername,i,j,i-nTimeSeries+1);
			strcat(commandstring,tempbuffer);
		}
	}
	strcat(commandstring,"\n");
	
	// change single backslashes to forward slashes to keep windows happy
#ifdef _WIN32
	int iterator = 0;
	while(commandstring[iterator] != '\0')
	{
		if(commandstring[iterator] == '\\') {commandstring[iterator] = '/';}
		iterator++;
	}
#endif

	fflush(buffer);
	SendPlotCommand(commandstring);

	return;	
}