// GnuPlotterEnsembleRunDirectorObserver.cpp: implementation of the GnuPlotterEnsembleRunDirectorObserver class.
//
//////////////////////////////////////////////////////////////////////

#include "GnuPlotterEnsembleRunDirectorObserver.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

GnuPlotterEnsembleRunDirectorObserver::GnuPlotterEnsembleRunDirectorObserver()
{
 
}

GnuPlotterEnsembleRunDirectorObserver::~GnuPlotterEnsembleRunDirectorObserver()
{

}

void GnuPlotterEnsembleRunDirectorObserver::AddChemicalToList(int whichChemical)
{
	m_viWhichChemicals.push_back(whichChemical);
}

void GnuPlotterEnsembleRunDirectorObserver::FixRunnable(int whichRunnable)
{
	m_iWhichRunnable = whichRunnable;
}

void GnuPlotterEnsembleRunDirectorObserver::Update(Subject *theChangedSubject)
{
	// static cast may be dangerous
	CEnsembleCombinationDirector *pDirector = (CEnsembleCombinationDirector *)theChangedSubject;

	// set the plot title
	char titlestring[100];
	char commandstring[2000];
	sprintf(titlestring,"set title \"%s\"\n",title);
	SendPlotCommand(titlestring);
	SendPlotCommand("set grid\n");
	SendPlotCommand("set xlabel \"time (min)\"\n");
	//SendPlotCommand("set ylabel \"[Chemical] (molecules)\"\n");
	SendPlotCommand("set ylabel \"Concentration/Activity (arb. units)\"\n");

	// get length of time for which data was recorded
	int nTS = pDirector->GetRunnable(m_iWhichRunnable)->GetCellObserver()->GetNumberOfTimeSteps();

	// write the simulation data to a temporary file
	freopen(buffername,"w",buffer);

	// plot each chemical's data separated by double newlines
	for(int chemCount = 0; chemCount < m_viWhichChemicals.size(); chemCount++)
	{
		int cIndex = m_viWhichChemicals[chemCount];
		for(int t = 0; t < nTS; t++)
		{
			double time = (double) t;
			double avg = pDirector->GetNoDataAverages(m_iWhichRunnable)[cIndex][t];
			double stddev = pDirector->GetNoDataStdDevs(m_iWhichRunnable)[cIndex][t];
			fprintf(buffer,"%e\t%e\t%e\t%e\n",time,avg,avg+stddev,avg-stddev);
		}
		fprintf(buffer,"\n\n");
	}
	
	// now plot everything
	// first block (done this way to keep the commas straight)
	char namestring[500];
	char tempbuffer[500];

	// first piece of the plot command is different, so plot the first chemical
	// manually
	int cIndex = m_viWhichChemicals[0];
	int lineType = 1;
	int index = 0;
	sprintf(namestring,pDirector->GetRunnable(m_iWhichRunnable)->GetReactionNetwork()->GetChemical(cIndex)->GetName().c_str());
	sprintf(commandstring,"plot \"%s\" index %i u 1:%i t \"%s\" w lines lw 3",buffername,index,2,namestring);
	for(int i = 3; i < 5; i++)
	{
		sprintf(tempbuffer,",\"%s\" index %i u 1:%i notitle w lines lt %i",buffername,index,i,lineType);
		strcat(commandstring,tempbuffer);
	}
	// now for the rest of the chemicals
	for(int cCount = 1; cCount < m_viWhichChemicals.size(); cCount++)
	{
		cIndex = m_viWhichChemicals[cCount];
		index++;
		lineType++;
		sprintf(namestring,pDirector->GetRunnable(m_iWhichRunnable)->GetReactionNetwork()->GetChemical(cIndex)->GetName().c_str());
		sprintf(tempbuffer,",\"%s\" index %i u 1:%i t \"%s\" w lines lt %i lw 3",buffername,index,2,namestring,lineType);
		strcat(commandstring,tempbuffer);
		for(i = 3; i < 5; i++)
		{
			sprintf(tempbuffer,",\"%s\" index %i u 1:%i notitle w lines lt %i",buffername,index,i,lineType);
			strcat(commandstring,tempbuffer);
		}
	}
	strcat(commandstring,"\n");
	
	// change single backslashes to forward slashes to keep windows happy
#ifdef _WIN32
	int iterator = 0;
	while(commandstring[iterator] != '\0')
	{
		if(commandstring[iterator] == '\\') {commandstring[iterator] = '/';}
		iterator++;
	}
#endif

	fflush(buffer);
	SendPlotCommand(commandstring);

	return;

}