// HessianMonteCarloQuench.h: interface for the CHessianMonteCarloQuench class.
//
//////////////////////////////////////////////////////////////////////

#if !defined(AFX_HESSIANMONTECARLOQUENCH_H__0AE0BBEB_3B16_47D5_BC59_E9761B5525A4__INCLUDED_)
#define AFX_HESSIANMONTECARLOQUENCH_H__0AE0BBEB_3B16_47D5_BC59_E9761B5525A4__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#include <iostream>
#include <mkl.h>
#include "..\SRC\Minimizer.h"
#include "..\src\ParameterFilter.h"
#include "..\src\Rand.h"
#include "..\src\NLLSMinimizable.h"

class CHessianMonteCarloQuench : public Minimizer  
{
public:
	CHessianMonteCarloQuench(int nIterations, int seed, CParameterFilter *pFilter);
	virtual ~CHessianMonteCarloQuench();
	double Minimize(double *parameters, Minimizable *minimizable);
	void ComputeDerivativeInformation(double *parameters, NLLSMinimizable *nlls);
	void ComputeCholeskyFactor();
private:
	int m_iNResiduals;
	int m_iNIterations;
	int m_iNUpdates;
	int m_iRNGSeed;
	// inverse of the covariance matrix
	double **m_pdSigmaInverse;
	// Cholesky factor of Sigma^-1, used to obtain appropriately dist. random numbers
	double **m_pdCholeskyFactor;
	CParameterFilter *m_pFilter;
	double m_dAcceptanceRatio;
	double m_dBestCost;
	// adjust this to get an appropriate acceptance ratio
	double m_dControlParameter;
	Rand *m_pRNG;
};

#endif // !defined(AFX_HESSIANMONTECARLOQUENCH_H__0AE0BBEB_3B16_47D5_BC59_E9761B5525A4__INCLUDED_)
