// OneGeneEnsembleDirector.cpp: implementation of the COneGeneEnsembleDirector class.
//
//////////////////////////////////////////////////////////////////////

#include "OneGeneEnsembleDirector.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

COneGeneEnsembleDirector::COneGeneEnsembleDirector(int ensembleSize)
:CEnsembleCombinationDirector(ensembleSize)
{
	double maxSimTime = 91.0;
	int intTime = (int) maxSimTime + 2;
	double stepSize = 0.0001;
	double frequency = 1.0;
	double moveTol = 1.0e-6;
	bool rateFlag = true;
	bool chemFlag = false;
	bool logsFlag = false;
	double timeWeight = 1.0;
	double rateWeight = 0.0;
	double chemWeight = 0.0;
	int nCells = 1;
	/*
	// runnable
	m_vpRxnNetworks.push_back(new OneGeneInhibitoryNetwork());
	m_vpRxnMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	int nChemicals = m_vpRxnNetworks[0]->GetNumberOfChemicals();
	m_vpCellObservers.push_back(new CellAverageObserver(nChemicals,intTime,1));
	m_vpRunnables.push_back(new CRunnable());
	m_vpRunnables[0]->SetComponents(m_vpRxnNetworks[0],m_vpRxnMovers[0],m_vpCellObservers[0]);
	m_vpEnsembleRunPlotters.push_back(new GnuPlotterEnsembleRunDirectorObserver());
	m_vpEnsembleRunPlotters[0]->SetTitle("OGN : 1 Bound Promoter, No Protein : ODE");
	m_vpEnsembleRunPlotters[0]->FixRunnable(0);
	m_vpEnsembleRunPlotters[0]->AddChemicalToList(2);
	m_vpEnsembleRunPlotters[0]->AddChemicalToList(3);
	this->Attach(m_vpEnsembleRunPlotters[0]);
	*/
	// minimizable 1 - 1 free promoter, no mRNA or protein
	m_vpNetworks.push_back(new OneGeneInhibitoryNetwork());
	m_vpExperiments.push_back(new Experiment(m_vpNetworks[0],"Free Promoter"));
	// data files
	m_vpExperiments[0]->AddDataFileToList("smallOneGeneDS.dat");
	// mover 
	m_vpMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	m_vpMinimizables.push_back(new SingleNetworkMinimizable());
	// parameters
	m_vpMinimizables[0]->Initialize(m_vpExperiments[0],m_vpMovers[0],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	m_vpMinimizables[0]->SetRateConstantsWeight(0.0);
	m_vpEnsembleDataPlotters.push_back(new GnuPlotterEnsembleDataDirectorObserver());
	m_vpEnsembleDataPlotters[0]->SetTitle("OGN : 1 Free Promoter, No Protein : ODE");
	m_vpEnsembleDataPlotters[0]->FixMinimizable(0);
	this->Attach(m_vpEnsembleDataPlotters[0]);

	// allocate space to accumulate statistics
	SumAllocate();

	// Define runs
	DefineRuns();

	// Define experiments
	DefineExperiments();

	// Load in the ensemble information
	LoadEnsembleInfo("ensemble.par");

}

COneGeneEnsembleDirector::~COneGeneEnsembleDirector()
{
	for(int i = 0; i < m_vpEnsembleRunPlotters.size(); i++)
	{
		this->Detach(m_vpEnsembleRunPlotters[i]);
	}
	for(i = 0; i < m_vpEnsembleDataPlotters.size(); i++)
	{
		this->Detach(m_vpEnsembleDataPlotters[i]);
	}
}

void COneGeneEnsembleDirector::DefineExperiments()
{
	// 1 free promoter region, no bound, no mRNA, no protein
	m_vpMinimizables[0]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(1.0);
	m_vpMinimizables[0]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->Reset();
	m_vpMinimizables[0]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->SetInitialAmount(0.0);
	m_vpMinimizables[0]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->Reset();
}

void COneGeneEnsembleDirector::DefineRuns()
{
	/*
	// 1 bound promoter, none free, no mRNA, no protein
	m_vpRunnables[0]->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(0.0);
	m_vpRunnables[0]->GetReactionNetwork()->GetChemical(0)->Reset();	
	m_vpRunnables[0]->GetReactionNetwork()->GetChemical(1)->SetInitialAmount(1.0);
	m_vpRunnables[0]->GetReactionNetwork()->GetChemical(1)->Reset();	
	m_vpRunnables[0]->GetReactionNetwork()->GetChemical(3)->SetInitialAmount(0.0);
	m_vpRunnables[0]->GetReactionNetwork()->GetChemical(3)->Reset();
	*/
}