// OneGeneEnsembleRunDirector.cpp: implementation of the COneGeneEnsembleRunDirector class.
//
//////////////////////////////////////////////////////////////////////

#include "OneGeneEnsembleRunDirector.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

COneGeneEnsembleRunDirector::COneGeneEnsembleRunDirector(int ensembleSize)
:CEnsembleRunDirector(ensembleSize)
{
	double maxSimTime = 90.0;
	int intTime = (int) maxSimTime + 2;
	double stepSize = 0.0001;
	double frequency = 1.0;
	double moveTol = 1.0e-6;

	m_vpRxnNetworks.push_back(new OneGeneInhibitoryNetwork());
	m_vpRxnMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	int nChemicals = m_vpRxnNetworks[0]->GetNumberOfChemicals();
	m_vpCellObservers.push_back(new CellAverageObserver(nChemicals,intTime,1));
	m_vpRunnables.push_back(new CRunnable());
	m_vpRunnables[0]->SetComponents(m_vpRxnNetworks[0],m_vpRxnMovers[0],m_vpCellObservers[0]);
	m_vpEnsemblePlotters.push_back(new GnuPlotterEnsembleRunDirectorObserver());
	m_vpEnsemblePlotters[0]->SetTitle("OGN : 1 Free Promoter, No Protein : ODE");
	m_vpEnsemblePlotters[0]->FixRunnable(0);
	m_vpEnsemblePlotters[0]->AddChemicalToList(2);
	m_vpEnsemblePlotters[0]->AddChemicalToList(3);
	this->Attach(m_vpEnsemblePlotters[0]);

	m_vpRxnNetworks.push_back(new OneGeneInhibitoryNetwork());
	m_vpRxnMovers.push_back(new CQualityControlCashKarpMover(frequency,stepSize,moveTol));
	nChemicals = m_vpRxnNetworks[1]->GetNumberOfChemicals();
	m_vpCellObservers.push_back(new CellAverageObserver(nChemicals,intTime,1));
	m_vpRunnables.push_back(new CRunnable());
	m_vpRunnables[1]->SetComponents(m_vpRxnNetworks[1],m_vpRxnMovers[1],m_vpCellObservers[1]);
	m_vpEnsemblePlotters.push_back(new GnuPlotterEnsembleRunDirectorObserver());
	m_vpEnsemblePlotters[1]->SetTitle("OGN : 1 Bound Promoter, No Protein : ODE");
	m_vpEnsemblePlotters[1]->FixRunnable(1);
	m_vpEnsemblePlotters[1]->AddChemicalToList(2);
	m_vpEnsemblePlotters[1]->AddChemicalToList(3);
	this->Attach(m_vpEnsemblePlotters[1]);
	
	// allocate space to accumulate statistics
	SumAllocate();

	// Define Runs
	DefineRuns();

	// Load in the ensemble information
	LoadEnsembleInfo("ensemble_200.par");
}

COneGeneEnsembleRunDirector::~COneGeneEnsembleRunDirector()
{
	
}

void COneGeneEnsembleRunDirector::DefineRuns()
{
	// specific to this simulation

	// 1 free promoter, no protein
	m_vpRunnables[0]->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(1.0);
	m_vpRunnables[0]->GetReactionNetwork()->GetChemical(0)->Reset();	
	m_vpRunnables[0]->GetReactionNetwork()->GetChemical(3)->SetInitialAmount(0.0);
	m_vpRunnables[0]->GetReactionNetwork()->GetChemical(3)->Reset();

	// 1 bound promoter, no protein
	m_vpRunnables[1]->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(0.0);
	m_vpRunnables[1]->GetReactionNetwork()->GetChemical(0)->Reset();	
	m_vpRunnables[1]->GetReactionNetwork()->GetChemical(1)->SetInitialAmount(1.0);
	m_vpRunnables[1]->GetReactionNetwork()->GetChemical(1)->Reset();	
	m_vpRunnables[1]->GetReactionNetwork()->GetChemical(3)->SetInitialAmount(0.0);
	m_vpRunnables[1]->GetReactionNetwork()->GetChemical(3)->Reset();

}
