// OneGeneInhibitoryAveragingDirector.cpp: implementation of the COneGeneInhibitoryAveragingDirector class.
//
//////////////////////////////////////////////////////////////////////

#include "OneGeneInhibitoryAveragingDirector.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

COneGeneInhibitoryAveragingDirector::COneGeneInhibitoryAveragingDirector()
{
	double maxSimTime = 90.0;
	int intTime = (int) maxSimTime + 2;
	double stepSize = 0.0001;
	double frequency = 1.0;
	int seed1 = 9785781;
	int seed2 = 89762209;
	int nCells = 1;
	
	
	// create a runnable to compare to (differential equation)
	m_vpRxnNetworks.push_back(new OneGeneInhibitoryNetwork());
	m_vpRxnMovers.push_back(new CQualityControlRungeKuttaMover(frequency,stepSize));
	int nChemicals = m_vpRxnNetworks[0]->GetNumberOfChemicals();
	m_vpCellObservers.push_back(new CellAverageObserver(nChemicals,intTime,1));
	m_vpRunnables.push_back(new CRunnable());
	m_vpRunnables[0]->SetComponents(m_vpRxnNetworks[0],m_vpRxnMovers[0],m_vpCellObservers[0]);
	// create an observer for the runnable
	m_vpGnuPlotters.push_back(new GnuPlotterRunnableObserver());
	m_vpGnuPlotters[0]->AddChemicalNumberToList(2);
	m_vpGnuPlotters[0]->AddChemicalNumberToList(3);
	// attach the observer
	m_vpRunnables[0]->Attach(m_vpGnuPlotters[0]);

	// pure stochastic simulation
	m_vpRxnNetworks.push_back(new OneGeneInhibitoryNetwork());
	m_vpRxnMovers.push_back(new CContinuousTimeMonteCarloMover(seed1,frequency));
	nChemicals = m_vpRxnNetworks[1]->GetNumberOfChemicals();
	m_vpCellObservers.push_back(new CellAverageObserver(nChemicals,intTime,1));
	m_vpRunnables.push_back(new CRunnable());
	m_vpRunnables[1]->SetComponents(m_vpRxnNetworks[1],m_vpRxnMovers[1],m_vpCellObservers[1]);
	// create an observer for the runnable
	m_vpGnuPlotters.push_back(new GnuPlotterRunnableObserver());
	m_vpGnuPlotters[1]->AddChemicalNumberToList(2);
	m_vpGnuPlotters[1]->AddChemicalNumberToList(3);
	// attach the observer
	m_vpRunnables[1]->Attach(m_vpGnuPlotters[1]);
	

	// mixed simulation
	double tol = 1.0e-06;
	intVector stocRxn;
	stocRxn.push_back(0);
	stocRxn.push_back(1);
	m_vpRxnNetworks.push_back(new CMixedReactionNetwork(new OneGeneInhibitoryNetwork(),stocRxn));
	m_vpRxnMovers.push_back(new CMixedReactionMover(seed2,new CQualityControlRungeKuttaMover(frequency,stepSize),tol));
	nChemicals = m_vpRxnNetworks[2]->GetNumberOfChemicals();
	m_vpCellObservers.push_back(new CellAverageObserver(nChemicals,intTime,1));
	m_vpRunnables.push_back(new CRunnable());
	m_vpRunnables[2]->SetComponents(m_vpRxnNetworks[2],m_vpRxnMovers[2],m_vpCellObservers[2]);
	// create an observer for the runnable
	m_vpGnuPlotters.push_back(new GnuPlotterRunnableObserver());
	m_vpGnuPlotters[2]->AddChemicalNumberToList(2);
	m_vpGnuPlotters[2]->AddChemicalNumberToList(3);
	// attach the observer
	m_vpRunnables[2]->Attach(m_vpGnuPlotters[2]);
}

COneGeneInhibitoryAveragingDirector::~COneGeneInhibitoryAveragingDirector()
{
	// delete the runnables
	for(int i = 0; i < m_vpRunnables.size(); i++)
	{
		delete m_vpRunnables[i];
	}
	// delete the movers
	for(i = 0; i < m_vpRxnMovers.size(); i++)
	{
		delete m_vpRxnMovers[i];
	}
	// delete the cell observers
	for(i = 0; i < m_vpCellObservers.size(); i++)
	{
		delete m_vpCellObservers[i];
	}
	// delete the networks
	for(i = 0; i < m_vpRxnNetworks.size(); i++)
	{
		delete m_vpRxnNetworks[i];
	}
}

void COneGeneInhibitoryAveragingDirector::Execute()
{
	// run the simulations
	for(int i = 0; i < m_vpRunnables.size(); i++)
	{
		m_vpRunnables[i]->Run();
	}
}
