// OneGeneReplicaMinimizableDirector.cpp: implementation of the COneGeneReplicaMinimizableDirector class.
//
//////////////////////////////////////////////////////////////////////

#include "OneGeneReplicaMinimizableDirector.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

COneGeneReplicaMinimizableDirector::COneGeneReplicaMinimizableDirector(double epsSqr, double deltaSqr)
:CReplicaMinimizableDirector(epsSqr, deltaSqr)
{
	double maxSimTime = 91.0;
	double stepSize = 0.0001;
	double frequency = 1.0;
	int nCells = 1;

	bool rateFlag = true;
	bool chemFlag = false;
	bool logsFlag = false;
	double timeWeight = 1.0;
	double rateWeight = 0.0;
	double chemWeight = 0.0;

	// penalty for long integrations
	m_dGammaSquared = 0.0;

	// fake experiment 1 - large network
	_networkList.push_back(new CAlternateOneGeneInhibitoryNetwork());
	_experimentList.push_back(new Experiment(_networkList[0],"Big Network"));
	// data files
	_experimentList[0]->AddDataFileToList("bigOneGeneDS.dat");
	// mover and plotter
	_moverList.push_back(new CQualityControlCashKarpMover(frequency,stepSize,1.0e-06));
	m_vpPlotterList.push_back(new GnuPlotterTimeSeriesObserver());
	// title
	m_vpPlotterList[0]->SetTitle("Big OGN:1 Free Promoter:ODE");
	// minimizable
	_minimizableList.push_back(new SingleNetworkMinimizable());
	// parameters
	_minimizableList[0]->Initialize(_experimentList[0],_moverList[0],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	// attach observer
	_minimizableList[0]->Attach(m_vpPlotterList[0]);

	// fake experiment 2 - small network
	_networkList.push_back(new OneGeneInhibitoryNetwork());
	_experimentList.push_back(new Experiment(_networkList[1],"Small Network"));
	// data files
	_experimentList[1]->AddDataFileToList("smallOneGeneDS.dat");
	// mover and plotter
	_moverList.push_back(new CQualityControlCashKarpMover(frequency,stepSize,1.0e-06));
	m_vpPlotterList.push_back(new GnuPlotterTimeSeriesObserver());
	// title
	m_vpPlotterList[1]->SetTitle("Small OGN:1 Free Promoter:ODE");
	// minimizable
	_minimizableList.push_back(new SingleNetworkMinimizable());
	// parameters
	_minimizableList[1]->Initialize(_experimentList[1],_moverList[1],nCells,rateFlag,chemFlag,logsFlag,timeWeight,rateWeight,chemWeight);
	// attach observer
	_minimizableList[1]->Attach(m_vpPlotterList[1]);

	// find the parameter intersection lists
	SetIntersectionLists();

	// allocate the master residuals list
	int masterResidualsSize = 0;
	for(int i = 0; i < _minimizableList.size(); i++)
	{
		masterResidualsSize += _minimizableList[i]->GetNResiduals();
	}
	masterResidualsSize += m_viIntersectOne.size();
	masterResidualsSize += 1;		// for the participation ratio	
	if(m_dGammaSquared > 0.0)
	{
		masterResidualsSize += 1;
	}
	Allocate(masterResidualsSize);

	cout << "Master Residuals size : " << masterResidualsSize << endl;
	
	// define the experiments
	DefineExperiments();
}

COneGeneReplicaMinimizableDirector::~COneGeneReplicaMinimizableDirector()
{
	for(int i = 0; i < _minimizableList.size(); i++)
	{
		_minimizableList[i]->Detach(m_vpPlotterList[i]);
	}
	for(i = 0; i < m_vpPlotterList.size(); i++)
	{
		delete m_vpPlotterList[i];
	}

}

void COneGeneReplicaMinimizableDirector::DefineExperiments()
{
	// 1 free promoter, no bound, no mRNA, no protein
	_minimizableList[0]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(1.0);
	_minimizableList[0]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->Reset();
	_minimizableList[0]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->SetInitialAmount(0.0);
	_minimizableList[0]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->Reset();

	// 1 free promoter, no bound, no mRNA, no protein
	_minimizableList[1]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->SetInitialAmount(1.0);
	_minimizableList[1]->GetExperiment()->GetReactionNetwork()->GetChemical(0)->Reset();
	_minimizableList[1]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->SetInitialAmount(0.0);
	_minimizableList[1]->GetExperiment()->GetReactionNetwork()->GetChemical(1)->Reset();

}