// RobustLevenbergMarquardtMinimizer.h: interface for the CRobustLevenbergMarquardtMinimizer class.
//
//////////////////////////////////////////////////////////////////////

#if !defined(AFX_ROBUSTLEVENBERGMARQUARDTMINIMIZER_H__699CF063_2C7A_408C_94EE_B02FB5D42FC3__INCLUDED_)
#define AFX_ROBUSTLEVENBERGMARQUARDTMINIMIZER_H__699CF063_2C7A_408C_94EE_B02FB5D42FC3__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#include <iostream>
#include <fstream.h>
#include <cmath>
#include <cfloat>
#include <mkl.h>
#include <assert.h>
#include "../src/NLLSMinimizable.h"
#include "../src/ParameterFilter.h"
#include "../src/Minimizer.h"

class CRobustLevenbergMarquardtMinimizer : public Minimizer  
{
public:
	CRobustLevenbergMarquardtMinimizer();
	CRobustLevenbergMarquardtMinimizer(CParameterFilter *pFilter, double marquardt, double chiTol, double gradTol, int nIterations);
	virtual ~CRobustLevenbergMarquardtMinimizer();
	double Minimize(double *parameters, Minimizable *minimizable);
	void ComputeDerivativeInformation(double *parameters, NLLSMinimizable *nlls);
	// solve LM system without explicit calculation of the Hessian
	void QRSolveMarquardtSystem(double *deltaP);
private:
	bool m_bBreakFlag;				// Set to true to break out of the routine
	double m_dMarquardt;			// Marquardt parameter
	int m_iNIterations;				// Maximum number of LM iterations
	double m_dChiSqTol;				// Fractional stopping criterion for Chi squared
	double m_dGradTol;				// Stopping criterion for the norm of the gradient
	double** m_pdJacobian;			// Jacobian matrix
	double** m_pdAlpha;				// (1/2)*approximate Hessian matrix
	double* m_pdBeta;				// (-1/2)*gradient
	double* m_pdScalingMatrix;		// Diagonal scaling matrix
	double* m_pdCurrentResiduals;	// Residuals at the current parameter values
	int m_iNResiduals;				// number of residuals in NLLSMinimizable
	CParameterFilter *m_pFilter;	// Filter if parameters need to be kept positive
};

#endif // !defined(AFX_ROBUSTLEVENBERGMARQUARDTMINIMIZER_H__699CF063_2C7A_408C_94EE_B02FB5D42FC3__INCLUDED_)
