// RowColumnSparseMatrix.cpp: implementation of the RowColumnSparseMatrix class.
//
//////////////////////////////////////////////////////////////////////

#include "RowColumnSparseMatrix.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

RowColumnSparseMatrix::RowColumnSparseMatrix(int nRows, int nCols)
:SparseMatrix(nRows,nCols)
{

}

RowColumnSparseMatrix::~RowColumnSparseMatrix()
{
	for(int i = 0; i < matrix.size(); i++)
	{
		delete matrix[i];
	}
}

bool RowColumnSparseMatrix::AddElement(int row, int col, int value)
{
	// create a matrix element
	RowColumnSparseMatrix::MatrixElement *elem = new RowColumnSparseMatrix::MatrixElement(row,col,value);
	// push it onto the list
	matrix.push_back(elem);

	return true;
}

void RowColumnSparseMatrix::OrderElements()
{
	return;
}

bool RowColumnSparseMatrix::RightVectorMultiply(double *colVector, int length)
{
	// check for size compatibility
	if(length != nCols)
	{
		return false;
	}

	// temporarily stores result of multiplication
	double *sums = new double[nCols];
	for(int i = 0; i < nCols; i++)
	{
		sums[i] = 0.0;
	}

	for(int index = 0; index < matrix.size(); index++)
	{	
		int mI = matrix[index]->GetRow();
		int mJ = matrix[index]->GetCol();
		double mElem = matrix[index]->GetValue();

		sums[mI] += mElem*colVector[mJ];
	}

	for(i = 0; i < nCols; i++)
	{
		colVector[i] = sums[i];
	}
	delete [] sums;

	return true;
}

