// RowColumnSparseMatrix.h: interface for the RowColumnSparseMatrix class.
//
//////////////////////////////////////////////////////////////////////

#if !defined(AFX_ROWCOLUMNSPARSEMATRIX_H__1A61EEB6_7D45_4A7B_8BC0_51B4D77A4906__INCLUDED_)
#define AFX_ROWCOLUMNSPARSEMATRIX_H__1A61EEB6_7D45_4A7B_8BC0_51B4D77A4906__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#include "SparseMatrix.h"
#include <vector>

// This is the simplest type of sparse storage.  It stores each matrix element as 
// a tuple (i,j,value), where i = row and j = column.  Pointers to matrix elements
// (used in sorting) are compared using the MatrixElementComparator - this particular
// comparator ranks the elements in row-increasing order

class RowColumnSparseMatrix : public SparseMatrix  
{
public:
	RowColumnSparseMatrix(int nRows, int nCols);
	virtual ~RowColumnSparseMatrix();
	void OrderElements();
	bool AddElement(int row, int col, int value);
	void PrintMatrix();
	bool RightVectorMultiply(double *colVector, int length);
	class MatrixElement
	{
	public:
		MatrixElement(int row, int col, int value)
		{
			this->row = row;
			this->col = col;
			this->value = value;
		}
		virtual ~MatrixElement() {return;}
		int GetRow() const {return row;}
		int GetCol() const {return col;}
		double GetValue() const {return value;}
	private:
		class MatrixElementComparator
		{
		public:
			MatrixElementComparator() {return;}
			virtual ~MatrixElementComparator() {return;}
			bool operator() (MatrixElement *m1, MatrixElement *m2)
			{
				return m1->GetRow() < m2->GetRow();
			}
		};
	private:
		int row,col;
		double value;
	};
private:
	std::vector<MatrixElement *> matrix;
};

#endif // !defined(AFX_ROWCOLUMNSPARSEMATRIX_H__1A61EEB6_7D45_4A7B_8BC0_51B4D77A4906__INCLUDED_)
