// Runnable.cpp: implementation of the CRunnable class.
//
//////////////////////////////////////////////////////////////////////

#include "Runnable.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

CRunnable::CRunnable()
{

}

CRunnable::~CRunnable()
{

}

void CRunnable::SetRunnableName(std::string name)
{
	m_sRunnableName = name;
}

void CRunnable::SetComponents(ReactionNetwork *pRxnNetwork, CReactionMover *pRxnMover, CellAverageObserver *pCellObserver)
{
	m_pRxnNetwork = pRxnNetwork;
	m_pRxnMover = pRxnMover;
	m_pCellObserver = pCellObserver;
}

void CRunnable::Run()
{
	// zero the observer
	m_pCellObserver->ZeroConcentrations();
	// attach the observer to the mover
	m_pRxnMover->Attach(m_pCellObserver);
	// run the network, averaging over the population
	int nCells = m_pCellObserver->GetNumberOfCells();
	int intTime = m_pCellObserver->GetNumberOfTimeSteps();
	for(int i = 0; i < nCells; i++)
	{
		m_pRxnNetwork->ChemicalReset();
		m_pRxnMover->Move(0.0,0.0,m_pRxnNetwork);
		m_pRxnMover->Move(0.0,(double)(intTime) - 1.0, m_pRxnNetwork);
	}
	// detach the observer
	m_pRxnMover->Detach(m_pCellObserver);
	// notify observers (a la plotters)
	Notify();
}
