// SimulatedAnnealingStrategy.cpp: implementation of the CSimulatedAnnealingStrategy class.
//
//////////////////////////////////////////////////////////////////////

#include "SimulatedAnnealingStrategy.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

CSimulatedAnnealingStrategy::CSimulatedAnnealingStrategy(int RNGSeed, CParameterFilter *pFilter)
{
	m_iRNGSeed = RNGSeed;
	m_pFilter = pFilter;

	m_pRNG = new Rand(m_iRNGSeed);
	m_pMO = new CMatrixOperations();

	m_dEBar = 0.0;
	m_dE2Bar = 0.0;
	m_dAcceptanceRatio = 0.0;
	m_iTrialCount = 0;
}

CSimulatedAnnealingStrategy::~CSimulatedAnnealingStrategy()
{
	delete m_pRNG;
	delete m_pMO;
}

double CSimulatedAnnealingStrategy::Minimize(double *parameters, Minimizable *minimizable)
{
	nParameters = minimizable->GetNParameters();
	m_pdCurrentParameters = new double[nParameters];
	m_pdTrialParameters = new double[nParameters];

	// copy the current parameters into starting parameters
	m_pMO->ElementCopy(parameters,m_pdCurrentParameters,nParameters);

	m_dEBest = minimizable->ObjectiveFunction(parameters);
	double Eold = m_dEBest;

	cout << "Initial cost of " << m_dEBest << endl;
	
	this->InitializeTemperature(minimizable);

	// avoids termination before any moves
	m_dEBar = -m_dEBest; 

	while( !(this->Terminate()) )
	{
		m_dEBar = 0.0;
		m_dE2Bar = 0.0;
		m_iTrialCount = 0;
		m_dAcceptanceRatio = 0.0;

		while( !(this->Equilibrated()) )
		{
			this->GenerateMove();
			double Enew = minimizable->ObjectiveFunction(m_pdTrialParameters);

			if(this->AcceptMove(Eold,Enew))
			{			
				
				Eold = Enew;
				m_dAcceptanceRatio += 1.0;
				m_pMO->ElementCopy(m_pdTrialParameters,m_pdCurrentParameters,nParameters);

				if(Enew < m_dEBest)
				{
					cout << "Best cost is now " << Enew << endl;
					m_dEBest = Enew;
					m_pMO->ElementCopy(m_pdTrialParameters,parameters,nParameters);
				}

			} // end AcceptMove if

			m_dEBar += Eold;
			m_dE2Bar += Eold*Eold;
			m_iTrialCount++;
		
		} // end equlibration stage

		// normalize statistical properties
		m_dEBar = m_dEBar/m_iTrialCount;
		m_dE2Bar = m_dE2Bar/m_iTrialCount;
		m_dAcceptanceRatio = m_dAcceptanceRatio/m_iTrialCount;
		
		// notify observers
		this->Notify();
		// update temperature
		this->Cool();
	
	} // end anneal

	delete [] m_pdCurrentParameters;
	delete [] m_pdTrialParameters;
	
	return m_dEBest;
}