// SimulatedAnnealingStrategy.h: interface for the CSimulatedAnnealingStrategy class.
//
//////////////////////////////////////////////////////////////////////

#if !defined(AFX_SIMULATEDANNEALINGSTRATEGY_H__0BA0E00A_3509_4CB6_9DCD_0915EBE298B4__INCLUDED_)
#define AFX_SIMULATEDANNEALINGSTRATEGY_H__0BA0E00A_3509_4CB6_9DCD_0915EBE298B4__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#include "..\src\Minimizer.h"
#include "..\src\Rand.h"
#include "..\src\MatrixOperations.h"
#include "..\src\ParameterFilter.h"
#include <math.h>
#include <iostream>
#include <fstream.h>
#include <vector>

class CSimulatedAnnealingStrategy : public Minimizer  
{
public:
	CSimulatedAnnealingStrategy(int RNGSeed, CParameterFilter *pFilter);
	virtual ~CSimulatedAnnealingStrategy();
	double Minimize(double *parameters, Minimizable *minimizable);
	virtual bool AcceptMove(double Eold, double Enew) = 0;
	virtual bool Terminate() = 0;
	virtual bool Equilibrated() = 0;
	virtual void Cool() = 0;
	virtual void InitializeTemperature(Minimizable *minimizable) = 0;
	virtual void GenerateMove() = 0;
	// returns the average energy 
	double GetEBar() const {return m_dEBar;}
	// returns the average squared energy 
	double GetE2Bar() const {return m_dE2Bar;}
	// returns the current minimum energy
	double GetEMin() const {return m_dEBest;}
	// returns the acceptance ratio at the current temperature
	double GetAcceptanceRatio() const {return m_dAcceptanceRatio;}
	// returns current temperature T
	double GetTemperature() const {return m_dTemperature;}
protected:
	// filter for parameters, available to derived classes for move generation
	CParameterFilter *m_pFilter;
	// current state
	double *m_pdCurrentParameters;
	// trial state
	double *m_pdTrialParameters;
	// thermodynamic temperature
	double m_dTemperature;
	// energy of best state
	double m_dEBest;
	// self-explanatory
	double m_dAcceptanceRatio;
	// seed
	double m_iRNGSeed;
	// RNG
	Rand *m_pRNG;
	// avg. E as a function of T
	double m_dEBar;
	// avg. E^2 as a function of T
	double m_dE2Bar;
	// number of trials at the current temperature
	int m_iTrialCount;
	// used to do vector copies and such
	CMatrixOperations *m_pMO;
};

#endif // !defined(AFX_SIMULATEDANNEALINGSTRATEGY_H__0BA0E00A_3509_4CB6_9DCD_0915EBE298B4__INCLUDED_)
